(self["webpackChunkalgovera"] = self["webpackChunkalgovera"] || []).push([
  ["vendors-node_modules_jupyter-widgets_controls_lib_index_js"],
  {
    /***/ "./node_modules/@jupyter-widgets/controls/lib/index.js":
      /*!*************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/index.js ***!
  \*************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ WrappedError: () =>
            /* reexport safe */ _utils__WEBPACK_IMPORTED_MODULE_0__.WrappedError,
          /* harmony export */ escape_html: () =>
            /* reexport safe */ _utils__WEBPACK_IMPORTED_MODULE_0__.escape_html,
          /* harmony export */ reject: () =>
            /* reexport safe */ _utils__WEBPACK_IMPORTED_MODULE_0__.reject,
          /* harmony export */ resolvePromisesDict: () =>
            /* reexport safe */ _utils__WEBPACK_IMPORTED_MODULE_0__.resolvePromisesDict,
          /* harmony export */ typeset: () =>
            /* reexport safe */ _utils__WEBPACK_IMPORTED_MODULE_0__.typeset,
          /* harmony export */ uuid: () =>
            /* reexport safe */ _utils__WEBPACK_IMPORTED_MODULE_0__.uuid,
          /* harmony export */ JUPYTER_CONTROLS_VERSION: () =>
            /* reexport safe */ _version__WEBPACK_IMPORTED_MODULE_1__.JUPYTER_CONTROLS_VERSION,
          /* harmony export */ DirectionalLinkModel: () =>
            /* reexport safe */ _widget_link__WEBPACK_IMPORTED_MODULE_2__.DirectionalLinkModel,
          /* harmony export */ LinkModel: () =>
            /* reexport safe */ _widget_link__WEBPACK_IMPORTED_MODULE_2__.LinkModel,
          /* harmony export */ BoolModel: () =>
            /* reexport safe */ _widget_bool__WEBPACK_IMPORTED_MODULE_3__.BoolModel,
          /* harmony export */ CheckboxModel: () =>
            /* reexport safe */ _widget_bool__WEBPACK_IMPORTED_MODULE_3__.CheckboxModel,
          /* harmony export */ CheckboxView: () =>
            /* reexport safe */ _widget_bool__WEBPACK_IMPORTED_MODULE_3__.CheckboxView,
          /* harmony export */ ToggleButtonModel: () =>
            /* reexport safe */ _widget_bool__WEBPACK_IMPORTED_MODULE_3__.ToggleButtonModel,
          /* harmony export */ ToggleButtonView: () =>
            /* reexport safe */ _widget_bool__WEBPACK_IMPORTED_MODULE_3__.ToggleButtonView,
          /* harmony export */ ValidModel: () =>
            /* reexport safe */ _widget_bool__WEBPACK_IMPORTED_MODULE_3__.ValidModel,
          /* harmony export */ ValidView: () =>
            /* reexport safe */ _widget_bool__WEBPACK_IMPORTED_MODULE_3__.ValidView,
          /* harmony export */ ButtonModel: () =>
            /* reexport safe */ _widget_button__WEBPACK_IMPORTED_MODULE_4__.ButtonModel,
          /* harmony export */ ButtonStyleModel: () =>
            /* reexport safe */ _widget_button__WEBPACK_IMPORTED_MODULE_4__.ButtonStyleModel,
          /* harmony export */ ButtonView: () =>
            /* reexport safe */ _widget_button__WEBPACK_IMPORTED_MODULE_4__.ButtonView,
          /* harmony export */ BoxModel: () =>
            /* reexport safe */ _widget_box__WEBPACK_IMPORTED_MODULE_5__.BoxModel,
          /* harmony export */ BoxView: () =>
            /* reexport safe */ _widget_box__WEBPACK_IMPORTED_MODULE_5__.BoxView,
          /* harmony export */ GridBoxModel: () =>
            /* reexport safe */ _widget_box__WEBPACK_IMPORTED_MODULE_5__.GridBoxModel,
          /* harmony export */ GridBoxView: () =>
            /* reexport safe */ _widget_box__WEBPACK_IMPORTED_MODULE_5__.GridBoxView,
          /* harmony export */ HBoxModel: () =>
            /* reexport safe */ _widget_box__WEBPACK_IMPORTED_MODULE_5__.HBoxModel,
          /* harmony export */ HBoxView: () =>
            /* reexport safe */ _widget_box__WEBPACK_IMPORTED_MODULE_5__.HBoxView,
          /* harmony export */ VBoxModel: () =>
            /* reexport safe */ _widget_box__WEBPACK_IMPORTED_MODULE_5__.VBoxModel,
          /* harmony export */ VBoxView: () =>
            /* reexport safe */ _widget_box__WEBPACK_IMPORTED_MODULE_5__.VBoxView,
          /* harmony export */ ImageModel: () =>
            /* reexport safe */ _widget_image__WEBPACK_IMPORTED_MODULE_6__.ImageModel,
          /* harmony export */ ImageView: () =>
            /* reexport safe */ _widget_image__WEBPACK_IMPORTED_MODULE_6__.ImageView,
          /* harmony export */ VideoModel: () =>
            /* reexport safe */ _widget_video__WEBPACK_IMPORTED_MODULE_7__.VideoModel,
          /* harmony export */ VideoView: () =>
            /* reexport safe */ _widget_video__WEBPACK_IMPORTED_MODULE_7__.VideoView,
          /* harmony export */ AudioModel: () =>
            /* reexport safe */ _widget_audio__WEBPACK_IMPORTED_MODULE_8__.AudioModel,
          /* harmony export */ AudioView: () =>
            /* reexport safe */ _widget_audio__WEBPACK_IMPORTED_MODULE_8__.AudioView,
          /* harmony export */ ColorPickerModel: () =>
            /* reexport safe */ _widget_color__WEBPACK_IMPORTED_MODULE_9__.ColorPickerModel,
          /* harmony export */ ColorPickerView: () =>
            /* reexport safe */ _widget_color__WEBPACK_IMPORTED_MODULE_9__.ColorPickerView,
          /* harmony export */ DatePickerModel: () =>
            /* reexport safe */ _widget_date__WEBPACK_IMPORTED_MODULE_10__.DatePickerModel,
          /* harmony export */ DatePickerView: () =>
            /* reexport safe */ _widget_date__WEBPACK_IMPORTED_MODULE_10__.DatePickerView,
          /* harmony export */ deserialize_date: () =>
            /* reexport safe */ _widget_date__WEBPACK_IMPORTED_MODULE_10__.deserialize_date,
          /* harmony export */ serialize_date: () =>
            /* reexport safe */ _widget_date__WEBPACK_IMPORTED_MODULE_10__.serialize_date,
          /* harmony export */ BaseIntSliderView: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.BaseIntSliderView,
          /* harmony export */ BoundedIntModel: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.BoundedIntModel,
          /* harmony export */ BoundedIntTextModel: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.BoundedIntTextModel,
          /* harmony export */ IntModel: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.IntModel,
          /* harmony export */ IntProgressModel: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.IntProgressModel,
          /* harmony export */ IntRangeSliderModel: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.IntRangeSliderModel,
          /* harmony export */ IntRangeSliderView: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.IntRangeSliderView,
          /* harmony export */ IntSliderModel: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.IntSliderModel,
          /* harmony export */ IntSliderView: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.IntSliderView,
          /* harmony export */ IntTextModel: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.IntTextModel,
          /* harmony export */ IntTextView: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.IntTextView,
          /* harmony export */ PlayModel: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.PlayModel,
          /* harmony export */ PlayView: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.PlayView,
          /* harmony export */ ProgressStyleModel: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.ProgressStyleModel,
          /* harmony export */ ProgressView: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.ProgressView,
          /* harmony export */ SliderStyleModel: () =>
            /* reexport safe */ _widget_int__WEBPACK_IMPORTED_MODULE_11__.SliderStyleModel,
          /* harmony export */ BoundedFloatModel: () =>
            /* reexport safe */ _widget_float__WEBPACK_IMPORTED_MODULE_12__.BoundedFloatModel,
          /* harmony export */ BoundedFloatTextModel: () =>
            /* reexport safe */ _widget_float__WEBPACK_IMPORTED_MODULE_12__.BoundedFloatTextModel,
          /* harmony export */ FloatLogSliderModel: () =>
            /* reexport safe */ _widget_float__WEBPACK_IMPORTED_MODULE_12__.FloatLogSliderModel,
          /* harmony export */ FloatLogSliderView: () =>
            /* reexport safe */ _widget_float__WEBPACK_IMPORTED_MODULE_12__.FloatLogSliderView,
          /* harmony export */ FloatModel: () =>
            /* reexport safe */ _widget_float__WEBPACK_IMPORTED_MODULE_12__.FloatModel,
          /* harmony export */ FloatProgressModel: () =>
            /* reexport safe */ _widget_float__WEBPACK_IMPORTED_MODULE_12__.FloatProgressModel,
          /* harmony export */ FloatRangeSliderModel: () =>
            /* reexport safe */ _widget_float__WEBPACK_IMPORTED_MODULE_12__.FloatRangeSliderModel,
          /* harmony export */ FloatRangeSliderView: () =>
            /* reexport safe */ _widget_float__WEBPACK_IMPORTED_MODULE_12__.FloatRangeSliderView,
          /* harmony export */ FloatSliderModel: () =>
            /* reexport safe */ _widget_float__WEBPACK_IMPORTED_MODULE_12__.FloatSliderModel,
          /* harmony export */ FloatSliderView: () =>
            /* reexport safe */ _widget_float__WEBPACK_IMPORTED_MODULE_12__.FloatSliderView,
          /* harmony export */ FloatTextModel: () =>
            /* reexport safe */ _widget_float__WEBPACK_IMPORTED_MODULE_12__.FloatTextModel,
          /* harmony export */ FloatTextView: () =>
            /* reexport safe */ _widget_float__WEBPACK_IMPORTED_MODULE_12__.FloatTextView,
          /* harmony export */ ControllerAxisModel: () =>
            /* reexport safe */ _widget_controller__WEBPACK_IMPORTED_MODULE_13__.ControllerAxisModel,
          /* harmony export */ ControllerAxisView: () =>
            /* reexport safe */ _widget_controller__WEBPACK_IMPORTED_MODULE_13__.ControllerAxisView,
          /* harmony export */ ControllerButtonModel: () =>
            /* reexport safe */ _widget_controller__WEBPACK_IMPORTED_MODULE_13__.ControllerButtonModel,
          /* harmony export */ ControllerButtonView: () =>
            /* reexport safe */ _widget_controller__WEBPACK_IMPORTED_MODULE_13__.ControllerButtonView,
          /* harmony export */ ControllerModel: () =>
            /* reexport safe */ _widget_controller__WEBPACK_IMPORTED_MODULE_13__.ControllerModel,
          /* harmony export */ ControllerView: () =>
            /* reexport safe */ _widget_controller__WEBPACK_IMPORTED_MODULE_13__.ControllerView,
          /* harmony export */ DropdownModel: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.DropdownModel,
          /* harmony export */ DropdownView: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.DropdownView,
          /* harmony export */ MultipleSelectionModel: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.MultipleSelectionModel,
          /* harmony export */ RadioButtonsModel: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.RadioButtonsModel,
          /* harmony export */ RadioButtonsView: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.RadioButtonsView,
          /* harmony export */ SelectModel: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.SelectModel,
          /* harmony export */ SelectMultipleModel: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.SelectMultipleModel,
          /* harmony export */ SelectMultipleView: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.SelectMultipleView,
          /* harmony export */ SelectView: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.SelectView,
          /* harmony export */ SelectionModel: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.SelectionModel,
          /* harmony export */ SelectionRangeSliderModel: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.SelectionRangeSliderModel,
          /* harmony export */ SelectionRangeSliderView: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.SelectionRangeSliderView,
          /* harmony export */ SelectionSliderModel: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.SelectionSliderModel,
          /* harmony export */ SelectionSliderView: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.SelectionSliderView,
          /* harmony export */ ToggleButtonsModel: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.ToggleButtonsModel,
          /* harmony export */ ToggleButtonsStyleModel: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.ToggleButtonsStyleModel,
          /* harmony export */ ToggleButtonsView: () =>
            /* reexport safe */ _widget_selection__WEBPACK_IMPORTED_MODULE_14__.ToggleButtonsView,
          /* harmony export */ AccordionModel: () =>
            /* reexport safe */ _widget_selectioncontainer__WEBPACK_IMPORTED_MODULE_15__.AccordionModel,
          /* harmony export */ AccordionView: () =>
            /* reexport safe */ _widget_selectioncontainer__WEBPACK_IMPORTED_MODULE_15__.AccordionView,
          /* harmony export */ JupyterPhosphorAccordionWidget: () =>
            /* reexport safe */ _widget_selectioncontainer__WEBPACK_IMPORTED_MODULE_15__.JupyterPhosphorAccordionWidget,
          /* harmony export */ JupyterPhosphorTabPanelWidget: () =>
            /* reexport safe */ _widget_selectioncontainer__WEBPACK_IMPORTED_MODULE_15__.JupyterPhosphorTabPanelWidget,
          /* harmony export */ SelectionContainerModel: () =>
            /* reexport safe */ _widget_selectioncontainer__WEBPACK_IMPORTED_MODULE_15__.SelectionContainerModel,
          /* harmony export */ TabModel: () =>
            /* reexport safe */ _widget_selectioncontainer__WEBPACK_IMPORTED_MODULE_15__.TabModel,
          /* harmony export */ TabView: () =>
            /* reexport safe */ _widget_selectioncontainer__WEBPACK_IMPORTED_MODULE_15__.TabView,
          /* harmony export */ ComboboxModel: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.ComboboxModel,
          /* harmony export */ ComboboxView: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.ComboboxView,
          /* harmony export */ HTMLMathModel: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.HTMLMathModel,
          /* harmony export */ HTMLMathView: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.HTMLMathView,
          /* harmony export */ HTMLModel: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.HTMLModel,
          /* harmony export */ HTMLView: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.HTMLView,
          /* harmony export */ LabelModel: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.LabelModel,
          /* harmony export */ LabelView: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.LabelView,
          /* harmony export */ PasswordModel: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.PasswordModel,
          /* harmony export */ PasswordView: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.PasswordView,
          /* harmony export */ StringModel: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.StringModel,
          /* harmony export */ TextModel: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.TextModel,
          /* harmony export */ TextView: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.TextView,
          /* harmony export */ TextareaModel: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.TextareaModel,
          /* harmony export */ TextareaView: () =>
            /* reexport safe */ _widget_string__WEBPACK_IMPORTED_MODULE_16__.TextareaView,
          /* harmony export */ DescriptionModel: () =>
            /* reexport safe */ _widget_description__WEBPACK_IMPORTED_MODULE_17__.DescriptionModel,
          /* harmony export */ DescriptionStyleModel: () =>
            /* reexport safe */ _widget_description__WEBPACK_IMPORTED_MODULE_17__.DescriptionStyleModel,
          /* harmony export */ DescriptionView: () =>
            /* reexport safe */ _widget_description__WEBPACK_IMPORTED_MODULE_17__.DescriptionView,
          /* harmony export */ LabeledDOMWidgetModel: () =>
            /* reexport safe */ _widget_description__WEBPACK_IMPORTED_MODULE_17__.LabeledDOMWidgetModel,
          /* harmony export */ LabeledDOMWidgetView: () =>
            /* reexport safe */ _widget_description__WEBPACK_IMPORTED_MODULE_17__.LabeledDOMWidgetView,
          /* harmony export */ FileUploadModel: () =>
            /* reexport safe */ _widget_upload__WEBPACK_IMPORTED_MODULE_18__.FileUploadModel,
          /* harmony export */ FileUploadView: () =>
            /* reexport safe */ _widget_upload__WEBPACK_IMPORTED_MODULE_18__.FileUploadView,
          /* harmony export */ version: () => /* binding */ version,
          /* harmony export */
        });
        /* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./utils */ "./node_modules/@jupyter-widgets/controls/lib/utils.js"
          );
        /* harmony import */ var _version__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./version */ "./node_modules/@jupyter-widgets/controls/lib/version.js"
          );
        /* harmony import */ var _widget_link__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./widget_link */ "./node_modules/@jupyter-widgets/controls/lib/widget_link.js"
          );
        /* harmony import */ var _widget_bool__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./widget_bool */ "./node_modules/@jupyter-widgets/controls/lib/widget_bool.js"
          );
        /* harmony import */ var _widget_button__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! ./widget_button */ "./node_modules/@jupyter-widgets/controls/lib/widget_button.js"
          );
        /* harmony import */ var _widget_box__WEBPACK_IMPORTED_MODULE_5__ =
          __webpack_require__(
            /*! ./widget_box */ "./node_modules/@jupyter-widgets/controls/lib/widget_box.js"
          );
        /* harmony import */ var _widget_image__WEBPACK_IMPORTED_MODULE_6__ =
          __webpack_require__(
            /*! ./widget_image */ "./node_modules/@jupyter-widgets/controls/lib/widget_image.js"
          );
        /* harmony import */ var _widget_video__WEBPACK_IMPORTED_MODULE_7__ =
          __webpack_require__(
            /*! ./widget_video */ "./node_modules/@jupyter-widgets/controls/lib/widget_video.js"
          );
        /* harmony import */ var _widget_audio__WEBPACK_IMPORTED_MODULE_8__ =
          __webpack_require__(
            /*! ./widget_audio */ "./node_modules/@jupyter-widgets/controls/lib/widget_audio.js"
          );
        /* harmony import */ var _widget_color__WEBPACK_IMPORTED_MODULE_9__ =
          __webpack_require__(
            /*! ./widget_color */ "./node_modules/@jupyter-widgets/controls/lib/widget_color.js"
          );
        /* harmony import */ var _widget_date__WEBPACK_IMPORTED_MODULE_10__ =
          __webpack_require__(
            /*! ./widget_date */ "./node_modules/@jupyter-widgets/controls/lib/widget_date.js"
          );
        /* harmony import */ var _widget_int__WEBPACK_IMPORTED_MODULE_11__ =
          __webpack_require__(
            /*! ./widget_int */ "./node_modules/@jupyter-widgets/controls/lib/widget_int.js"
          );
        /* harmony import */ var _widget_float__WEBPACK_IMPORTED_MODULE_12__ =
          __webpack_require__(
            /*! ./widget_float */ "./node_modules/@jupyter-widgets/controls/lib/widget_float.js"
          );
        /* harmony import */ var _widget_controller__WEBPACK_IMPORTED_MODULE_13__ =
          __webpack_require__(
            /*! ./widget_controller */ "./node_modules/@jupyter-widgets/controls/lib/widget_controller.js"
          );
        /* harmony import */ var _widget_selection__WEBPACK_IMPORTED_MODULE_14__ =
          __webpack_require__(
            /*! ./widget_selection */ "./node_modules/@jupyter-widgets/controls/lib/widget_selection.js"
          );
        /* harmony import */ var _widget_selectioncontainer__WEBPACK_IMPORTED_MODULE_15__ =
          __webpack_require__(
            /*! ./widget_selectioncontainer */ "./node_modules/@jupyter-widgets/controls/lib/widget_selectioncontainer.js"
          );
        /* harmony import */ var _widget_string__WEBPACK_IMPORTED_MODULE_16__ =
          __webpack_require__(
            /*! ./widget_string */ "./node_modules/@jupyter-widgets/controls/lib/widget_string.js"
          );
        /* harmony import */ var _widget_description__WEBPACK_IMPORTED_MODULE_17__ =
          __webpack_require__(
            /*! ./widget_description */ "./node_modules/@jupyter-widgets/controls/lib/widget_description.js"
          );
        /* harmony import */ var _widget_upload__WEBPACK_IMPORTED_MODULE_18__ =
          __webpack_require__(
            /*! ./widget_upload */ "./node_modules/@jupyter-widgets/controls/lib/widget_upload.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.

        var version = __webpack_require__(
          /*! ../package.json */ "./node_modules/@jupyter-widgets/controls/package.json"
        ).version;

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/phosphor/accordion.js":
      /*!**************************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/phosphor/accordion.js ***!
  \**************************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ Collapse: () => /* binding */ Collapse,
          /* harmony export */ Accordion: () => /* binding */ Accordion,
          /* harmony export */
        });
        /* harmony import */ var _lumino_algorithm__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @lumino/algorithm */ "webpack/sharing/consume/default/@lumino/algorithm"
          );
        /* harmony import */ var _lumino_algorithm__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_algorithm__WEBPACK_IMPORTED_MODULE_0__
          );
        /* harmony import */ var _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! @lumino/signaling */ "webpack/sharing/consume/default/@lumino/signaling"
          );
        /* harmony import */ var _lumino_signaling__WEBPACK_IMPORTED_MODULE_1___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__
          );
        /* harmony import */ var _lumino_widgets__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! @lumino/widgets */ "webpack/sharing/consume/default/@lumino/widgets"
          );
        /* harmony import */ var _lumino_widgets__WEBPACK_IMPORTED_MODULE_2___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_widgets__WEBPACK_IMPORTED_MODULE_2__
          );
        /* harmony import */ var _currentselection__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./currentselection */ "./node_modules/@jupyter-widgets/controls/lib/phosphor/currentselection.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();

        /**
         * The class name added to Collapse instances.
         */
        var COLLAPSE_CLASS = "p-Collapse";
        /**
         * The class name added to a Collapse's header.
         */
        var COLLAPSE_HEADER_CLASS = "p-Collapse-header";
        /**
         * The class name added to a Collapse's contents.
         */
        var COLLAPSE_CONTENTS_CLASS = "p-Collapse-contents";
        /**
         * The class name added to a Collapse when it is opened
         */
        var COLLAPSE_CLASS_OPEN = "p-Collapse-open";
        /**
         * A panel that supports a collapsible header, made from the widget's title.
         * Clicking on the title expands or contracts the widget.
         */
        var Collapse = /** @class */ (function (_super) {
          __extends(Collapse, _super);
          function Collapse(options) {
            var _this = _super.call(this, options) || this;
            _this._collapseChanged =
              new _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__.Signal(_this);
            _this.addClass(COLLAPSE_CLASS);
            _this._header =
              new _lumino_widgets__WEBPACK_IMPORTED_MODULE_2__.Widget();
            _this._header.addClass(COLLAPSE_HEADER_CLASS);
            _this._header.node.addEventListener("click", _this);
            // Fontawesome icon for caret
            var icon = document.createElement("i");
            icon.classList.add("fa", "fa-fw", "fa-caret-right");
            _this._header.node.appendChild(icon);
            // Label content
            _this._header.node.appendChild(document.createElement("span"));
            _this._content =
              new _lumino_widgets__WEBPACK_IMPORTED_MODULE_2__.Panel();
            _this._content.addClass(COLLAPSE_CONTENTS_CLASS);
            var layout =
              new _lumino_widgets__WEBPACK_IMPORTED_MODULE_2__.PanelLayout();
            _this.layout = layout;
            layout.addWidget(_this._header);
            layout.addWidget(_this._content);
            if (options.widget) {
              _this.widget = options.widget;
            }
            _this.collapsed = false;
            return _this;
          }
          Collapse.prototype.dispose = function () {
            if (this.isDisposed) {
              return;
            }
            _super.prototype.dispose.call(this);
            this._header = null;
            this._widget = null;
            this._content = null;
          };
          Object.defineProperty(Collapse.prototype, "widget", {
            get: function () {
              return this._widget;
            },
            set: function (widget) {
              var oldWidget = this._widget;
              if (oldWidget) {
                oldWidget.disposed.disconnect(this._onChildDisposed, this);
                oldWidget.title.changed.disconnect(this._onTitleChanged, this);
                oldWidget.parent = null;
              }
              this._widget = widget;
              widget.disposed.connect(this._onChildDisposed, this);
              widget.title.changed.connect(this._onTitleChanged, this);
              this._onTitleChanged(widget.title);
              this._content.addWidget(widget);
            },
            enumerable: true,
            configurable: true,
          });
          Object.defineProperty(Collapse.prototype, "collapsed", {
            get: function () {
              return this._collapsed;
            },
            set: function (value) {
              // TODO: should we have this check here?
              if (value === this._collapsed) {
                return;
              }
              if (value) {
                this._collapse();
              } else {
                this._uncollapse();
              }
            },
            enumerable: true,
            configurable: true,
          });
          Collapse.prototype.toggle = function () {
            this.collapsed = !this.collapsed;
          };
          Object.defineProperty(Collapse.prototype, "collapseChanged", {
            get: function () {
              return this._collapseChanged;
            },
            enumerable: true,
            configurable: true,
          });
          Collapse.prototype._collapse = function () {
            this._collapsed = true;
            if (this._content) {
              this._content.hide();
            }
            this.removeClass(COLLAPSE_CLASS_OPEN);
            this._header.node.children[0].classList.add("fa-caret-right");
            this._header.node.children[0].classList.remove("fa-caret-down");
            this._collapseChanged.emit(void 0);
          };
          Collapse.prototype._uncollapse = function () {
            this._collapsed = false;
            if (this._content) {
              this._content.show();
            }
            this.addClass(COLLAPSE_CLASS_OPEN);
            this._header.node.children[0].classList.add("fa-caret-down");
            this._header.node.children[0].classList.remove("fa-caret-right");
            this._collapseChanged.emit(void 0);
          };
          /**
           * Handle the DOM events for the Collapse widget.
           *
           * @param event - The DOM event sent to the panel.
           *
           * #### Notes
           * This method implements the DOM `EventListener` interface and is
           * called in response to events on the panel's DOM node. It should
           * not be called directly by user code.
           */
          Collapse.prototype.handleEvent = function (event) {
            switch (event.type) {
              case "click":
                this._evtClick(event);
                break;
              default:
                break;
            }
          };
          Collapse.prototype._evtClick = function (event) {
            this.toggle();
          };
          /**
           * Handle the `changed` signal of a title object.
           */
          Collapse.prototype._onTitleChanged = function (sender) {
            this._header.node.children[1].textContent =
              this._widget.title.label;
          };
          Collapse.prototype._onChildDisposed = function (sender) {
            this.dispose();
          };
          return Collapse;
        })(_lumino_widgets__WEBPACK_IMPORTED_MODULE_2__.Widget);

        /**
         * The class name added to Accordion instances.
         */
        var ACCORDION_CLASS = "p-Accordion";
        /**
         * The class name added to an Accordion child.
         */
        var ACCORDION_CHILD_CLASS = "p-Accordion-child";
        var ACCORDION_CHILD_ACTIVE_CLASS = "p-Accordion-child-active";
        /**
         * A panel that supports a collapsible header, made from the widget's title.
         * Clicking on the title expands or contracts the widget.
         */
        var Accordion = /** @class */ (function (_super) {
          __extends(Accordion, _super);
          function Accordion(options) {
            var _this = _super.call(this, options) || this;
            _this._selection =
              new _currentselection__WEBPACK_IMPORTED_MODULE_3__.Selection(
                _this.widgets
              );
            _this._selection.selectionChanged.connect(
              _this._onSelectionChanged,
              _this
            );
            _this.addClass(ACCORDION_CLASS);
            return _this;
          }
          Object.defineProperty(Accordion.prototype, "collapseWidgets", {
            /**
             * A read-only sequence of the widgets in the panel.
             *
             * #### Notes
             * This is a read-only property.
             */
            /*  get widgets(): ISequence<Widget> {
            return new ArraySequence(toArray(map((this.layout as PanelLayout).widgets, (w: Collapse) => w.widget)));
          }
        */
            get: function () {
              return this.layout.widgets;
            },
            enumerable: true,
            configurable: true,
          });
          Object.defineProperty(Accordion.prototype, "selection", {
            get: function () {
              return this._selection;
            },
            enumerable: true,
            configurable: true,
          });
          Accordion.prototype.indexOf = function (widget) {
            return _lumino_algorithm__WEBPACK_IMPORTED_MODULE_0__.ArrayExt.findFirstIndex(
              this.collapseWidgets,
              function (w) {
                return w.widget === widget;
              }
            );
          };
          /**
           * Add a widget to the end of the accordion.
           *
           * @param widget - The widget to add to the accordion.
           *
           * @returns The Collapse widget wrapping the added widget.
           *
           * #### Notes
           * The widget will be wrapped in a CollapsedWidget.
           */
          Accordion.prototype.addWidget = function (widget) {
            var collapse = this._wrapWidget(widget);
            collapse.collapsed = true;
            _super.prototype.addWidget.call(this, collapse);
            this._selection.adjustSelectionForInsert(
              this.widgets.length - 1,
              collapse
            );
            return collapse;
          };
          /**
           * Insert a widget at the specified index.
           *
           * @param index - The index at which to insert the widget.
           *
           * @param widget - The widget to insert into to the accordion.
           *
           * #### Notes
           * If the widget is already contained in the panel, it will be moved.
           */
          Accordion.prototype.insertWidget = function (index, widget) {
            var collapse = this._wrapWidget(widget);
            collapse.collapsed = true;
            _super.prototype.insertWidget.call(this, index, collapse);
            this._selection.adjustSelectionForInsert(index, collapse);
          };
          Accordion.prototype.removeWidget = function (widget) {
            var index = this.indexOf(widget);
            if (index >= 0) {
              var collapse = this.collapseWidgets[index];
              widget.parent = null;
              collapse.dispose();
              this._selection.adjustSelectionForRemove(index, null);
            }
          };
          Accordion.prototype._wrapWidget = function (widget) {
            var collapse = new Collapse({ widget: widget });
            collapse.addClass(ACCORDION_CHILD_CLASS);
            collapse.collapseChanged.connect(this._onCollapseChange, this);
            return collapse;
          };
          Accordion.prototype._onCollapseChange = function (sender) {
            if (!sender.collapsed) {
              this._selection.value = sender;
            } else if (this._selection.value === sender && sender.collapsed) {
              this._selection.value = null;
            }
          };
          Accordion.prototype._onSelectionChanged = function (sender, change) {
            // Collapse previous widget, open current widget
            var pv = change.previousValue;
            var cv = change.currentValue;
            if (pv) {
              pv.collapsed = true;
              pv.removeClass(ACCORDION_CHILD_ACTIVE_CLASS);
            }
            if (cv) {
              cv.collapsed = false;
              cv.addClass(ACCORDION_CHILD_ACTIVE_CLASS);
            }
          };
          return Accordion;
        })(_lumino_widgets__WEBPACK_IMPORTED_MODULE_2__.Panel);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/phosphor/currentselection.js":
      /*!*********************************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/phosphor/currentselection.js ***!
  \*********************************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ Selection: () => /* binding */ Selection,
          /* harmony export */
        });
        /* harmony import */ var _lumino_algorithm__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @lumino/algorithm */ "webpack/sharing/consume/default/@lumino/algorithm"
          );
        /* harmony import */ var _lumino_algorithm__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_algorithm__WEBPACK_IMPORTED_MODULE_0__
          );
        /* harmony import */ var _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! @lumino/signaling */ "webpack/sharing/consume/default/@lumino/signaling"
          );
        /* harmony import */ var _lumino_signaling__WEBPACK_IMPORTED_MODULE_1___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        /**
         * A variety of convenience methods for maintaining a current selection
         */

        var Selection = /** @class */ (function () {
          function Selection(sequence, options) {
            if (options === void 0) {
              options = {};
            }
            this._array = null;
            this._value = null;
            this._previousValue = null;
            this._selectionChanged =
              new _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__.Signal(this);
            this._array = sequence;
            this._insertBehavior =
              options.insertBehavior || "select-item-if-needed";
            this._removeBehavior =
              options.removeBehavior || "select-item-after";
          }
          Object.defineProperty(Selection.prototype, "selectionChanged", {
            /**
             * A signal emitted when the current item is changed.
             *
             * #### Notes
             * This signal is emitted when the currently selected item is changed either
             * through user or programmatic interaction.
             *
             * Notably, this signal is not emitted when the index of the current item
             * changes due to other items being inserted, removed, or moved, but the
             * current item remains the same. It is only emitted when the actual current
             * item is changed.
             */
            get: function () {
              return this._selectionChanged;
            },
            enumerable: true,
            configurable: true,
          });
          /**
           * Adjust for setting an item.
           *
           * This should be called *after* the set.
           *
           * @param index - The index set.
           * @param oldValue - The old value at the index.
           */
          Selection.prototype.adjustSelectionForSet = function (index) {
            // We just need to send a signal if the currentValue changed.
            // Get the current index and value.
            var pi = this.index;
            var pv = this.value;
            // Exit early if this doesn't affect the selection
            if (index !== pi) {
              return;
            }
            this._updateSelectedValue();
            var cv = this.value;
            // The previous item is now null, since it is no longer in the array.
            this._previousValue = null;
            // Send signal if there was a change
            if (pv !== cv) {
              // Emit the current changed signal.
              this._selectionChanged.emit({
                previousIndex: pi,
                previousValue: pv,
                currentIndex: pi,
                currentValue: cv,
              });
            }
          };
          Object.defineProperty(Selection.prototype, "value", {
            /**
             * Get the currently selected item.
             *
             * #### Notes
             * This will be `null` if no item is selected.
             */
            get: function () {
              return this._value;
            },
            /**
             * Set the currently selected item.
             *
             * #### Notes
             * If the item does not exist in the vector, the currentValue will be set to
             * `null`. This selects the first entry equal to the desired item.
             */
            set: function (value) {
              if (value === null) {
                this.index = null;
              } else {
                this.index =
                  _lumino_algorithm__WEBPACK_IMPORTED_MODULE_0__.ArrayExt.firstIndexOf(
                    this._array,
                    value
                  );
              }
            },
            enumerable: true,
            configurable: true,
          });
          Object.defineProperty(Selection.prototype, "index", {
            /**
             * Get the index of the currently selected item.
             *
             * #### Notes
             * This will be `null` if no item is selected.
             */
            get: function () {
              return this._index;
            },
            /**
             * Set the index of the currently selected tab.
             *
             * @param index - The index to select.
             *
             * #### Notes
             * If the value is out of range, the index will be set to `null`, which
             * indicates no item is selected.
             */
            set: function (index) {
              // Coerce the value to an index.
              var i;
              if (index !== null) {
                i = Math.floor(index);
                if (i < 0 || i >= this._array.length) {
                  i = null;
                }
              } else {
                i = null;
              }
              // Bail early if the index will not change.
              if (this._index === i) {
                return;
              }
              // Look up the previous index and item.
              var pi = this._index;
              var pv = this._value;
              // Update the state
              this._index = i;
              this._updateSelectedValue();
              this._previousValue = pv;
              // Emit the current changed signal.
              this._selectionChanged.emit({
                previousIndex: pi,
                previousValue: pv,
                currentIndex: i,
                currentValue: this._value,
              });
            },
            enumerable: true,
            configurable: true,
          });
          Object.defineProperty(Selection.prototype, "insertBehavior", {
            /**
             * Get the selection behavior when inserting a tab.
             */
            get: function () {
              return this._insertBehavior;
            },
            /**
             * Set the selection behavior when inserting a tab.
             */
            set: function (value) {
              this._insertBehavior = value;
            },
            enumerable: true,
            configurable: true,
          });
          Object.defineProperty(Selection.prototype, "removeBehavior", {
            /**
             * Get the selection behavior when removing a tab.
             */
            get: function () {
              return this._removeBehavior;
            },
            /**
             * Set the selection behavior when removing a tab.
             */
            set: function (value) {
              this._removeBehavior = value;
            },
            enumerable: true,
            configurable: true,
          });
          /**
           * Adjust the current index for a tab insert operation.
           *
           * @param i - The new index of the inserted item.
           * @param j - The inserted item.
           *
           * #### Notes
           * This method accounts for the tab bar's insertion behavior when adjusting
           * the current index and emitting the changed signal. This should be called
           * after the insertion.
           */
          Selection.prototype.adjustSelectionForInsert = function (i, item) {
            // Lookup commonly used variables.
            var cv = this._value;
            var ci = this._index;
            var bh = this._insertBehavior;
            // Handle the behavior where the new item is always selected,
            // or the behavior where the new item is selected if needed.
            if (
              bh === "select-item" ||
              (bh === "select-item-if-needed" && ci === null)
            ) {
              this._index = i;
              this._value = item;
              this._previousValue = cv;
              this._selectionChanged.emit({
                previousIndex: ci,
                previousValue: cv,
                currentIndex: i,
                currentValue: item,
              });
              return;
            }
            // Otherwise, silently adjust the current index if needed.
            if (ci >= i) {
              this._index++;
            }
          };
          /**
           * Adjust the current index for move operation.
           *
           * @param i - The previous index of the item.
           * @param j - The new index of the item.
           *
           * #### Notes
           * This method will not cause the actual current item to change. It silently
           * adjusts the current index to account for the given move.
           */
          Selection.prototype.adjustSelectionForMove = function (i, j) {
            if (this._index === i) {
              this._index = j;
            } else if (this._index < i && this._index >= j) {
              this._index++;
            } else if (this._index > i && this._index <= j) {
              this._index--;
            }
          };
          /**
           * Clear the selection and history.
           */
          Selection.prototype.clearSelection = function () {
            // Get the current index and item.
            var pi = this._index;
            var pv = this._value;
            // Reset the current index and previous item.
            this._index = null;
            this._value = null;
            this._previousValue = null;
            // If no item was selected, there's nothing else to do.
            if (pi === null) {
              return;
            }
            // Emit the current changed signal.
            this._selectionChanged.emit({
              previousIndex: pi,
              previousValue: pv,
              currentIndex: this._index,
              currentValue: this._value,
            });
          };
          /**
           * Adjust the current index for an item remove operation.
           *
           * @param i - The former index of the removed item.
           * @param item - The removed item.
           *
           * #### Notes
           * This method accounts for the remove behavior when adjusting the current
           * index and emitting the changed signal. It should be called after the item
           * is removed.
           */
          Selection.prototype.adjustSelectionForRemove = function (i, item) {
            // Lookup commonly used variables.
            var ci = this._index;
            var bh = this._removeBehavior;
            // Silently adjust the index if the current item is not removed.
            if (ci !== i) {
              if (ci > i) {
                this._index--;
              }
              return;
            }
            // No item gets selected if the vector is empty.
            if (this._array.length === 0) {
              // Reset the current index and previous item.
              this._index = null;
              this._value = null;
              this._previousValue = null;
              this._selectionChanged.emit({
                previousIndex: i,
                previousValue: item,
                currentIndex: this._index,
                currentValue: this._value,
              });
              return;
            }
            // Handle behavior where the next sibling item is selected.
            if (bh === "select-item-after") {
              this._index = Math.min(i, this._array.length - 1);
              this._updateSelectedValue();
              this._previousValue = null;
              this._selectionChanged.emit({
                previousIndex: i,
                previousValue: item,
                currentIndex: this._index,
                currentValue: this._value,
              });
              return;
            }
            // Handle behavior where the previous sibling item is selected.
            if (bh === "select-item-before") {
              this._index = Math.max(0, i - 1);
              this._updateSelectedValue();
              this._previousValue = null;
              this._selectionChanged.emit({
                previousIndex: i,
                previousValue: item,
                currentIndex: this._index,
                currentValue: this._value,
              });
              return;
            }
            // Handle behavior where the previous history item is selected.
            if (bh === "select-previous-item") {
              if (this._previousValue) {
                this.value = this._previousValue;
              } else {
                this._index = Math.min(i, this._array.length - 1);
                this._updateSelectedValue();
              }
              this._previousValue = null;
              this._selectionChanged.emit({
                previousIndex: i,
                previousValue: item,
                currentIndex: this._index,
                currentValue: this.value,
              });
              return;
            }
            // Otherwise, no item gets selected.
            this._index = null;
            this._value = null;
            this._previousValue = null;
            this._selectionChanged.emit({
              previousIndex: i,
              previousValue: item,
              currentIndex: this._index,
              currentValue: this._value,
            });
          };
          /**
           * Set the current value based on the current index.
           */
          Selection.prototype._updateSelectedValue = function () {
            var i = this._index;
            this._value = i !== null ? this._array[i] : null;
          };
          return Selection;
        })();

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/phosphor/tabpanel.js":
      /*!*************************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/phosphor/tabpanel.js ***!
  \*************************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ EventedPanel: () => /* binding */ EventedPanel,
          /* harmony export */ TabPanel: () => /* binding */ TabPanel,
          /* harmony export */
        });
        /* harmony import */ var _lumino_messaging__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @lumino/messaging */ "webpack/sharing/consume/default/@lumino/messaging"
          );
        /* harmony import */ var _lumino_messaging__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_messaging__WEBPACK_IMPORTED_MODULE_0__
          );
        /* harmony import */ var _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! @lumino/signaling */ "webpack/sharing/consume/default/@lumino/signaling"
          );
        /* harmony import */ var _lumino_signaling__WEBPACK_IMPORTED_MODULE_1___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__
          );
        /* harmony import */ var _lumino_domutils__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! @lumino/domutils */ "webpack/sharing/consume/default/@lumino/domutils"
          );
        /* harmony import */ var _lumino_domutils__WEBPACK_IMPORTED_MODULE_2___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_domutils__WEBPACK_IMPORTED_MODULE_2__
          );
        /* harmony import */ var _lumino_widgets__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! @lumino/widgets */ "webpack/sharing/consume/default/@lumino/widgets"
          );
        /* harmony import */ var _lumino_widgets__WEBPACK_IMPORTED_MODULE_3___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_widgets__WEBPACK_IMPORTED_MODULE_3__
          );
        /* This file has code derived from PhosphorJS. The license for this PhosphorJS code is:

Copyright (c) 2014-2017, PhosphorJS Contributors
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

* Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

* Neither the name of the copyright holder nor the names of its
  contributors may be used to endorse or promote products derived from
  this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

*/
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();

        /**
         * A panel where visible widgets are stacked atop one another.
         *
         * #### Notes
         * This class provides a convenience wrapper around a [[PanelLayout]].
         */
        var EventedPanel = /** @class */ (function (_super) {
          __extends(EventedPanel, _super);
          function EventedPanel() {
            var _this =
              (_super !== null && _super.apply(this, arguments)) || this;
            _this._widgetRemoved =
              new _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__.Signal(_this);
            return _this;
          }
          Object.defineProperty(EventedPanel.prototype, "widgetRemoved", {
            /**
             * A signal emitted when a widget is removed from the panel.
             */
            get: function () {
              return this._widgetRemoved;
            },
            enumerable: true,
            configurable: true,
          });
          /**
           * A message handler invoked on a `'child-removed'` message.
           */
          EventedPanel.prototype.onChildRemoved = function (msg) {
            this._widgetRemoved.emit(msg.child);
          };
          return EventedPanel;
        })(_lumino_widgets__WEBPACK_IMPORTED_MODULE_3__.Panel);

        /**
         * A widget which combines a `TabBar` and a `EventedPanel`.
         *
         * #### Notes
         * This is a simple panel which handles the common case of a tab bar
         * placed next to a content area. The selected tab controls the widget
         * which is shown in the content area.
         *
         * For use cases which require more control than is provided by this
         * panel, the `TabBar` widget may be used independently.
         *
         * TODO: Support setting the direction??
         */
        var TabPanel = /** @class */ (function (_super) {
          __extends(TabPanel, _super);
          /**
           * Construct a new tab panel.
           *
           * @param options - The options for initializing the tab panel.
           */
          function TabPanel(options) {
            if (options === void 0) {
              options = {};
            }
            var _this = _super.call(this) || this;
            _this._currentChanged =
              new _lumino_signaling__WEBPACK_IMPORTED_MODULE_1__.Signal(_this);
            _this.addClass("p-TabPanel");
            // Create the tab bar and contents panel.
            _this.tabBar =
              new _lumino_widgets__WEBPACK_IMPORTED_MODULE_3__.TabBar(options);
            _this.tabBar.addClass("p-TabPanel-tabBar");
            _this.tabContents = new EventedPanel();
            _this.tabContents.addClass("p-TabPanel-tabContents");
            // Connect the tab bar signal handlers.
            _this.tabBar.tabMoved.connect(_this._onTabMoved, _this);
            _this.tabBar.currentChanged.connect(_this._onCurrentChanged, _this);
            _this.tabBar.tabCloseRequested.connect(
              _this._onTabCloseRequested,
              _this
            );
            _this.tabBar.tabActivateRequested.connect(
              _this._onTabActivateRequested,
              _this
            );
            // Connect the evented panel signal handlers.
            _this.tabContents.widgetRemoved.connect(
              _this._onWidgetRemoved,
              _this
            );
            // Create the layout.
            var layout =
              new _lumino_widgets__WEBPACK_IMPORTED_MODULE_3__.PanelLayout();
            // Add the child widgets to the layout.
            layout.addWidget(_this.tabBar);
            layout.addWidget(_this.tabContents);
            // Install the layout on the tab panel.
            _this.layout = layout;
            return _this;
          }
          Object.defineProperty(TabPanel.prototype, "currentChanged", {
            /**
             * A signal emitted when the current tab is changed.
             *
             * #### Notes
             * This signal is emitted when the currently selected tab is changed
             * either through user or programmatic interaction.
             *
             * Notably, this signal is not emitted when the index of the current
             * tab changes due to tabs being inserted, removed, or moved. It is
             * only emitted when the actual current tab node is changed.
             */
            get: function () {
              return this._currentChanged;
            },
            enumerable: true,
            configurable: true,
          });
          Object.defineProperty(TabPanel.prototype, "currentIndex", {
            /**
             * Get the index of the currently selected tab.
             *
             * #### Notes
             * This will be `null` if no tab is selected.
             */
            get: function () {
              var currentIndex = this.tabBar.currentIndex;
              // Phosphor tab bars have an index of -1 if no tab is selected
              return currentIndex === -1 ? null : currentIndex;
            },
            /**
             * Set the index of the currently selected tab.
             *
             * #### Notes
             * If the index is out of range, it will be set to `null`.
             */
            set: function (value) {
              this.tabBar.currentIndex = value === null ? -1 : value;
            },
            enumerable: true,
            configurable: true,
          });
          Object.defineProperty(TabPanel.prototype, "currentWidget", {
            /**
             * Get the currently selected widget.
             *
             * #### Notes
             * This will be `null` if there is no selected tab.
             */
            get: function () {
              var title = this.tabBar.currentTitle;
              return title ? title.owner : null;
            },
            /**
             * Set the currently selected widget.
             *
             * #### Notes
             * If the widget is not in the panel, it will be set to `null`.
             */
            set: function (value) {
              this.tabBar.currentTitle = value ? value.title : null;
            },
            enumerable: true,
            configurable: true,
          });
          Object.defineProperty(TabPanel.prototype, "tabsMovable", {
            /**
             * Get the whether the tabs are movable by the user.
             *
             * #### Notes
             * Tabs can always be moved programmatically.
             */
            get: function () {
              return this.tabBar.tabsMovable;
            },
            /**
             * Set the whether the tabs are movable by the user.
             *
             * #### Notes
             * Tabs can always be moved programmatically.
             */
            set: function (value) {
              this.tabBar.tabsMovable = value;
            },
            enumerable: true,
            configurable: true,
          });
          Object.defineProperty(TabPanel.prototype, "widgets", {
            /**
             * A read-only array of the widgets in the panel.
             */
            get: function () {
              return this.tabContents.widgets;
            },
            enumerable: true,
            configurable: true,
          });
          /**
           * Add a widget to the end of the tab panel.
           *
           * @param widget - The widget to add to the tab panel.
           *
           * #### Notes
           * If the widget is already contained in the panel, it will be moved.
           *
           * The widget's `title` is used to populate the tab.
           */
          TabPanel.prototype.addWidget = function (widget) {
            this.insertWidget(this.widgets.length, widget);
          };
          /**
           * Insert a widget into the tab panel at a specified index.
           *
           * @param index - The index at which to insert the widget.
           *
           * @param widget - The widget to insert into to the tab panel.
           *
           * #### Notes
           * If the widget is already contained in the panel, it will be moved.
           *
           * The widget's `title` is used to populate the tab.
           */
          TabPanel.prototype.insertWidget = function (index, widget) {
            if (widget !== this.currentWidget) {
              widget.hide();
            }
            this.tabContents.insertWidget(index, widget);
            this.tabBar.insertTab(index, widget.title);
          };
          /**
           * Handle the `currentChanged` signal from the tab bar.
           */
          TabPanel.prototype._onCurrentChanged = function (sender, args) {
            // Extract the previous and current title from the args.
            var previousIndex = args.previousIndex,
              previousTitle = args.previousTitle,
              currentIndex = args.currentIndex,
              currentTitle = args.currentTitle;
            // Extract the widgets from the titles.
            var previousWidget = previousTitle ? previousTitle.owner : null;
            var currentWidget = currentTitle ? currentTitle.owner : null;
            // Hide the previous widget.
            if (previousWidget) {
              previousWidget.hide();
            }
            // Show the current widget.
            if (currentWidget) {
              currentWidget.show();
            }
            // Emit the `currentChanged` signal for the tab panel.
            this._currentChanged.emit({
              previousIndex: previousIndex,
              previousWidget: previousWidget,
              currentIndex: currentIndex,
              currentWidget: currentWidget,
            });
            // Flush the message loop on IE and Edge to prevent flicker.
            if (
              _lumino_domutils__WEBPACK_IMPORTED_MODULE_2__.Platform.IS_EDGE ||
              _lumino_domutils__WEBPACK_IMPORTED_MODULE_2__.Platform.IS_IE
            ) {
              _lumino_messaging__WEBPACK_IMPORTED_MODULE_0__.MessageLoop.flush();
            }
          };
          /**
           * Handle the `tabActivateRequested` signal from the tab bar.
           */
          TabPanel.prototype._onTabActivateRequested = function (sender, args) {
            args.title.owner.activate();
          };
          /**
           * Handle the `tabCloseRequested` signal from the tab bar.
           */
          TabPanel.prototype._onTabCloseRequested = function (sender, args) {
            args.title.owner.close();
          };
          /**
           * Handle the `tabMoved` signal from the tab bar.
           */
          TabPanel.prototype._onTabMoved = function (sender, args) {
            this.tabContents.insertWidget(args.toIndex, args.title.owner);
          };
          /**
           * Handle the `widgetRemoved` signal from the stacked panel.
           */
          TabPanel.prototype._onWidgetRemoved = function (sender, widget) {
            this.tabBar.removeTab(widget.title);
          };
          return TabPanel;
        })(_lumino_widgets__WEBPACK_IMPORTED_MODULE_3__.Widget);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/utils.js":
      /*!*************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/utils.js ***!
  \*************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ uuid: () =>
            /* reexport safe */ _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.uuid,
          /* harmony export */ WrappedError: () =>
            /* reexport safe */ _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.WrappedError,
          /* harmony export */ resolvePromisesDict: () =>
            /* reexport safe */ _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.resolvePromisesDict,
          /* harmony export */ reject: () => /* binding */ reject,
          /* harmony export */ typeset: () => /* binding */ typeset,
          /* harmony export */ escape_html: () => /* binding */ escape_html,
          /* harmony export */
        });
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.

        /**
         * Creates a wrappable Promise rejection function.
         *
         * Creates a function that returns a Promise.reject with a new WrappedError
         * that has the provided message and wraps the original error that
         * caused the promise to reject.
         */
        function reject(message, log) {
          return function promiseRejection(error) {
            var wrapped_error =
              new _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.WrappedError(
                message,
                error
              );
            if (log) {
              console.error(wrapped_error);
            }
            return Promise.reject(wrapped_error);
          };
        }
        /**
         * Apply MathJax rendering to an element, and optionally set its text.
         *
         * If MathJax is not available, make no changes.
         *
         * Parameters
         * ----------
         * element: Node
         * text: optional string
         */
        function typeset(element, text) {
          if (text !== void 0) {
            element.textContent = text;
          }
          if (window.MathJax !== void 0) {
            MathJax.Hub.Queue(["Typeset", MathJax.Hub, element]);
          }
        }
        /**
         * escape text to HTML
         */
        function escape_html(text) {
          var esc = document.createElement("div");
          esc.textContent = text;
          return esc.innerHTML;
        }

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/version.js":
      /*!***************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/version.js ***!
  \***************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ JUPYTER_CONTROLS_VERSION: () =>
            /* binding */ JUPYTER_CONTROLS_VERSION,
          /* harmony export */
        });
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        /**
         * The version of the Jupyter controls widget attribute spec that this package
         * implements.
         */
        var JUPYTER_CONTROLS_VERSION = "1.5.0";

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_audio.js":
      /*!********************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_audio.js ***!
  \********************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ AudioModel: () => /* binding */ AudioModel,
          /* harmony export */ AudioView: () => /* binding */ AudioView,
          /* harmony export */
        });
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__
          );
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        var __assign =
          (undefined && undefined.__assign) ||
          function () {
            __assign =
              Object.assign ||
              function (t) {
                for (var s, i = 1, n = arguments.length; i < n; i++) {
                  s = arguments[i];
                  for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
                }
                return t;
              };
            return __assign.apply(this, arguments);
          };

        var AudioModel = /** @class */ (function (_super) {
          __extends(AudioModel, _super);
          function AudioModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          AudioModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_2__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "AudioModel",
                _view_name: "AudioView",
                format: "mp3",
                autoplay: true,
                loop: true,
                controls: true,
                value: new DataView(new ArrayBuffer(0)),
              }
            );
          };
          AudioModel.serializers = __assign(
            __assign(
              {},
              _widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreDOMWidgetModel
                .serializers
            ),
            {
              value: {
                serialize: function (value) {
                  return new DataView(value.buffer.slice(0));
                },
              },
            }
          );
          return AudioModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreDOMWidgetModel);

        var AudioView = /** @class */ (function (_super) {
          __extends(AudioView, _super);
          function AudioView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          AudioView.prototype.render = function () {
            /**
             * Called when view is rendered.
             */
            _super.prototype.render.call(this);
            this.pWidget.addClass("jupyter-widgets");
            this.update(); // Set defaults.
          };
          AudioView.prototype.update = function () {
            /**
             * Update the contents of this view
             *
             * Called when the model is changed.  The model may have been
             * changed by another view or by a state update from the back-end.
             */
            var url;
            var format = this.model.get("format");
            var value = this.model.get("value");
            if (format !== "url") {
              var blob = new Blob([value], {
                type: "audio/" + this.model.get("format"),
              });
              url = URL.createObjectURL(blob);
            } else {
              url = new TextDecoder("utf-8").decode(value.buffer);
            }
            // Clean up the old objectURL
            var oldurl = this.el.src;
            this.el.src = url;
            if (oldurl && typeof oldurl !== "string") {
              URL.revokeObjectURL(oldurl);
            }
            // Audio attributes
            this.el.loop = this.model.get("loop");
            this.el.autoplay = this.model.get("autoplay");
            this.el.controls = this.model.get("controls");
            return _super.prototype.update.call(this);
          };
          AudioView.prototype.remove = function () {
            if (this.el.src) {
              URL.revokeObjectURL(this.el.src);
            }
            _super.prototype.remove.call(this);
          };
          Object.defineProperty(AudioView.prototype, "tagName", {
            /**
             * The default tag name.
             *
             * #### Notes
             * This is a read-only attribute.
             */
            get: function () {
              // We can't make this an attribute with a default value
              // since it would be set after it is needed in the
              // constructor.
              return "audio";
            },
            enumerable: true,
            configurable: true,
          });
          return AudioView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.DOMWidgetView);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_bool.js":
      /*!*******************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_bool.js ***!
  \*******************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ BoolModel: () => /* binding */ BoolModel,
          /* harmony export */ CheckboxModel: () => /* binding */ CheckboxModel,
          /* harmony export */ CheckboxView: () => /* binding */ CheckboxView,
          /* harmony export */ ToggleButtonModel: () =>
            /* binding */ ToggleButtonModel,
          /* harmony export */ ToggleButtonView: () =>
            /* binding */ ToggleButtonView,
          /* harmony export */ ValidModel: () => /* binding */ ValidModel,
          /* harmony export */ ValidView: () => /* binding */ ValidView,
          /* harmony export */
        });
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var _widget_description__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_description */ "./node_modules/@jupyter-widgets/controls/lib/widget_description.js"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_2___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_2__
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();

        var BoolModel = /** @class */ (function (_super) {
          __extends(BoolModel, _super);
          function BoolModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          BoolModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                value: false,
                disabled: false,
                _model_name: "BoolModel",
              }
            );
          };
          return BoolModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDescriptionModel);

        var CheckboxModel = /** @class */ (function (_super) {
          __extends(CheckboxModel, _super);
          function CheckboxModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          CheckboxModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                indent: true,
                _view_name: "CheckboxView",
                _model_name: "CheckboxModel",
              }
            );
          };
          return CheckboxModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDescriptionModel);

        var CheckboxView = /** @class */ (function (_super) {
          __extends(CheckboxView, _super);
          function CheckboxView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Called when view is rendered.
           */
          CheckboxView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-checkbox");
            // adding a zero-width space to the label to help
            // the browser set the baseline correctly
            this.label.innerHTML = "&#8203;";
            // label containing the checkbox and description span
            this.checkboxLabel = document.createElement("label");
            this.checkboxLabel.classList.add("widget-label-basic");
            this.el.appendChild(this.checkboxLabel);
            // checkbox
            this.checkbox = document.createElement("input");
            this.checkbox.setAttribute("type", "checkbox");
            this.checkboxLabel.appendChild(this.checkbox);
            // span to the right of the checkbox that will render the description
            this.descriptionSpan = document.createElement("span");
            this.checkboxLabel.appendChild(this.descriptionSpan);
            this.listenTo(this.model, "change:indent", this.updateIndent);
            this.update(); // Set defaults.
            this.updateDescription();
            this.updateIndent();
          };
          /**
           * Overriden from super class
           *
           * Update the description span (rather than the label) since
           * we want the description to the right of the checkbox.
           */
          CheckboxView.prototype.updateDescription = function () {
            // can be called before the view is fully initialized
            if (this.checkboxLabel == null) {
              return;
            }
            var description = this.model.get("description");
            this.descriptionSpan.innerHTML = description;
            this.typeset(this.descriptionSpan);
            this.descriptionSpan.title = description;
            this.checkbox.title = description;
          };
          /**
           * Update the visibility of the label in the super class
           * to provide the optional indent.
           */
          CheckboxView.prototype.updateIndent = function () {
            var indent = this.model.get("indent");
            this.label.style.display = indent ? "" : "none";
          };
          CheckboxView.prototype.events = function () {
            return {
              'click input[type="checkbox"]': "_handle_click",
            };
          };
          /**
           * Handles when the checkbox is clicked.
           *
           * Calling model.set will trigger all of the other views of the
           * model to update.
           */
          CheckboxView.prototype._handle_click = function () {
            var value = this.model.get("value");
            this.model.set("value", !value, { updated_view: this });
            this.touch();
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed. The model may have been
           * changed by another view or by a state update from the back-end.
           */
          CheckboxView.prototype.update = function (options) {
            this.checkbox.checked = this.model.get("value");
            if (options === undefined || options.updated_view != this) {
              this.checkbox.disabled = this.model.get("disabled");
            }
            return _super.prototype.update.call(this);
          };
          return CheckboxView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var ToggleButtonModel = /** @class */ (function (_super) {
          __extends(ToggleButtonModel, _super);
          function ToggleButtonModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ToggleButtonModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                _view_name: "ToggleButtonView",
                _model_name: "ToggleButtonModel",
                tooltip: "",
                icon: "",
                button_style: "",
              }
            );
          };
          return ToggleButtonModel;
        })(BoolModel);

        var ToggleButtonView = /** @class */ (function (_super) {
          __extends(ToggleButtonView, _super);
          function ToggleButtonView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Called when view is rendered.
           */
          ToggleButtonView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("jupyter-button");
            this.el.classList.add("widget-toggle-button");
            this.listenTo(
              this.model,
              "change:button_style",
              this.update_button_style
            );
            this.set_button_style();
            this.update(); // Set defaults.
          };
          ToggleButtonView.prototype.update_button_style = function () {
            this.update_mapped_classes(
              ToggleButtonView.class_map,
              "button_style"
            );
          };
          ToggleButtonView.prototype.set_button_style = function () {
            this.set_mapped_classes(ToggleButtonView.class_map, "button_style");
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed. The model may have been
           * changed by another view or by a state update from the back-end.
           */
          ToggleButtonView.prototype.update = function (options) {
            if (this.model.get("value")) {
              this.el.classList.add("mod-active");
            } else {
              this.el.classList.remove("mod-active");
            }
            if (options === undefined || options.updated_view !== this) {
              this.el.disabled = this.model.get("disabled");
              this.el.setAttribute("title", this.model.get("tooltip"));
              var description = this.model.get("description");
              var icon = this.model.get("icon");
              if (description.trim().length === 0 && icon.trim().length === 0) {
                this.el.innerHTML = "&nbsp;"; // Preserve button height
              } else {
                this.el.textContent = "";
                if (icon.trim().length) {
                  var i = document.createElement("i");
                  this.el.appendChild(i);
                  i.classList.add("fa");
                  i.classList.add("fa-" + icon);
                }
                this.el.appendChild(document.createTextNode(description));
              }
            }
            return _super.prototype.update.call(this);
          };
          ToggleButtonView.prototype.events = function () {
            return {
              // Dictionary of events and their handlers.
              click: "_handle_click",
            };
          };
          /**
           * Handles and validates user input.
           *
           * Calling model.set will trigger all of the other views of the
           * model to update.
           */
          ToggleButtonView.prototype._handle_click = function (event) {
            event.preventDefault();
            var value = this.model.get("value");
            this.model.set("value", !value, { updated_view: this });
            this.touch();
          };
          Object.defineProperty(ToggleButtonView.prototype, "tagName", {
            /**
             * The default tag name.
             *
             * #### Notes
             * This is a read-only attribute.
             */
            get: function () {
              // We can't make this an attribute with a default value
              // since it would be set after it is needed in the
              // constructor.
              return "button";
            },
            enumerable: true,
            configurable: true,
          });
          ToggleButtonView.class_map = {
            primary: ["mod-primary"],
            success: ["mod-success"],
            info: ["mod-info"],
            warning: ["mod-warning"],
            danger: ["mod-danger"],
          };
          return ToggleButtonView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_2__.DOMWidgetView);

        var ValidModel = /** @class */ (function (_super) {
          __extends(ValidModel, _super);
          function ValidModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ValidModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                readout: "Invalid",
                _view_name: "ValidView",
                _model_name: "ValidModel",
              }
            );
          };
          return ValidModel;
        })(BoolModel);

        var ValidView = /** @class */ (function (_super) {
          __extends(ValidView, _super);
          function ValidView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Called when view is rendered.
           */
          ValidView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-valid");
            this.el.classList.add("widget-inline-hbox");
            this.icon = document.createElement("i");
            this.icon.classList.add("fa", "fa-fw");
            this.el.appendChild(this.icon);
            this.readout = document.createElement("span");
            this.readout.classList.add("widget-valid-readout");
            this.readout.classList.add("widget-readout");
            this.el.appendChild(this.readout);
            this.update();
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed.  The model may have been
           * changed by another view or by a state update from the back-end.
           */
          ValidView.prototype.update = function () {
            this.el.classList.remove("mod-valid");
            this.el.classList.remove("mod-invalid");
            this.icon.classList.remove("fa-check");
            this.icon.classList.remove("fa-times");
            this.readout.textContent = this.model.get("readout");
            if (this.model.get("value")) {
              this.el.classList.add("mod-valid");
              this.icon.classList.add("fa-check");
            } else {
              this.el.classList.add("mod-invalid");
              this.icon.classList.add("fa-times");
            }
          };
          return ValidView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_box.js":
      /*!******************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_box.js ***!
  \******************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ BoxModel: () => /* binding */ BoxModel,
          /* harmony export */ HBoxModel: () => /* binding */ HBoxModel,
          /* harmony export */ VBoxModel: () => /* binding */ VBoxModel,
          /* harmony export */ BoxView: () => /* binding */ BoxView,
          /* harmony export */ HBoxView: () => /* binding */ HBoxView,
          /* harmony export */ VBoxView: () => /* binding */ VBoxView,
          /* harmony export */ GridBoxView: () => /* binding */ GridBoxView,
          /* harmony export */ GridBoxModel: () => /* binding */ GridBoxModel,
          /* harmony export */
        });
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__
          );
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./utils */ "./node_modules/@jupyter-widgets/controls/lib/utils.js"
          );
        /* harmony import */ var _lumino_algorithm__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! @lumino/algorithm */ "webpack/sharing/consume/default/@lumino/algorithm"
          );
        /* harmony import */ var _lumino_algorithm__WEBPACK_IMPORTED_MODULE_3___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_algorithm__WEBPACK_IMPORTED_MODULE_3__
          );
        /* harmony import */ var _lumino_messaging__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! @lumino/messaging */ "webpack/sharing/consume/default/@lumino/messaging"
          );
        /* harmony import */ var _lumino_messaging__WEBPACK_IMPORTED_MODULE_4___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_messaging__WEBPACK_IMPORTED_MODULE_4__
          );
        /* harmony import */ var _lumino_widgets__WEBPACK_IMPORTED_MODULE_5__ =
          __webpack_require__(
            /*! @lumino/widgets */ "webpack/sharing/consume/default/@lumino/widgets"
          );
        /* harmony import */ var _lumino_widgets__WEBPACK_IMPORTED_MODULE_5___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_widgets__WEBPACK_IMPORTED_MODULE_5__
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_6__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        /* harmony import */ var jquery__WEBPACK_IMPORTED_MODULE_7__ =
          __webpack_require__(
            /*! jquery */ "./node_modules/jquery/dist/jquery.js"
          );
        /* harmony import */ var jquery__WEBPACK_IMPORTED_MODULE_7___default =
          /*#__PURE__*/ __webpack_require__.n(
            jquery__WEBPACK_IMPORTED_MODULE_7__
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        var __assign =
          (undefined && undefined.__assign) ||
          function () {
            __assign =
              Object.assign ||
              function (t) {
                for (var s, i = 1, n = arguments.length; i < n; i++) {
                  s = arguments[i];
                  for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
                }
                return t;
              };
            return __assign.apply(this, arguments);
          };

        var BoxModel = /** @class */ (function (_super) {
          __extends(BoxModel, _super);
          function BoxModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          BoxModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_6__.extend(
              _super.prototype.defaults.call(this),
              {
                _view_name: "BoxView",
                _model_name: "BoxModel",
                children: [],
                box_style: "",
              }
            );
          };
          BoxModel.serializers = __assign(
            __assign(
              {},
              _widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreDOMWidgetModel
                .serializers
            ),
            {
              children: {
                deserialize:
                  _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.unpack_models,
              },
            }
          );
          return BoxModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreDOMWidgetModel);

        var HBoxModel = /** @class */ (function (_super) {
          __extends(HBoxModel, _super);
          function HBoxModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          HBoxModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_6__.extend(
              _super.prototype.defaults.call(this),
              {
                _view_name: "HBoxView",
                _model_name: "HBoxModel",
              }
            );
          };
          return HBoxModel;
        })(BoxModel);

        var VBoxModel = /** @class */ (function (_super) {
          __extends(VBoxModel, _super);
          function VBoxModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          VBoxModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_6__.extend(
              _super.prototype.defaults.call(this),
              {
                _view_name: "VBoxView",
                _model_name: "VBoxModel",
              }
            );
          };
          return VBoxModel;
        })(BoxModel);

        var BoxView = /** @class */ (function (_super) {
          __extends(BoxView, _super);
          function BoxView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          BoxView.prototype._createElement = function (tagName) {
            this.pWidget =
              new _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.JupyterPhosphorPanelWidget(
                { view: this }
              );
            return this.pWidget.node;
          };
          BoxView.prototype._setElement = function (el) {
            if (this.el || el !== this.pWidget.node) {
              // Boxes don't allow setting the element beyond the initial creation.
              throw new Error("Cannot reset the DOM element.");
            }
            this.el = this.pWidget.node;
            this.$el = jquery__WEBPACK_IMPORTED_MODULE_7___default()(
              this.pWidget.node
            );
          };
          BoxView.prototype.initialize = function (parameters) {
            _super.prototype.initialize.call(this, parameters);
            this.children_views =
              new _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.ViewList(
                this.add_child_model,
                null,
                this
              );
            this.listenTo(this.model, "change:children", this.update_children);
            this.listenTo(
              this.model,
              "change:box_style",
              this.update_box_style
            );
            this.pWidget.addClass("jupyter-widgets");
            this.pWidget.addClass("widget-container");
            this.pWidget.addClass("widget-box");
          };
          BoxView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.update_children();
            this.set_box_style();
          };
          BoxView.prototype.update_children = function () {
            this.children_views
              .update(this.model.get("children"))
              .then(function (views) {
                // Notify all children that their sizes may have changed.
                views.forEach(function (view) {
                  _lumino_messaging__WEBPACK_IMPORTED_MODULE_4__.MessageLoop.postMessage(
                    view.pWidget,
                    _lumino_widgets__WEBPACK_IMPORTED_MODULE_5__.Widget
                      .ResizeMessage.UnknownSize
                  );
                });
              });
          };
          BoxView.prototype.update_box_style = function () {
            this.update_mapped_classes(BoxView.class_map, "box_style");
          };
          BoxView.prototype.set_box_style = function () {
            this.set_mapped_classes(BoxView.class_map, "box_style");
          };
          BoxView.prototype.add_child_model = function (model) {
            var _this = this;
            // we insert a dummy element so the order is preserved when we add
            // the rendered content later.
            var dummy =
              new _lumino_widgets__WEBPACK_IMPORTED_MODULE_5__.Widget();
            this.pWidget.addWidget(dummy);
            return this.create_child_view(model)
              .then(function (view) {
                // replace the dummy widget with the new one.
                var i =
                  _lumino_algorithm__WEBPACK_IMPORTED_MODULE_3__.ArrayExt.firstIndexOf(
                    _this.pWidget.widgets,
                    dummy
                  );
                _this.pWidget.insertWidget(i, view.pWidget);
                dummy.dispose();
                return view;
              })
              .catch(
                (0, _utils__WEBPACK_IMPORTED_MODULE_2__.reject)(
                  "Could not add child view to box",
                  true
                )
              );
          };
          BoxView.prototype.remove = function () {
            this.children_views = null;
            _super.prototype.remove.call(this);
          };
          BoxView.class_map = {
            success: ["alert", "alert-success"],
            info: ["alert", "alert-info"],
            warning: ["alert", "alert-warning"],
            danger: ["alert", "alert-danger"],
          };
          return BoxView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.DOMWidgetView);

        var HBoxView = /** @class */ (function (_super) {
          __extends(HBoxView, _super);
          function HBoxView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Public constructor
           */
          HBoxView.prototype.initialize = function (parameters) {
            _super.prototype.initialize.call(this, parameters);
            this.pWidget.addClass("widget-hbox");
          };
          return HBoxView;
        })(BoxView);

        var VBoxView = /** @class */ (function (_super) {
          __extends(VBoxView, _super);
          function VBoxView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Public constructor
           */
          VBoxView.prototype.initialize = function (parameters) {
            _super.prototype.initialize.call(this, parameters);
            this.pWidget.addClass("widget-vbox");
          };
          return VBoxView;
        })(BoxView);

        var GridBoxView = /** @class */ (function (_super) {
          __extends(GridBoxView, _super);
          function GridBoxView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Public constructor
           */
          GridBoxView.prototype.initialize = function (parameters) {
            _super.prototype.initialize.call(this, parameters);
            this.pWidget.addClass("widget-gridbox");
            // display needn't be set to flex and grid
            this.pWidget.removeClass("widget-box");
          };
          return GridBoxView;
        })(BoxView);

        var GridBoxModel = /** @class */ (function (_super) {
          __extends(GridBoxModel, _super);
          function GridBoxModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          GridBoxModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_6__.extend(
              _super.prototype.defaults.call(this),
              {
                _view_name: "GridBoxView",
                _model_name: "GridBoxModel",
              }
            );
          };
          return GridBoxModel;
        })(BoxModel);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_button.js":
      /*!*********************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_button.js ***!
  \*********************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ ButtonStyleModel: () =>
            /* binding */ ButtonStyleModel,
          /* harmony export */ ButtonModel: () => /* binding */ ButtonModel,
          /* harmony export */ ButtonView: () => /* binding */ ButtonView,
          /* harmony export */
        });
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__
          );
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var _version__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./version */ "./node_modules/@jupyter-widgets/controls/lib/version.js"
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();

        var ButtonStyleModel = /** @class */ (function (_super) {
          __extends(ButtonStyleModel, _super);
          function ButtonStyleModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ButtonStyleModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "ButtonStyleModel",
                _model_module: "@jupyter-widgets/controls",
                _model_module_version:
                  _version__WEBPACK_IMPORTED_MODULE_2__.JUPYTER_CONTROLS_VERSION,
              }
            );
          };
          ButtonStyleModel.styleProperties = {
            button_color: {
              selector: "",
              attribute: "background-color",
              default: null,
            },
            font_weight: {
              selector: "",
              attribute: "font-weight",
              default: "",
            },
          };
          return ButtonStyleModel;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.StyleModel);

        var ButtonModel = /** @class */ (function (_super) {
          __extends(ButtonModel, _super);
          function ButtonModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ButtonModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                description: "",
                tooltip: "",
                disabled: false,
                icon: "",
                button_style: "",
                _view_name: "ButtonView",
                _model_name: "ButtonModel",
                style: null,
              }
            );
          };
          return ButtonModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreDOMWidgetModel);

        var ButtonView = /** @class */ (function (_super) {
          __extends(ButtonView, _super);
          function ButtonView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Called when view is rendered.
           */
          ButtonView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("jupyter-button");
            this.el.classList.add("widget-button");
            this.listenTo(
              this.model,
              "change:button_style",
              this.update_button_style
            );
            this.set_button_style();
            this.update(); // Set defaults.
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed. The model may have been
           * changed by another view or by a state update from the back-end.
           */
          ButtonView.prototype.update = function () {
            this.el.disabled = this.model.get("disabled");
            this.el.setAttribute("title", this.model.get("tooltip"));
            var description = this.model.get("description");
            var icon = this.model.get("icon");
            if (description.length || icon.length) {
              this.el.textContent = "";
              if (icon.length) {
                var i = document.createElement("i");
                i.classList.add("fa");
                i.classList.add("fa-" + icon);
                if (description.length === 0) {
                  i.classList.add("center");
                }
                this.el.appendChild(i);
              }
              this.el.appendChild(document.createTextNode(description));
            }
            return _super.prototype.update.call(this);
          };
          ButtonView.prototype.update_button_style = function () {
            this.update_mapped_classes(ButtonView.class_map, "button_style");
          };
          ButtonView.prototype.set_button_style = function () {
            this.set_mapped_classes(ButtonView.class_map, "button_style");
          };
          /**
           * Dictionary of events and handlers
           */
          ButtonView.prototype.events = function () {
            // TODO: return typing not needed in Typescript later than 1.8.x
            // See http://stackoverflow.com/questions/22077023/why-cant-i-indirectly-return-an-object-literal-to-satisfy-an-index-signature-re and https://github.com/Microsoft/TypeScript/pull/7029
            return { click: "_handle_click" };
          };
          /**
           * Handles when the button is clicked.
           */
          ButtonView.prototype._handle_click = function (event) {
            event.preventDefault();
            this.send({ event: "click" });
          };
          Object.defineProperty(ButtonView.prototype, "tagName", {
            /**
             * The default tag name.
             *
             * #### Notes
             * This is a read-only attribute.
             */
            get: function () {
              // We can't make this an attribute with a default value
              // since it would be set after it is needed in the
              // constructor.
              return "button";
            },
            enumerable: true,
            configurable: true,
          });
          ButtonView.class_map = {
            primary: ["mod-primary"],
            success: ["mod-success"],
            info: ["mod-info"],
            warning: ["mod-warning"],
            danger: ["mod-danger"],
          };
          return ButtonView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.DOMWidgetView);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_color.js":
      /*!********************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_color.js ***!
  \********************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ ColorPickerModel: () =>
            /* binding */ ColorPickerModel,
          /* harmony export */ ColorPickerView: () =>
            /* binding */ ColorPickerView,
          /* harmony export */
        });
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var _widget_description__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_description */ "./node_modules/@jupyter-widgets/controls/lib/widget_description.js"
          );
        /* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./utils */ "./node_modules/@jupyter-widgets/controls/lib/utils.js"
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();

        var ColorPickerModel = /** @class */ (function (_super) {
          __extends(ColorPickerModel, _super);
          function ColorPickerModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ColorPickerModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                value: "black",
                concise: false,
                _model_name: "ColorPickerModel",
                _view_name: "ColorPickerView",
              }
            );
          };
          return ColorPickerModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDescriptionModel);

        var ColorPickerView = /** @class */ (function (_super) {
          __extends(ColorPickerView, _super);
          function ColorPickerView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ColorPickerView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-colorpicker");
            this._color_container = document.createElement("div");
            this._color_container.className =
              "widget-inline-hbox widget-colorpicker-input";
            this.el.appendChild(this._color_container);
            this._textbox = document.createElement("input");
            this._textbox.setAttribute("type", "text");
            this._textbox.id = this.label.htmlFor = (0,
            _utils__WEBPACK_IMPORTED_MODULE_2__.uuid)();
            this._color_container.appendChild(this._textbox);
            this._textbox.value = this.model.get("value");
            this._colorpicker = document.createElement("input");
            this._colorpicker.setAttribute("type", "color");
            this._color_container.appendChild(this._colorpicker);
            this.listenTo(this.model, "change:value", this._update_value);
            this.listenTo(this.model, "change:concise", this._update_concise);
            this._update_concise();
            this._update_value();
            this.update();
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed. The model may have been
           * changed by another view or by a state update from the back-end.
           */
          ColorPickerView.prototype.update = function (options) {
            if (options === undefined || options.updated_view != this) {
              var disabled = this.model.get("disabled");
              this._textbox.disabled = disabled;
              this._colorpicker.disabled = disabled;
            }
            return _super.prototype.update.call(this);
          };
          ColorPickerView.prototype.events = function () {
            // Typescript doesn't understand that these functions are called, so we
            // specifically use them here so it knows they are being used.
            void this._picker_change;
            void this._text_change;
            return {
              'change [type="color"]': "_picker_change",
              'change [type="text"]': "_text_change",
            };
          };
          ColorPickerView.prototype._update_value = function () {
            var value = this.model.get("value");
            this._colorpicker.value = color2hex(value);
            this._textbox.value = value;
          };
          ColorPickerView.prototype._update_concise = function () {
            var concise = this.model.get("concise");
            if (concise) {
              this.el.classList.add("concise");
              this._textbox.style.display = "none";
            } else {
              this.el.classList.remove("concise");
              this._textbox.style.display = "";
            }
          };
          ColorPickerView.prototype._picker_change = function () {
            this.model.set("value", this._colorpicker.value);
            this.touch();
          };
          ColorPickerView.prototype._text_change = function () {
            var value = this._validate_color(
              this._textbox.value,
              this.model.get("value")
            );
            this.model.set("value", value);
            this.touch();
          };
          ColorPickerView.prototype._validate_color = function (
            color,
            fallback
          ) {
            return color.match(/#[a-fA-F0-9]{3}(?:[a-fA-F0-9]{3})?$/) ||
              named_colors[color.toLowerCase()]
              ? color
              : fallback;
          };
          return ColorPickerView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var named_colors = {
          aliceblue: "#f0f8ff",
          antiquewhite: "#faebd7",
          aqua: "#00ffff",
          aquamarine: "#7fffd4",
          azure: "#f0ffff",
          beige: "#f5f5dc",
          bisque: "#ffe4c4",
          black: "#000000",
          blanchedalmond: "#ffebcd",
          blue: "#0000ff",
          blueviolet: "#8a2be2",
          brown: "#a52a2a",
          burlywood: "#deb887",
          cadetblue: "#5f9ea0",
          chartreuse: "#7fff00",
          chocolate: "#d2691e",
          coral: "#ff7f50",
          cornflowerblue: "#6495ed",
          cornsilk: "#fff8dc",
          crimson: "#dc143c",
          cyan: "#00ffff",
          darkblue: "#00008b",
          darkcyan: "#008b8b",
          darkgoldenrod: "#b8860b",
          darkgray: "#a9a9a9",
          darkgrey: "#a9a9a9",
          darkgreen: "#006400",
          darkkhaki: "#bdb76b",
          darkmagenta: "#8b008b",
          darkolivegreen: "#556b2f",
          darkorange: "#ff8c00",
          darkorchid: "#9932cc",
          darkred: "#8b0000",
          darksalmon: "#e9967a",
          darkseagreen: "#8fbc8f",
          darkslateblue: "#483d8b",
          darkslategray: "#2f4f4f",
          darkslategrey: "#2f4f4f",
          darkturquoise: "#00ced1",
          darkviolet: "#9400d3",
          deeppink: "#ff1493",
          deepskyblue: "#00bfff",
          dimgray: "#696969",
          dimgrey: "#696969",
          dodgerblue: "#1e90ff",
          firebrick: "#b22222",
          floralwhite: "#fffaf0",
          forestgreen: "#228b22",
          fuchsia: "#ff00ff",
          gainsboro: "#dcdcdc",
          ghostwhite: "#f8f8ff",
          gold: "#ffd700",
          goldenrod: "#daa520",
          gray: "#808080",
          grey: "#808080",
          green: "#008000",
          greenyellow: "#adff2f",
          honeydew: "#f0fff0",
          hotpink: "#ff69b4",
          indianred: "#cd5c5c",
          indigo: "#4b0082",
          ivory: "#fffff0",
          khaki: "#f0e68c",
          lavender: "#e6e6fa",
          lavenderblush: "#fff0f5",
          lawngreen: "#7cfc00",
          lemonchiffon: "#fffacd",
          lightblue: "#add8e6",
          lightcoral: "#f08080",
          lightcyan: "#e0ffff",
          lightgoldenrodyellow: "#fafad2",
          lightgreen: "#90ee90",
          lightgray: "#d3d3d3",
          lightgrey: "#d3d3d3",
          lightpink: "#ffb6c1",
          lightsalmon: "#ffa07a",
          lightseagreen: "#20b2aa",
          lightskyblue: "#87cefa",
          lightslategray: "#778899",
          lightslategrey: "#778899",
          lightsteelblue: "#b0c4de",
          lightyellow: "#ffffe0",
          lime: "#00ff00",
          limegreen: "#32cd32",
          linen: "#faf0e6",
          magenta: "#ff00ff",
          maroon: "#800000",
          mediumaquamarine: "#66cdaa",
          mediumblue: "#0000cd",
          mediumorchid: "#ba55d3",
          mediumpurple: "#9370db",
          mediumseagreen: "#3cb371",
          mediumslateblue: "#7b68ee",
          mediumspringgreen: "#00fa9a",
          mediumturquoise: "#48d1cc",
          mediumvioletred: "#c71585",
          midnightblue: "#191970",
          mintcream: "#f5fffa",
          mistyrose: "#ffe4e1",
          moccasin: "#ffe4b5",
          navajowhite: "#ffdead",
          navy: "#000080",
          oldlace: "#fdf5e6",
          olive: "#808000",
          olivedrab: "#6b8e23",
          orange: "#ffa500",
          orangered: "#ff4500",
          orchid: "#da70d6",
          palegoldenrod: "#eee8aa",
          palegreen: "#98fb98",
          paleturquoise: "#afeeee",
          palevioletred: "#db7093",
          papayawhip: "#ffefd5",
          peachpuff: "#ffdab9",
          peru: "#cd853f",
          pink: "#ffc0cb",
          plum: "#dda0dd",
          powderblue: "#b0e0e6",
          purple: "#800080",
          red: "#ff0000",
          rosybrown: "#bc8f8f",
          royalblue: "#4169e1",
          saddlebrown: "#8b4513",
          salmon: "#fa8072",
          sandybrown: "#f4a460",
          seagreen: "#2e8b57",
          seashell: "#fff5ee",
          sienna: "#a0522d",
          silver: "#c0c0c0",
          skyblue: "#87ceeb",
          slateblue: "#6a5acd",
          slategray: "#708090",
          slategrey: "#708090",
          snow: "#fffafa",
          springgreen: "#00ff7f",
          steelblue: "#4682b4",
          tan: "#d2b48c",
          teal: "#008080",
          thistle: "#d8bfd8",
          tomato: "#ff6347",
          turquoise: "#40e0d0",
          violet: "#ee82ee",
          wheat: "#f5deb3",
          white: "#ffffff",
          whitesmoke: "#f5f5f5",
          yellow: "#ffff00",
          yellowgreen: "#9acd32",
        };
        /*
         * From a valid html color (named color, 6-digits or 3-digits hex format)
         * return a 6-digits hexadecimal color #rrggbb.
         */
        function color2hex(color) {
          return named_colors[color.toLowerCase()] || rgb3_to_rgb6(color);
        }
        function rgb3_to_rgb6(rgb) {
          if (rgb.length === 7) {
            return rgb;
          } else {
            return (
              "#" +
              rgb.charAt(1) +
              rgb.charAt(1) +
              rgb.charAt(2) +
              rgb.charAt(2) +
              rgb.charAt(3) +
              rgb.charAt(3)
            );
          }
        }

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_controller.js":
      /*!*************************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_controller.js ***!
  \*************************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ ControllerButtonModel: () =>
            /* binding */ ControllerButtonModel,
          /* harmony export */ ControllerButtonView: () =>
            /* binding */ ControllerButtonView,
          /* harmony export */ ControllerAxisModel: () =>
            /* binding */ ControllerAxisModel,
          /* harmony export */ ControllerAxisView: () =>
            /* binding */ ControllerAxisView,
          /* harmony export */ ControllerModel: () =>
            /* binding */ ControllerModel,
          /* harmony export */ ControllerView: () =>
            /* binding */ ControllerView,
          /* harmony export */
        });
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__
          );
        /* harmony import */ var _lumino_widgets__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! @lumino/widgets */ "webpack/sharing/consume/default/@lumino/widgets"
          );
        /* harmony import */ var _lumino_widgets__WEBPACK_IMPORTED_MODULE_2___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_widgets__WEBPACK_IMPORTED_MODULE_2__
          );
        /* harmony import */ var _lumino_algorithm__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! @lumino/algorithm */ "webpack/sharing/consume/default/@lumino/algorithm"
          );
        /* harmony import */ var _lumino_algorithm__WEBPACK_IMPORTED_MODULE_3___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_algorithm__WEBPACK_IMPORTED_MODULE_3__
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        /* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_5__ =
          __webpack_require__(
            /*! ./utils */ "./node_modules/@jupyter-widgets/controls/lib/utils.js"
          );
        /* harmony import */ var jquery__WEBPACK_IMPORTED_MODULE_6__ =
          __webpack_require__(
            /*! jquery */ "./node_modules/jquery/dist/jquery.js"
          );
        /* harmony import */ var jquery__WEBPACK_IMPORTED_MODULE_6___default =
          /*#__PURE__*/ __webpack_require__.n(
            jquery__WEBPACK_IMPORTED_MODULE_6__
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        var __assign =
          (undefined && undefined.__assign) ||
          function () {
            __assign =
              Object.assign ||
              function (t) {
                for (var s, i = 1, n = arguments.length; i < n; i++) {
                  s = arguments[i];
                  for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
                }
                return t;
              };
            return __assign.apply(this, arguments);
          };

        var ControllerButtonModel = /** @class */ (function (_super) {
          __extends(ControllerButtonModel, _super);
          function ControllerButtonModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ControllerButtonModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_4__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "ControllerButtonModel",
                _view_name: "ControllerButtonView",
                value: 0.0,
                pressed: false,
              }
            );
          };
          return ControllerButtonModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDOMWidgetModel);

        /**
         * Very simple view for a gamepad button.
         */
        var ControllerButtonView = /** @class */ (function (_super) {
          __extends(ControllerButtonView, _super);
          function ControllerButtonView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ControllerButtonView.prototype.render = function () {
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-controller-button");
            this.el.style.width = "fit-content";
            this.support = document.createElement("div");
            this.support.style.position = "relative";
            this.support.style.margin = "1px";
            this.support.style.width = "16px";
            this.support.style.height = "16px";
            this.support.style.border = "1px solid black";
            this.support.style.background = "lightgray";
            this.el.appendChild(this.support);
            this.bar = document.createElement("div");
            this.bar.style.position = "absolute";
            this.bar.style.width = "100%";
            this.bar.style.bottom = "0px";
            this.bar.style.background = "gray";
            this.support.appendChild(this.bar);
            this.update();
            this.label = document.createElement("div");
            this.label.textContent = this.model.get("description");
            this.label.style.textAlign = "center";
            this.el.appendChild(this.label);
          };
          ControllerButtonView.prototype.update = function () {
            this.bar.style.height = 100 * this.model.get("value") + "%";
          };
          return ControllerButtonView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__.DOMWidgetView);

        var ControllerAxisModel = /** @class */ (function (_super) {
          __extends(ControllerAxisModel, _super);
          function ControllerAxisModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ControllerAxisModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_4__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "ControllerAxisModel",
                _view_name: "ControllerAxisView",
                value: 0.0,
              }
            );
          };
          return ControllerAxisModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDOMWidgetModel);

        /**
         * Very simple view for a gamepad axis.
         */
        var ControllerAxisView = /** @class */ (function (_super) {
          __extends(ControllerAxisView, _super);
          function ControllerAxisView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ControllerAxisView.prototype.render = function () {
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-controller-axis");
            this.el.style.width = "16px";
            this.el.style.padding = "4px";
            this.support = document.createElement("div");
            this.support.style.position = "relative";
            this.support.style.margin = "1px";
            this.support.style.width = "4px";
            this.support.style.height = "64px";
            this.support.style.border = "1px solid black";
            this.support.style.background = "lightgray";
            this.bullet = document.createElement("div");
            this.bullet.style.position = "absolute";
            this.bullet.style.margin = "-3px";
            this.bullet.style.boxSizing = "unset";
            this.bullet.style.width = "10px";
            this.bullet.style.height = "10px";
            this.bullet.style.background = "gray";
            this.label = document.createElement("div");
            this.label.textContent = this.model.get("description");
            this.label.style.textAlign = "center";
            this.support.appendChild(this.bullet);
            this.el.appendChild(this.support);
            this.el.appendChild(this.label);
            this.update();
          };
          ControllerAxisView.prototype.update = function () {
            this.bullet.style.top = 50 * (this.model.get("value") + 1) + "%";
          };
          return ControllerAxisView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__.DOMWidgetView);

        var ControllerModel = /** @class */ (function (_super) {
          __extends(ControllerModel, _super);
          function ControllerModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ControllerModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_4__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "ControllerModel",
                _view_name: "ControllerView",
                index: 0,
                name: "",
                mapping: "",
                connected: false,
                timestamp: 0,
                buttons: [],
                axes: [],
              }
            );
          };
          ControllerModel.prototype.initialize = function (
            attributes,
            options
          ) {
            _super.prototype.initialize.call(this, attributes, options);
            if (navigator.getGamepads === void 0) {
              // Checks if the browser supports the gamepad API
              this.readout = "This browser does not support gamepads.";
              console.error(this.readout);
            } else {
              // Start the wait loop, and listen to updates of the only
              // user-provided attribute, the gamepad index.
              this.readout = "Connect gamepad and press any button.";
              if (this.get("connected")) {
                // No need to re-create Button and Axis widgets, re-use
                // the models provided by the backend which may already
                // be wired to other things.
                this.update_loop();
              } else {
                // Wait for a gamepad to be connected.
                this.wait_loop();
              }
            }
          };
          /**
           * Waits for a gamepad to be connected at the provided index.
           * Once one is connected, it will start the update loop, which
           * populates the update of axes and button values.
           */
          ControllerModel.prototype.wait_loop = function () {
            var index = this.get("index");
            var pad = navigator.getGamepads()[index];
            if (pad) {
              var that_1 = this;
              this.setup(pad).then(function (controls) {
                that_1.set(controls);
                that_1.save_changes();
                window.requestAnimationFrame(that_1.update_loop.bind(that_1));
              });
            } else {
              window.requestAnimationFrame(this.wait_loop.bind(this));
            }
          };
          /**
           * Given a native gamepad object, returns a promise for a dictionary of
           * controls, of the form
           * {
           *     buttons: list of Button models,
           *     axes: list of Axis models,
           * }
           */
          ControllerModel.prototype.setup = function (pad) {
            // Set up the main gamepad attributes
            this.set({
              name: pad.id,
              mapping: pad.mapping,
              connected: pad.connected,
              timestamp: pad.timestamp,
            });
            // Create buttons and axes. When done, start the update loop
            var that = this;
            return _utils__WEBPACK_IMPORTED_MODULE_5__.resolvePromisesDict({
              buttons: Promise.all(
                pad.buttons.map(function (btn, index) {
                  return that._create_button_model(index);
                })
              ),
              axes: Promise.all(
                pad.axes.map(function (axis, index) {
                  return that._create_axis_model(index);
                })
              ),
            });
          };
          /**
           * Update axes and buttons values, until the gamepad is disconnected.
           * When the gamepad is disconnected, this.reset_gamepad is called.
           */
          ControllerModel.prototype.update_loop = function () {
            var index = this.get("index");
            var id = this.get("name");
            var pad = navigator.getGamepads()[index];
            if (pad && index === pad.index && id === pad.id) {
              this.set({
                timestamp: pad.timestamp,
                connected: pad.connected,
              });
              this.save_changes();
              this.get("buttons").forEach(function (model, index) {
                model.set({
                  value: pad.buttons[index].value,
                  pressed: pad.buttons[index].pressed,
                });
                model.save_changes();
              });
              this.get("axes").forEach(function (model, index) {
                model.set("value", pad.axes[index]);
                model.save_changes();
              });
              window.requestAnimationFrame(this.update_loop.bind(this));
            } else {
              this.reset_gamepad();
            }
          };
          /**
           * Resets the gamepad attributes, and start the wait_loop.
           */
          ControllerModel.prototype.reset_gamepad = function () {
            this.get("buttons").forEach(function (button) {
              button.close();
            });
            this.get("axes").forEach(function (axis) {
              axis.close();
            });
            this.set({
              name: "",
              mapping: "",
              connected: false,
              timestamp: 0.0,
              buttons: [],
              axes: [],
            });
            this.save_changes();
            window.requestAnimationFrame(this.wait_loop.bind(this));
          };
          /**
           * Creates a gamepad button widget.
           */
          ControllerModel.prototype._create_button_model = function (index) {
            return this.widget_manager
              .new_widget({
                model_name: "ControllerButtonModel",
                model_module: "@jupyter-widgets/controls",
                model_module_version: this.get("_model_module_version"),
                view_name: "ControllerButtonView",
                view_module: "@jupyter-widgets/controls",
                view_module_version: this.get("_view_module_version"),
              })
              .then(function (model) {
                model.set("description", index);
                return model;
              });
          };
          /**
           * Creates a gamepad axis widget.
           */
          ControllerModel.prototype._create_axis_model = function (index) {
            return this.widget_manager
              .new_widget({
                model_name: "ControllerAxisModel",
                model_module: "@jupyter-widgets/controls",
                model_module_version: this.get("_model_module_version"),
                view_name: "ControllerAxisView",
                view_module: "@jupyter-widgets/controls",
                view_module_version: this.get("_view_module_version"),
              })
              .then(function (model) {
                model.set("description", index);
                return model;
              });
          };
          ControllerModel.serializers = __assign(
            __assign(
              {},
              _widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDOMWidgetModel
                .serializers
            ),
            {
              buttons: {
                deserialize:
                  _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__.unpack_models,
              },
              axes: {
                deserialize:
                  _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__.unpack_models,
              },
            }
          );
          return ControllerModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDOMWidgetModel);

        /**
         * A simple view for a gamepad.
         */
        var ControllerView = /** @class */ (function (_super) {
          __extends(ControllerView, _super);
          function ControllerView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ControllerView.prototype._createElement = function (tagName) {
            this.pWidget =
              new _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__.JupyterPhosphorPanelWidget(
                { view: this }
              );
            return this.pWidget.node;
          };
          ControllerView.prototype._setElement = function (el) {
            if (this.el || el !== this.pWidget.node) {
              // Boxes don't allow setting the element beyond the initial creation.
              throw new Error("Cannot reset the DOM element.");
            }
            this.el = this.pWidget.node;
            this.$el = jquery__WEBPACK_IMPORTED_MODULE_6___default()(
              this.pWidget.node
            );
          };
          ControllerView.prototype.initialize = function (parameters) {
            _super.prototype.initialize.call(this, parameters);
            this.button_views =
              new _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__.ViewList(
                this.add_button,
                null,
                this
              );
            this.listenTo(
              this.model,
              "change:buttons",
              function (model, value) {
                this.button_views.update(value);
              }
            );
            this.axis_views =
              new _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__.ViewList(
                this.add_axis,
                null,
                this
              );
            this.listenTo(this.model, "change:axes", function (model, value) {
              this.axis_views.update(value);
            });
            this.listenTo(this.model, "change:name", this.update_label);
          };
          ControllerView.prototype.render = function () {
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-controller");
            this.label = document.createElement("div");
            this.el.appendChild(this.label);
            this.axis_box =
              new _lumino_widgets__WEBPACK_IMPORTED_MODULE_2__.Panel();
            this.axis_box.node.style.display = "flex";
            this.pWidget.addWidget(this.axis_box);
            this.button_box =
              new _lumino_widgets__WEBPACK_IMPORTED_MODULE_2__.Panel();
            this.button_box.node.style.display = "flex";
            this.pWidget.addWidget(this.button_box);
            this.button_views.update(this.model.get("buttons"));
            this.axis_views.update(this.model.get("axes"));
            this.update_label();
          };
          ControllerView.prototype.update_label = function () {
            this.label.textContent =
              this.model.get("name") || this.model.readout;
          };
          ControllerView.prototype.add_button = function (model) {
            var _this = this;
            // we insert a dummy element so the order is preserved when we add
            // the rendered content later.
            var dummy =
              new _lumino_widgets__WEBPACK_IMPORTED_MODULE_2__.Widget();
            this.button_box.addWidget(dummy);
            return this.create_child_view(model)
              .then(function (view) {
                // replace the dummy widget with the new one.
                var i =
                  _lumino_algorithm__WEBPACK_IMPORTED_MODULE_3__.ArrayExt.firstIndexOf(
                    _this.button_box.widgets,
                    dummy
                  );
                _this.button_box.insertWidget(i, view.pWidget);
                dummy.dispose();
                return view;
              })
              .catch(
                _utils__WEBPACK_IMPORTED_MODULE_5__.reject(
                  "Could not add child button view to controller",
                  true
                )
              );
          };
          ControllerView.prototype.add_axis = function (model) {
            var _this = this;
            // we insert a dummy element so the order is preserved when we add
            // the rendered content later.
            var dummy =
              new _lumino_widgets__WEBPACK_IMPORTED_MODULE_2__.Widget();
            this.axis_box.addWidget(dummy);
            return this.create_child_view(model)
              .then(function (view) {
                // replace the dummy widget with the new one.
                var i =
                  _lumino_algorithm__WEBPACK_IMPORTED_MODULE_3__.ArrayExt.firstIndexOf(
                    _this.axis_box.widgets,
                    dummy
                  );
                _this.axis_box.insertWidget(i, view.pWidget);
                dummy.dispose();
                return view;
              })
              .catch(
                _utils__WEBPACK_IMPORTED_MODULE_5__.reject(
                  "Could not add child axis view to controller",
                  true
                )
              );
          };
          ControllerView.prototype.remove = function () {
            _super.prototype.remove.call(this);
            this.button_views.remove();
            this.axis_views.remove();
          };
          return ControllerView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__.DOMWidgetView);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js":
      /*!*******************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_core.js ***!
  \*******************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ CoreWidgetModel: () =>
            /* binding */ CoreWidgetModel,
          /* harmony export */ CoreDOMWidgetModel: () =>
            /* binding */ CoreDOMWidgetModel,
          /* harmony export */ CoreDescriptionModel: () =>
            /* binding */ CoreDescriptionModel,
          /* harmony export */
        });
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__
          );
        /* harmony import */ var _widget_description__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_description */ "./node_modules/@jupyter-widgets/controls/lib/widget_description.js"
          );
        /* harmony import */ var _version__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./version */ "./node_modules/@jupyter-widgets/controls/lib/version.js"
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        // widget_core implements some common patterns for the core widget collection
        // that are not to be used directly by third-party widget authors.

        var CoreWidgetModel = /** @class */ (function (_super) {
          __extends(CoreWidgetModel, _super);
          function CoreWidgetModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          CoreWidgetModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "CoreWidgetModel",
                _view_module: "@jupyter-widgets/controls",
                _model_module: "@jupyter-widgets/controls",
                _view_module_version:
                  _version__WEBPACK_IMPORTED_MODULE_2__.JUPYTER_CONTROLS_VERSION,
                _model_module_version:
                  _version__WEBPACK_IMPORTED_MODULE_2__.JUPYTER_CONTROLS_VERSION,
              }
            );
          };
          return CoreWidgetModel;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.WidgetModel);

        var CoreDOMWidgetModel = /** @class */ (function (_super) {
          __extends(CoreDOMWidgetModel, _super);
          function CoreDOMWidgetModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          CoreDOMWidgetModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "CoreDOMWidgetModel",
                _view_module: "@jupyter-widgets/controls",
                _model_module: "@jupyter-widgets/controls",
                _view_module_version:
                  _version__WEBPACK_IMPORTED_MODULE_2__.JUPYTER_CONTROLS_VERSION,
                _model_module_version:
                  _version__WEBPACK_IMPORTED_MODULE_2__.JUPYTER_CONTROLS_VERSION,
              }
            );
          };
          return CoreDOMWidgetModel;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.DOMWidgetModel);

        var CoreDescriptionModel = /** @class */ (function (_super) {
          __extends(CoreDescriptionModel, _super);
          function CoreDescriptionModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          CoreDescriptionModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "CoreDescriptionModel",
                _view_module: "@jupyter-widgets/controls",
                _model_module: "@jupyter-widgets/controls",
                _view_module_version:
                  _version__WEBPACK_IMPORTED_MODULE_2__.JUPYTER_CONTROLS_VERSION,
                _model_module_version:
                  _version__WEBPACK_IMPORTED_MODULE_2__.JUPYTER_CONTROLS_VERSION,
              }
            );
          };
          return CoreDescriptionModel;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionModel);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_date.js":
      /*!*******************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_date.js ***!
  \*******************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ serialize_date: () =>
            /* binding */ serialize_date,
          /* harmony export */ deserialize_date: () =>
            /* binding */ deserialize_date,
          /* harmony export */ DatePickerModel: () =>
            /* binding */ DatePickerModel,
          /* harmony export */ DatePickerView: () =>
            /* binding */ DatePickerView,
          /* harmony export */
        });
        /* harmony import */ var _widget_description__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./widget_description */ "./node_modules/@jupyter-widgets/controls/lib/widget_description.js"
          );
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./utils */ "./node_modules/@jupyter-widgets/controls/lib/utils.js"
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        var __assign =
          (undefined && undefined.__assign) ||
          function () {
            __assign =
              Object.assign ||
              function (t) {
                for (var s, i = 1, n = arguments.length; i < n; i++) {
                  s = arguments[i];
                  for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
                }
                return t;
              };
            return __assign.apply(this, arguments);
          };

        function serialize_date(value) {
          if (value === null) {
            return null;
          } else {
            return {
              year: value.getUTCFullYear(),
              month: value.getUTCMonth(),
              date: value.getUTCDate(),
            };
          }
        }
        function deserialize_date(value) {
          if (value === null) {
            return null;
          } else {
            var date = new Date();
            date.setUTCFullYear(value.year, value.month, value.date);
            date.setUTCHours(0, 0, 0, 0);
            return date;
          }
        }
        var DatePickerModel = /** @class */ (function (_super) {
          __extends(DatePickerModel, _super);
          function DatePickerModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          DatePickerModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                value: null,
                _model_name: "DatePickerModel",
                _view_name: "DatePickerView",
              }
            );
          };
          DatePickerModel.serializers = __assign(
            __assign(
              {},
              _widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreDescriptionModel
                .serializers
            ),
            {
              value: {
                serialize: serialize_date,
                deserialize: deserialize_date,
              },
            }
          );
          return DatePickerModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreDescriptionModel);

        var DatePickerView = /** @class */ (function (_super) {
          __extends(DatePickerView, _super);
          function DatePickerView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          DatePickerView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-datepicker");
            this._datepicker = document.createElement("input");
            this._datepicker.setAttribute("type", "date");
            this._datepicker.id = this.label.htmlFor = (0,
            _utils__WEBPACK_IMPORTED_MODULE_2__.uuid)();
            this.el.appendChild(this._datepicker);
            this.listenTo(this.model, "change:value", this._update_value);
            this._update_value();
            this.update();
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed. The model may have been
           * changed by another view or by a state update from the back-end.
           */
          DatePickerView.prototype.update = function (options) {
            if (options === undefined || options.updated_view !== this) {
              this._datepicker.disabled = this.model.get("disabled");
            }
            return _super.prototype.update.call(this);
          };
          DatePickerView.prototype.events = function () {
            // Typescript doesn't understand that these functions are called, so we
            // specifically use them here so it knows they are being used.
            void this._picker_change;
            void this._picker_focusout;
            return {
              'change [type="date"]': "_picker_change",
              'focusout [type="date"]': "_picker_focusout",
            };
          };
          DatePickerView.prototype._update_value = function () {
            var value = this.model.get("value");
            this._datepicker.valueAsDate = value;
          };
          DatePickerView.prototype._picker_change = function () {
            if (!this._datepicker.validity.badInput) {
              this.model.set("value", this._datepicker.valueAsDate);
              this.touch();
            }
          };
          DatePickerView.prototype._picker_focusout = function () {
            if (this._datepicker.validity.badInput) {
              this.model.set("value", null);
              this.touch();
            }
          };
          return DatePickerView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_0__.DescriptionView);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_description.js":
      /*!**************************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_description.js ***!
  \**************************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ DescriptionStyleModel: () =>
            /* binding */ DescriptionStyleModel,
          /* harmony export */ DescriptionModel: () =>
            /* binding */ DescriptionModel,
          /* harmony export */ DescriptionView: () =>
            /* binding */ DescriptionView,
          /* harmony export */ LabeledDOMWidgetModel: () =>
            /* binding */ LabeledDOMWidgetModel,
          /* harmony export */ LabeledDOMWidgetView: () =>
            /* binding */ LabeledDOMWidgetView,
          /* harmony export */
        });
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__
          );
        /* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./utils */ "./node_modules/@jupyter-widgets/controls/lib/utils.js"
          );
        /* harmony import */ var _version__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./version */ "./node_modules/@jupyter-widgets/controls/lib/version.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        var __assign =
          (undefined && undefined.__assign) ||
          function () {
            __assign =
              Object.assign ||
              function (t) {
                for (var s, i = 1, n = arguments.length; i < n; i++) {
                  s = arguments[i];
                  for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
                }
                return t;
              };
            return __assign.apply(this, arguments);
          };

        var DescriptionStyleModel = /** @class */ (function (_super) {
          __extends(DescriptionStyleModel, _super);
          function DescriptionStyleModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          DescriptionStyleModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              {
                _model_name: "DescriptionStyleModel",
                _model_module: "@jupyter-widgets/controls",
                _model_module_version:
                  _version__WEBPACK_IMPORTED_MODULE_2__.JUPYTER_CONTROLS_VERSION,
              }
            );
          };
          DescriptionStyleModel.styleProperties = {
            description_width: {
              selector: ".widget-label",
              attribute: "width",
              default: null,
            },
          };
          return DescriptionStyleModel;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.StyleModel);

        var DescriptionModel = /** @class */ (function (_super) {
          __extends(DescriptionModel, _super);
          function DescriptionModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          DescriptionModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              {
                _model_name: "DescriptionModel",
                _view_name: "DescriptionView",
                _view_module: "@jupyter-widgets/controls",
                _model_module: "@jupyter-widgets/controls",
                _view_module_version:
                  _version__WEBPACK_IMPORTED_MODULE_2__.JUPYTER_CONTROLS_VERSION,
                _model_module_version:
                  _version__WEBPACK_IMPORTED_MODULE_2__.JUPYTER_CONTROLS_VERSION,
                description: "",
                description_tooltip: null,
              }
            );
          };
          return DescriptionModel;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.DOMWidgetModel);

        var DescriptionView = /** @class */ (function (_super) {
          __extends(DescriptionView, _super);
          function DescriptionView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          DescriptionView.prototype.render = function () {
            this.label = document.createElement("label");
            this.el.appendChild(this.label);
            this.label.className = "widget-label";
            this.label.style.display = "none";
            this.listenTo(
              this.model,
              "change:description",
              this.updateDescription
            );
            this.listenTo(
              this.model,
              "change:description_tooltip",
              this.updateDescription
            );
            this.updateDescription();
          };
          DescriptionView.prototype.typeset = function (element, text) {
            this.displayed.then(function () {
              return (0,
              _utils__WEBPACK_IMPORTED_MODULE_1__.typeset)(element, text);
            });
          };
          DescriptionView.prototype.updateDescription = function () {
            var description = this.model.get("description");
            var description_tooltip = this.model.get("description_tooltip");
            if (description_tooltip === null) {
              description_tooltip = description;
            }
            if (description.length === 0) {
              this.label.style.display = "none";
            } else {
              this.label.innerHTML = description;
              this.typeset(this.label);
              this.label.style.display = "";
            }
            this.label.title = description_tooltip;
          };
          return DescriptionView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.DOMWidgetView);

        /**
         * For backwards compatibility with jupyter-js-widgets 2.x.
         *
         * Use DescriptionModel instead.
         */
        var LabeledDOMWidgetModel = /** @class */ (function (_super) {
          __extends(LabeledDOMWidgetModel, _super);
          function LabeledDOMWidgetModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          return LabeledDOMWidgetModel;
        })(DescriptionModel);

        /**
         * For backwards compatibility with jupyter-js-widgets 2.x.
         *
         * Use DescriptionView instead.
         */
        var LabeledDOMWidgetView = /** @class */ (function (_super) {
          __extends(LabeledDOMWidgetView, _super);
          function LabeledDOMWidgetView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          return LabeledDOMWidgetView;
        })(DescriptionView);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_float.js":
      /*!********************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_float.js ***!
  \********************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ FloatModel: () => /* binding */ FloatModel,
          /* harmony export */ BoundedFloatModel: () =>
            /* binding */ BoundedFloatModel,
          /* harmony export */ FloatSliderModel: () =>
            /* binding */ FloatSliderModel,
          /* harmony export */ FloatLogSliderModel: () =>
            /* binding */ FloatLogSliderModel,
          /* harmony export */ FloatRangeSliderModel: () =>
            /* binding */ FloatRangeSliderModel,
          /* harmony export */ FloatSliderView: () =>
            /* binding */ FloatSliderView,
          /* harmony export */ FloatLogSliderView: () =>
            /* binding */ FloatLogSliderView,
          /* harmony export */ FloatRangeSliderView: () =>
            /* binding */ FloatRangeSliderView,
          /* harmony export */ FloatTextModel: () =>
            /* binding */ FloatTextModel,
          /* harmony export */ BoundedFloatTextModel: () =>
            /* binding */ BoundedFloatTextModel,
          /* harmony export */ FloatTextView: () => /* binding */ FloatTextView,
          /* harmony export */ FloatProgressModel: () =>
            /* binding */ FloatProgressModel,
          /* harmony export */
        });
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        /* harmony import */ var _widget_int__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./widget_int */ "./node_modules/@jupyter-widgets/controls/lib/widget_int.js"
          );
        /* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! d3-format */ "./node_modules/d3-format/src/defaultLocale.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();

        var FloatModel = /** @class */ (function (_super) {
          __extends(FloatModel, _super);
          function FloatModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          FloatModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_1__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "FloatModel",
                value: 0,
              }
            );
          };
          return FloatModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDescriptionModel);

        var BoundedFloatModel = /** @class */ (function (_super) {
          __extends(BoundedFloatModel, _super);
          function BoundedFloatModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          BoundedFloatModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_1__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "BoundedFloatModel",
                max: 100.0,
                min: 0.0,
              }
            );
          };
          return BoundedFloatModel;
        })(FloatModel);

        var FloatSliderModel = /** @class */ (function (_super) {
          __extends(FloatSliderModel, _super);
          function FloatSliderModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          FloatSliderModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_1__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "FloatSliderModel",
                _view_name: "FloatSliderView",
                step: 1.0,
                orientation: "horizontal",
                _range: false,
                readout: true,
                readout_format: ".2f",
                slider_color: null,
                continuous_update: true,
                disabled: false,
              }
            );
          };
          FloatSliderModel.prototype.initialize = function (
            attributes,
            options
          ) {
            _super.prototype.initialize.call(this, attributes, options);
            this.on("change:readout_format", this.update_readout_format, this);
            this.update_readout_format();
          };
          FloatSliderModel.prototype.update_readout_format = function () {
            this.readout_formatter = (0,
            d3_format__WEBPACK_IMPORTED_MODULE_3__.format)(
              this.get("readout_format")
            );
          };
          return FloatSliderModel;
        })(BoundedFloatModel);

        var FloatLogSliderModel = /** @class */ (function (_super) {
          __extends(FloatLogSliderModel, _super);
          function FloatLogSliderModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          FloatLogSliderModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_1__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "FloatLogSliderModel",
                _view_name: "FloatLogSliderView",
                step: 0.1,
                orientation: "horizontal",
                _range: false,
                readout: true,
                readout_format: ".3g",
                slider_color: null,
                continuous_update: true,
                disabled: false,
                base: 10,
                value: 1.0,
                min: 0,
                max: 4,
              }
            );
          };
          FloatLogSliderModel.prototype.initialize = function (
            attributes,
            options
          ) {
            _super.prototype.initialize.call(this, attributes, options);
            this.on("change:readout_format", this.update_readout_format, this);
            this.update_readout_format();
          };
          FloatLogSliderModel.prototype.update_readout_format = function () {
            this.readout_formatter = (0,
            d3_format__WEBPACK_IMPORTED_MODULE_3__.format)(
              this.get("readout_format")
            );
          };
          return FloatLogSliderModel;
        })(BoundedFloatModel);

        var FloatRangeSliderModel = /** @class */ (function (_super) {
          __extends(FloatRangeSliderModel, _super);
          function FloatRangeSliderModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          return FloatRangeSliderModel;
        })(FloatSliderModel);

        var FloatSliderView = /** @class */ (function (_super) {
          __extends(FloatSliderView, _super);
          function FloatSliderView() {
            var _this =
              (_super !== null && _super.apply(this, arguments)) || this;
            _this._parse_value = parseFloat;
            return _this;
          }
          /**
           * Validate the value of the slider before sending it to the back-end
           * and applying it to the other views on the page.
           */
          FloatSliderView.prototype._validate_slide_value = function (x) {
            return x;
          };
          return FloatSliderView;
        })(_widget_int__WEBPACK_IMPORTED_MODULE_2__.IntSliderView);

        var FloatLogSliderView = /** @class */ (function (_super) {
          __extends(FloatLogSliderView, _super);
          function FloatLogSliderView() {
            var _this =
              (_super !== null && _super.apply(this, arguments)) || this;
            _this._parse_value = parseFloat;
            return _this;
          }
          FloatLogSliderView.prototype.update = function (options) {
            _super.prototype.update.call(this, options);
            var min = this.model.get("min");
            var max = this.model.get("max");
            var value = this.model.get("value");
            var base = this.model.get("base");
            var log_value = Math.log(value) / Math.log(base);
            if (log_value > max) {
              log_value = max;
            } else if (log_value < min) {
              log_value = min;
            }
            this.$slider.slider("option", "value", log_value);
            this.readout.textContent = this.valueToString(value);
            if (this.model.get("value") !== value) {
              this.model.set("value", value, { updated_view: this });
              this.touch();
            }
          };
          /**
           * Write value to a string
           */
          FloatLogSliderView.prototype.valueToString = function (value) {
            var format = this.model.readout_formatter;
            return format(value);
          };
          /**
           * Parse value from a string
           */
          FloatLogSliderView.prototype.stringToValue = function (text) {
            return this._parse_value(text);
          };
          /**
           * this handles the entry of text into the contentEditable label first, the
           * value is checked if it contains a parseable value then it is clamped
           * within the min-max range of the slider finally, the model is updated if
           * the value is to be changed
           *
           * if any of these conditions are not met, the text is reset
           */
          FloatLogSliderView.prototype.handleTextChange = function () {
            var value = this.stringToValue(this.readout.textContent);
            var vmin = this.model.get("min");
            var vmax = this.model.get("max");
            var base = this.model.get("base");
            if (isNaN(value)) {
              this.readout.textContent = this.valueToString(
                this.model.get("value")
              );
            } else {
              value = Math.max(
                Math.min(value, Math.pow(base, vmax)),
                Math.pow(base, vmin)
              );
              if (value !== this.model.get("value")) {
                this.readout.textContent = this.valueToString(value);
                this.model.set("value", value, { updated_view: this });
                this.touch();
              } else {
                this.readout.textContent = this.valueToString(
                  this.model.get("value")
                );
              }
            }
          };
          /**
           * Called when the slider value is changing.
           */
          FloatLogSliderView.prototype.handleSliderChange = function (e, ui) {
            var base = this.model.get("base");
            var actual_value = Math.pow(
              base,
              this._validate_slide_value(ui.value)
            );
            this.readout.textContent = this.valueToString(actual_value);
            // Only persist the value while sliding if the continuous_update
            // trait is set to true.
            if (this.model.get("continuous_update")) {
              this.handleSliderChanged(e, ui);
            }
          };
          /**
           * Called when the slider value has changed.
           *
           * Calling model.set will trigger all of the other views of the
           * model to update.
           */
          FloatLogSliderView.prototype.handleSliderChanged = function (e, ui) {
            var base = this.model.get("base");
            var actual_value = Math.pow(
              base,
              this._validate_slide_value(ui.value)
            );
            this.model.set("value", actual_value, { updated_view: this });
            this.touch();
          };
          FloatLogSliderView.prototype._validate_slide_value = function (x) {
            return x;
          };
          return FloatLogSliderView;
        })(_widget_int__WEBPACK_IMPORTED_MODULE_2__.BaseIntSliderView);

        var FloatRangeSliderView = /** @class */ (function (_super) {
          __extends(FloatRangeSliderView, _super);
          function FloatRangeSliderView() {
            var _this =
              (_super !== null && _super.apply(this, arguments)) || this;
            _this._parse_value = parseFloat;
            // matches: whitespace?, float, whitespace?, (hyphen, colon, or en-dash), whitespace?, float
            _this._range_regex =
              /^\s*([+-]?(?:\d*\.?\d+|\d+\.)(?:[eE][-:]?\d+)?)\s*[-:–]\s*([+-]?(?:\d*\.?\d+|\d+\.)(?:[eE][+-]?\d+)?)/;
            return _this;
          }
          /**
           * Validate the value of the slider before sending it to the back-end
           * and applying it to the other views on the page.
           */
          FloatRangeSliderView.prototype._validate_slide_value = function (x) {
            return x;
          };
          return FloatRangeSliderView;
        })(_widget_int__WEBPACK_IMPORTED_MODULE_2__.IntRangeSliderView);

        var FloatTextModel = /** @class */ (function (_super) {
          __extends(FloatTextModel, _super);
          function FloatTextModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          FloatTextModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_1__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "FloatTextModel",
                _view_name: "FloatTextView",
                disabled: false,
                continuous_update: false,
              }
            );
          };
          return FloatTextModel;
        })(FloatModel);

        var BoundedFloatTextModel = /** @class */ (function (_super) {
          __extends(BoundedFloatTextModel, _super);
          function BoundedFloatTextModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          BoundedFloatTextModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_1__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "BoundedFloatTextModel",
                _view_name: "FloatTextView",
                disabled: false,
                continuous_update: false,
                step: 0.1,
              }
            );
          };
          return BoundedFloatTextModel;
        })(BoundedFloatModel);

        var FloatTextView = /** @class */ (function (_super) {
          __extends(FloatTextView, _super);
          function FloatTextView() {
            var _this =
              (_super !== null && _super.apply(this, arguments)) || this;
            _this._parse_value = parseFloat;
            _this._default_step = "any";
            return _this;
          }
          /**
           * Handle key press
           */
          FloatTextView.prototype.handleKeypress = function (e) {
            // Overwrite IntTextView's handleKeypress
            // which prevents decimal points.
            e.stopPropagation();
          };
          /**
           * Handle key up
           */
          FloatTextView.prototype.handleKeyUp = function (e) {
            // Overwrite IntTextView's handleKeyUp
            // which prevents decimal points.
          };
          return FloatTextView;
        })(_widget_int__WEBPACK_IMPORTED_MODULE_2__.IntTextView);

        var FloatProgressModel = /** @class */ (function (_super) {
          __extends(FloatProgressModel, _super);
          function FloatProgressModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          FloatProgressModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_1__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "FloatProgressModel",
                _view_name: "ProgressView",
                orientation: "horizontal",
                bar_style: "",
                style: null,
              }
            );
          };
          return FloatProgressModel;
        })(BoundedFloatModel);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_image.js":
      /*!********************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_image.js ***!
  \********************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ ImageModel: () => /* binding */ ImageModel,
          /* harmony export */ ImageView: () => /* binding */ ImageView,
          /* harmony export */
        });
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__
          );
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        var __assign =
          (undefined && undefined.__assign) ||
          function () {
            __assign =
              Object.assign ||
              function (t) {
                for (var s, i = 1, n = arguments.length; i < n; i++) {
                  s = arguments[i];
                  for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
                }
                return t;
              };
            return __assign.apply(this, arguments);
          };

        var ImageModel = /** @class */ (function (_super) {
          __extends(ImageModel, _super);
          function ImageModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ImageModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_2__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "ImageModel",
                _view_name: "ImageView",
                format: "png",
                width: "",
                height: "",
                value: new DataView(new ArrayBuffer(0)),
              }
            );
          };
          ImageModel.serializers = __assign(
            __assign(
              {},
              _widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreDOMWidgetModel
                .serializers
            ),
            {
              value: {
                serialize: function (value) {
                  return new DataView(value.buffer.slice(0));
                },
              },
            }
          );
          return ImageModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreDOMWidgetModel);

        var ImageView = /** @class */ (function (_super) {
          __extends(ImageView, _super);
          function ImageView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ImageView.prototype.render = function () {
            /**
             * Called when view is rendered.
             */
            _super.prototype.render.call(this);
            this.pWidget.addClass("jupyter-widgets");
            this.pWidget.addClass("widget-image");
            this.update(); // Set defaults.
          };
          ImageView.prototype.update = function () {
            /**
             * Update the contents of this view
             *
             * Called when the model is changed.  The model may have been
             * changed by another view or by a state update from the back-end.
             */
            var url;
            var format = this.model.get("format");
            var value = this.model.get("value");
            if (format !== "url") {
              var blob = new Blob([value], {
                type: "image/" + this.model.get("format"),
              });
              url = URL.createObjectURL(blob);
            } else {
              url = new TextDecoder("utf-8").decode(value.buffer);
            }
            // Clean up the old objectURL
            var oldurl = this.el.src;
            this.el.src = url;
            if (oldurl && typeof oldurl !== "string") {
              URL.revokeObjectURL(oldurl);
            }
            var width = this.model.get("width");
            if (width !== undefined && width.length > 0) {
              this.el.setAttribute("width", width);
            } else {
              this.el.removeAttribute("width");
            }
            var height = this.model.get("height");
            if (height !== undefined && height.length > 0) {
              this.el.setAttribute("height", height);
            } else {
              this.el.removeAttribute("height");
            }
            return _super.prototype.update.call(this);
          };
          ImageView.prototype.remove = function () {
            if (this.el.src) {
              URL.revokeObjectURL(this.el.src);
            }
            _super.prototype.remove.call(this);
          };
          Object.defineProperty(ImageView.prototype, "tagName", {
            /**
             * The default tag name.
             *
             * #### Notes
             * This is a read-only attribute.
             */
            get: function () {
              // We can't make this an attribute with a default value
              // since it would be set after it is needed in the
              // constructor.
              return "img";
            },
            enumerable: true,
            configurable: true,
          });
          return ImageView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.DOMWidgetView);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_int.js":
      /*!******************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_int.js ***!
  \******************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ IntModel: () => /* binding */ IntModel,
          /* harmony export */ BoundedIntModel: () =>
            /* binding */ BoundedIntModel,
          /* harmony export */ SliderStyleModel: () =>
            /* binding */ SliderStyleModel,
          /* harmony export */ IntSliderModel: () =>
            /* binding */ IntSliderModel,
          /* harmony export */ IntRangeSliderModel: () =>
            /* binding */ IntRangeSliderModel,
          /* harmony export */ BaseIntSliderView: () =>
            /* binding */ BaseIntSliderView,
          /* harmony export */ IntRangeSliderView: () =>
            /* binding */ IntRangeSliderView,
          /* harmony export */ IntSliderView: () => /* binding */ IntSliderView,
          /* harmony export */ IntTextModel: () => /* binding */ IntTextModel,
          /* harmony export */ BoundedIntTextModel: () =>
            /* binding */ BoundedIntTextModel,
          /* harmony export */ IntTextView: () => /* binding */ IntTextView,
          /* harmony export */ ProgressStyleModel: () =>
            /* binding */ ProgressStyleModel,
          /* harmony export */ IntProgressModel: () =>
            /* binding */ IntProgressModel,
          /* harmony export */ ProgressView: () => /* binding */ ProgressView,
          /* harmony export */ PlayModel: () => /* binding */ PlayModel,
          /* harmony export */ PlayView: () => /* binding */ PlayView,
          /* harmony export */
        });
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var _widget_description__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_description */ "./node_modules/@jupyter-widgets/controls/lib/widget_description.js"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_2___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_2__
          );
        /* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./utils */ "./node_modules/@jupyter-widgets/controls/lib/utils.js"
          );
        /* harmony import */ var d3_format__WEBPACK_IMPORTED_MODULE_7__ =
          __webpack_require__(
            /*! d3-format */ "./node_modules/d3-format/src/defaultLocale.js"
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        /* harmony import */ var jquery__WEBPACK_IMPORTED_MODULE_5__ =
          __webpack_require__(
            /*! jquery */ "./node_modules/jquery/dist/jquery.js"
          );
        /* harmony import */ var jquery__WEBPACK_IMPORTED_MODULE_5___default =
          /*#__PURE__*/ __webpack_require__.n(
            jquery__WEBPACK_IMPORTED_MODULE_5__
          );
        /* harmony import */ var jquery_ui_ui_widgets_slider__WEBPACK_IMPORTED_MODULE_6__ =
          __webpack_require__(
            /*! jquery-ui/ui/widgets/slider */ "./node_modules/jquery-ui/ui/widgets/slider.js"
          );
        /* harmony import */ var jquery_ui_ui_widgets_slider__WEBPACK_IMPORTED_MODULE_6___default =
          /*#__PURE__*/ __webpack_require__.n(
            jquery_ui_ui_widgets_slider__WEBPACK_IMPORTED_MODULE_6__
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        var __assign =
          (undefined && undefined.__assign) ||
          function () {
            __assign =
              Object.assign ||
              function (t) {
                for (var s, i = 1, n = arguments.length; i < n; i++) {
                  s = arguments[i];
                  for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
                }
                return t;
              };
            return __assign.apply(this, arguments);
          };

        var IntModel = /** @class */ (function (_super) {
          __extends(IntModel, _super);
          function IntModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          IntModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_4__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "IntModel",
                value: 0,
              }
            );
          };
          return IntModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDescriptionModel);

        var BoundedIntModel = /** @class */ (function (_super) {
          __extends(BoundedIntModel, _super);
          function BoundedIntModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          BoundedIntModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_4__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "BoundedIntModel",
                max: 100,
                min: 0,
              }
            );
          };
          return BoundedIntModel;
        })(IntModel);

        var SliderStyleModel = /** @class */ (function (_super) {
          __extends(SliderStyleModel, _super);
          function SliderStyleModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          SliderStyleModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              { _model_name: "SliderStyleModel" }
            );
          };
          SliderStyleModel.styleProperties = __assign(
            __assign(
              {},
              _widget_description__WEBPACK_IMPORTED_MODULE_1__
                .DescriptionStyleModel.styleProperties
            ),
            {
              handle_color: {
                selector: ".ui-slider-handle",
                attribute: "background-color",
                default: null,
              },
            }
          );
          return SliderStyleModel;
        })(
          _widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionStyleModel
        );

        var IntSliderModel = /** @class */ (function (_super) {
          __extends(IntSliderModel, _super);
          function IntSliderModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          IntSliderModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_4__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "IntSliderModel",
                _view_name: "IntSliderView",
                step: 1,
                orientation: "horizontal",
                readout: true,
                readout_format: "d",
                continuous_update: true,
                style: null,
                disabled: false,
              }
            );
          };
          IntSliderModel.prototype.initialize = function (attributes, options) {
            _super.prototype.initialize.call(this, attributes, options);
            this.on("change:readout_format", this.update_readout_format, this);
            this.update_readout_format();
          };
          IntSliderModel.prototype.update_readout_format = function () {
            this.readout_formatter = (0,
            d3_format__WEBPACK_IMPORTED_MODULE_7__.format)(
              this.get("readout_format")
            );
          };
          return IntSliderModel;
        })(BoundedIntModel);

        var IntRangeSliderModel = /** @class */ (function (_super) {
          __extends(IntRangeSliderModel, _super);
          function IntRangeSliderModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          return IntRangeSliderModel;
        })(IntSliderModel);

        var BaseIntSliderView = /** @class */ (function (_super) {
          __extends(BaseIntSliderView, _super);
          function BaseIntSliderView() {
            var _this =
              (_super !== null && _super.apply(this, arguments)) || this;
            _this._parse_value = parseInt;
            return _this;
          }
          BaseIntSliderView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-slider");
            this.el.classList.add("widget-hslider");
            (this.$slider =
              jquery__WEBPACK_IMPORTED_MODULE_5___default()("<div />"))
              .slider({
                slide: this.handleSliderChange.bind(this),
                stop: this.handleSliderChanged.bind(this),
              })
              .addClass("slider");
            // Put the slider in a container
            this.slider_container = document.createElement("div");
            this.slider_container.classList.add("slider-container");
            this.slider_container.appendChild(this.$slider[0]);
            this.el.appendChild(this.slider_container);
            this.readout = document.createElement("div");
            this.el.appendChild(this.readout);
            this.readout.classList.add("widget-readout");
            this.readout.contentEditable = "true";
            this.readout.style.display = "none";
            // Set defaults.
            this.update();
          };
          BaseIntSliderView.prototype.update = function (options) {
            /**
             * Update the contents of this view
             *
             * Called when the model is changed.  The model may have been
             * changed by another view or by a state update from the back-end.
             */
            if (options === undefined || options.updated_view !== this) {
              // JQuery slider option keys.  These keys happen to have a
              // one-to-one mapping with the corresponding keys of the model.
              var jquery_slider_keys = ["step", "disabled"];
              var that_1 = this;
              that_1.$slider.slider({});
              jquery_slider_keys.forEach(function (key) {
                var model_value = that_1.model.get(key);
                if (model_value !== undefined) {
                  that_1.$slider.slider("option", key, model_value);
                }
              });
              if (this.model.get("disabled")) {
                this.readout.contentEditable = "false";
              } else {
                this.readout.contentEditable = "true";
              }
              var max = this.model.get("max");
              var min = this.model.get("min");
              if (min <= max) {
                if (max !== undefined) {
                  this.$slider.slider("option", "max", max);
                }
                if (min !== undefined) {
                  this.$slider.slider("option", "min", min);
                }
              }
              // WORKAROUND FOR JQUERY SLIDER BUG.
              // The horizontal position of the slider handle
              // depends on the value of the slider at the time
              // of orientation change.  Before applying the new
              // workaround, we set the value to the minimum to
              // make sure that the horizontal placement of the
              // handle in the vertical slider is always
              // consistent.
              var orientation_1 = this.model.get("orientation");
              this.$slider.slider("option", "orientation", orientation_1);
              // Use the right CSS classes for vertical & horizontal sliders
              if (orientation_1 === "vertical") {
                this.el.classList.remove("widget-hslider");
                this.el.classList.add("widget-vslider");
                this.el.classList.remove("widget-inline-hbox");
                this.el.classList.add("widget-inline-vbox");
              } else {
                this.el.classList.remove("widget-vslider");
                this.el.classList.add("widget-hslider");
                this.el.classList.remove("widget-inline-vbox");
                this.el.classList.add("widget-inline-hbox");
              }
              var readout = this.model.get("readout");
              if (readout) {
                this.readout.style.display = "";
                this.displayed.then(function () {
                  if (that_1.readout_overflow()) {
                    that_1.readout.classList.add("overflow");
                  } else {
                    that_1.readout.classList.remove("overflow");
                  }
                });
              } else {
                this.readout.style.display = "none";
              }
            }
            return _super.prototype.update.call(this);
          };
          /**
           * Returns true if the readout box content overflows.
           */
          BaseIntSliderView.prototype.readout_overflow = function () {
            return this.readout.scrollWidth > this.readout.clientWidth;
          };
          BaseIntSliderView.prototype.events = function () {
            return {
              // Dictionary of events and their handlers.
              slide: "handleSliderChange",
              slidestop: "handleSliderChanged",
              "blur [contentEditable=true]": "handleTextChange",
              "keydown [contentEditable=true]": "handleKeyDown",
            };
          };
          BaseIntSliderView.prototype.handleKeyDown = function (e) {
            if (e.keyCode === 13) {
              /* keyboard keycodes `enter` */
              e.preventDefault();
              this.handleTextChange();
            }
          };
          /**
           * Validate the value of the slider before sending it to the back-end
           * and applying it to the other views on the page.
           */
          BaseIntSliderView.prototype._validate_slide_value = function (x) {
            return Math.floor(x);
          };
          return BaseIntSliderView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var IntRangeSliderView = /** @class */ (function (_super) {
          __extends(IntRangeSliderView, _super);
          function IntRangeSliderView() {
            var _this =
              (_super !== null && _super.apply(this, arguments)) || this;
            // range numbers can be separated by a hyphen, colon, or an en-dash
            _this._range_regex = /^\s*([+-]?\d+)\s*[-:–]\s*([+-]?\d+)/;
            return _this;
          }
          IntRangeSliderView.prototype.update = function (options) {
            _super.prototype.update.call(this, options);
            this.$slider.slider("option", "range", true);
            // values for the range case are validated python-side in
            // _Bounded{Int,Float}RangeWidget._validate
            var value = this.model.get("value");
            this.$slider.slider("option", "values", value.slice());
            this.readout.textContent = this.valueToString(value);
            if (this.model.get("value") !== value) {
              this.model.set("value", value, { updated_view: this });
              this.touch();
            }
          };
          /**
           * Write value to a string
           */
          IntRangeSliderView.prototype.valueToString = function (value) {
            var format = this.model.readout_formatter;
            return value
              .map(function (v) {
                return format(v);
              })
              .join(" – ");
          };
          /**
           * Parse value from a string
           */
          IntRangeSliderView.prototype.stringToValue = function (text) {
            // ranges can be expressed either 'val-val' or 'val:val' (+spaces)
            var match = this._range_regex.exec(text);
            if (match) {
              return [this._parse_value(match[1]), this._parse_value(match[2])];
            } else {
              return null;
            }
          };
          /**
           * this handles the entry of text into the contentEditable label first, the
           * value is checked if it contains a parseable value then it is clamped
           * within the min-max range of the slider finally, the model is updated if
           * the value is to be changed
           *
           * if any of these conditions are not met, the text is reset
           */
          IntRangeSliderView.prototype.handleTextChange = function () {
            var value = this.stringToValue(this.readout.textContent);
            var vmin = this.model.get("min");
            var vmax = this.model.get("max");
            // reject input where NaN or lower > upper
            if (
              value === null ||
              isNaN(value[0]) ||
              isNaN(value[1]) ||
              value[0] > value[1]
            ) {
              this.readout.textContent = this.valueToString(
                this.model.get("value")
              );
            } else {
              // clamp to range
              value = [
                Math.max(Math.min(value[0], vmax), vmin),
                Math.max(Math.min(value[1], vmax), vmin),
              ];
              if (
                value[0] !== this.model.get("value")[0] ||
                value[1] !== this.model.get("value")[1]
              ) {
                this.readout.textContent = this.valueToString(value);
                this.model.set("value", value, { updated_view: this });
                this.touch();
              } else {
                this.readout.textContent = this.valueToString(
                  this.model.get("value")
                );
              }
            }
          };
          /**
           * Called when the slider value is changing.
           */
          IntRangeSliderView.prototype.handleSliderChange = function (e, ui) {
            var actual_value = ui.values.map(this._validate_slide_value);
            this.readout.textContent = this.valueToString(actual_value);
            // Only persist the value while sliding if the continuous_update
            // trait is set to true.
            if (this.model.get("continuous_update")) {
              this.handleSliderChanged(e, ui);
            }
          };
          /**
           * Called when the slider value has changed.
           *
           * Calling model.set will trigger all of the other views of the
           * model to update.
           */
          IntRangeSliderView.prototype.handleSliderChanged = function (e, ui) {
            var actual_value = ui.values.map(this._validate_slide_value);
            this.model.set("value", actual_value, { updated_view: this });
            this.touch();
          };
          return IntRangeSliderView;
        })(BaseIntSliderView);

        var IntSliderView = /** @class */ (function (_super) {
          __extends(IntSliderView, _super);
          function IntSliderView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          IntSliderView.prototype.update = function (options) {
            _super.prototype.update.call(this, options);
            var min = this.model.get("min");
            var max = this.model.get("max");
            var value = this.model.get("value");
            if (value > max) {
              value = max;
            } else if (value < min) {
              value = min;
            }
            this.$slider.slider("option", "value", value);
            this.readout.textContent = this.valueToString(value);
            if (this.model.get("value") !== value) {
              this.model.set("value", value, { updated_view: this });
              this.touch();
            }
          };
          /**
           * Write value to a string
           */
          IntSliderView.prototype.valueToString = function (value) {
            var format = this.model.readout_formatter;
            return format(value);
          };
          /**
           * Parse value from a string
           */
          IntSliderView.prototype.stringToValue = function (text) {
            return this._parse_value(text);
          };
          /**
           * this handles the entry of text into the contentEditable label first, the
           * value is checked if it contains a parseable value then it is clamped
           * within the min-max range of the slider finally, the model is updated if
           * the value is to be changed
           *
           * if any of these conditions are not met, the text is reset
           */
          IntSliderView.prototype.handleTextChange = function () {
            var value = this.stringToValue(this.readout.textContent);
            var vmin = this.model.get("min");
            var vmax = this.model.get("max");
            if (isNaN(value)) {
              this.readout.textContent = this.valueToString(
                this.model.get("value")
              );
            } else {
              value = Math.max(Math.min(value, vmax), vmin);
              if (value !== this.model.get("value")) {
                this.readout.textContent = this.valueToString(value);
                this.model.set("value", value, { updated_view: this });
                this.touch();
              } else {
                this.readout.textContent = this.valueToString(
                  this.model.get("value")
                );
              }
            }
          };
          /**
           * Called when the slider value is changing.
           */
          IntSliderView.prototype.handleSliderChange = function (e, ui) {
            var actual_value = this._validate_slide_value(ui.value);
            this.readout.textContent = this.valueToString(actual_value);
            // Only persist the value while sliding if the continuous_update
            // trait is set to true.
            if (this.model.get("continuous_update")) {
              this.handleSliderChanged(e, ui);
            }
          };
          /**
           * Called when the slider value has changed.
           *
           * Calling model.set will trigger all of the other views of the
           * model to update.
           */
          IntSliderView.prototype.handleSliderChanged = function (e, ui) {
            var actual_value = this._validate_slide_value(ui.value);
            this.model.set("value", actual_value, { updated_view: this });
            this.touch();
          };
          return IntSliderView;
        })(BaseIntSliderView);

        var IntTextModel = /** @class */ (function (_super) {
          __extends(IntTextModel, _super);
          function IntTextModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          IntTextModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_4__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "IntTextModel",
                _view_name: "IntTextView",
                disabled: false,
                continuous_update: false,
              }
            );
          };
          return IntTextModel;
        })(IntModel);

        var BoundedIntTextModel = /** @class */ (function (_super) {
          __extends(BoundedIntTextModel, _super);
          function BoundedIntTextModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          BoundedIntTextModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_4__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "BoundedIntTextModel",
                _view_name: "IntTextView",
                disabled: false,
                continuous_update: false,
                step: 1,
              }
            );
          };
          return BoundedIntTextModel;
        })(BoundedIntModel);

        var IntTextView = /** @class */ (function (_super) {
          __extends(IntTextView, _super);
          function IntTextView() {
            var _this =
              (_super !== null && _super.apply(this, arguments)) || this;
            _this._parse_value = parseInt;
            _this._default_step = "1";
            return _this;
          }
          IntTextView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-text");
            this.textbox = document.createElement("input");
            this.textbox.type = "number";
            this.textbox.required = true;
            this.textbox.id = this.label.htmlFor = (0,
            _utils__WEBPACK_IMPORTED_MODULE_3__.uuid)();
            this.el.appendChild(this.textbox);
            this.update(); // Set defaults.
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed.  The model may have been
           * changed by another view or by a state update from the back-end.
           */
          IntTextView.prototype.update = function (options) {
            if (options === undefined || options.updated_view !== this) {
              var value = this.model.get("value");
              if (this._parse_value(this.textbox.value) !== value) {
                this.textbox.value = value.toString();
              }
              if (this.model.get("min") !== undefined) {
                this.textbox.min = this.model.get("min");
              }
              if (this.model.get("max") !== undefined) {
                this.textbox.max = this.model.get("max");
              }
              if (
                this.model.get("step") !== undefined &&
                this.model.get("step") !== null
              ) {
                this.textbox.step = this.model.get("step");
              } else {
                this.textbox.step = this._default_step;
              }
              this.textbox.disabled = this.model.get("disabled");
            }
            return _super.prototype.update.call(this);
          };
          IntTextView.prototype.events = function () {
            return {
              "keydown input": "handleKeyDown",
              "keypress input": "handleKeypress",
              "keyup input": "handleKeyUp",
              "input input": "handleChanging",
              "change input": "handleChanged",
            };
          };
          /**
           * Handle key down
           *
           * Stop propagation so the event isn't sent to the application.
           */
          IntTextView.prototype.handleKeyDown = function (e) {
            e.stopPropagation();
          };
          /**
           * Handles key press
           */
          IntTextView.prototype.handleKeypress = function (e) {
            if (/[e,.\s]/.test(String.fromCharCode(e.keyCode))) {
              e.preventDefault();
            }
          };
          /**
           * Handle key up
           */
          IntTextView.prototype.handleKeyUp = function (e) {
            if (e.altKey || e.ctrlKey) {
              return;
            }
            var target = e.target;
            /* remove invalid characters */
            var value = target.value;
            value = value.replace(/[e,.\s]/g, "");
            if (value.length >= 1) {
              var subvalue = value.substr(1);
              value = value[0] + subvalue.replace(/[+-]/g, "");
            }
            if (target.value != value) {
              e.preventDefault();
              target.value = value;
            }
          };
          /**
           * Call the submit handler if continuous update is true and we are not
           * obviously incomplete.
           */
          IntTextView.prototype.handleChanging = function (e) {
            var target = e.target;
            var trimmed = target.value.trim();
            if (
              trimmed === "" ||
              ["-", "-.", ".", "+.", "+"].indexOf(trimmed) >= 0
            ) {
              // incomplete number
              return;
            }
            if (this.model.get("continuous_update")) {
              this.handleChanged(e);
            }
          };
          /**
           * Applies validated input.
           */
          IntTextView.prototype.handleChanged = function (e) {
            var target = e.target;
            var numericalValue = this._parse_value(target.value);
            // If parse failed, reset value to value stored in model.
            if (isNaN(numericalValue)) {
              target.value = this.model.get("value");
            } else {
              // Handle both the unbounded and bounded case by
              // checking to see if the max/min properties are defined
              var boundedValue = numericalValue;
              if (this.model.get("max") !== undefined) {
                boundedValue = Math.min(this.model.get("max"), boundedValue);
              }
              if (this.model.get("min") !== undefined) {
                boundedValue = Math.max(this.model.get("min"), boundedValue);
              }
              if (boundedValue !== numericalValue) {
                target.value = boundedValue;
                numericalValue = boundedValue;
              }
              // Apply the value if it has changed.
              if (numericalValue !== this.model.get("value")) {
                this.model.set("value", numericalValue, { updated_view: this });
                this.touch();
              }
            }
          };
          return IntTextView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var ProgressStyleModel = /** @class */ (function (_super) {
          __extends(ProgressStyleModel, _super);
          function ProgressStyleModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ProgressStyleModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              { _model_name: "ProgressStyleModel" }
            );
          };
          ProgressStyleModel.styleProperties = __assign(
            __assign(
              {},
              _widget_description__WEBPACK_IMPORTED_MODULE_1__
                .DescriptionStyleModel.styleProperties
            ),
            {
              bar_color: {
                selector: ".progress-bar",
                attribute: "background-color",
                default: null,
              },
            }
          );
          return ProgressStyleModel;
        })(
          _widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionStyleModel
        );

        var IntProgressModel = /** @class */ (function (_super) {
          __extends(IntProgressModel, _super);
          function IntProgressModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          IntProgressModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_4__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "IntProgressModel",
                _view_name: "ProgressView",
                orientation: "horizontal",
                bar_style: "",
                style: null,
              }
            );
          };
          return IntProgressModel;
        })(BoundedIntModel);

        var ProgressView = /** @class */ (function (_super) {
          __extends(ProgressView, _super);
          function ProgressView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ProgressView.prototype.initialize = function (parameters) {
            _super.prototype.initialize.call(this, parameters);
            this.listenTo(
              this.model,
              "change:bar_style",
              this.update_bar_style
            );
            this.pWidget.addClass("jupyter-widgets");
          };
          ProgressView.prototype.render = function () {
            _super.prototype.render.call(this);
            var orientation = this.model.get("orientation");
            var className =
              orientation === "horizontal"
                ? "widget-hprogress"
                : "widget-vprogress";
            this.el.classList.add(className);
            this.progress = document.createElement("div");
            this.progress.classList.add("progress");
            this.progress.style.position = "relative";
            this.el.appendChild(this.progress);
            this.bar = document.createElement("div");
            this.bar.classList.add("progress-bar");
            this.bar.style.position = "absolute";
            this.bar.style.bottom = "0px";
            this.bar.style.left = "0px";
            this.progress.appendChild(this.bar);
            // Set defaults.
            this.update();
            this.set_bar_style();
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed.  The model may have been
           * changed by another view or by a state update from the back-end.
           */
          ProgressView.prototype.update = function () {
            var value = this.model.get("value");
            var max = this.model.get("max");
            var min = this.model.get("min");
            var orientation = this.model.get("orientation");
            var percent = (100.0 * (value - min)) / (max - min);
            if (orientation === "horizontal") {
              this.el.classList.remove("widget-inline-vbox");
              this.el.classList.remove("widget-vprogress");
              this.el.classList.add("widget-inline-hbox");
              this.el.classList.add("widget-hprogress");
              this.bar.style.width = percent + "%";
              this.bar.style.height = "100%";
            } else {
              this.el.classList.remove("widget-inline-hbox");
              this.el.classList.remove("widget-hprogress");
              this.el.classList.add("widget-inline-vbox");
              this.el.classList.add("widget-vprogress");
              this.bar.style.width = "100%";
              this.bar.style.height = percent + "%";
            }
            return _super.prototype.update.call(this);
          };
          ProgressView.prototype.update_bar_style = function () {
            this.update_mapped_classes(
              ProgressView.class_map,
              "bar_style",
              this.bar
            );
          };
          ProgressView.prototype.set_bar_style = function () {
            this.set_mapped_classes(
              ProgressView.class_map,
              "bar_style",
              this.bar
            );
          };
          ProgressView.class_map = {
            success: ["progress-bar-success"],
            info: ["progress-bar-info"],
            warning: ["progress-bar-warning"],
            danger: ["progress-bar-danger"],
          };
          return ProgressView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var PlayModel = /** @class */ (function (_super) {
          __extends(PlayModel, _super);
          function PlayModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          PlayModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_4__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "PlayModel",
                _view_name: "PlayView",
                _playing: false,
                _repeat: false,
                show_repeat: true,
                interval: 100,
                step: 1,
                disabled: false,
              }
            );
          };
          PlayModel.prototype.initialize = function (attributes, options) {
            _super.prototype.initialize.call(this, attributes, options);
          };
          PlayModel.prototype.loop = function () {
            if (this.get("_playing")) {
              var next_value = this.get("value") + this.get("step");
              if (next_value <= this.get("max")) {
                this.set("value", next_value);
                this.schedule_next();
              } else {
                if (this.get("_repeat")) {
                  this.set("value", this.get("min"));
                  this.schedule_next();
                } else {
                  this.set("_playing", false);
                }
              }
              this.save_changes();
            }
          };
          PlayModel.prototype.schedule_next = function () {
            window.setTimeout(this.loop.bind(this), this.get("interval"));
          };
          PlayModel.prototype.stop = function () {
            this.set("_playing", false);
            this.set("value", this.get("min"));
            this.save_changes();
          };
          PlayModel.prototype.pause = function () {
            this.set("_playing", false);
            this.save_changes();
          };
          PlayModel.prototype.play = function () {
            this.set("_playing", true);
            if (this.get("value") == this.get("max")) {
              // if the value is at the end, reset if first, and then schedule the next
              this.set("value", this.get("min"));
              this.schedule_next();
              this.save_changes();
            } else {
              // otherwise directly start with the next value
              // loop will call save_changes in this case
              this.loop();
            }
          };
          PlayModel.prototype.repeat = function () {
            this.set("_repeat", !this.get("_repeat"));
            this.save_changes();
          };
          return PlayModel;
        })(BoundedIntModel);

        var PlayView = /** @class */ (function (_super) {
          __extends(PlayView, _super);
          function PlayView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          PlayView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-play");
            this.playButton = document.createElement("button");
            this.pauseButton = document.createElement("button");
            this.stopButton = document.createElement("button");
            this.repeatButton = document.createElement("button");
            this.playButton.className = "jupyter-button";
            this.pauseButton.className = "jupyter-button";
            this.stopButton.className = "jupyter-button";
            this.repeatButton.className = "jupyter-button";
            this.el.appendChild(this.playButton); // Toggle button with playing
            this.el.appendChild(this.pauseButton); // Disable if not playing
            this.el.appendChild(this.stopButton); // Disable if not playing
            this.el.appendChild(this.repeatButton); // Always enabled, but may be hidden
            var playIcon = document.createElement("i");
            playIcon.className = "fa fa-play";
            this.playButton.appendChild(playIcon);
            var pauseIcon = document.createElement("i");
            pauseIcon.className = "fa fa-pause";
            this.pauseButton.appendChild(pauseIcon);
            var stopIcon = document.createElement("i");
            stopIcon.className = "fa fa-stop";
            this.stopButton.appendChild(stopIcon);
            var repeatIcon = document.createElement("i");
            repeatIcon.className = "fa fa-retweet";
            this.repeatButton.appendChild(repeatIcon);
            this.playButton.onclick = this.model.play.bind(this.model);
            this.pauseButton.onclick = this.model.pause.bind(this.model);
            this.stopButton.onclick = this.model.stop.bind(this.model);
            this.repeatButton.onclick = this.model.repeat.bind(this.model);
            this.listenTo(this.model, "change:_playing", this.update_playing);
            this.listenTo(this.model, "change:_repeat", this.update_repeat);
            this.listenTo(this.model, "change:show_repeat", this.update_repeat);
            this.update_playing();
            this.update_repeat();
            this.update();
          };
          PlayView.prototype.update = function () {
            var disabled = this.model.get("disabled");
            this.playButton.disabled = disabled;
            this.pauseButton.disabled = disabled;
            this.stopButton.disabled = disabled;
            this.repeatButton.disabled = disabled;
            this.update_playing();
          };
          PlayView.prototype.update_playing = function () {
            var playing = this.model.get("_playing");
            var disabled = this.model.get("disabled");
            if (playing) {
              if (!disabled) {
                this.pauseButton.disabled = false;
              }
              this.playButton.classList.add("mod-active");
            } else {
              if (!disabled) {
                this.pauseButton.disabled = true;
              }
              this.playButton.classList.remove("mod-active");
            }
          };
          PlayView.prototype.update_repeat = function () {
            var repeat = this.model.get("_repeat");
            this.repeatButton.style.display = this.model.get("show_repeat")
              ? this.playButton.style.display
              : "none";
            if (repeat) {
              this.repeatButton.classList.add("mod-active");
            } else {
              this.repeatButton.classList.remove("mod-active");
            }
          };
          return PlayView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_2__.DOMWidgetView);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_link.js":
      /*!*******************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_link.js ***!
  \*******************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ DirectionalLinkModel: () =>
            /* binding */ DirectionalLinkModel,
          /* harmony export */ LinkModel: () => /* binding */ LinkModel,
          /* harmony export */
        });
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__
          );
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        var __assign =
          (undefined && undefined.__assign) ||
          function () {
            __assign =
              Object.assign ||
              function (t) {
                for (var s, i = 1, n = arguments.length; i < n; i++) {
                  s = arguments[i];
                  for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
                }
                return t;
              };
            return __assign.apply(this, arguments);
          };

        var DirectionalLinkModel = /** @class */ (function (_super) {
          __extends(DirectionalLinkModel, _super);
          function DirectionalLinkModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          DirectionalLinkModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_2__.extend(
              _super.prototype.defaults.call(this),
              {
                target: undefined,
                source: undefined,
                _model_name: "DirectionalLinkModel",
              }
            );
          };
          DirectionalLinkModel.prototype.initialize = function (
            attributes,
            options
          ) {
            _super.prototype.initialize.call(this, attributes, options);
            this.on("change", this.updateBindings, this);
            this.updateBindings();
          };
          DirectionalLinkModel.prototype.updateValue = function (
            sourceModel,
            sourceAttr,
            targetModel,
            targetAttr
          ) {
            if (this._updating) {
              return;
            }
            this._updating = true;
            try {
              if (targetModel) {
                targetModel.set(targetAttr, sourceModel.get(sourceAttr));
                targetModel.save_changes();
              }
            } finally {
              this._updating = false;
            }
          };
          DirectionalLinkModel.prototype.updateBindings = function () {
            var _a, _b;
            var _this = this;
            this.cleanup();
            (_a = this.get("source") || [null, null]),
              (this.sourceModel = _a[0]),
              (this.sourceAttr = _a[1]);
            (_b = this.get("target") || [null, null]),
              (this.targetModel = _b[0]),
              (this.targetAttr = _b[1]);
            if (this.sourceModel) {
              this.listenTo(
                this.sourceModel,
                "change:" + this.sourceAttr,
                function () {
                  _this.updateValue(
                    _this.sourceModel,
                    _this.sourceAttr,
                    _this.targetModel,
                    _this.targetAttr
                  );
                }
              );
              this.updateValue(
                this.sourceModel,
                this.sourceAttr,
                this.targetModel,
                this.targetAttr
              );
              this.listenToOnce(this.sourceModel, "destroy", this.cleanup);
            }
            if (this.targetModel) {
              this.listenToOnce(this.targetModel, "destroy", this.cleanup);
            }
          };
          DirectionalLinkModel.prototype.cleanup = function () {
            // Stop listening to 'change' and 'destroy' events of the source and target
            if (this.sourceModel) {
              this.stopListening(
                this.sourceModel,
                "change:" + this.sourceAttr,
                null
              );
              this.stopListening(this.sourceModel, "destroy", null);
            }
            if (this.targetModel) {
              this.stopListening(this.targetModel, "destroy", null);
            }
          };
          DirectionalLinkModel.serializers = __assign(
            __assign(
              {},
              _widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreWidgetModel
                .serializers
            ),
            {
              target: {
                deserialize:
                  _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.unpack_models,
              },
              source: {
                deserialize:
                  _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.unpack_models,
              },
            }
          );
          return DirectionalLinkModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreWidgetModel);

        var LinkModel = /** @class */ (function (_super) {
          __extends(LinkModel, _super);
          function LinkModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          LinkModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_2__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "LinkModel",
              }
            );
          };
          LinkModel.prototype.updateBindings = function () {
            var _this = this;
            _super.prototype.updateBindings.call(this);
            if (this.targetModel) {
              this.listenTo(
                this.targetModel,
                "change:" + this.targetAttr,
                function () {
                  _this.updateValue(
                    _this.targetModel,
                    _this.targetAttr,
                    _this.sourceModel,
                    _this.sourceAttr
                  );
                }
              );
            }
          };
          LinkModel.prototype.cleanup = function () {
            _super.prototype.cleanup.call(this);
            if (this.targetModel) {
              this.stopListening(
                this.targetModel,
                "change:" + this.targetAttr,
                null
              );
            }
          };
          return LinkModel;
        })(DirectionalLinkModel);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_selection.js":
      /*!************************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_selection.js ***!
  \************************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ SelectionModel: () =>
            /* binding */ SelectionModel,
          /* harmony export */ DropdownModel: () => /* binding */ DropdownModel,
          /* harmony export */ DropdownView: () => /* binding */ DropdownView,
          /* harmony export */ SelectModel: () => /* binding */ SelectModel,
          /* harmony export */ SelectView: () => /* binding */ SelectView,
          /* harmony export */ RadioButtonsModel: () =>
            /* binding */ RadioButtonsModel,
          /* harmony export */ RadioButtonsView: () =>
            /* binding */ RadioButtonsView,
          /* harmony export */ ToggleButtonsStyleModel: () =>
            /* binding */ ToggleButtonsStyleModel,
          /* harmony export */ ToggleButtonsModel: () =>
            /* binding */ ToggleButtonsModel,
          /* harmony export */ ToggleButtonsView: () =>
            /* binding */ ToggleButtonsView,
          /* harmony export */ SelectionSliderModel: () =>
            /* binding */ SelectionSliderModel,
          /* harmony export */ SelectionSliderView: () =>
            /* binding */ SelectionSliderView,
          /* harmony export */ MultipleSelectionModel: () =>
            /* binding */ MultipleSelectionModel,
          /* harmony export */ SelectMultipleModel: () =>
            /* binding */ SelectMultipleModel,
          /* harmony export */ SelectMultipleView: () =>
            /* binding */ SelectMultipleView,
          /* harmony export */ SelectionRangeSliderModel: () =>
            /* binding */ SelectionRangeSliderModel,
          /* harmony export */ SelectionRangeSliderView: () =>
            /* binding */ SelectionRangeSliderView,
          /* harmony export */
        });
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var _widget_description__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_description */ "./node_modules/@jupyter-widgets/controls/lib/widget_description.js"
          );
        /* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./utils */ "./node_modules/@jupyter-widgets/controls/lib/utils.js"
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        /* harmony import */ var jquery__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! jquery */ "./node_modules/jquery/dist/jquery.js"
          );
        /* harmony import */ var jquery__WEBPACK_IMPORTED_MODULE_4___default =
          /*#__PURE__*/ __webpack_require__.n(
            jquery__WEBPACK_IMPORTED_MODULE_4__
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        var __assign =
          (undefined && undefined.__assign) ||
          function () {
            __assign =
              Object.assign ||
              function (t) {
                for (var s, i = 1, n = arguments.length; i < n; i++) {
                  s = arguments[i];
                  for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
                }
                return t;
              };
            return __assign.apply(this, arguments);
          };

        var SelectionModel = /** @class */ (function (_super) {
          __extends(SelectionModel, _super);
          function SelectionModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          SelectionModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              {
                _model_name: "SelectionModel",
                index: "",
                _options_labels: [],
                disabled: false,
              }
            );
          };
          return SelectionModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDescriptionModel);

        var DropdownModel = /** @class */ (function (_super) {
          __extends(DropdownModel, _super);
          function DropdownModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          DropdownModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              {
                _model_name: "DropdownModel",
                _view_name: "DropdownView",
                button_style: "",
              }
            );
          };
          return DropdownModel;
        })(SelectionModel);

        // TODO: Make a phosphor dropdown control, wrapped in DropdownView. Also, fix
        // bugs in keyboard handling. See
        // https://github.com/jupyter-widgets/ipywidgets/issues/1055 and
        // https://github.com/jupyter-widgets/ipywidgets/issues/1049
        // For now, we subclass SelectView to provide DropdownView
        // For the old code, see commit f68bfbc566f3a78a8f3350b438db8ed523ce3642
        var DropdownView = /** @class */ (function (_super) {
          __extends(DropdownView, _super);
          function DropdownView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Public constructor.
           */
          DropdownView.prototype.initialize = function (parameters) {
            var _this = this;
            _super.prototype.initialize.call(this, parameters);
            this.listenTo(this.model, "change:_options_labels", function () {
              return _this._updateOptions();
            });
          };
          /**
           * Called when view is rendered.
           */
          DropdownView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-dropdown");
            this.listbox = document.createElement("select");
            this.listbox.id = this.label.htmlFor = (0,
            _utils__WEBPACK_IMPORTED_MODULE_2__.uuid)();
            this.el.appendChild(this.listbox);
            this._updateOptions();
            this.update();
          };
          /**
           * Update the contents of this view
           */
          DropdownView.prototype.update = function () {
            // Disable listbox if needed
            this.listbox.disabled = this.model.get("disabled");
            // Select the correct element
            var index = this.model.get("index");
            this.listbox.selectedIndex = index === null ? -1 : index;
            return _super.prototype.update.call(this);
          };
          DropdownView.prototype._updateOptions = function () {
            this.listbox.textContent = "";
            var items = this.model.get("_options_labels");
            for (var i = 0; i < items.length; i++) {
              var item = items[i];
              var option = document.createElement("option");
              option.textContent = item.replace(/ /g, "\xa0"); // space -> &nbsp;
              option.setAttribute("data-value", encodeURIComponent(item));
              option.value = item;
              this.listbox.appendChild(option);
            }
          };
          DropdownView.prototype.events = function () {
            return {
              "change select": "_handle_change",
            };
          };
          /**
           * Handle when a new value is selected.
           */
          DropdownView.prototype._handle_change = function () {
            this.model.set(
              "index",
              this.listbox.selectedIndex === -1
                ? null
                : this.listbox.selectedIndex
            );
            this.touch();
          };
          return DropdownView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var SelectModel = /** @class */ (function (_super) {
          __extends(SelectModel, _super);
          function SelectModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          SelectModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              { _model_name: "SelectModel", _view_name: "SelectView", rows: 5 }
            );
          };
          return SelectModel;
        })(SelectionModel);

        var SelectView = /** @class */ (function (_super) {
          __extends(SelectView, _super);
          function SelectView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Public constructor.
           */
          SelectView.prototype.initialize = function (parameters) {
            var _this = this;
            _super.prototype.initialize.call(this, parameters);
            this.listenTo(this.model, "change:_options_labels", function () {
              return _this._updateOptions();
            });
            this.listenTo(
              this.model,
              "change:index",
              function (model, value, options) {
                return _this.updateSelection(options);
              }
            );
            // Create listbox here so that subclasses can modify it before it is populated in render()
            this.listbox = document.createElement("select");
          };
          /**
           * Called when view is rendered.
           */
          SelectView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-select");
            this.listbox.id = this.label.htmlFor = (0,
            _utils__WEBPACK_IMPORTED_MODULE_2__.uuid)();
            this.el.appendChild(this.listbox);
            this._updateOptions();
            this.update();
            this.updateSelection();
          };
          /**
           * Update the contents of this view
           */
          SelectView.prototype.update = function () {
            _super.prototype.update.call(this);
            this.listbox.disabled = this.model.get("disabled");
            var rows = this.model.get("rows");
            if (rows === null) {
              rows = "";
            }
            this.listbox.setAttribute("size", rows);
          };
          SelectView.prototype.updateSelection = function (options) {
            if (options === void 0) {
              options = {};
            }
            if (options.updated_view === this) {
              return;
            }
            var index = this.model.get("index");
            this.listbox.selectedIndex = index === null ? -1 : index;
          };
          SelectView.prototype._updateOptions = function () {
            this.listbox.textContent = "";
            var items = this.model.get("_options_labels");
            for (var i = 0; i < items.length; i++) {
              var item = items[i];
              var option = document.createElement("option");
              option.textContent = item.replace(/ /g, "\xa0"); // space -> &nbsp;
              option.setAttribute("data-value", encodeURIComponent(item));
              option.value = item;
              this.listbox.appendChild(option);
            }
          };
          SelectView.prototype.events = function () {
            return {
              "change select": "_handle_change",
            };
          };
          /**
           * Handle when a new value is selected.
           */
          SelectView.prototype._handle_change = function () {
            this.model.set("index", this.listbox.selectedIndex, {
              updated_view: this,
            });
            this.touch();
          };
          return SelectView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var RadioButtonsModel = /** @class */ (function (_super) {
          __extends(RadioButtonsModel, _super);
          function RadioButtonsModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          RadioButtonsModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              {
                _model_name: "RadioButtonsModel",
                _view_name: "RadioButtonsView",
                tooltips: [],
                icons: [],
                button_style: "",
              }
            );
          };
          return RadioButtonsModel;
        })(SelectionModel);

        var RadioButtonsView = /** @class */ (function (_super) {
          __extends(RadioButtonsView, _super);
          function RadioButtonsView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Called when view is rendered.
           */
          RadioButtonsView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-radio");
            this.container = document.createElement("div");
            this.el.appendChild(this.container);
            this.container.classList.add("widget-radio-box");
            this.update();
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed.  The model may have been
           * changed by another view or by a state update from the back-end.
           */
          RadioButtonsView.prototype.update = function (options) {
            var view = this;
            var items = this.model.get("_options_labels");
            var radios = underscore__WEBPACK_IMPORTED_MODULE_3__.pluck(
              this.container.querySelectorAll('input[type="radio"]'),
              "value"
            );
            var stale = items.length != radios.length;
            if (!stale) {
              for (var i = 0, len = items.length; i < len; ++i) {
                if (radios[i] !== items[i]) {
                  stale = true;
                  break;
                }
              }
            }
            if (
              stale &&
              (options === undefined || options.updated_view !== this)
            ) {
              // Add items to the DOM.
              this.container.textContent = "";
              items.forEach(function (item, index) {
                var label = document.createElement("label");
                label.textContent = item;
                view.container.appendChild(label);
                var radio = document.createElement("input");
                radio.setAttribute("type", "radio");
                radio.value = index.toString();
                radio.setAttribute("data-value", encodeURIComponent(item));
                label.appendChild(radio);
              });
            }
            items.forEach(function (item, index) {
              var item_query =
                'input[data-value="' + encodeURIComponent(item) + '"]';
              var radio = view.container.querySelectorAll(item_query);
              if (radio.length > 0) {
                var radio_el = radio[0];
                radio_el.checked = view.model.get("index") === index;
                radio_el.disabled = view.model.get("disabled");
              }
            });
            // Schedule adjustPadding asynchronously to
            // allow dom elements to be created properly
            setTimeout(this.adjustPadding, 0, this);
            return _super.prototype.update.call(this, options);
          };
          /**
           * Adjust Padding to Multiple of Line Height
           *
           * Adjust margins so that the overall height
           * is a multiple of a single line height.
           *
           * This widget needs it because radio options
           * are spaced tighter than individual widgets
           * yet we would like the full widget line up properly
           * when displayed side-by-side with other widgets.
           */
          RadioButtonsView.prototype.adjustPadding = function (e) {
            // Vertical margins on a widget
            var elStyles = window.getComputedStyle(e.el);
            var margins =
              parseInt(elStyles.marginTop, 10) +
              parseInt(elStyles.marginBottom, 10);
            // Total spaces taken by a single-line widget
            var lineHeight = e.label.offsetHeight + margins;
            // Current adjustment value on this widget
            var cStyles = window.getComputedStyle(e.container);
            var containerMargin = parseInt(cStyles.marginBottom);
            // How far we are off from a multiple of single windget lines
            var diff =
              (e.el.offsetHeight + margins - containerMargin) % lineHeight;
            // Apply the new adjustment
            var extraMargin = diff == 0 ? 0 : lineHeight - diff;
            e.container.style.marginBottom = extraMargin + "px";
          };
          RadioButtonsView.prototype.events = function () {
            return {
              'click input[type="radio"]': "_handle_click",
            };
          };
          /**
           * Handle when a value is clicked.
           *
           * Calling model.set will trigger all of the other views of the
           * model to update.
           */
          RadioButtonsView.prototype._handle_click = function (event) {
            var target = event.target;
            this.model.set("index", parseInt(target.value), {
              updated_view: this,
            });
            this.touch();
          };
          return RadioButtonsView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var ToggleButtonsStyleModel = /** @class */ (function (_super) {
          __extends(ToggleButtonsStyleModel, _super);
          function ToggleButtonsStyleModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ToggleButtonsStyleModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "ToggleButtonsStyleModel",
              }
            );
          };
          ToggleButtonsStyleModel.styleProperties = __assign(
            __assign(
              {},
              _widget_description__WEBPACK_IMPORTED_MODULE_1__
                .DescriptionStyleModel.styleProperties
            ),
            {
              button_width: {
                selector: ".widget-toggle-button",
                attribute: "width",
                default: null,
              },
              font_weight: {
                selector: ".widget-toggle-button",
                attribute: "font-weight",
                default: "",
              },
            }
          );
          return ToggleButtonsStyleModel;
        })(
          _widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionStyleModel
        );

        var ToggleButtonsModel = /** @class */ (function (_super) {
          __extends(ToggleButtonsModel, _super);
          function ToggleButtonsModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ToggleButtonsModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              {
                _model_name: "ToggleButtonsModel",
                _view_name: "ToggleButtonsView",
              }
            );
          };
          return ToggleButtonsModel;
        })(SelectionModel);

        var ToggleButtonsView = /** @class */ (function (_super) {
          __extends(ToggleButtonsView, _super);
          function ToggleButtonsView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ToggleButtonsView.prototype.initialize = function (options) {
            this._css_state = {};
            _super.prototype.initialize.call(this, options);
            this.listenTo(
              this.model,
              "change:button_style",
              this.update_button_style
            );
          };
          /**
           * Called when view is rendered.
           */
          ToggleButtonsView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-toggle-buttons");
            this.buttongroup = document.createElement("div");
            this.el.appendChild(this.buttongroup);
            this.update();
            this.set_button_style();
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed.  The model may have been
           * changed by another view or by a state update from the back-end.
           */
          ToggleButtonsView.prototype.update = function (options) {
            var view = this;
            var items = this.model.get("_options_labels");
            var icons = this.model.get("icons") || [];
            var previous_icons = this.model.previous("icons") || [];
            var previous_bstyle =
              ToggleButtonsView.classMap[this.model.previous("button_style")] ||
              "";
            var tooltips = view.model.get("tooltips") || [];
            var disabled = this.model.get("disabled");
            var buttons = this.buttongroup.querySelectorAll("button");
            var values = underscore__WEBPACK_IMPORTED_MODULE_3__.pluck(
              buttons,
              "value"
            );
            var stale = false;
            for (var i = 0, len = items.length; i < len; ++i) {
              if (values[i] !== items[i] || icons[i] !== previous_icons[i]) {
                stale = true;
                break;
              }
            }
            if (
              stale &&
              (options === undefined || options.updated_view !== this)
            ) {
              // Add items to the DOM.
              this.buttongroup.textContent = "";
              items.forEach(function (item, index) {
                var item_html;
                var empty =
                  item.trim().length === 0 &&
                  (!icons[index] || icons[index].trim().length === 0);
                if (empty) {
                  item_html = "&nbsp;";
                } else {
                  item_html =
                    _utils__WEBPACK_IMPORTED_MODULE_2__.escape_html(item);
                }
                var icon = document.createElement("i");
                var button = document.createElement("button");
                if (icons[index]) {
                  icon.className = "fa fa-" + icons[index];
                }
                button.setAttribute("type", "button");
                button.className = "widget-toggle-button jupyter-button";
                if (previous_bstyle) {
                  button.classList.add(previous_bstyle);
                }
                button.innerHTML = item_html;
                button.setAttribute("data-value", encodeURIComponent(item));
                button.setAttribute("value", index.toString());
                button.appendChild(icon);
                button.disabled = disabled;
                if (tooltips[index]) {
                  button.setAttribute("title", tooltips[index]);
                }
                view.update_style_traits(button);
                view.buttongroup.appendChild(button);
              });
            }
            // Select active button.
            items.forEach(function (item, index) {
              var item_query =
                '[data-value="' + encodeURIComponent(item) + '"]';
              var button = view.buttongroup.querySelector(item_query);
              if (view.model.get("index") === index) {
                button.classList.add("mod-active");
              } else {
                button.classList.remove("mod-active");
              }
            });
            this.stylePromise.then(function (style) {
              if (style) {
                style.style();
              }
            });
            return _super.prototype.update.call(this, options);
          };
          ToggleButtonsView.prototype.update_style_traits = function (button) {
            for (var name_1 in this._css_state) {
              if (this._css_state.hasOwnProperty(name_1)) {
                if (name_1 === "margin") {
                  this.buttongroup.style[name_1] = this._css_state[name_1];
                } else if (name_1 !== "width") {
                  if (button) {
                    button.style[name_1] = this._css_state[name_1];
                  } else {
                    var buttons = this.buttongroup.querySelectorAll("button");
                    if (buttons.length) {
                      buttons[0].style[name_1] = this._css_state[name_1];
                    }
                  }
                }
              }
            }
          };
          ToggleButtonsView.prototype.update_button_style = function () {
            var buttons = this.buttongroup.querySelectorAll("button");
            for (var i = 0; i < buttons.length; i++) {
              this.update_mapped_classes(
                ToggleButtonsView.classMap,
                "button_style",
                buttons[i]
              );
            }
          };
          ToggleButtonsView.prototype.set_button_style = function () {
            var buttons = this.buttongroup.querySelectorAll("button");
            for (var i = 0; i < buttons.length; i++) {
              this.set_mapped_classes(
                ToggleButtonsView.classMap,
                "button_style",
                buttons[i]
              );
            }
          };
          ToggleButtonsView.prototype.events = function () {
            return {
              "click button": "_handle_click",
            };
          };
          /**
           * Handle when a value is clicked.
           *
           * Calling model.set will trigger all of the other views of the
           * model to update.
           */
          ToggleButtonsView.prototype._handle_click = function (event) {
            var target = event.target;
            this.model.set("index", parseInt(target.value, 10), {
              updated_view: this,
            });
            this.touch();
            // We also send a clicked event, since the value is only set if it changed.
            // See https://github.com/jupyter-widgets/ipywidgets/issues/763
            this.send({ event: "click" });
          };
          return ToggleButtonsView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        (function (ToggleButtonsView) {
          ToggleButtonsView.classMap = {
            primary: ["mod-primary"],
            success: ["mod-success"],
            info: ["mod-info"],
            warning: ["mod-warning"],
            danger: ["mod-danger"],
          };
        })(ToggleButtonsView || (ToggleButtonsView = {}));
        var SelectionSliderModel = /** @class */ (function (_super) {
          __extends(SelectionSliderModel, _super);
          function SelectionSliderModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          SelectionSliderModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              {
                _model_name: "SelectionSliderModel",
                _view_name: "SelectionSliderView",
                orientation: "horizontal",
                readout: true,
                continuous_update: true,
              }
            );
          };
          return SelectionSliderModel;
        })(SelectionModel);

        var SelectionSliderView = /** @class */ (function (_super) {
          __extends(SelectionSliderView, _super);
          function SelectionSliderView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Called when view is rendered.
           */
          SelectionSliderView.prototype.render = function () {
            var _this = this;
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-hslider");
            this.el.classList.add("widget-slider");
            (this.$slider =
              jquery__WEBPACK_IMPORTED_MODULE_4___default()("<div />"))
              .slider({
                slide: this.handleSliderChange.bind(this),
                stop: this.handleSliderChanged.bind(this),
              })
              .addClass("slider");
            // Put the slider in a container
            this.slider_container = document.createElement("div");
            this.slider_container.classList.add("slider-container");
            this.slider_container.appendChild(this.$slider[0]);
            this.el.appendChild(this.slider_container);
            this.readout = document.createElement("div");
            this.el.appendChild(this.readout);
            this.readout.classList.add("widget-readout");
            this.readout.style.display = "none";
            this.listenTo(
              this.model,
              "change:slider_color",
              function (sender, value) {
                _this.$slider.find("a").css("background", value);
              }
            );
            this.$slider
              .find("a")
              .css("background", this.model.get("slider_color"));
            // Set defaults.
            this.update();
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed.  The model may have been
           * changed by another view or by a state update from the back-end.
           */
          SelectionSliderView.prototype.update = function (options) {
            if (options === undefined || options.updated_view !== this) {
              var labels = this.model.get("_options_labels");
              var max = labels.length - 1;
              var min = 0;
              this.$slider.slider("option", "step", 1);
              this.$slider.slider("option", "max", max);
              this.$slider.slider("option", "min", min);
              // WORKAROUND FOR JQUERY SLIDER BUG.
              // The horizontal position of the slider handle
              // depends on the value of the slider at the time
              // of orientation change.  Before applying the new
              // workaround, we set the value to the minimum to
              // make sure that the horizontal placement of the
              // handle in the vertical slider is always
              // consistent.
              var orientation_1 = this.model.get("orientation");
              this.$slider.slider("option", "value", min);
              this.$slider.slider("option", "orientation", orientation_1);
              var disabled = this.model.get("disabled");
              this.$slider.slider("option", "disabled", disabled);
              if (disabled) {
                this.readout.contentEditable = "false";
              } else {
                this.readout.contentEditable = "true";
              }
              // Use the right CSS classes for vertical & horizontal sliders
              if (orientation_1 === "vertical") {
                this.el.classList.remove("widget-hslider");
                this.el.classList.remove("widget-inline-hbox");
                this.el.classList.add("widget-vslider");
                this.el.classList.add("widget-inline-vbox");
              } else {
                this.el.classList.remove("widget-vslider");
                this.el.classList.remove("widget-inline-vbox");
                this.el.classList.add("widget-hslider");
                this.el.classList.add("widget-inline-hbox");
              }
              var readout = this.model.get("readout");
              if (readout) {
                // this.$readout.show();
                this.readout.style.display = "";
              } else {
                // this.$readout.hide();
                this.readout.style.display = "none";
              }
              this.updateSelection();
            }
            return _super.prototype.update.call(this, options);
          };
          SelectionSliderView.prototype.events = function () {
            return {
              slide: "handleSliderChange",
              slidestop: "handleSliderChanged",
            };
          };
          SelectionSliderView.prototype.updateSelection = function () {
            var index = this.model.get("index");
            this.$slider.slider("option", "value", index);
            this.updateReadout(index);
          };
          SelectionSliderView.prototype.updateReadout = function (index) {
            var value = this.model.get("_options_labels")[index];
            this.readout.textContent = value;
          };
          /**
           * Called when the slider value is changing.
           */
          SelectionSliderView.prototype.handleSliderChange = function (e, ui) {
            this.updateReadout(ui.value);
            // Only persist the value while sliding if the continuous_update
            // trait is set to true.
            if (this.model.get("continuous_update")) {
              this.handleSliderChanged(e, ui);
            }
          };
          /**
           * Called when the slider value has changed.
           *
           * Calling model.set will trigger all of the other views of the
           * model to update.
           */
          SelectionSliderView.prototype.handleSliderChanged = function (e, ui) {
            this.updateReadout(ui.value);
            this.model.set("index", ui.value, { updated_view: this });
            this.touch();
          };
          return SelectionSliderView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var MultipleSelectionModel = /** @class */ (function (_super) {
          __extends(MultipleSelectionModel, _super);
          function MultipleSelectionModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          MultipleSelectionModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              { _model_name: "MultipleSelectionModel" }
            );
          };
          return MultipleSelectionModel;
        })(SelectionModel);

        var SelectMultipleModel = /** @class */ (function (_super) {
          __extends(SelectMultipleModel, _super);
          function SelectMultipleModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          SelectMultipleModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              {
                _model_name: "SelectMultipleModel",
                _view_name: "SelectMultipleView",
                rows: null,
              }
            );
          };
          return SelectMultipleModel;
        })(MultipleSelectionModel);

        var SelectMultipleView = /** @class */ (function (_super) {
          __extends(SelectMultipleView, _super);
          function SelectMultipleView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Public constructor.
           */
          SelectMultipleView.prototype.initialize = function (parameters) {
            _super.prototype.initialize.call(this, parameters);
            this.listbox.multiple = true;
          };
          /**
           * Called when view is rendered.
           */
          SelectMultipleView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("widget-select-multiple");
          };
          SelectMultipleView.prototype.updateSelection = function (options) {
            if (options === void 0) {
              options = {};
            }
            if (options.updated_view === this) {
              return;
            }
            var selected = this.model.get("index") || [];
            var listboxOptions = this.listbox.options;
            // Clear the selection
            this.listbox.selectedIndex = -1;
            // Select the appropriate options
            selected.forEach(function (i) {
              listboxOptions[i].selected = true;
            });
          };
          /**
           * Handle when a new value is selected.
           */
          SelectMultipleView.prototype._handle_change = function () {
            var index = Array.prototype.map.call(
              this.listbox.selectedOptions || [],
              function (option) {
                return option.index;
              }
            );
            this.model.set("index", index, { updated_view: this });
            this.touch();
          };
          return SelectMultipleView;
        })(SelectView);

        var SelectionRangeSliderModel = /** @class */ (function (_super) {
          __extends(SelectionRangeSliderModel, _super);
          function SelectionRangeSliderModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          SelectionRangeSliderModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              {
                _model_name: "SelectionSliderModel",
                _view_name: "SelectionSliderView",
                orientation: "horizontal",
                readout: true,
                continuous_update: true,
              }
            );
          };
          return SelectionRangeSliderModel;
        })(MultipleSelectionModel);

        var SelectionRangeSliderView = /** @class */ (function (_super) {
          __extends(SelectionRangeSliderView, _super);
          function SelectionRangeSliderView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Called when view is rendered.
           */
          SelectionRangeSliderView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.$slider.slider("option", "range", true);
          };
          SelectionRangeSliderView.prototype.updateSelection = function () {
            var index = this.model.get("index");
            this.$slider.slider("option", "values", index.slice());
            this.updateReadout(index);
          };
          SelectionRangeSliderView.prototype.updateReadout = function (index) {
            var labels = this.model.get("_options_labels");
            var minValue = labels[index[0]];
            var maxValue = labels[index[1]];
            this.readout.textContent = minValue + "-" + maxValue;
          };
          /**
           * Called when the slider value is changing.
           */
          SelectionRangeSliderView.prototype.handleSliderChange = function (
            e,
            ui
          ) {
            this.updateReadout(ui.values);
            // Only persist the value while sliding if the continuous_update
            // trait is set to true.
            if (this.model.get("continuous_update")) {
              this.handleSliderChanged(e, ui);
            }
          };
          /**
           * Called when the slider value has changed.
           *
           * Calling model.set will trigger all of the other views of the
           * model to update.
           */
          SelectionRangeSliderView.prototype.handleSliderChanged = function (
            e,
            ui
          ) {
            // The jqueryui documentation indicates ui.values doesn't exist on the slidestop event,
            // but it appears that it actually does: https://github.com/jquery/jquery-ui/blob/ae31f2b3b478975f70526bdf3299464b9afa8bb1/ui/widgets/slider.js#L313
            this.updateReadout(ui.values);
            this.model.set("index", ui.values.slice(), { updated_view: this });
            this.touch();
          };
          return SelectionRangeSliderView;
        })(SelectionSliderView);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_selectioncontainer.js":
      /*!*********************************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_selectioncontainer.js ***!
  \*********************************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ SelectionContainerModel: () =>
            /* binding */ SelectionContainerModel,
          /* harmony export */ AccordionModel: () =>
            /* binding */ AccordionModel,
          /* harmony export */ JupyterPhosphorAccordionWidget: () =>
            /* binding */ JupyterPhosphorAccordionWidget,
          /* harmony export */ AccordionView: () => /* binding */ AccordionView,
          /* harmony export */ TabModel: () => /* binding */ TabModel,
          /* harmony export */ JupyterPhosphorTabPanelWidget: () =>
            /* binding */ JupyterPhosphorTabPanelWidget,
          /* harmony export */ TabView: () => /* binding */ TabView,
          /* harmony export */
        });
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__
          );
        /* harmony import */ var _widget_box__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_box */ "./node_modules/@jupyter-widgets/controls/lib/widget_box.js"
          );
        /* harmony import */ var _phosphor_tabpanel__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./phosphor/tabpanel */ "./node_modules/@jupyter-widgets/controls/lib/phosphor/tabpanel.js"
          );
        /* harmony import */ var _phosphor_accordion__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./phosphor/accordion */ "./node_modules/@jupyter-widgets/controls/lib/phosphor/accordion.js"
          );
        /* harmony import */ var _lumino_widgets__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! @lumino/widgets */ "webpack/sharing/consume/default/@lumino/widgets"
          );
        /* harmony import */ var _lumino_widgets__WEBPACK_IMPORTED_MODULE_4___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_widgets__WEBPACK_IMPORTED_MODULE_4__
          );
        /* harmony import */ var _lumino_algorithm__WEBPACK_IMPORTED_MODULE_5__ =
          __webpack_require__(
            /*! @lumino/algorithm */ "webpack/sharing/consume/default/@lumino/algorithm"
          );
        /* harmony import */ var _lumino_algorithm__WEBPACK_IMPORTED_MODULE_5___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_algorithm__WEBPACK_IMPORTED_MODULE_5__
          );
        /* harmony import */ var _lumino_messaging__WEBPACK_IMPORTED_MODULE_6__ =
          __webpack_require__(
            /*! @lumino/messaging */ "webpack/sharing/consume/default/@lumino/messaging"
          );
        /* harmony import */ var _lumino_messaging__WEBPACK_IMPORTED_MODULE_6___default =
          /*#__PURE__*/ __webpack_require__.n(
            _lumino_messaging__WEBPACK_IMPORTED_MODULE_6__
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_7__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        /* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_8__ =
          __webpack_require__(
            /*! ./utils */ "./node_modules/@jupyter-widgets/controls/lib/utils.js"
          );
        /* harmony import */ var jquery__WEBPACK_IMPORTED_MODULE_9__ =
          __webpack_require__(
            /*! jquery */ "./node_modules/jquery/dist/jquery.js"
          );
        /* harmony import */ var jquery__WEBPACK_IMPORTED_MODULE_9___default =
          /*#__PURE__*/ __webpack_require__.n(
            jquery__WEBPACK_IMPORTED_MODULE_9__
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();

        var SelectionContainerModel = /** @class */ (function (_super) {
          __extends(SelectionContainerModel, _super);
          function SelectionContainerModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          SelectionContainerModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_7__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "SelectionContainerModel",
                selected_index: 0,
                _titles: {},
              }
            );
          };
          return SelectionContainerModel;
        })(_widget_box__WEBPACK_IMPORTED_MODULE_1__.BoxModel);

        var AccordionModel = /** @class */ (function (_super) {
          __extends(AccordionModel, _super);
          function AccordionModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          AccordionModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_7__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "AccordionModel",
                _view_name: "AccordionView",
              }
            );
          };
          return AccordionModel;
        })(SelectionContainerModel);

        // We implement our own tab widget since Phoshpor's TabPanel uses an absolute
        // positioning BoxLayout, but we want a more an html/css-based Panel layout.
        var JupyterPhosphorAccordionWidget = /** @class */ (function (_super) {
          __extends(JupyterPhosphorAccordionWidget, _super);
          function JupyterPhosphorAccordionWidget(options) {
            var _this = this;
            var view = options.view;
            delete options.view;
            _this = _super.call(this, options) || this;
            _this._view = view;
            return _this;
          }
          /**
           * Process the phosphor message.
           *
           * Any custom phosphor widget used inside a Jupyter widget should override
           * the processMessage function like this.
           */
          JupyterPhosphorAccordionWidget.prototype.processMessage = function (
            msg
          ) {
            _super.prototype.processMessage.call(this, msg);
            this._view.processPhosphorMessage(msg);
          };
          /**
           * Dispose the widget.
           *
           * This causes the view to be destroyed as well with 'remove'
           */
          JupyterPhosphorAccordionWidget.prototype.dispose = function () {
            if (this.isDisposed) {
              return;
            }
            _super.prototype.dispose.call(this);
            if (this._view) {
              this._view.remove();
            }
            this._view = null;
          };
          return JupyterPhosphorAccordionWidget;
        })(_phosphor_accordion__WEBPACK_IMPORTED_MODULE_3__.Accordion);

        var AccordionView = /** @class */ (function (_super) {
          __extends(AccordionView, _super);
          function AccordionView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          AccordionView.prototype._createElement = function (tagName) {
            this.pWidget = new JupyterPhosphorAccordionWidget({ view: this });
            return this.pWidget.node;
          };
          AccordionView.prototype._setElement = function (el) {
            if (this.el || el !== this.pWidget.node) {
              // Accordions don't allow setting the element beyond the initial creation.
              throw new Error("Cannot reset the DOM element.");
            }
            this.el = this.pWidget.node;
            this.$el = jquery__WEBPACK_IMPORTED_MODULE_9___default()(
              this.pWidget.node
            );
          };
          AccordionView.prototype.initialize = function (parameters) {
            var _this = this;
            _super.prototype.initialize.call(this, parameters);
            this.children_views =
              new _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.ViewList(
                this.add_child_view,
                this.remove_child_view,
                this
              );
            this.listenTo(this.model, "change:children", function () {
              return _this.updateChildren();
            });
            this.listenTo(this.model, "change:selected_index", function () {
              return _this.update_selected_index();
            });
            this.listenTo(this.model, "change:_titles", function () {
              return _this.update_titles();
            });
          };
          /**
           * Called when view is rendered.
           */
          AccordionView.prototype.render = function () {
            var _this = this;
            _super.prototype.render.call(this);
            var accordion = this.pWidget;
            accordion.addClass("jupyter-widgets");
            accordion.addClass("widget-accordion");
            accordion.addClass("widget-container");
            accordion.selection.selectionChanged.connect(function (sender) {
              if (!_this.updatingChildren) {
                _this.model.set("selected_index", accordion.selection.index);
                _this.touch();
              }
            });
            this.children_views.update(this.model.get("children"));
            this.update_titles();
            this.update_selected_index();
          };
          /**
           * Update children
           */
          AccordionView.prototype.updateChildren = function () {
            // While we are updating, the index may not be valid, so deselect the
            // tabs before updating so we don't get spurious changes in the index,
            // which would then set off another sync cycle.
            this.updatingChildren = true;
            this.pWidget.selection.index = null;
            this.children_views.update(this.model.get("children"));
            this.update_selected_index();
            this.updatingChildren = false;
          };
          /**
           * Set header titles
           */
          AccordionView.prototype.update_titles = function () {
            var collapsed = this.pWidget.collapseWidgets;
            var titles = this.model.get("_titles");
            for (var i = 0; i < collapsed.length; i++) {
              if (titles[i] !== void 0) {
                collapsed[i].widget.title.label = titles[i];
              }
            }
          };
          /**
           * Make the rendering and selected index consistent.
           */
          AccordionView.prototype.update_selected_index = function () {
            this.pWidget.selection.index = this.model.get("selected_index");
          };
          /**
           * Called when a child is removed from children list.
           */
          AccordionView.prototype.remove_child_view = function (view) {
            this.pWidget.removeWidget(view.pWidget);
            view.remove();
          };
          /**
           * Called when a child is added to children list.
           */
          AccordionView.prototype.add_child_view = function (model, index) {
            // Placeholder widget to keep our position in the tab panel while we create the view.
            var accordion = this.pWidget;
            var placeholder =
              new _lumino_widgets__WEBPACK_IMPORTED_MODULE_4__.Widget();
            placeholder.title.label = this.model.get("_titles")[index] || "";
            accordion.addWidget(placeholder);
            return this.create_child_view(model)
              .then(function (view) {
                var widget = view.pWidget;
                widget.title.label = placeholder.title.label;
                var collapse =
                  accordion.collapseWidgets[accordion.indexOf(placeholder)];
                collapse.widget = widget;
                placeholder.dispose();
                return view;
              })
              .catch(
                _utils__WEBPACK_IMPORTED_MODULE_8__.reject(
                  "Could not add child view to box",
                  true
                )
              );
          };
          AccordionView.prototype.remove = function () {
            this.children_views = null;
            _super.prototype.remove.call(this);
          };
          return AccordionView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.DOMWidgetView);

        var TabModel = /** @class */ (function (_super) {
          __extends(TabModel, _super);
          function TabModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          TabModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_7__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "TabModel",
                _view_name: "TabView",
              }
            );
          };
          return TabModel;
        })(SelectionContainerModel);

        // We implement our own tab widget since Phoshpor's TabPanel uses an absolute
        // positioning BoxLayout, but we want a more an html/css-based Panel layout.
        var JupyterPhosphorTabPanelWidget = /** @class */ (function (_super) {
          __extends(JupyterPhosphorTabPanelWidget, _super);
          function JupyterPhosphorTabPanelWidget(options) {
            var _this = this;
            var view = options.view;
            delete options.view;
            _this = _super.call(this, options) || this;
            _this._view = view;
            // We want the view's messages to be the messages the tabContents panel
            // gets.
            _lumino_messaging__WEBPACK_IMPORTED_MODULE_6__.MessageLoop.installMessageHook(
              _this.tabContents,
              function (handler, msg) {
                // There may be times when we want the view's handler to be called
                // *after* the message has been processed by the widget, in which
                // case we'll need to revisit using a message hook.
                _this._view.processPhosphorMessage(msg);
                return true;
              }
            );
            return _this;
          }
          /**
           * Dispose the widget.
           *
           * This causes the view to be destroyed as well with 'remove'
           */
          JupyterPhosphorTabPanelWidget.prototype.dispose = function () {
            if (this.isDisposed) {
              return;
            }
            _super.prototype.dispose.call(this);
            if (this._view) {
              this._view.remove();
            }
            this._view = null;
          };
          return JupyterPhosphorTabPanelWidget;
        })(_phosphor_tabpanel__WEBPACK_IMPORTED_MODULE_2__.TabPanel);

        var TabView = /** @class */ (function (_super) {
          __extends(TabView, _super);
          function TabView() {
            var _this =
              (_super !== null && _super.apply(this, arguments)) || this;
            _this.updatingTabs = false;
            return _this;
          }
          TabView.prototype._createElement = function (tagName) {
            this.pWidget = new JupyterPhosphorTabPanelWidget({
              view: this,
            });
            return this.pWidget.node;
          };
          TabView.prototype._setElement = function (el) {
            if (this.el || el !== this.pWidget.node) {
              // TabViews don't allow setting the element beyond the initial creation.
              throw new Error("Cannot reset the DOM element.");
            }
            this.el = this.pWidget.node;
            this.$el = jquery__WEBPACK_IMPORTED_MODULE_9___default()(
              this.pWidget.node
            );
          };
          /**
           * Public constructor.
           */
          TabView.prototype.initialize = function (parameters) {
            var _this = this;
            _super.prototype.initialize.call(this, parameters);
            this.childrenViews =
              new _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.ViewList(
                this.addChildView,
                function (view) {
                  view.remove();
                },
                this
              );
            this.listenTo(this.model, "change:children", function () {
              return _this.updateTabs();
            });
            this.listenTo(this.model, "change:_titles", function () {
              return _this.updateTitles();
            });
          };
          /**
           * Called when view is rendered.
           */
          TabView.prototype.render = function () {
            _super.prototype.render.call(this);
            var tabs = this.pWidget;
            tabs.addClass("jupyter-widgets");
            tabs.addClass("widget-container");
            tabs.addClass("widget-tab");
            tabs.tabsMovable = true;
            tabs.tabBar.insertBehavior = "none"; // needed for insert behavior, see below.
            tabs.tabBar.currentChanged.connect(this._onTabChanged, this);
            tabs.tabBar.tabMoved.connect(this._onTabMoved, this);
            tabs.tabBar.addClass("widget-tab-bar");
            tabs.tabContents.addClass("widget-tab-contents");
            // TODO: expose this option in python
            tabs.tabBar.tabsMovable = false;
            this.updateTabs();
            this.update();
          };
          /**
           * Render tab views based on the current model's children.
           */
          TabView.prototype.updateTabs = function () {
            // While we are updating, the index may not be valid, so deselect the
            // tabs before updating so we don't get spurious changes in the index,
            // which would then set off another sync cycle.
            this.updatingTabs = true;
            this.pWidget.currentIndex = null;
            this.childrenViews.update(this.model.get("children"));
            this.pWidget.currentIndex = this.model.get("selected_index");
            this.updatingTabs = false;
          };
          /**
           * Called when a child is added to children list.
           */
          TabView.prototype.addChildView = function (model, index) {
            // Placeholder widget to keep our position in the tab panel while we create the view.
            var label = this.model.get("_titles")[index] || "";
            var tabs = this.pWidget;
            var placeholder =
              new _lumino_widgets__WEBPACK_IMPORTED_MODULE_4__.Widget();
            placeholder.title.label = label;
            tabs.addWidget(placeholder);
            return this.create_child_view(model)
              .then(function (view) {
                var widget = view.pWidget;
                widget.title.label = placeholder.title.label;
                widget.title.closable = false;
                var i =
                  _lumino_algorithm__WEBPACK_IMPORTED_MODULE_5__.ArrayExt.firstIndexOf(
                    tabs.widgets,
                    placeholder
                  );
                // insert after placeholder so that if placholder is selected, the
                // real widget will be selected now (this depends on the tab bar
                // insert behavior)
                tabs.insertWidget(i + 1, widget);
                placeholder.dispose();
                return view;
              })
              .catch(
                _utils__WEBPACK_IMPORTED_MODULE_8__.reject(
                  "Could not add child view to box",
                  true
                )
              );
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed.  The model may have been
           * changed by another view or by a state update from the back-end.
           */
          TabView.prototype.update = function () {
            // Update the selected index in the overall update method because it
            // should be run after the tabs have been updated. Otherwise the
            // selected index may not be a valid tab in the tab bar.
            this.updateSelectedIndex();
            return _super.prototype.update.call(this);
          };
          /**
           * Updates the tab page titles.
           */
          TabView.prototype.updateTitles = function () {
            var titles = this.model.get("_titles") || {};
            (0, _lumino_algorithm__WEBPACK_IMPORTED_MODULE_5__.each)(
              this.pWidget.widgets,
              function (widget, i) {
                widget.title.label = titles[i] || "";
              }
            );
          };
          /**
           * Updates the selected index.
           */
          TabView.prototype.updateSelectedIndex = function () {
            this.pWidget.currentIndex = this.model.get("selected_index");
          };
          TabView.prototype.remove = function () {
            this.childrenViews = null;
            _super.prototype.remove.call(this);
          };
          TabView.prototype._onTabChanged = function (sender, args) {
            if (!this.updatingTabs) {
              var i = args.currentIndex;
              this.model.set("selected_index", i === -1 ? null : i);
              this.touch();
            }
          };
          /**
           * Handle the `tabMoved` signal from the tab bar.
           */
          TabView.prototype._onTabMoved = function (sender, args) {
            var children = this.model.get("children").slice();
            _lumino_algorithm__WEBPACK_IMPORTED_MODULE_5__.ArrayExt.move(
              children,
              args.fromIndex,
              args.toIndex
            );
            this.model.set("children", children);
            this.touch();
          };
          return TabView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.DOMWidgetView);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_string.js":
      /*!*********************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_string.js ***!
  \*********************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ StringModel: () => /* binding */ StringModel,
          /* harmony export */ HTMLModel: () => /* binding */ HTMLModel,
          /* harmony export */ HTMLView: () => /* binding */ HTMLView,
          /* harmony export */ HTMLMathModel: () => /* binding */ HTMLMathModel,
          /* harmony export */ HTMLMathView: () => /* binding */ HTMLMathView,
          /* harmony export */ LabelModel: () => /* binding */ LabelModel,
          /* harmony export */ LabelView: () => /* binding */ LabelView,
          /* harmony export */ TextareaModel: () => /* binding */ TextareaModel,
          /* harmony export */ TextareaView: () => /* binding */ TextareaView,
          /* harmony export */ TextModel: () => /* binding */ TextModel,
          /* harmony export */ TextView: () => /* binding */ TextView,
          /* harmony export */ PasswordModel: () => /* binding */ PasswordModel,
          /* harmony export */ PasswordView: () => /* binding */ PasswordView,
          /* harmony export */ ComboboxModel: () => /* binding */ ComboboxModel,
          /* harmony export */ ComboboxView: () => /* binding */ ComboboxView,
          /* harmony export */
        });
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var _widget_description__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_description */ "./node_modules/@jupyter-widgets/controls/lib/widget_description.js"
          );
        /* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./utils */ "./node_modules/@jupyter-widgets/controls/lib/utils.js"
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        var __assign =
          (undefined && undefined.__assign) ||
          function () {
            __assign =
              Object.assign ||
              function (t) {
                for (var s, i = 1, n = arguments.length; i < n; i++) {
                  s = arguments[i];
                  for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
                }
                return t;
              };
            return __assign.apply(this, arguments);
          };

        /**
         * Class name for a combobox with an invlid value.
         */
        var INVALID_VALUE_CLASS = "jpwidgets-invalidComboValue";
        var StringModel = /** @class */ (function (_super) {
          __extends(StringModel, _super);
          function StringModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          StringModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                value: "",
                disabled: false,
                placeholder: "\u200b",
                _model_name: "StringModel",
              }
            );
          };
          return StringModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDescriptionModel);

        var HTMLModel = /** @class */ (function (_super) {
          __extends(HTMLModel, _super);
          function HTMLModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          HTMLModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                _view_name: "HTMLView",
                _model_name: "HTMLModel",
              }
            );
          };
          return HTMLModel;
        })(StringModel);

        var HTMLView = /** @class */ (function (_super) {
          __extends(HTMLView, _super);
          function HTMLView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Called when view is rendered.
           */
          HTMLView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-html");
            this.content = document.createElement("div");
            this.content.classList.add("widget-html-content");
            this.el.appendChild(this.content);
            this.update(); // Set defaults.
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed.  The model may have been
           * changed by another view or by a state update from the back-end.
           */
          HTMLView.prototype.update = function () {
            this.content.innerHTML = this.model.get("value");
            return _super.prototype.update.call(this);
          };
          return HTMLView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var HTMLMathModel = /** @class */ (function (_super) {
          __extends(HTMLMathModel, _super);
          function HTMLMathModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          HTMLMathModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                _view_name: "HTMLMathView",
                _model_name: "HTMLMathModel",
              }
            );
          };
          return HTMLMathModel;
        })(StringModel);

        var HTMLMathView = /** @class */ (function (_super) {
          __extends(HTMLMathView, _super);
          function HTMLMathView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Called when view is rendered.
           */
          HTMLMathView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-htmlmath");
            this.content = document.createElement("div");
            this.content.classList.add("widget-htmlmath-content");
            this.el.appendChild(this.content);
            this.update(); // Set defaults.
          };
          /**
           * Update the contents of this view
           */
          HTMLMathView.prototype.update = function () {
            this.content.innerHTML = this.model.get("value");
            this.typeset(this.content);
            return _super.prototype.update.call(this);
          };
          return HTMLMathView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var LabelModel = /** @class */ (function (_super) {
          __extends(LabelModel, _super);
          function LabelModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          LabelModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                _view_name: "LabelView",
                _model_name: "LabelModel",
              }
            );
          };
          return LabelModel;
        })(StringModel);

        var LabelView = /** @class */ (function (_super) {
          __extends(LabelView, _super);
          function LabelView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Called when view is rendered.
           */
          LabelView.prototype.render = function () {
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-label");
            this.update(); // Set defaults.
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed.  The model may have been
           * changed by another view or by a state update from the back-end.
           */
          LabelView.prototype.update = function () {
            this.typeset(this.el, this.model.get("value"));
            return _super.prototype.update.call(this);
          };
          return LabelView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var TextareaModel = /** @class */ (function (_super) {
          __extends(TextareaModel, _super);
          function TextareaModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          TextareaModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                _view_name: "TextareaView",
                _model_name: "TextareaModel",
                rows: null,
                continuous_update: true,
              }
            );
          };
          return TextareaModel;
        })(StringModel);

        var TextareaView = /** @class */ (function (_super) {
          __extends(TextareaView, _super);
          function TextareaView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          /**
           * Called when view is rendered.
           */
          TextareaView.prototype.render = function () {
            var _this = this;
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-textarea");
            this.textbox = document.createElement("textarea");
            this.textbox.setAttribute("rows", "5");
            this.textbox.id = this.label.htmlFor = (0,
            _utils__WEBPACK_IMPORTED_MODULE_2__.uuid)();
            this.el.appendChild(this.textbox);
            this.update(); // Set defaults.
            this.listenTo(
              this.model,
              "change:placeholder",
              function (model, value, options) {
                _this.update_placeholder(value);
              }
            );
            this.update_placeholder();
          };
          TextareaView.prototype.update_placeholder = function (value) {
            value = value || this.model.get("placeholder");
            this.textbox.setAttribute("placeholder", value.toString());
          };
          /**
           * Update the contents of this view
           *
           * Called when the model is changed.  The model may have been
           * changed by another view or by a state update from the back-end.
           */
          TextareaView.prototype.update = function (options) {
            if (options === undefined || options.updated_view != this) {
              this.textbox.value = this.model.get("value");
              var rows = this.model.get("rows");
              if (rows === null) {
                rows = "";
              }
              this.textbox.setAttribute("rows", rows);
              this.textbox.disabled = this.model.get("disabled");
            }
            return _super.prototype.update.call(this);
          };
          TextareaView.prototype.events = function () {
            return {
              "keydown input": "handleKeyDown",
              "keypress input": "handleKeypress",
              "input textarea": "handleChanging",
              "change textarea": "handleChanged",
            };
          };
          /**
           * Handle key down
           *
           * Stop propagation so the event isn't sent to the application.
           */
          TextareaView.prototype.handleKeyDown = function (e) {
            e.stopPropagation();
          };
          /**
           * Handles key press
           *
           * Stop propagation so the keypress isn't sent to the application.
           */
          TextareaView.prototype.handleKeypress = function (e) {
            e.stopPropagation();
          };
          /**
           * Triggered on input change
           */
          TextareaView.prototype.handleChanging = function (e) {
            if (this.model.get("continuous_update")) {
              this.handleChanged(e);
            }
          };
          /**
           * Sync the value with the kernel.
           *
           * @param e Event
           */
          TextareaView.prototype.handleChanged = function (e) {
            var target = e.target;
            this.model.set("value", target.value, { updated_view: this });
            this.touch();
          };
          return TextareaView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var TextModel = /** @class */ (function (_super) {
          __extends(TextModel, _super);
          function TextModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          TextModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                _view_name: "TextView",
                _model_name: "TextModel",
                continuous_update: true,
              }
            );
          };
          return TextModel;
        })(StringModel);

        var TextView = /** @class */ (function (_super) {
          __extends(TextView, _super);
          function TextView() {
            var _this =
              (_super !== null && _super.apply(this, arguments)) || this;
            _this.inputType = "text";
            return _this;
          }
          /**
           * Called when view is rendered.
           */
          TextView.prototype.render = function () {
            var _this = this;
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-inline-hbox");
            this.el.classList.add("widget-text");
            this.textbox = document.createElement("input");
            this.textbox.setAttribute("type", this.inputType);
            this.textbox.id = this.label.htmlFor = (0,
            _utils__WEBPACK_IMPORTED_MODULE_2__.uuid)();
            this.el.appendChild(this.textbox);
            this.update(); // Set defaults.
            this.listenTo(
              this.model,
              "change:placeholder",
              function (model, value, options) {
                _this.update_placeholder(value);
              }
            );
            this.listenTo(
              this.model,
              "change:description_tooltip",
              this.update_title
            );
            this.listenTo(this.model, "change:description", this.update_title);
            this.update_placeholder();
            this.update_title();
          };
          TextView.prototype.update_placeholder = function (value) {
            this.textbox.setAttribute(
              "placeholder",
              value || this.model.get("placeholder")
            );
          };
          TextView.prototype.update_title = function () {
            var title = this.model.get("description_tooltip");
            if (!title) {
              this.textbox.removeAttribute("title");
            } else if (this.model.get("description").length === 0) {
              this.textbox.setAttribute("title", title);
            }
          };
          TextView.prototype.update = function (options) {
            /**
             * Update the contents of this view
             *
             * Called when the model is changed.  The model may have been
             * changed by another view or by a state update from the back-end.
             */
            if (options === undefined || options.updated_view !== this) {
              if (this.textbox.value !== this.model.get("value")) {
                this.textbox.value = this.model.get("value");
              }
              this.textbox.disabled = this.model.get("disabled");
            }
            return _super.prototype.update.call(this);
          };
          TextView.prototype.events = function () {
            return {
              "keydown input": "handleKeyDown",
              "keypress input": "handleKeypress",
              "input input": "handleChanging",
              "change input": "handleChanged",
            };
          };
          /**
           * Handle key down
           *
           * Stop propagation so the keypress isn't sent to the application.
           */
          TextView.prototype.handleKeyDown = function (e) {
            e.stopPropagation();
          };
          /**
           * Handles text submission
           */
          TextView.prototype.handleKeypress = function (e) {
            e.stopPropagation();
            // The submit message is deprecated in widgets 7
            if (e.keyCode === 13) {
              // Return key
              this.send({ event: "submit" });
            }
          };
          /**
           * Handles user input.
           *
           * Calling model.set will trigger all of the other views of the
           * model to update.
           */
          TextView.prototype.handleChanging = function (e) {
            if (this.model.get("continuous_update")) {
              this.handleChanged(e);
            }
          };
          /**
           * Handles user input.
           *
           * Calling model.set will trigger all of the other views of the
           * model to update.
           */
          TextView.prototype.handleChanged = function (e) {
            var target = e.target;
            this.model.set("value", target.value, { updated_view: this });
            this.touch();
          };
          return TextView;
        })(_widget_description__WEBPACK_IMPORTED_MODULE_1__.DescriptionView);

        var PasswordModel = /** @class */ (function (_super) {
          __extends(PasswordModel, _super);
          function PasswordModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          PasswordModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_3__.extend(
              _super.prototype.defaults.call(this),
              {
                _view_name: "PasswordView",
                _model_name: "PasswordModel",
              }
            );
          };
          return PasswordModel;
        })(TextModel);

        var PasswordView = /** @class */ (function (_super) {
          __extends(PasswordView, _super);
          function PasswordView() {
            var _this =
              (_super !== null && _super.apply(this, arguments)) || this;
            _this.inputType = "password";
            return _this;
          }
          return PasswordView;
        })(TextView);

        /**
         * Combobox widget model class.
         */
        var ComboboxModel = /** @class */ (function (_super) {
          __extends(ComboboxModel, _super);
          function ComboboxModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          ComboboxModel.prototype.defaults = function () {
            return __assign(
              __assign({}, _super.prototype.defaults.call(this)),
              {
                _model_name: "ComboboxModel",
                _view_name: "ComboboxView",
                options: [],
                ensure_options: false,
              }
            );
          };
          return ComboboxModel;
        })(TextModel);

        /**
         * Combobox widget view class.
         */
        var ComboboxView = /** @class */ (function (_super) {
          __extends(ComboboxView, _super);
          function ComboboxView() {
            var _this =
              (_super !== null && _super.apply(this, arguments)) || this;
            _this.isInitialRender = true;
            return _this;
          }
          ComboboxView.prototype.render = function () {
            this.datalist = document.createElement("datalist");
            this.datalist.id = (0, _utils__WEBPACK_IMPORTED_MODULE_2__.uuid)();
            _super.prototype.render.call(this);
            this.textbox.setAttribute("list", this.datalist.id);
            this.el.appendChild(this.datalist);
          };
          ComboboxView.prototype.update = function (options) {
            _super.prototype.update.call(this, options);
            if (!this.datalist) {
              return;
            }
            var valid = this.isValid(this.model.get("value"));
            this.highlightValidState(valid);
            // Check if we need to update options
            if (
              (options !== undefined && options.updated_view) ||
              (!this.model.hasChanged("options") && !this.isInitialRender)
            ) {
              // Value update only, keep current options
              return;
            }
            this.isInitialRender = false;
            var opts = this.model.get("options");
            var optLines = opts.map(function (o) {
              return '<option value="' + o + '"></option>';
            });
            this.datalist.innerHTML = optLines.join("\n");
          };
          ComboboxView.prototype.isValid = function (value) {
            if (true === this.model.get("ensure_option")) {
              var options = this.model.get("options");
              if (options.indexOf(value) === -1) {
                return false;
              }
            }
            return true;
          };
          ComboboxView.prototype.handleChanging = function (e) {
            // Override to validate value
            var target = e.target;
            var valid = this.isValid(target.value);
            this.highlightValidState(valid);
            if (valid) {
              _super.prototype.handleChanging.call(this, e);
            }
          };
          ComboboxView.prototype.handleChanged = function (e) {
            // Override to validate value
            var target = e.target;
            var valid = this.isValid(target.value);
            this.highlightValidState(valid);
            if (valid) {
              _super.prototype.handleChanged.call(this, e);
            }
          };
          ComboboxView.prototype.highlightValidState = function (valid) {
            this.textbox.classList.toggle(INVALID_VALUE_CLASS, !valid);
          };
          return ComboboxView;
        })(TextView);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_upload.js":
      /*!*********************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_upload.js ***!
  \*********************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ FileUploadModel: () =>
            /* binding */ FileUploadModel,
          /* harmony export */ FileUploadView: () =>
            /* binding */ FileUploadView,
          /* harmony export */
        });
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        var __assign =
          (undefined && undefined.__assign) ||
          function () {
            __assign =
              Object.assign ||
              function (t) {
                for (var s, i = 1, n = arguments.length; i < n; i++) {
                  s = arguments[i];
                  for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
                }
                return t;
              };
            return __assign.apply(this, arguments);
          };
        var __spreadArrays =
          (undefined && undefined.__spreadArrays) ||
          function () {
            for (var s = 0, i = 0, il = arguments.length; i < il; i++)
              s += arguments[i].length;
            for (var r = Array(s), k = 0, i = 0; i < il; i++)
              for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
                r[k] = a[j];
            return r;
          };

        var FileUploadModel = /** @class */ (function (_super) {
          __extends(FileUploadModel, _super);
          function FileUploadModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          FileUploadModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_2__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "FileUploadModel",
                _view_name: "FileUploadView",
                _counter: 0,
                accept: "",
                description: "Upload",
                tooltip: "",
                disabled: false,
                icon: "upload",
                button_style: "",
                multiple: false,
                metadata: [],
                data: [],
                error: "",
                style: null,
              }
            );
          };
          FileUploadModel.serializers = __assign(
            __assign(
              {},
              _widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDOMWidgetModel
                .serializers
            ),
            {
              data: {
                serialize: function (buffers) {
                  return __spreadArrays(buffers);
                },
              },
            }
          );
          return FileUploadModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_0__.CoreDOMWidgetModel);

        var FileUploadView = /** @class */ (function (_super) {
          __extends(FileUploadView, _super);
          function FileUploadView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          Object.defineProperty(FileUploadView.prototype, "tagName", {
            get: function () {
              return "button";
            },
            enumerable: true,
            configurable: true,
          });
          FileUploadView.prototype.render = function () {
            var _this = this;
            _super.prototype.render.call(this);
            this.el.classList.add("jupyter-widgets");
            this.el.classList.add("widget-upload");
            this.el.classList.add("jupyter-button");
            this.fileInput = document.createElement("input");
            this.fileInput.type = "file";
            this.fileInput.style.display = "none";
            this.el.appendChild(this.fileInput);
            this.el.addEventListener("click", function () {
              _this.fileInput.click();
            });
            this.fileInput.addEventListener("click", function () {
              _this.fileInput.value = "";
            });
            this.fileInput.addEventListener("change", function () {
              var promisesFile = [];
              Array.from(_this.fileInput.files).forEach(function (file) {
                promisesFile.push(
                  new Promise(function (resolve, reject) {
                    var metadata = {
                      name: file.name,
                      type: file.type,
                      size: file.size,
                      lastModified: file.lastModified,
                    };
                    _this.fileReader = new FileReader();
                    _this.fileReader.onload = function (event) {
                      var buffer = event.target.result;
                      resolve({
                        buffer: buffer,
                        metadata: metadata,
                        error: "",
                      });
                    };
                    _this.fileReader.onerror = function () {
                      reject();
                    };
                    _this.fileReader.onabort = _this.fileReader.onerror;
                    _this.fileReader.readAsArrayBuffer(file);
                  })
                );
              });
              Promise.all(promisesFile)
                .then(function (contents) {
                  var metadata = [];
                  var li_buffer = [];
                  contents.forEach(function (c) {
                    metadata.push(c.metadata);
                    li_buffer.push(c.buffer);
                  });
                  var counter = _this.model.get("_counter");
                  _this.model.set({
                    _counter: counter + contents.length,
                    metadata: metadata,
                    data: li_buffer,
                    error: "",
                  });
                  _this.touch();
                })
                .catch(function (err) {
                  console.error("error in file upload: %o", err);
                  _this.model.set({
                    error: err,
                  });
                  _this.touch();
                });
            });
            this.listenTo(
              this.model,
              "change:button_style",
              this.update_button_style
            );
            this.set_button_style();
            this.update(); // Set defaults.
          };
          FileUploadView.prototype.update = function () {
            this.el.disabled = this.model.get("disabled");
            this.el.setAttribute("title", this.model.get("tooltip"));
            var description =
              this.model.get("description") +
              " (" +
              this.model.get("_counter") +
              ")";
            var icon = this.model.get("icon");
            if (description.length || icon.length) {
              this.el.textContent = "";
              if (icon.length) {
                var i = document.createElement("i");
                i.classList.add("fa");
                i.classList.add("fa-" + icon);
                if (description.length === 0) {
                  i.classList.add("center");
                }
                this.el.appendChild(i);
              }
              this.el.appendChild(document.createTextNode(description));
            }
            this.fileInput.accept = this.model.get("accept");
            this.fileInput.multiple = this.model.get("multiple");
            return _super.prototype.update.call(this);
          };
          FileUploadView.prototype.update_button_style = function () {
            this.update_mapped_classes(
              FileUploadView.class_map,
              "button_style",
              this.el
            );
          };
          FileUploadView.prototype.set_button_style = function () {
            this.set_mapped_classes(
              FileUploadView.class_map,
              "button_style",
              this.el
            );
          };
          FileUploadView.class_map = {
            primary: ["mod-primary"],
            success: ["mod-success"],
            info: ["mod-info"],
            warning: ["mod-warning"],
            danger: ["mod-danger"],
          };
          return FileUploadView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_1__.DOMWidgetView);

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/lib/widget_video.js":
      /*!********************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/lib/widget_video.js ***!
  \********************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ VideoModel: () => /* binding */ VideoModel,
          /* harmony export */ VideoView: () => /* binding */ VideoView,
          /* harmony export */
        });
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! @jupyter-widgets/base */ "webpack/sharing/consume/default/@jupyter-widgets/base?d99c"
          );
        /* harmony import */ var _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0___default =
          /*#__PURE__*/ __webpack_require__.n(
            _jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__
          );
        /* harmony import */ var _widget_core__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./widget_core */ "./node_modules/@jupyter-widgets/controls/lib/widget_core.js"
          );
        /* harmony import */ var underscore__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! underscore */ "./node_modules/underscore/modules/index-all.js"
          );
        // Copyright (c) Jupyter Development Team.
        // Distributed under the terms of the Modified BSD License.
        var __extends =
          (undefined && undefined.__extends) ||
          (function () {
            var extendStatics = function (d, b) {
              extendStatics =
                Object.setPrototypeOf ||
                ({ __proto__: [] } instanceof Array &&
                  function (d, b) {
                    d.__proto__ = b;
                  }) ||
                function (d, b) {
                  for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
                };
              return extendStatics(d, b);
            };
            return function (d, b) {
              extendStatics(d, b);
              function __() {
                this.constructor = d;
              }
              d.prototype =
                b === null
                  ? Object.create(b)
                  : ((__.prototype = b.prototype), new __());
            };
          })();
        var __assign =
          (undefined && undefined.__assign) ||
          function () {
            __assign =
              Object.assign ||
              function (t) {
                for (var s, i = 1, n = arguments.length; i < n; i++) {
                  s = arguments[i];
                  for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
                }
                return t;
              };
            return __assign.apply(this, arguments);
          };

        var VideoModel = /** @class */ (function (_super) {
          __extends(VideoModel, _super);
          function VideoModel() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          VideoModel.prototype.defaults = function () {
            return underscore__WEBPACK_IMPORTED_MODULE_2__.extend(
              _super.prototype.defaults.call(this),
              {
                _model_name: "VideoModel",
                _view_name: "VideoView",
                format: "mp4",
                width: "",
                height: "",
                autoplay: true,
                loop: true,
                controls: true,
                value: new DataView(new ArrayBuffer(0)),
              }
            );
          };
          VideoModel.serializers = __assign(
            __assign(
              {},
              _widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreDOMWidgetModel
                .serializers
            ),
            {
              value: {
                serialize: function (value) {
                  return new DataView(value.buffer.slice(0));
                },
              },
            }
          );
          return VideoModel;
        })(_widget_core__WEBPACK_IMPORTED_MODULE_1__.CoreDOMWidgetModel);

        var VideoView = /** @class */ (function (_super) {
          __extends(VideoView, _super);
          function VideoView() {
            return (_super !== null && _super.apply(this, arguments)) || this;
          }
          VideoView.prototype.render = function () {
            /**
             * Called when view is rendered.
             */
            _super.prototype.render.call(this);
            this.pWidget.addClass("jupyter-widgets");
            this.pWidget.addClass("widget-image");
            this.update(); // Set defaults.
          };
          VideoView.prototype.update = function () {
            /**
             * Update the contents of this view
             *
             * Called when the model is changed.  The model may have been
             * changed by another view or by a state update from the back-end.
             */
            var url;
            var format = this.model.get("format");
            var value = this.model.get("value");
            if (format !== "url") {
              var blob = new Blob([value], {
                type: "video/" + this.model.get("format"),
              });
              url = URL.createObjectURL(blob);
            } else {
              url = new TextDecoder("utf-8").decode(value.buffer);
            }
            // Clean up the old objectURL
            var oldurl = this.el.src;
            this.el.src = url;
            if (oldurl && typeof oldurl !== "string") {
              URL.revokeObjectURL(oldurl);
            }
            // Height and width
            var width = this.model.get("width");
            if (width !== undefined && width.length > 0) {
              this.el.setAttribute("width", width);
            } else {
              this.el.removeAttribute("width");
            }
            var height = this.model.get("height");
            if (height !== undefined && height.length > 0) {
              this.el.setAttribute("height", height);
            } else {
              this.el.removeAttribute("height");
            }
            // Video attributes
            this.el.loop = this.model.get("loop");
            this.el.autoplay = this.model.get("autoplay");
            this.el.controls = this.model.get("controls");
            return _super.prototype.update.call(this);
          };
          VideoView.prototype.remove = function () {
            if (this.el.src) {
              URL.revokeObjectURL(this.el.src);
            }
            _super.prototype.remove.call(this);
          };
          Object.defineProperty(VideoView.prototype, "tagName", {
            /**
             * The default tag name.
             *
             * #### Notes
             * This is a read-only attribute.
             */
            get: function () {
              // We can't make this an attribute with a default value
              // since it would be set after it is needed in the
              // constructor.
              return "video";
            },
            enumerable: true,
            configurable: true,
          });
          return VideoView;
        })(_jupyter_widgets_base__WEBPACK_IMPORTED_MODULE_0__.DOMWidgetView);

        /***/
      },

    /***/ "./node_modules/d3-format/src/defaultLocale.js":
      /*!*****************************************************!*\
  !*** ./node_modules/d3-format/src/defaultLocale.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ format: () => /* binding */ format,
          /* harmony export */ formatPrefix: () => /* binding */ formatPrefix,
          /* harmony export */ default: () => /* binding */ defaultLocale,
          /* harmony export */
        });
        /* harmony import */ var _locale_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./locale.js */ "./node_modules/d3-format/src/locale.js"
          );

        var locale;
        var format;
        var formatPrefix;

        defaultLocale({
          decimal: ".",
          thousands: ",",
          grouping: [3],
          currency: ["$", ""],
          minus: "-",
        });

        function defaultLocale(definition) {
          locale = (0, _locale_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            definition
          );
          format = locale.format;
          formatPrefix = locale.formatPrefix;
          return locale;
        }

        /***/
      },

    /***/ "./node_modules/d3-format/src/exponent.js":
      /*!************************************************!*\
  !*** ./node_modules/d3-format/src/exponent.js ***!
  \************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () =>
            /* export default binding */ __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./formatDecimal.js */ "./node_modules/d3-format/src/formatDecimal.js"
          );

        /* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {
          return (
            (x = (0,
            _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__.formatDecimalParts)(
              Math.abs(x)
            )),
            x ? x[1] : NaN
          );
        }

        /***/
      },

    /***/ "./node_modules/d3-format/src/formatDecimal.js":
      /*!*****************************************************!*\
  !*** ./node_modules/d3-format/src/formatDecimal.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () =>
            /* export default binding */ __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */ formatDecimalParts: () =>
            /* binding */ formatDecimalParts,
          /* harmony export */
        });
        /* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {
          return Math.abs((x = Math.round(x))) >= 1e21
            ? x.toLocaleString("en").replace(/,/g, "")
            : x.toString(10);
        }

        // Computes the decimal coefficient and exponent of the specified number x with
        // significant digits p, where x is positive and p is in [1, 21] or undefined.
        // For example, formatDecimalParts(1.23) returns ["123", 0].
        function formatDecimalParts(x, p) {
          if (
            (i = (x = p ? x.toExponential(p - 1) : x.toExponential()).indexOf(
              "e"
            )) < 0
          )
            return null; // NaN, ±Infinity
          var i,
            coefficient = x.slice(0, i);

          // The string returned by toExponential either has the form \d\.\d+e[-+]\d+
          // (e.g., 1.2e+3) or the form \de[-+]\d+ (e.g., 1e+3).
          return [
            coefficient.length > 1
              ? coefficient[0] + coefficient.slice(2)
              : coefficient,
            +x.slice(i + 1),
          ];
        }

        /***/
      },

    /***/ "./node_modules/d3-format/src/formatGroup.js":
      /*!***************************************************!*\
  !*** ./node_modules/d3-format/src/formatGroup.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () =>
            /* export default binding */ __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(
          grouping,
          thousands
        ) {
          return function (value, width) {
            var i = value.length,
              t = [],
              j = 0,
              g = grouping[0],
              length = 0;

            while (i > 0 && g > 0) {
              if (length + g + 1 > width) g = Math.max(1, width - length);
              t.push(value.substring((i -= g), i + g));
              if ((length += g + 1) > width) break;
              g = grouping[(j = (j + 1) % grouping.length)];
            }

            return t.reverse().join(thousands);
          };
        }

        /***/
      },

    /***/ "./node_modules/d3-format/src/formatNumerals.js":
      /*!******************************************************!*\
  !*** ./node_modules/d3-format/src/formatNumerals.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () =>
            /* export default binding */ __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(
          numerals
        ) {
          return function (value) {
            return value.replace(/[0-9]/g, function (i) {
              return numerals[+i];
            });
          };
        }

        /***/
      },

    /***/ "./node_modules/d3-format/src/formatPrefixAuto.js":
      /*!********************************************************!*\
  !*** ./node_modules/d3-format/src/formatPrefixAuto.js ***!
  \********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ prefixExponent: () =>
            /* binding */ prefixExponent,
          /* harmony export */ default: () =>
            /* export default binding */ __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./formatDecimal.js */ "./node_modules/d3-format/src/formatDecimal.js"
          );

        var prefixExponent;

        /* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x, p) {
          var d = (0,
          _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__.formatDecimalParts)(
            x,
            p
          );
          if (!d) return x + "";
          var coefficient = d[0],
            exponent = d[1],
            i =
              exponent -
              (prefixExponent =
                Math.max(-8, Math.min(8, Math.floor(exponent / 3))) * 3) +
              1,
            n = coefficient.length;
          return i === n
            ? coefficient
            : i > n
            ? coefficient + new Array(i - n + 1).join("0")
            : i > 0
            ? coefficient.slice(0, i) + "." + coefficient.slice(i)
            : "0." +
              new Array(1 - i).join("0") +
              (0,
              _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__.formatDecimalParts)(
                x,
                Math.max(0, p + i - 1)
              )[0]; // less than 1y!
        }

        /***/
      },

    /***/ "./node_modules/d3-format/src/formatRounded.js":
      /*!*****************************************************!*\
  !*** ./node_modules/d3-format/src/formatRounded.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () =>
            /* export default binding */ __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./formatDecimal.js */ "./node_modules/d3-format/src/formatDecimal.js"
          );

        /* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x, p) {
          var d = (0,
          _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__.formatDecimalParts)(
            x,
            p
          );
          if (!d) return x + "";
          var coefficient = d[0],
            exponent = d[1];
          return exponent < 0
            ? "0." + new Array(-exponent).join("0") + coefficient
            : coefficient.length > exponent + 1
            ? coefficient.slice(0, exponent + 1) +
              "." +
              coefficient.slice(exponent + 1)
            : coefficient +
              new Array(exponent - coefficient.length + 2).join("0");
        }

        /***/
      },

    /***/ "./node_modules/d3-format/src/formatSpecifier.js":
      /*!*******************************************************!*\
  !*** ./node_modules/d3-format/src/formatSpecifier.js ***!
  \*******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ formatSpecifier,
          /* harmony export */ FormatSpecifier: () =>
            /* binding */ FormatSpecifier,
          /* harmony export */
        });
        // [[fill]align][sign][symbol][0][width][,][.precision][~][type]
        var re =
          /^(?:(.)?([<>=^]))?([+\-( ])?([$#])?(0)?(\d+)?(,)?(\.\d+)?(~)?([a-z%])?$/i;

        function formatSpecifier(specifier) {
          if (!(match = re.exec(specifier)))
            throw new Error("invalid format: " + specifier);
          var match;
          return new FormatSpecifier({
            fill: match[1],
            align: match[2],
            sign: match[3],
            symbol: match[4],
            zero: match[5],
            width: match[6],
            comma: match[7],
            precision: match[8] && match[8].slice(1),
            trim: match[9],
            type: match[10],
          });
        }

        formatSpecifier.prototype = FormatSpecifier.prototype; // instanceof

        function FormatSpecifier(specifier) {
          this.fill = specifier.fill === undefined ? " " : specifier.fill + "";
          this.align =
            specifier.align === undefined ? ">" : specifier.align + "";
          this.sign = specifier.sign === undefined ? "-" : specifier.sign + "";
          this.symbol =
            specifier.symbol === undefined ? "" : specifier.symbol + "";
          this.zero = !!specifier.zero;
          this.width =
            specifier.width === undefined ? undefined : +specifier.width;
          this.comma = !!specifier.comma;
          this.precision =
            specifier.precision === undefined
              ? undefined
              : +specifier.precision;
          this.trim = !!specifier.trim;
          this.type = specifier.type === undefined ? "" : specifier.type + "";
        }

        FormatSpecifier.prototype.toString = function () {
          return (
            this.fill +
            this.align +
            this.sign +
            this.symbol +
            (this.zero ? "0" : "") +
            (this.width === undefined ? "" : Math.max(1, this.width | 0)) +
            (this.comma ? "," : "") +
            (this.precision === undefined
              ? ""
              : "." + Math.max(0, this.precision | 0)) +
            (this.trim ? "~" : "") +
            this.type
          );
        };

        /***/
      },

    /***/ "./node_modules/d3-format/src/formatTrim.js":
      /*!**************************************************!*\
  !*** ./node_modules/d3-format/src/formatTrim.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () =>
            /* export default binding */ __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        // Trims insignificant zeros, e.g., replaces 1.2000k with 1.2k.
        /* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(s) {
          out: for (var n = s.length, i = 1, i0 = -1, i1; i < n; ++i) {
            switch (s[i]) {
              case ".":
                i0 = i1 = i;
                break;
              case "0":
                if (i0 === 0) i0 = i;
                i1 = i;
                break;
              default:
                if (!+s[i]) break out;
                if (i0 > 0) i0 = 0;
                break;
            }
          }
          return i0 > 0 ? s.slice(0, i0) + s.slice(i1 + 1) : s;
        }

        /***/
      },

    /***/ "./node_modules/d3-format/src/formatTypes.js":
      /*!***************************************************!*\
  !*** ./node_modules/d3-format/src/formatTypes.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./formatDecimal.js */ "./node_modules/d3-format/src/formatDecimal.js"
          );
        /* harmony import */ var _formatPrefixAuto_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./formatPrefixAuto.js */ "./node_modules/d3-format/src/formatPrefixAuto.js"
          );
        /* harmony import */ var _formatRounded_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./formatRounded.js */ "./node_modules/d3-format/src/formatRounded.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = {
          "%": function (x, p) {
            return (x * 100).toFixed(p);
          },
          b: function (x) {
            return Math.round(x).toString(2);
          },
          c: function (x) {
            return x + "";
          },
          d: _formatDecimal_js__WEBPACK_IMPORTED_MODULE_0__["default"],
          e: function (x, p) {
            return x.toExponential(p);
          },
          f: function (x, p) {
            return x.toFixed(p);
          },
          g: function (x, p) {
            return x.toPrecision(p);
          },
          o: function (x) {
            return Math.round(x).toString(8);
          },
          p: function (x, p) {
            return (0,
            _formatRounded_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              x * 100,
              p
            );
          },
          r: _formatRounded_js__WEBPACK_IMPORTED_MODULE_1__["default"],
          s: _formatPrefixAuto_js__WEBPACK_IMPORTED_MODULE_2__["default"],
          X: function (x) {
            return Math.round(x).toString(16).toUpperCase();
          },
          x: function (x) {
            return Math.round(x).toString(16);
          },
        };

        /***/
      },

    /***/ "./node_modules/d3-format/src/identity.js":
      /*!************************************************!*\
  !*** ./node_modules/d3-format/src/identity.js ***!
  \************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () =>
            /* export default binding */ __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(x) {
          return x;
        }

        /***/
      },

    /***/ "./node_modules/d3-format/src/locale.js":
      /*!**********************************************!*\
  !*** ./node_modules/d3-format/src/locale.js ***!
  \**********************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () =>
            /* export default binding */ __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _exponent_js__WEBPACK_IMPORTED_MODULE_7__ =
          __webpack_require__(
            /*! ./exponent.js */ "./node_modules/d3-format/src/exponent.js"
          );
        /* harmony import */ var _formatGroup_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./formatGroup.js */ "./node_modules/d3-format/src/formatGroup.js"
          );
        /* harmony import */ var _formatNumerals_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./formatNumerals.js */ "./node_modules/d3-format/src/formatNumerals.js"
          );
        /* harmony import */ var _formatSpecifier_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./formatSpecifier.js */ "./node_modules/d3-format/src/formatSpecifier.js"
          );
        /* harmony import */ var _formatTrim_js__WEBPACK_IMPORTED_MODULE_5__ =
          __webpack_require__(
            /*! ./formatTrim.js */ "./node_modules/d3-format/src/formatTrim.js"
          );
        /* harmony import */ var _formatTypes_js__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! ./formatTypes.js */ "./node_modules/d3-format/src/formatTypes.js"
          );
        /* harmony import */ var _formatPrefixAuto_js__WEBPACK_IMPORTED_MODULE_6__ =
          __webpack_require__(
            /*! ./formatPrefixAuto.js */ "./node_modules/d3-format/src/formatPrefixAuto.js"
          );
        /* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./identity.js */ "./node_modules/d3-format/src/identity.js"
          );

        var map = Array.prototype.map,
          prefixes = [
            "y",
            "z",
            "a",
            "f",
            "p",
            "n",
            "µ",
            "m",
            "",
            "k",
            "M",
            "G",
            "T",
            "P",
            "E",
            "Z",
            "Y",
          ];

        /* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(
          locale
        ) {
          var group =
              locale.grouping === undefined || locale.thousands === undefined
                ? _identity_js__WEBPACK_IMPORTED_MODULE_0__["default"]
                : (0, _formatGroup_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
                    map.call(locale.grouping, Number),
                    locale.thousands + ""
                  ),
            currencyPrefix =
              locale.currency === undefined ? "" : locale.currency[0] + "",
            currencySuffix =
              locale.currency === undefined ? "" : locale.currency[1] + "",
            decimal = locale.decimal === undefined ? "." : locale.decimal + "",
            numerals =
              locale.numerals === undefined
                ? _identity_js__WEBPACK_IMPORTED_MODULE_0__["default"]
                : (0,
                  _formatNumerals_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
                    map.call(locale.numerals, String)
                  ),
            percent = locale.percent === undefined ? "%" : locale.percent + "",
            minus = locale.minus === undefined ? "-" : locale.minus + "",
            nan = locale.nan === undefined ? "NaN" : locale.nan + "";

          function newFormat(specifier) {
            specifier = (0,
            _formatSpecifier_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
              specifier
            );

            var fill = specifier.fill,
              align = specifier.align,
              sign = specifier.sign,
              symbol = specifier.symbol,
              zero = specifier.zero,
              width = specifier.width,
              comma = specifier.comma,
              precision = specifier.precision,
              trim = specifier.trim,
              type = specifier.type;

            // The "n" type is an alias for ",g".
            if (type === "n") (comma = true), (type = "g");
            // The "" type, and any invalid type, is an alias for ".12~g".
            else if (
              !_formatTypes_js__WEBPACK_IMPORTED_MODULE_4__["default"][type]
            )
              precision === undefined && (precision = 12),
                (trim = true),
                (type = "g");

            // If zero fill is specified, padding goes after sign and before digits.
            if (zero || (fill === "0" && align === "="))
              (zero = true), (fill = "0"), (align = "=");

            // Compute the prefix and suffix.
            // For SI-prefix, the suffix is lazily computed.
            var prefix =
                symbol === "$"
                  ? currencyPrefix
                  : symbol === "#" && /[boxX]/.test(type)
                  ? "0" + type.toLowerCase()
                  : "",
              suffix =
                symbol === "$"
                  ? currencySuffix
                  : /[%p]/.test(type)
                  ? percent
                  : "";

            // What format function should we use?
            // Is this an integer type?
            // Can this type generate exponential notation?
            var formatType =
                _formatTypes_js__WEBPACK_IMPORTED_MODULE_4__["default"][type],
              maybeSuffix = /[defgprs%]/.test(type);

            // Set the default precision if not specified,
            // or clamp the specified precision to the supported range.
            // For significant precision, it must be in [1, 21].
            // For fixed precision, it must be in [0, 20].
            precision =
              precision === undefined
                ? 6
                : /[gprs]/.test(type)
                ? Math.max(1, Math.min(21, precision))
                : Math.max(0, Math.min(20, precision));

            function format(value) {
              var valuePrefix = prefix,
                valueSuffix = suffix,
                i,
                n,
                c;

              if (type === "c") {
                valueSuffix = formatType(value) + valueSuffix;
                value = "";
              } else {
                value = +value;

                // Determine the sign. -0 is not less than 0, but 1 / -0 is!
                var valueNegative = value < 0 || 1 / value < 0;

                // Perform the initial formatting.
                value = isNaN(value)
                  ? nan
                  : formatType(Math.abs(value), precision);

                // Trim insignificant zeros.
                if (trim)
                  value = (0,
                  _formatTrim_js__WEBPACK_IMPORTED_MODULE_5__["default"])(
                    value
                  );

                // If a negative value rounds to zero after formatting, and no explicit positive sign is requested, hide the sign.
                if (valueNegative && +value === 0 && sign !== "+")
                  valueNegative = false;

                // Compute the prefix and suffix.
                valuePrefix =
                  (valueNegative
                    ? sign === "("
                      ? sign
                      : minus
                    : sign === "-" || sign === "("
                    ? ""
                    : sign) + valuePrefix;
                valueSuffix =
                  (type === "s"
                    ? prefixes[
                        8 +
                          _formatPrefixAuto_js__WEBPACK_IMPORTED_MODULE_6__.prefixExponent /
                            3
                      ]
                    : "") +
                  valueSuffix +
                  (valueNegative && sign === "(" ? ")" : "");

                // Break the formatted value into the integer “value” part that can be
                // grouped, and fractional or exponential “suffix” part that is not.
                if (maybeSuffix) {
                  (i = -1), (n = value.length);
                  while (++i < n) {
                    if (((c = value.charCodeAt(i)), 48 > c || c > 57)) {
                      valueSuffix =
                        (c === 46
                          ? decimal + value.slice(i + 1)
                          : value.slice(i)) + valueSuffix;
                      value = value.slice(0, i);
                      break;
                    }
                  }
                }
              }

              // If the fill character is not "0", grouping is applied before padding.
              if (comma && !zero) value = group(value, Infinity);

              // Compute the padding.
              var length =
                  valuePrefix.length + value.length + valueSuffix.length,
                padding =
                  length < width
                    ? new Array(width - length + 1).join(fill)
                    : "";

              // If the fill character is "0", grouping is applied after padding.
              if (comma && zero)
                (value = group(
                  padding + value,
                  padding.length ? width - valueSuffix.length : Infinity
                )),
                  (padding = "");

              // Reconstruct the final output based on the desired alignment.
              switch (align) {
                case "<":
                  value = valuePrefix + value + valueSuffix + padding;
                  break;
                case "=":
                  value = valuePrefix + padding + value + valueSuffix;
                  break;
                case "^":
                  value =
                    padding.slice(0, (length = padding.length >> 1)) +
                    valuePrefix +
                    value +
                    valueSuffix +
                    padding.slice(length);
                  break;
                default:
                  value = padding + valuePrefix + value + valueSuffix;
                  break;
              }

              return numerals(value);
            }

            format.toString = function () {
              return specifier + "";
            };

            return format;
          }

          function formatPrefix(specifier, value) {
            var f = newFormat(
                ((specifier = (0,
                _formatSpecifier_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
                  specifier
                )),
                (specifier.type = "f"),
                specifier)
              ),
              e =
                Math.max(
                  -8,
                  Math.min(
                    8,
                    Math.floor(
                      (0, _exponent_js__WEBPACK_IMPORTED_MODULE_7__["default"])(
                        value
                      ) / 3
                    )
                  )
                ) * 3,
              k = Math.pow(10, -e),
              prefix = prefixes[8 + e / 3];
            return function (value) {
              return f(k * value) + prefix;
            };
          }

          return {
            format: newFormat,
            formatPrefix: formatPrefix,
          };
        }

        /***/
      },

    /***/ "./node_modules/jquery-ui/ui/ie.js":
      /*!*****************************************!*\
  !*** ./node_modules/jquery-ui/ui/ie.js ***!
  \*****************************************/
      /***/ (module, exports, __webpack_require__) => {
        var __WEBPACK_AMD_DEFINE_FACTORY__,
          __WEBPACK_AMD_DEFINE_ARRAY__,
          __WEBPACK_AMD_DEFINE_RESULT__;
        (function (factory) {
          "use strict";

          if (true) {
            // AMD. Register as an anonymous module.
            !((__WEBPACK_AMD_DEFINE_ARRAY__ = [
              __webpack_require__(
                /*! jquery */ "./node_modules/jquery/dist/jquery.js"
              ),
              __webpack_require__(
                /*! ./version */ "./node_modules/jquery-ui/ui/version.js"
              ),
            ]),
            (__WEBPACK_AMD_DEFINE_FACTORY__ = factory),
            (__WEBPACK_AMD_DEFINE_RESULT__ =
              typeof __WEBPACK_AMD_DEFINE_FACTORY__ === "function"
                ? __WEBPACK_AMD_DEFINE_FACTORY__.apply(
                    exports,
                    __WEBPACK_AMD_DEFINE_ARRAY__
                  )
                : __WEBPACK_AMD_DEFINE_FACTORY__),
            __WEBPACK_AMD_DEFINE_RESULT__ !== undefined &&
              (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
          } else {
          }
        })(function ($) {
          "use strict";

          // This file is deprecated
          return ($.ui.ie = !!/msie [\w.]+/.exec(
            navigator.userAgent.toLowerCase()
          ));
        });

        /***/
      },

    /***/ "./node_modules/jquery-ui/ui/keycode.js":
      /*!**********************************************!*\
  !*** ./node_modules/jquery-ui/ui/keycode.js ***!
  \**********************************************/
      /***/ (module, exports, __webpack_require__) => {
        var __WEBPACK_AMD_DEFINE_FACTORY__,
          __WEBPACK_AMD_DEFINE_ARRAY__,
          __WEBPACK_AMD_DEFINE_RESULT__;
        /*!
         * jQuery UI Keycode 1.13.0
         * http://jqueryui.com
         *
         * Copyright jQuery Foundation and other contributors
         * Released under the MIT license.
         * http://jquery.org/license
         */

        //>>label: Keycode
        //>>group: Core
        //>>description: Provide keycodes as keynames
        //>>docs: http://api.jqueryui.com/jQuery.ui.keyCode/

        (function (factory) {
          "use strict";

          if (true) {
            // AMD. Register as an anonymous module.
            !((__WEBPACK_AMD_DEFINE_ARRAY__ = [
              __webpack_require__(
                /*! jquery */ "./node_modules/jquery/dist/jquery.js"
              ),
              __webpack_require__(
                /*! ./version */ "./node_modules/jquery-ui/ui/version.js"
              ),
            ]),
            (__WEBPACK_AMD_DEFINE_FACTORY__ = factory),
            (__WEBPACK_AMD_DEFINE_RESULT__ =
              typeof __WEBPACK_AMD_DEFINE_FACTORY__ === "function"
                ? __WEBPACK_AMD_DEFINE_FACTORY__.apply(
                    exports,
                    __WEBPACK_AMD_DEFINE_ARRAY__
                  )
                : __WEBPACK_AMD_DEFINE_FACTORY__),
            __WEBPACK_AMD_DEFINE_RESULT__ !== undefined &&
              (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
          } else {
          }
        })(function ($) {
          "use strict";

          return ($.ui.keyCode = {
            BACKSPACE: 8,
            COMMA: 188,
            DELETE: 46,
            DOWN: 40,
            END: 35,
            ENTER: 13,
            ESCAPE: 27,
            HOME: 36,
            LEFT: 37,
            PAGE_DOWN: 34,
            PAGE_UP: 33,
            PERIOD: 190,
            RIGHT: 39,
            SPACE: 32,
            TAB: 9,
            UP: 38,
          });
        });

        /***/
      },

    /***/ "./node_modules/jquery-ui/ui/version.js":
      /*!**********************************************!*\
  !*** ./node_modules/jquery-ui/ui/version.js ***!
  \**********************************************/
      /***/ (module, exports, __webpack_require__) => {
        var __WEBPACK_AMD_DEFINE_FACTORY__,
          __WEBPACK_AMD_DEFINE_ARRAY__,
          __WEBPACK_AMD_DEFINE_RESULT__;
        (function (factory) {
          "use strict";

          if (true) {
            // AMD. Register as an anonymous module.
            !((__WEBPACK_AMD_DEFINE_ARRAY__ = [
              __webpack_require__(
                /*! jquery */ "./node_modules/jquery/dist/jquery.js"
              ),
            ]),
            (__WEBPACK_AMD_DEFINE_FACTORY__ = factory),
            (__WEBPACK_AMD_DEFINE_RESULT__ =
              typeof __WEBPACK_AMD_DEFINE_FACTORY__ === "function"
                ? __WEBPACK_AMD_DEFINE_FACTORY__.apply(
                    exports,
                    __WEBPACK_AMD_DEFINE_ARRAY__
                  )
                : __WEBPACK_AMD_DEFINE_FACTORY__),
            __WEBPACK_AMD_DEFINE_RESULT__ !== undefined &&
              (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
          } else {
          }
        })(function ($) {
          "use strict";

          $.ui = $.ui || {};

          return ($.ui.version = "1.13.0");
        });

        /***/
      },

    /***/ "./node_modules/jquery-ui/ui/widget.js":
      /*!*********************************************!*\
  !*** ./node_modules/jquery-ui/ui/widget.js ***!
  \*********************************************/
      /***/ (module, exports, __webpack_require__) => {
        var __WEBPACK_AMD_DEFINE_FACTORY__,
          __WEBPACK_AMD_DEFINE_ARRAY__,
          __WEBPACK_AMD_DEFINE_RESULT__;
        /*!
         * jQuery UI Widget 1.13.0
         * http://jqueryui.com
         *
         * Copyright jQuery Foundation and other contributors
         * Released under the MIT license.
         * http://jquery.org/license
         */

        //>>label: Widget
        //>>group: Core
        //>>description: Provides a factory for creating stateful widgets with a common API.
        //>>docs: http://api.jqueryui.com/jQuery.widget/
        //>>demos: http://jqueryui.com/widget/

        (function (factory) {
          "use strict";

          if (true) {
            // AMD. Register as an anonymous module.
            !((__WEBPACK_AMD_DEFINE_ARRAY__ = [
              __webpack_require__(
                /*! jquery */ "./node_modules/jquery/dist/jquery.js"
              ),
              __webpack_require__(
                /*! ./version */ "./node_modules/jquery-ui/ui/version.js"
              ),
            ]),
            (__WEBPACK_AMD_DEFINE_FACTORY__ = factory),
            (__WEBPACK_AMD_DEFINE_RESULT__ =
              typeof __WEBPACK_AMD_DEFINE_FACTORY__ === "function"
                ? __WEBPACK_AMD_DEFINE_FACTORY__.apply(
                    exports,
                    __WEBPACK_AMD_DEFINE_ARRAY__
                  )
                : __WEBPACK_AMD_DEFINE_FACTORY__),
            __WEBPACK_AMD_DEFINE_RESULT__ !== undefined &&
              (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
          } else {
          }
        })(function ($) {
          "use strict";

          var widgetUuid = 0;
          var widgetHasOwnProperty = Array.prototype.hasOwnProperty;
          var widgetSlice = Array.prototype.slice;

          $.cleanData = (function (orig) {
            return function (elems) {
              var events, elem, i;
              for (i = 0; (elem = elems[i]) != null; i++) {
                // Only trigger remove when necessary to save time
                events = $._data(elem, "events");
                if (events && events.remove) {
                  $(elem).triggerHandler("remove");
                }
              }
              orig(elems);
            };
          })($.cleanData);

          $.widget = function (name, base, prototype) {
            var existingConstructor, constructor, basePrototype;

            // ProxiedPrototype allows the provided prototype to remain unmodified
            // so that it can be used as a mixin for multiple widgets (#8876)
            var proxiedPrototype = {};

            var namespace = name.split(".")[0];
            name = name.split(".")[1];
            var fullName = namespace + "-" + name;

            if (!prototype) {
              prototype = base;
              base = $.Widget;
            }

            if (Array.isArray(prototype)) {
              prototype = $.extend.apply(null, [{}].concat(prototype));
            }

            // Create selector for plugin
            $.expr.pseudos[fullName.toLowerCase()] = function (elem) {
              return !!$.data(elem, fullName);
            };

            $[namespace] = $[namespace] || {};
            existingConstructor = $[namespace][name];
            constructor = $[namespace][name] = function (options, element) {
              // Allow instantiation without "new" keyword
              if (!this._createWidget) {
                return new constructor(options, element);
              }

              // Allow instantiation without initializing for simple inheritance
              // must use "new" keyword (the code above always passes args)
              if (arguments.length) {
                this._createWidget(options, element);
              }
            };

            // Extend with the existing constructor to carry over any static properties
            $.extend(constructor, existingConstructor, {
              version: prototype.version,

              // Copy the object used to create the prototype in case we need to
              // redefine the widget later
              _proto: $.extend({}, prototype),

              // Track widgets that inherit from this widget in case this widget is
              // redefined after a widget inherits from it
              _childConstructors: [],
            });

            basePrototype = new base();

            // We need to make the options hash a property directly on the new instance
            // otherwise we'll modify the options hash on the prototype that we're
            // inheriting from
            basePrototype.options = $.widget.extend({}, basePrototype.options);
            $.each(prototype, function (prop, value) {
              if (typeof value !== "function") {
                proxiedPrototype[prop] = value;
                return;
              }
              proxiedPrototype[prop] = (function () {
                function _super() {
                  return base.prototype[prop].apply(this, arguments);
                }

                function _superApply(args) {
                  return base.prototype[prop].apply(this, args);
                }

                return function () {
                  var __super = this._super;
                  var __superApply = this._superApply;
                  var returnValue;

                  this._super = _super;
                  this._superApply = _superApply;

                  returnValue = value.apply(this, arguments);

                  this._super = __super;
                  this._superApply = __superApply;

                  return returnValue;
                };
              })();
            });
            constructor.prototype = $.widget.extend(
              basePrototype,
              {
                // TODO: remove support for widgetEventPrefix
                // always use the name + a colon as the prefix, e.g., draggable:start
                // don't prefix for widgets that aren't DOM-based
                widgetEventPrefix: existingConstructor
                  ? basePrototype.widgetEventPrefix || name
                  : name,
              },
              proxiedPrototype,
              {
                constructor: constructor,
                namespace: namespace,
                widgetName: name,
                widgetFullName: fullName,
              }
            );

            // If this widget is being redefined then we need to find all widgets that
            // are inheriting from it and redefine all of them so that they inherit from
            // the new version of this widget. We're essentially trying to replace one
            // level in the prototype chain.
            if (existingConstructor) {
              $.each(
                existingConstructor._childConstructors,
                function (i, child) {
                  var childPrototype = child.prototype;

                  // Redefine the child widget using the same prototype that was
                  // originally used, but inherit from the new version of the base
                  $.widget(
                    childPrototype.namespace + "." + childPrototype.widgetName,
                    constructor,
                    child._proto
                  );
                }
              );

              // Remove the list of existing child constructors from the old constructor
              // so the old child constructors can be garbage collected
              delete existingConstructor._childConstructors;
            } else {
              base._childConstructors.push(constructor);
            }

            $.widget.bridge(name, constructor);

            return constructor;
          };

          $.widget.extend = function (target) {
            var input = widgetSlice.call(arguments, 1);
            var inputIndex = 0;
            var inputLength = input.length;
            var key;
            var value;

            for (; inputIndex < inputLength; inputIndex++) {
              for (key in input[inputIndex]) {
                value = input[inputIndex][key];
                if (
                  widgetHasOwnProperty.call(input[inputIndex], key) &&
                  value !== undefined
                ) {
                  // Clone objects
                  if ($.isPlainObject(value)) {
                    target[key] = $.isPlainObject(target[key])
                      ? $.widget.extend({}, target[key], value)
                      : // Don't extend strings, arrays, etc. with objects
                        $.widget.extend({}, value);

                    // Copy everything else by reference
                  } else {
                    target[key] = value;
                  }
                }
              }
            }
            return target;
          };

          $.widget.bridge = function (name, object) {
            var fullName = object.prototype.widgetFullName || name;
            $.fn[name] = function (options) {
              var isMethodCall = typeof options === "string";
              var args = widgetSlice.call(arguments, 1);
              var returnValue = this;

              if (isMethodCall) {
                // If this is an empty collection, we need to have the instance method
                // return undefined instead of the jQuery instance
                if (!this.length && options === "instance") {
                  returnValue = undefined;
                } else {
                  this.each(function () {
                    var methodValue;
                    var instance = $.data(this, fullName);

                    if (options === "instance") {
                      returnValue = instance;
                      return false;
                    }

                    if (!instance) {
                      return $.error(
                        "cannot call methods on " +
                          name +
                          " prior to initialization; " +
                          "attempted to call method '" +
                          options +
                          "'"
                      );
                    }

                    if (
                      typeof instance[options] !== "function" ||
                      options.charAt(0) === "_"
                    ) {
                      return $.error(
                        "no such method '" +
                          options +
                          "' for " +
                          name +
                          " widget instance"
                      );
                    }

                    methodValue = instance[options].apply(instance, args);

                    if (methodValue !== instance && methodValue !== undefined) {
                      returnValue =
                        methodValue && methodValue.jquery
                          ? returnValue.pushStack(methodValue.get())
                          : methodValue;
                      return false;
                    }
                  });
                }
              } else {
                // Allow multiple hashes to be passed on init
                if (args.length) {
                  options = $.widget.extend.apply(null, [options].concat(args));
                }

                this.each(function () {
                  var instance = $.data(this, fullName);
                  if (instance) {
                    instance.option(options || {});
                    if (instance._init) {
                      instance._init();
                    }
                  } else {
                    $.data(this, fullName, new object(options, this));
                  }
                });
              }

              return returnValue;
            };
          };

          $.Widget = function (/* options, element */) {};
          $.Widget._childConstructors = [];

          $.Widget.prototype = {
            widgetName: "widget",
            widgetEventPrefix: "",
            defaultElement: "<div>",

            options: {
              classes: {},
              disabled: false,

              // Callbacks
              create: null,
            },

            _createWidget: function (options, element) {
              element = $(element || this.defaultElement || this)[0];
              this.element = $(element);
              this.uuid = widgetUuid++;
              this.eventNamespace = "." + this.widgetName + this.uuid;

              this.bindings = $();
              this.hoverable = $();
              this.focusable = $();
              this.classesElementLookup = {};

              if (element !== this) {
                $.data(element, this.widgetFullName, this);
                this._on(true, this.element, {
                  remove: function (event) {
                    if (event.target === element) {
                      this.destroy();
                    }
                  },
                });
                this.document = $(
                  element.style
                    ? // Element within the document
                      element.ownerDocument
                    : // Element is window or document
                      element.document || element
                );
                this.window = $(
                  this.document[0].defaultView || this.document[0].parentWindow
                );
              }

              this.options = $.widget.extend(
                {},
                this.options,
                this._getCreateOptions(),
                options
              );

              this._create();

              if (this.options.disabled) {
                this._setOptionDisabled(this.options.disabled);
              }

              this._trigger("create", null, this._getCreateEventData());
              this._init();
            },

            _getCreateOptions: function () {
              return {};
            },

            _getCreateEventData: $.noop,

            _create: $.noop,

            _init: $.noop,

            destroy: function () {
              var that = this;

              this._destroy();
              $.each(this.classesElementLookup, function (key, value) {
                that._removeClass(value, key);
              });

              // We can probably remove the unbind calls in 2.0
              // all event bindings should go through this._on()
              this.element
                .off(this.eventNamespace)
                .removeData(this.widgetFullName);
              this.widget()
                .off(this.eventNamespace)
                .removeAttr("aria-disabled");

              // Clean up events and states
              this.bindings.off(this.eventNamespace);
            },

            _destroy: $.noop,

            widget: function () {
              return this.element;
            },

            option: function (key, value) {
              var options = key;
              var parts;
              var curOption;
              var i;

              if (arguments.length === 0) {
                // Don't return a reference to the internal hash
                return $.widget.extend({}, this.options);
              }

              if (typeof key === "string") {
                // Handle nested keys, e.g., "foo.bar" => { foo: { bar: ___ } }
                options = {};
                parts = key.split(".");
                key = parts.shift();
                if (parts.length) {
                  curOption = options[key] = $.widget.extend(
                    {},
                    this.options[key]
                  );
                  for (i = 0; i < parts.length - 1; i++) {
                    curOption[parts[i]] = curOption[parts[i]] || {};
                    curOption = curOption[parts[i]];
                  }
                  key = parts.pop();
                  if (arguments.length === 1) {
                    return curOption[key] === undefined ? null : curOption[key];
                  }
                  curOption[key] = value;
                } else {
                  if (arguments.length === 1) {
                    return this.options[key] === undefined
                      ? null
                      : this.options[key];
                  }
                  options[key] = value;
                }
              }

              this._setOptions(options);

              return this;
            },

            _setOptions: function (options) {
              var key;

              for (key in options) {
                this._setOption(key, options[key]);
              }

              return this;
            },

            _setOption: function (key, value) {
              if (key === "classes") {
                this._setOptionClasses(value);
              }

              this.options[key] = value;

              if (key === "disabled") {
                this._setOptionDisabled(value);
              }

              return this;
            },

            _setOptionClasses: function (value) {
              var classKey, elements, currentElements;

              for (classKey in value) {
                currentElements = this.classesElementLookup[classKey];
                if (
                  value[classKey] === this.options.classes[classKey] ||
                  !currentElements ||
                  !currentElements.length
                ) {
                  continue;
                }

                // We are doing this to create a new jQuery object because the _removeClass() call
                // on the next line is going to destroy the reference to the current elements being
                // tracked. We need to save a copy of this collection so that we can add the new classes
                // below.
                elements = $(currentElements.get());
                this._removeClass(currentElements, classKey);

                // We don't use _addClass() here, because that uses this.options.classes
                // for generating the string of classes. We want to use the value passed in from
                // _setOption(), this is the new value of the classes option which was passed to
                // _setOption(). We pass this value directly to _classes().
                elements.addClass(
                  this._classes({
                    element: elements,
                    keys: classKey,
                    classes: value,
                    add: true,
                  })
                );
              }
            },

            _setOptionDisabled: function (value) {
              this._toggleClass(
                this.widget(),
                this.widgetFullName + "-disabled",
                null,
                !!value
              );

              // If the widget is becoming disabled, then nothing is interactive
              if (value) {
                this._removeClass(this.hoverable, null, "ui-state-hover");
                this._removeClass(this.focusable, null, "ui-state-focus");
              }
            },

            enable: function () {
              return this._setOptions({ disabled: false });
            },

            disable: function () {
              return this._setOptions({ disabled: true });
            },

            _classes: function (options) {
              var full = [];
              var that = this;

              options = $.extend(
                {
                  element: this.element,
                  classes: this.options.classes || {},
                },
                options
              );

              function bindRemoveEvent() {
                options.element.each(function (_, element) {
                  var isTracked = $.map(
                    that.classesElementLookup,
                    function (elements) {
                      return elements;
                    }
                  ).some(function (elements) {
                    return elements.is(element);
                  });

                  if (!isTracked) {
                    that._on($(element), {
                      remove: "_untrackClassesElement",
                    });
                  }
                });
              }

              function processClassString(classes, checkOption) {
                var current, i;
                for (i = 0; i < classes.length; i++) {
                  current = that.classesElementLookup[classes[i]] || $();
                  if (options.add) {
                    bindRemoveEvent();
                    current = $(
                      $.uniqueSort(current.get().concat(options.element.get()))
                    );
                  } else {
                    current = $(current.not(options.element).get());
                  }
                  that.classesElementLookup[classes[i]] = current;
                  full.push(classes[i]);
                  if (checkOption && options.classes[classes[i]]) {
                    full.push(options.classes[classes[i]]);
                  }
                }
              }

              if (options.keys) {
                processClassString(options.keys.match(/\S+/g) || [], true);
              }
              if (options.extra) {
                processClassString(options.extra.match(/\S+/g) || []);
              }

              return full.join(" ");
            },

            _untrackClassesElement: function (event) {
              var that = this;
              $.each(that.classesElementLookup, function (key, value) {
                if ($.inArray(event.target, value) !== -1) {
                  that.classesElementLookup[key] = $(
                    value.not(event.target).get()
                  );
                }
              });

              this._off($(event.target));
            },

            _removeClass: function (element, keys, extra) {
              return this._toggleClass(element, keys, extra, false);
            },

            _addClass: function (element, keys, extra) {
              return this._toggleClass(element, keys, extra, true);
            },

            _toggleClass: function (element, keys, extra, add) {
              add = typeof add === "boolean" ? add : extra;
              var shift = typeof element === "string" || element === null,
                options = {
                  extra: shift ? keys : extra,
                  keys: shift ? element : keys,
                  element: shift ? this.element : element,
                  add: add,
                };
              options.element.toggleClass(this._classes(options), add);
              return this;
            },

            _on: function (suppressDisabledCheck, element, handlers) {
              var delegateElement;
              var instance = this;

              // No suppressDisabledCheck flag, shuffle arguments
              if (typeof suppressDisabledCheck !== "boolean") {
                handlers = element;
                element = suppressDisabledCheck;
                suppressDisabledCheck = false;
              }

              // No element argument, shuffle and use this.element
              if (!handlers) {
                handlers = element;
                element = this.element;
                delegateElement = this.widget();
              } else {
                element = delegateElement = $(element);
                this.bindings = this.bindings.add(element);
              }

              $.each(handlers, function (event, handler) {
                function handlerProxy() {
                  // Allow widgets to customize the disabled handling
                  // - disabled as an array instead of boolean
                  // - disabled class as method for disabling individual parts
                  if (
                    !suppressDisabledCheck &&
                    (instance.options.disabled === true ||
                      $(this).hasClass("ui-state-disabled"))
                  ) {
                    return;
                  }
                  return (
                    typeof handler === "string" ? instance[handler] : handler
                  ).apply(instance, arguments);
                }

                // Copy the guid so direct unbinding works
                if (typeof handler !== "string") {
                  handlerProxy.guid = handler.guid =
                    handler.guid || handlerProxy.guid || $.guid++;
                }

                var match = event.match(/^([\w:-]*)\s*(.*)$/);
                var eventName = match[1] + instance.eventNamespace;
                var selector = match[2];

                if (selector) {
                  delegateElement.on(eventName, selector, handlerProxy);
                } else {
                  element.on(eventName, handlerProxy);
                }
              });
            },

            _off: function (element, eventName) {
              eventName =
                (eventName || "").split(" ").join(this.eventNamespace + " ") +
                this.eventNamespace;
              element.off(eventName);

              // Clear the stack to avoid memory leaks (#10056)
              this.bindings = $(this.bindings.not(element).get());
              this.focusable = $(this.focusable.not(element).get());
              this.hoverable = $(this.hoverable.not(element).get());
            },

            _delay: function (handler, delay) {
              function handlerProxy() {
                return (
                  typeof handler === "string" ? instance[handler] : handler
                ).apply(instance, arguments);
              }
              var instance = this;
              return setTimeout(handlerProxy, delay || 0);
            },

            _hoverable: function (element) {
              this.hoverable = this.hoverable.add(element);
              this._on(element, {
                mouseenter: function (event) {
                  this._addClass(
                    $(event.currentTarget),
                    null,
                    "ui-state-hover"
                  );
                },
                mouseleave: function (event) {
                  this._removeClass(
                    $(event.currentTarget),
                    null,
                    "ui-state-hover"
                  );
                },
              });
            },

            _focusable: function (element) {
              this.focusable = this.focusable.add(element);
              this._on(element, {
                focusin: function (event) {
                  this._addClass(
                    $(event.currentTarget),
                    null,
                    "ui-state-focus"
                  );
                },
                focusout: function (event) {
                  this._removeClass(
                    $(event.currentTarget),
                    null,
                    "ui-state-focus"
                  );
                },
              });
            },

            _trigger: function (type, event, data) {
              var prop, orig;
              var callback = this.options[type];

              data = data || {};
              event = $.Event(event);
              event.type = (
                type === this.widgetEventPrefix
                  ? type
                  : this.widgetEventPrefix + type
              ).toLowerCase();

              // The original event may come from any element
              // so we need to reset the target on the new event
              event.target = this.element[0];

              // Copy original event properties over to the new event
              orig = event.originalEvent;
              if (orig) {
                for (prop in orig) {
                  if (!(prop in event)) {
                    event[prop] = orig[prop];
                  }
                }
              }

              this.element.trigger(event, data);
              return !(
                (typeof callback === "function" &&
                  callback.apply(this.element[0], [event].concat(data)) ===
                    false) ||
                event.isDefaultPrevented()
              );
            },
          };

          $.each(
            { show: "fadeIn", hide: "fadeOut" },
            function (method, defaultEffect) {
              $.Widget.prototype["_" + method] = function (
                element,
                options,
                callback
              ) {
                if (typeof options === "string") {
                  options = { effect: options };
                }

                var hasOptions;
                var effectName = !options
                  ? method
                  : options === true || typeof options === "number"
                  ? defaultEffect
                  : options.effect || defaultEffect;

                options = options || {};
                if (typeof options === "number") {
                  options = { duration: options };
                } else if (options === true) {
                  options = {};
                }

                hasOptions = !$.isEmptyObject(options);
                options.complete = callback;

                if (options.delay) {
                  element.delay(options.delay);
                }

                if (hasOptions && $.effects && $.effects.effect[effectName]) {
                  element[method](options);
                } else if (effectName !== method && element[effectName]) {
                  element[effectName](
                    options.duration,
                    options.easing,
                    callback
                  );
                } else {
                  element.queue(function (next) {
                    $(this)[method]();
                    if (callback) {
                      callback.call(element[0]);
                    }
                    next();
                  });
                }
              };
            }
          );

          return $.widget;
        });

        /***/
      },

    /***/ "./node_modules/jquery-ui/ui/widgets/mouse.js":
      /*!****************************************************!*\
  !*** ./node_modules/jquery-ui/ui/widgets/mouse.js ***!
  \****************************************************/
      /***/ (module, exports, __webpack_require__) => {
        var __WEBPACK_AMD_DEFINE_FACTORY__,
          __WEBPACK_AMD_DEFINE_ARRAY__,
          __WEBPACK_AMD_DEFINE_RESULT__;
        /*!
         * jQuery UI Mouse 1.13.0
         * http://jqueryui.com
         *
         * Copyright jQuery Foundation and other contributors
         * Released under the MIT license.
         * http://jquery.org/license
         */

        //>>label: Mouse
        //>>group: Widgets
        //>>description: Abstracts mouse-based interactions to assist in creating certain widgets.
        //>>docs: http://api.jqueryui.com/mouse/

        (function (factory) {
          "use strict";

          if (true) {
            // AMD. Register as an anonymous module.
            !((__WEBPACK_AMD_DEFINE_ARRAY__ = [
              __webpack_require__(
                /*! jquery */ "./node_modules/jquery/dist/jquery.js"
              ),
              __webpack_require__(
                /*! ../ie */ "./node_modules/jquery-ui/ui/ie.js"
              ),
              __webpack_require__(
                /*! ../version */ "./node_modules/jquery-ui/ui/version.js"
              ),
              __webpack_require__(
                /*! ../widget */ "./node_modules/jquery-ui/ui/widget.js"
              ),
            ]),
            (__WEBPACK_AMD_DEFINE_FACTORY__ = factory),
            (__WEBPACK_AMD_DEFINE_RESULT__ =
              typeof __WEBPACK_AMD_DEFINE_FACTORY__ === "function"
                ? __WEBPACK_AMD_DEFINE_FACTORY__.apply(
                    exports,
                    __WEBPACK_AMD_DEFINE_ARRAY__
                  )
                : __WEBPACK_AMD_DEFINE_FACTORY__),
            __WEBPACK_AMD_DEFINE_RESULT__ !== undefined &&
              (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
          } else {
          }
        })(function ($) {
          "use strict";

          var mouseHandled = false;
          $(document).on("mouseup", function () {
            mouseHandled = false;
          });

          return $.widget("ui.mouse", {
            version: "1.13.0",
            options: {
              cancel: "input, textarea, button, select, option",
              distance: 1,
              delay: 0,
            },
            _mouseInit: function () {
              var that = this;

              this.element
                .on("mousedown." + this.widgetName, function (event) {
                  return that._mouseDown(event);
                })
                .on("click." + this.widgetName, function (event) {
                  if (
                    true ===
                    $.data(event.target, that.widgetName + ".preventClickEvent")
                  ) {
                    $.removeData(
                      event.target,
                      that.widgetName + ".preventClickEvent"
                    );
                    event.stopImmediatePropagation();
                    return false;
                  }
                });

              this.started = false;
            },

            // TODO: make sure destroying one instance of mouse doesn't mess with
            // other instances of mouse
            _mouseDestroy: function () {
              this.element.off("." + this.widgetName);
              if (this._mouseMoveDelegate) {
                this.document
                  .off("mousemove." + this.widgetName, this._mouseMoveDelegate)
                  .off("mouseup." + this.widgetName, this._mouseUpDelegate);
              }
            },

            _mouseDown: function (event) {
              // don't let more than one widget handle mouseStart
              if (mouseHandled) {
                return;
              }

              this._mouseMoved = false;

              // We may have missed mouseup (out of window)
              if (this._mouseStarted) {
                this._mouseUp(event);
              }

              this._mouseDownEvent = event;

              var that = this,
                btnIsLeft = event.which === 1,
                // event.target.nodeName works around a bug in IE 8 with
                // disabled inputs (#7620)
                elIsCancel =
                  typeof this.options.cancel === "string" &&
                  event.target.nodeName
                    ? $(event.target).closest(this.options.cancel).length
                    : false;
              if (!btnIsLeft || elIsCancel || !this._mouseCapture(event)) {
                return true;
              }

              this.mouseDelayMet = !this.options.delay;
              if (!this.mouseDelayMet) {
                this._mouseDelayTimer = setTimeout(function () {
                  that.mouseDelayMet = true;
                }, this.options.delay);
              }

              if (this._mouseDistanceMet(event) && this._mouseDelayMet(event)) {
                this._mouseStarted = this._mouseStart(event) !== false;
                if (!this._mouseStarted) {
                  event.preventDefault();
                  return true;
                }
              }

              // Click event may never have fired (Gecko & Opera)
              if (
                true ===
                $.data(event.target, this.widgetName + ".preventClickEvent")
              ) {
                $.removeData(
                  event.target,
                  this.widgetName + ".preventClickEvent"
                );
              }

              // These delegates are required to keep context
              this._mouseMoveDelegate = function (event) {
                return that._mouseMove(event);
              };
              this._mouseUpDelegate = function (event) {
                return that._mouseUp(event);
              };

              this.document
                .on("mousemove." + this.widgetName, this._mouseMoveDelegate)
                .on("mouseup." + this.widgetName, this._mouseUpDelegate);

              event.preventDefault();

              mouseHandled = true;
              return true;
            },

            _mouseMove: function (event) {
              // Only check for mouseups outside the document if you've moved inside the document
              // at least once. This prevents the firing of mouseup in the case of IE<9, which will
              // fire a mousemove event if content is placed under the cursor. See #7778
              // Support: IE <9
              if (this._mouseMoved) {
                // IE mouseup check - mouseup happened when mouse was out of window
                if (
                  $.ui.ie &&
                  (!document.documentMode || document.documentMode < 9) &&
                  !event.button
                ) {
                  return this._mouseUp(event);

                  // Iframe mouseup check - mouseup occurred in another document
                } else if (!event.which) {
                  // Support: Safari <=8 - 9
                  // Safari sets which to 0 if you press any of the following keys
                  // during a drag (#14461)
                  if (
                    event.originalEvent.altKey ||
                    event.originalEvent.ctrlKey ||
                    event.originalEvent.metaKey ||
                    event.originalEvent.shiftKey
                  ) {
                    this.ignoreMissingWhich = true;
                  } else if (!this.ignoreMissingWhich) {
                    return this._mouseUp(event);
                  }
                }
              }

              if (event.which || event.button) {
                this._mouseMoved = true;
              }

              if (this._mouseStarted) {
                this._mouseDrag(event);
                return event.preventDefault();
              }

              if (this._mouseDistanceMet(event) && this._mouseDelayMet(event)) {
                this._mouseStarted =
                  this._mouseStart(this._mouseDownEvent, event) !== false;
                if (this._mouseStarted) {
                  this._mouseDrag(event);
                } else {
                  this._mouseUp(event);
                }
              }

              return !this._mouseStarted;
            },

            _mouseUp: function (event) {
              this.document
                .off("mousemove." + this.widgetName, this._mouseMoveDelegate)
                .off("mouseup." + this.widgetName, this._mouseUpDelegate);

              if (this._mouseStarted) {
                this._mouseStarted = false;

                if (event.target === this._mouseDownEvent.target) {
                  $.data(
                    event.target,
                    this.widgetName + ".preventClickEvent",
                    true
                  );
                }

                this._mouseStop(event);
              }

              if (this._mouseDelayTimer) {
                clearTimeout(this._mouseDelayTimer);
                delete this._mouseDelayTimer;
              }

              this.ignoreMissingWhich = false;
              mouseHandled = false;
              event.preventDefault();
            },

            _mouseDistanceMet: function (event) {
              return (
                Math.max(
                  Math.abs(this._mouseDownEvent.pageX - event.pageX),
                  Math.abs(this._mouseDownEvent.pageY - event.pageY)
                ) >= this.options.distance
              );
            },

            _mouseDelayMet: function (/* event */) {
              return this.mouseDelayMet;
            },

            // These are placeholder methods, to be overriden by extending plugin
            _mouseStart: function (/* event */) {},
            _mouseDrag: function (/* event */) {},
            _mouseStop: function (/* event */) {},
            _mouseCapture: function (/* event */) {
              return true;
            },
          });
        });

        /***/
      },

    /***/ "./node_modules/jquery-ui/ui/widgets/slider.js":
      /*!*****************************************************!*\
  !*** ./node_modules/jquery-ui/ui/widgets/slider.js ***!
  \*****************************************************/
      /***/ (module, exports, __webpack_require__) => {
        var __WEBPACK_AMD_DEFINE_FACTORY__,
          __WEBPACK_AMD_DEFINE_ARRAY__,
          __WEBPACK_AMD_DEFINE_RESULT__;
        /*!
         * jQuery UI Slider 1.13.0
         * http://jqueryui.com
         *
         * Copyright jQuery Foundation and other contributors
         * Released under the MIT license.
         * http://jquery.org/license
         */

        //>>label: Slider
        //>>group: Widgets
        //>>description: Displays a flexible slider with ranges and accessibility via keyboard.
        //>>docs: http://api.jqueryui.com/slider/
        //>>demos: http://jqueryui.com/slider/
        //>>css.structure: ../../themes/base/core.css
        //>>css.structure: ../../themes/base/slider.css
        //>>css.theme: ../../themes/base/theme.css

        (function (factory) {
          "use strict";

          if (true) {
            // AMD. Register as an anonymous module.
            !((__WEBPACK_AMD_DEFINE_ARRAY__ = [
              __webpack_require__(
                /*! jquery */ "./node_modules/jquery/dist/jquery.js"
              ),
              __webpack_require__(
                /*! ./mouse */ "./node_modules/jquery-ui/ui/widgets/mouse.js"
              ),
              __webpack_require__(
                /*! ../keycode */ "./node_modules/jquery-ui/ui/keycode.js"
              ),
              __webpack_require__(
                /*! ../version */ "./node_modules/jquery-ui/ui/version.js"
              ),
              __webpack_require__(
                /*! ../widget */ "./node_modules/jquery-ui/ui/widget.js"
              ),
            ]),
            (__WEBPACK_AMD_DEFINE_FACTORY__ = factory),
            (__WEBPACK_AMD_DEFINE_RESULT__ =
              typeof __WEBPACK_AMD_DEFINE_FACTORY__ === "function"
                ? __WEBPACK_AMD_DEFINE_FACTORY__.apply(
                    exports,
                    __WEBPACK_AMD_DEFINE_ARRAY__
                  )
                : __WEBPACK_AMD_DEFINE_FACTORY__),
            __WEBPACK_AMD_DEFINE_RESULT__ !== undefined &&
              (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
          } else {
          }
        })(function ($) {
          "use strict";

          return $.widget("ui.slider", $.ui.mouse, {
            version: "1.13.0",
            widgetEventPrefix: "slide",

            options: {
              animate: false,
              classes: {
                "ui-slider": "ui-corner-all",
                "ui-slider-handle": "ui-corner-all",

                // Note: ui-widget-header isn't the most fittingly semantic framework class for this
                // element, but worked best visually with a variety of themes
                "ui-slider-range": "ui-corner-all ui-widget-header",
              },
              distance: 0,
              max: 100,
              min: 0,
              orientation: "horizontal",
              range: false,
              step: 1,
              value: 0,
              values: null,

              // Callbacks
              change: null,
              slide: null,
              start: null,
              stop: null,
            },

            // Number of pages in a slider
            // (how many times can you page up/down to go through the whole range)
            numPages: 5,

            _create: function () {
              this._keySliding = false;
              this._mouseSliding = false;
              this._animateOff = true;
              this._handleIndex = null;
              this._detectOrientation();
              this._mouseInit();
              this._calculateNewMax();

              this._addClass(
                "ui-slider ui-slider-" + this.orientation,
                "ui-widget ui-widget-content"
              );

              this._refresh();

              this._animateOff = false;
            },

            _refresh: function () {
              this._createRange();
              this._createHandles();
              this._setupEvents();
              this._refreshValue();
            },

            _createHandles: function () {
              var i,
                handleCount,
                options = this.options,
                existingHandles = this.element.find(".ui-slider-handle"),
                handle = "<span tabindex='0'></span>",
                handles = [];

              handleCount = (options.values && options.values.length) || 1;

              if (existingHandles.length > handleCount) {
                existingHandles.slice(handleCount).remove();
                existingHandles = existingHandles.slice(0, handleCount);
              }

              for (i = existingHandles.length; i < handleCount; i++) {
                handles.push(handle);
              }

              this.handles = existingHandles.add(
                $(handles.join("")).appendTo(this.element)
              );

              this._addClass(
                this.handles,
                "ui-slider-handle",
                "ui-state-default"
              );

              this.handle = this.handles.eq(0);

              this.handles.each(function (i) {
                $(this).data("ui-slider-handle-index", i).attr("tabIndex", 0);
              });
            },

            _createRange: function () {
              var options = this.options;

              if (options.range) {
                if (options.range === true) {
                  if (!options.values) {
                    options.values = [this._valueMin(), this._valueMin()];
                  } else if (
                    options.values.length &&
                    options.values.length !== 2
                  ) {
                    options.values = [options.values[0], options.values[0]];
                  } else if (Array.isArray(options.values)) {
                    options.values = options.values.slice(0);
                  }
                }

                if (!this.range || !this.range.length) {
                  this.range = $("<div>").appendTo(this.element);

                  this._addClass(this.range, "ui-slider-range");
                } else {
                  this._removeClass(
                    this.range,
                    "ui-slider-range-min ui-slider-range-max"
                  );

                  // Handle range switching from true to min/max
                  this.range.css({
                    left: "",
                    bottom: "",
                  });
                }
                if (options.range === "min" || options.range === "max") {
                  this._addClass(
                    this.range,
                    "ui-slider-range-" + options.range
                  );
                }
              } else {
                if (this.range) {
                  this.range.remove();
                }
                this.range = null;
              }
            },

            _setupEvents: function () {
              this._off(this.handles);
              this._on(this.handles, this._handleEvents);
              this._hoverable(this.handles);
              this._focusable(this.handles);
            },

            _destroy: function () {
              this.handles.remove();
              if (this.range) {
                this.range.remove();
              }

              this._mouseDestroy();
            },

            _mouseCapture: function (event) {
              var position,
                normValue,
                distance,
                closestHandle,
                index,
                allowed,
                offset,
                mouseOverHandle,
                that = this,
                o = this.options;

              if (o.disabled) {
                return false;
              }

              this.elementSize = {
                width: this.element.outerWidth(),
                height: this.element.outerHeight(),
              };
              this.elementOffset = this.element.offset();

              position = { x: event.pageX, y: event.pageY };
              normValue = this._normValueFromMouse(position);
              distance = this._valueMax() - this._valueMin() + 1;
              this.handles.each(function (i) {
                var thisDistance = Math.abs(normValue - that.values(i));
                if (
                  distance > thisDistance ||
                  (distance === thisDistance &&
                    (i === that._lastChangedValue || that.values(i) === o.min))
                ) {
                  distance = thisDistance;
                  closestHandle = $(this);
                  index = i;
                }
              });

              allowed = this._start(event, index);
              if (allowed === false) {
                return false;
              }
              this._mouseSliding = true;

              this._handleIndex = index;

              this._addClass(closestHandle, null, "ui-state-active");
              closestHandle.trigger("focus");

              offset = closestHandle.offset();
              mouseOverHandle = !$(event.target)
                .parents()
                .addBack()
                .is(".ui-slider-handle");
              this._clickOffset = mouseOverHandle
                ? { left: 0, top: 0 }
                : {
                    left: event.pageX - offset.left - closestHandle.width() / 2,
                    top:
                      event.pageY -
                      offset.top -
                      closestHandle.height() / 2 -
                      (parseInt(closestHandle.css("borderTopWidth"), 10) || 0) -
                      (parseInt(closestHandle.css("borderBottomWidth"), 10) ||
                        0) +
                      (parseInt(closestHandle.css("marginTop"), 10) || 0),
                  };

              if (!this.handles.hasClass("ui-state-hover")) {
                this._slide(event, index, normValue);
              }
              this._animateOff = true;
              return true;
            },

            _mouseStart: function () {
              return true;
            },

            _mouseDrag: function (event) {
              var position = { x: event.pageX, y: event.pageY },
                normValue = this._normValueFromMouse(position);

              this._slide(event, this._handleIndex, normValue);

              return false;
            },

            _mouseStop: function (event) {
              this._removeClass(this.handles, null, "ui-state-active");
              this._mouseSliding = false;

              this._stop(event, this._handleIndex);
              this._change(event, this._handleIndex);

              this._handleIndex = null;
              this._clickOffset = null;
              this._animateOff = false;

              return false;
            },

            _detectOrientation: function () {
              this.orientation =
                this.options.orientation === "vertical"
                  ? "vertical"
                  : "horizontal";
            },

            _normValueFromMouse: function (position) {
              var pixelTotal, pixelMouse, percentMouse, valueTotal, valueMouse;

              if (this.orientation === "horizontal") {
                pixelTotal = this.elementSize.width;
                pixelMouse =
                  position.x -
                  this.elementOffset.left -
                  (this._clickOffset ? this._clickOffset.left : 0);
              } else {
                pixelTotal = this.elementSize.height;
                pixelMouse =
                  position.y -
                  this.elementOffset.top -
                  (this._clickOffset ? this._clickOffset.top : 0);
              }

              percentMouse = pixelMouse / pixelTotal;
              if (percentMouse > 1) {
                percentMouse = 1;
              }
              if (percentMouse < 0) {
                percentMouse = 0;
              }
              if (this.orientation === "vertical") {
                percentMouse = 1 - percentMouse;
              }

              valueTotal = this._valueMax() - this._valueMin();
              valueMouse = this._valueMin() + percentMouse * valueTotal;

              return this._trimAlignValue(valueMouse);
            },

            _uiHash: function (index, value, values) {
              var uiHash = {
                handle: this.handles[index],
                handleIndex: index,
                value: value !== undefined ? value : this.value(),
              };

              if (this._hasMultipleValues()) {
                uiHash.value = value !== undefined ? value : this.values(index);
                uiHash.values = values || this.values();
              }

              return uiHash;
            },

            _hasMultipleValues: function () {
              return this.options.values && this.options.values.length;
            },

            _start: function (event, index) {
              return this._trigger("start", event, this._uiHash(index));
            },

            _slide: function (event, index, newVal) {
              var allowed,
                otherVal,
                currentValue = this.value(),
                newValues = this.values();

              if (this._hasMultipleValues()) {
                otherVal = this.values(index ? 0 : 1);
                currentValue = this.values(index);

                if (
                  this.options.values.length === 2 &&
                  this.options.range === true
                ) {
                  newVal =
                    index === 0
                      ? Math.min(otherVal, newVal)
                      : Math.max(otherVal, newVal);
                }

                newValues[index] = newVal;
              }

              if (newVal === currentValue) {
                return;
              }

              allowed = this._trigger(
                "slide",
                event,
                this._uiHash(index, newVal, newValues)
              );

              // A slide can be canceled by returning false from the slide callback
              if (allowed === false) {
                return;
              }

              if (this._hasMultipleValues()) {
                this.values(index, newVal);
              } else {
                this.value(newVal);
              }
            },

            _stop: function (event, index) {
              this._trigger("stop", event, this._uiHash(index));
            },

            _change: function (event, index) {
              if (!this._keySliding && !this._mouseSliding) {
                //store the last changed value index for reference when handles overlap
                this._lastChangedValue = index;
                this._trigger("change", event, this._uiHash(index));
              }
            },

            value: function (newValue) {
              if (arguments.length) {
                this.options.value = this._trimAlignValue(newValue);
                this._refreshValue();
                this._change(null, 0);
                return;
              }

              return this._value();
            },

            values: function (index, newValue) {
              var vals, newValues, i;

              if (arguments.length > 1) {
                this.options.values[index] = this._trimAlignValue(newValue);
                this._refreshValue();
                this._change(null, index);
                return;
              }

              if (arguments.length) {
                if (Array.isArray(arguments[0])) {
                  vals = this.options.values;
                  newValues = arguments[0];
                  for (i = 0; i < vals.length; i += 1) {
                    vals[i] = this._trimAlignValue(newValues[i]);
                    this._change(null, i);
                  }
                  this._refreshValue();
                } else {
                  if (this._hasMultipleValues()) {
                    return this._values(index);
                  } else {
                    return this.value();
                  }
                }
              } else {
                return this._values();
              }
            },

            _setOption: function (key, value) {
              var i,
                valsLength = 0;

              if (key === "range" && this.options.range === true) {
                if (value === "min") {
                  this.options.value = this._values(0);
                  this.options.values = null;
                } else if (value === "max") {
                  this.options.value = this._values(
                    this.options.values.length - 1
                  );
                  this.options.values = null;
                }
              }

              if (Array.isArray(this.options.values)) {
                valsLength = this.options.values.length;
              }

              this._super(key, value);

              switch (key) {
                case "orientation":
                  this._detectOrientation();
                  this._removeClass(
                    "ui-slider-horizontal ui-slider-vertical"
                  )._addClass("ui-slider-" + this.orientation);
                  this._refreshValue();
                  if (this.options.range) {
                    this._refreshRange(value);
                  }

                  // Reset positioning from previous orientation
                  this.handles.css(
                    value === "horizontal" ? "bottom" : "left",
                    ""
                  );
                  break;
                case "value":
                  this._animateOff = true;
                  this._refreshValue();
                  this._change(null, 0);
                  this._animateOff = false;
                  break;
                case "values":
                  this._animateOff = true;
                  this._refreshValue();

                  // Start from the last handle to prevent unreachable handles (#9046)
                  for (i = valsLength - 1; i >= 0; i--) {
                    this._change(null, i);
                  }
                  this._animateOff = false;
                  break;
                case "step":
                case "min":
                case "max":
                  this._animateOff = true;
                  this._calculateNewMax();
                  this._refreshValue();
                  this._animateOff = false;
                  break;
                case "range":
                  this._animateOff = true;
                  this._refresh();
                  this._animateOff = false;
                  break;
              }
            },

            _setOptionDisabled: function (value) {
              this._super(value);

              this._toggleClass(null, "ui-state-disabled", !!value);
            },

            //internal value getter
            // _value() returns value trimmed by min and max, aligned by step
            _value: function () {
              var val = this.options.value;
              val = this._trimAlignValue(val);

              return val;
            },

            //internal values getter
            // _values() returns array of values trimmed by min and max, aligned by step
            // _values( index ) returns single value trimmed by min and max, aligned by step
            _values: function (index) {
              var val, vals, i;

              if (arguments.length) {
                val = this.options.values[index];
                val = this._trimAlignValue(val);

                return val;
              } else if (this._hasMultipleValues()) {
                // .slice() creates a copy of the array
                // this copy gets trimmed by min and max and then returned
                vals = this.options.values.slice();
                for (i = 0; i < vals.length; i += 1) {
                  vals[i] = this._trimAlignValue(vals[i]);
                }

                return vals;
              } else {
                return [];
              }
            },

            // Returns the step-aligned value that val is closest to, between (inclusive) min and max
            _trimAlignValue: function (val) {
              if (val <= this._valueMin()) {
                return this._valueMin();
              }
              if (val >= this._valueMax()) {
                return this._valueMax();
              }
              var step = this.options.step > 0 ? this.options.step : 1,
                valModStep = (val - this._valueMin()) % step,
                alignValue = val - valModStep;

              if (Math.abs(valModStep) * 2 >= step) {
                alignValue += valModStep > 0 ? step : -step;
              }

              // Since JavaScript has problems with large floats, round
              // the final value to 5 digits after the decimal point (see #4124)
              return parseFloat(alignValue.toFixed(5));
            },

            _calculateNewMax: function () {
              var max = this.options.max,
                min = this._valueMin(),
                step = this.options.step,
                aboveMin = Math.round((max - min) / step) * step;
              max = aboveMin + min;
              if (max > this.options.max) {
                //If max is not divisible by step, rounding off may increase its value
                max -= step;
              }
              this.max = parseFloat(max.toFixed(this._precision()));
            },

            _precision: function () {
              var precision = this._precisionOf(this.options.step);
              if (this.options.min !== null) {
                precision = Math.max(
                  precision,
                  this._precisionOf(this.options.min)
                );
              }
              return precision;
            },

            _precisionOf: function (num) {
              var str = num.toString(),
                decimal = str.indexOf(".");
              return decimal === -1 ? 0 : str.length - decimal - 1;
            },

            _valueMin: function () {
              return this.options.min;
            },

            _valueMax: function () {
              return this.max;
            },

            _refreshRange: function (orientation) {
              if (orientation === "vertical") {
                this.range.css({ width: "", left: "" });
              }
              if (orientation === "horizontal") {
                this.range.css({ height: "", bottom: "" });
              }
            },

            _refreshValue: function () {
              var lastValPercent,
                valPercent,
                value,
                valueMin,
                valueMax,
                oRange = this.options.range,
                o = this.options,
                that = this,
                animate = !this._animateOff ? o.animate : false,
                _set = {};

              if (this._hasMultipleValues()) {
                this.handles.each(function (i) {
                  valPercent =
                    ((that.values(i) - that._valueMin()) /
                      (that._valueMax() - that._valueMin())) *
                    100;
                  _set[that.orientation === "horizontal" ? "left" : "bottom"] =
                    valPercent + "%";
                  $(this)
                    .stop(1, 1)
                    [animate ? "animate" : "css"](_set, o.animate);
                  if (that.options.range === true) {
                    if (that.orientation === "horizontal") {
                      if (i === 0) {
                        that.range.stop(1, 1)[animate ? "animate" : "css"](
                          {
                            left: valPercent + "%",
                          },
                          o.animate
                        );
                      }
                      if (i === 1) {
                        that.range[animate ? "animate" : "css"](
                          {
                            width: valPercent - lastValPercent + "%",
                          },
                          {
                            queue: false,
                            duration: o.animate,
                          }
                        );
                      }
                    } else {
                      if (i === 0) {
                        that.range.stop(1, 1)[animate ? "animate" : "css"](
                          {
                            bottom: valPercent + "%",
                          },
                          o.animate
                        );
                      }
                      if (i === 1) {
                        that.range[animate ? "animate" : "css"](
                          {
                            height: valPercent - lastValPercent + "%",
                          },
                          {
                            queue: false,
                            duration: o.animate,
                          }
                        );
                      }
                    }
                  }
                  lastValPercent = valPercent;
                });
              } else {
                value = this.value();
                valueMin = this._valueMin();
                valueMax = this._valueMax();
                valPercent =
                  valueMax !== valueMin
                    ? ((value - valueMin) / (valueMax - valueMin)) * 100
                    : 0;
                _set[this.orientation === "horizontal" ? "left" : "bottom"] =
                  valPercent + "%";
                this.handle
                  .stop(1, 1)
                  [animate ? "animate" : "css"](_set, o.animate);

                if (oRange === "min" && this.orientation === "horizontal") {
                  this.range.stop(1, 1)[animate ? "animate" : "css"](
                    {
                      width: valPercent + "%",
                    },
                    o.animate
                  );
                }
                if (oRange === "max" && this.orientation === "horizontal") {
                  this.range.stop(1, 1)[animate ? "animate" : "css"](
                    {
                      width: 100 - valPercent + "%",
                    },
                    o.animate
                  );
                }
                if (oRange === "min" && this.orientation === "vertical") {
                  this.range.stop(1, 1)[animate ? "animate" : "css"](
                    {
                      height: valPercent + "%",
                    },
                    o.animate
                  );
                }
                if (oRange === "max" && this.orientation === "vertical") {
                  this.range.stop(1, 1)[animate ? "animate" : "css"](
                    {
                      height: 100 - valPercent + "%",
                    },
                    o.animate
                  );
                }
              }
            },

            _handleEvents: {
              keydown: function (event) {
                var allowed,
                  curVal,
                  newVal,
                  step,
                  index = $(event.target).data("ui-slider-handle-index");

                switch (event.keyCode) {
                  case $.ui.keyCode.HOME:
                  case $.ui.keyCode.END:
                  case $.ui.keyCode.PAGE_UP:
                  case $.ui.keyCode.PAGE_DOWN:
                  case $.ui.keyCode.UP:
                  case $.ui.keyCode.RIGHT:
                  case $.ui.keyCode.DOWN:
                  case $.ui.keyCode.LEFT:
                    event.preventDefault();
                    if (!this._keySliding) {
                      this._keySliding = true;
                      this._addClass($(event.target), null, "ui-state-active");
                      allowed = this._start(event, index);
                      if (allowed === false) {
                        return;
                      }
                    }
                    break;
                }

                step = this.options.step;
                if (this._hasMultipleValues()) {
                  curVal = newVal = this.values(index);
                } else {
                  curVal = newVal = this.value();
                }

                switch (event.keyCode) {
                  case $.ui.keyCode.HOME:
                    newVal = this._valueMin();
                    break;
                  case $.ui.keyCode.END:
                    newVal = this._valueMax();
                    break;
                  case $.ui.keyCode.PAGE_UP:
                    newVal = this._trimAlignValue(
                      curVal +
                        (this._valueMax() - this._valueMin()) / this.numPages
                    );
                    break;
                  case $.ui.keyCode.PAGE_DOWN:
                    newVal = this._trimAlignValue(
                      curVal -
                        (this._valueMax() - this._valueMin()) / this.numPages
                    );
                    break;
                  case $.ui.keyCode.UP:
                  case $.ui.keyCode.RIGHT:
                    if (curVal === this._valueMax()) {
                      return;
                    }
                    newVal = this._trimAlignValue(curVal + step);
                    break;
                  case $.ui.keyCode.DOWN:
                  case $.ui.keyCode.LEFT:
                    if (curVal === this._valueMin()) {
                      return;
                    }
                    newVal = this._trimAlignValue(curVal - step);
                    break;
                }

                this._slide(event, index, newVal);
              },
              keyup: function (event) {
                var index = $(event.target).data("ui-slider-handle-index");

                if (this._keySliding) {
                  this._keySliding = false;
                  this._stop(event, index);
                  this._change(event, index);
                  this._removeClass($(event.target), null, "ui-state-active");
                }
              },
            },
          });
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/_baseCreate.js":
      /*!********************************************************!*\
  !*** ./node_modules/underscore/modules/_baseCreate.js ***!
  \********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ baseCreate,
          /* harmony export */
        });
        /* harmony import */ var _isObject_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./isObject.js */ "./node_modules/underscore/modules/isObject.js"
          );
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );

        // Create a naked function reference for surrogate-prototype-swapping.
        function ctor() {
          return function () {};
        }

        // An internal function for creating a new object that inherits from another.
        function baseCreate(prototype) {
          if (
            !(0, _isObject_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
              prototype
            )
          )
            return {};
          if (_setup_js__WEBPACK_IMPORTED_MODULE_1__.nativeCreate)
            return (0, _setup_js__WEBPACK_IMPORTED_MODULE_1__.nativeCreate)(
              prototype
            );
          var Ctor = ctor();
          Ctor.prototype = prototype;
          var result = new Ctor();
          Ctor.prototype = null;
          return result;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_baseIteratee.js":
      /*!**********************************************************!*\
  !*** ./node_modules/underscore/modules/_baseIteratee.js ***!
  \**********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ baseIteratee,
          /* harmony export */
        });
        /* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./identity.js */ "./node_modules/underscore/modules/identity.js"
          );
        /* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isFunction.js */ "./node_modules/underscore/modules/isFunction.js"
          );
        /* harmony import */ var _isObject_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./isObject.js */ "./node_modules/underscore/modules/isObject.js"
          );
        /* harmony import */ var _isArray_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./isArray.js */ "./node_modules/underscore/modules/isArray.js"
          );
        /* harmony import */ var _matcher_js__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! ./matcher.js */ "./node_modules/underscore/modules/matcher.js"
          );
        /* harmony import */ var _property_js__WEBPACK_IMPORTED_MODULE_5__ =
          __webpack_require__(
            /*! ./property.js */ "./node_modules/underscore/modules/property.js"
          );
        /* harmony import */ var _optimizeCb_js__WEBPACK_IMPORTED_MODULE_6__ =
          __webpack_require__(
            /*! ./_optimizeCb.js */ "./node_modules/underscore/modules/_optimizeCb.js"
          );

        // An internal function to generate callbacks that can be applied to each
        // element in a collection, returning the desired result — either `_.identity`,
        // an arbitrary callback, a property matcher, or a property accessor.
        function baseIteratee(value, context, argCount) {
          if (value == null)
            return _identity_js__WEBPACK_IMPORTED_MODULE_0__["default"];
          if (
            (0, _isFunction_js__WEBPACK_IMPORTED_MODULE_1__["default"])(value)
          )
            return (0, _optimizeCb_js__WEBPACK_IMPORTED_MODULE_6__["default"])(
              value,
              context,
              argCount
            );
          if (
            (0, _isObject_js__WEBPACK_IMPORTED_MODULE_2__["default"])(value) &&
            !(0, _isArray_js__WEBPACK_IMPORTED_MODULE_3__["default"])(value)
          )
            return (0, _matcher_js__WEBPACK_IMPORTED_MODULE_4__["default"])(
              value
            );
          return (0, _property_js__WEBPACK_IMPORTED_MODULE_5__["default"])(
            value
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_cb.js":
      /*!************************************************!*\
  !*** ./node_modules/underscore/modules/_cb.js ***!
  \************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ cb,
          /* harmony export */
        });
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );
        /* harmony import */ var _baseIteratee_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_baseIteratee.js */ "./node_modules/underscore/modules/_baseIteratee.js"
          );
        /* harmony import */ var _iteratee_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./iteratee.js */ "./node_modules/underscore/modules/iteratee.js"
          );

        // The function we call internally to generate a callback. It invokes
        // `_.iteratee` if overridden, otherwise `baseIteratee`.
        function cb(value, context, argCount) {
          if (
            _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"].iteratee !==
            _iteratee_js__WEBPACK_IMPORTED_MODULE_2__["default"]
          )
            return _underscore_js__WEBPACK_IMPORTED_MODULE_0__[
              "default"
            ].iteratee(value, context);
          return (0, _baseIteratee_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
            value,
            context,
            argCount
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_chainResult.js":
      /*!*********************************************************!*\
  !*** ./node_modules/underscore/modules/_chainResult.js ***!
  \*********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ chainResult,
          /* harmony export */
        });
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );

        // Helper function to continue chaining intermediate results.
        function chainResult(instance, obj) {
          return instance._chain
            ? (0, _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
                obj
              ).chain()
            : obj;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_collectNonEnumProps.js":
      /*!*****************************************************************!*\
  !*** ./node_modules/underscore/modules/_collectNonEnumProps.js ***!
  \*****************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ collectNonEnumProps,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isFunction.js */ "./node_modules/underscore/modules/isFunction.js"
          );
        /* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_has.js */ "./node_modules/underscore/modules/_has.js"
          );

        // Internal helper to create a simple lookup structure.
        // `collectNonEnumProps` used to depend on `_.contains`, but this led to
        // circular imports. `emulatedSet` is a one-off solution that only works for
        // arrays of strings.
        function emulatedSet(keys) {
          var hash = {};
          for (var l = keys.length, i = 0; i < l; ++i) hash[keys[i]] = true;
          return {
            contains: function (key) {
              return hash[key];
            },
            push: function (key) {
              hash[key] = true;
              return keys.push(key);
            },
          };
        }

        // Internal helper. Checks `keys` for the presence of keys in IE < 9 that won't
        // be iterated by `for key in ...` and thus missed. Extends `keys` in place if
        // needed.
        function collectNonEnumProps(obj, keys) {
          keys = emulatedSet(keys);
          var nonEnumIdx =
            _setup_js__WEBPACK_IMPORTED_MODULE_0__.nonEnumerableProps.length;
          var constructor = obj.constructor;
          var proto =
            ((0, _isFunction_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              constructor
            ) &&
              constructor.prototype) ||
            _setup_js__WEBPACK_IMPORTED_MODULE_0__.ObjProto;

          // Constructor is a special case.
          var prop = "constructor";
          if (
            (0, _has_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj, prop) &&
            !keys.contains(prop)
          )
            keys.push(prop);

          while (nonEnumIdx--) {
            prop =
              _setup_js__WEBPACK_IMPORTED_MODULE_0__.nonEnumerableProps[
                nonEnumIdx
              ];
            if (
              prop in obj &&
              obj[prop] !== proto[prop] &&
              !keys.contains(prop)
            ) {
              keys.push(prop);
            }
          }
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_createAssigner.js":
      /*!************************************************************!*\
  !*** ./node_modules/underscore/modules/_createAssigner.js ***!
  \************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ createAssigner,
          /* harmony export */
        });
        // An internal function for creating assigner functions.
        function createAssigner(keysFunc, defaults) {
          return function (obj) {
            var length = arguments.length;
            if (defaults) obj = Object(obj);
            if (length < 2 || obj == null) return obj;
            for (var index = 1; index < length; index++) {
              var source = arguments[index],
                keys = keysFunc(source),
                l = keys.length;
              for (var i = 0; i < l; i++) {
                var key = keys[i];
                if (!defaults || obj[key] === void 0) obj[key] = source[key];
              }
            }
            return obj;
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_createEscaper.js":
      /*!***********************************************************!*\
  !*** ./node_modules/underscore/modules/_createEscaper.js ***!
  \***********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ createEscaper,
          /* harmony export */
        });
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Internal helper to generate functions for escaping and unescaping strings
        // to/from HTML interpolation.
        function createEscaper(map) {
          var escaper = function (match) {
            return map[match];
          };
          // Regexes for identifying a key that needs to be escaped.
          var source =
            "(?:" +
            (0, _keys_js__WEBPACK_IMPORTED_MODULE_0__["default"])(map).join(
              "|"
            ) +
            ")";
          var testRegexp = RegExp(source);
          var replaceRegexp = RegExp(source, "g");
          return function (string) {
            string = string == null ? "" : "" + string;
            return testRegexp.test(string)
              ? string.replace(replaceRegexp, escaper)
              : string;
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_createIndexFinder.js":
      /*!***************************************************************!*\
  !*** ./node_modules/underscore/modules/_createIndexFinder.js ***!
  \***************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ createIndexFinder,
          /* harmony export */
        });
        /* harmony import */ var _getLength_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_getLength.js */ "./node_modules/underscore/modules/_getLength.js"
          );
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _isNaN_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./isNaN.js */ "./node_modules/underscore/modules/isNaN.js"
          );

        // Internal function to generate the `_.indexOf` and `_.lastIndexOf` functions.
        function createIndexFinder(dir, predicateFind, sortedIndex) {
          return function (array, item, idx) {
            var i = 0,
              length = (0,
              _getLength_js__WEBPACK_IMPORTED_MODULE_0__["default"])(array);
            if (typeof idx == "number") {
              if (dir > 0) {
                i = idx >= 0 ? idx : Math.max(idx + length, i);
              } else {
                length =
                  idx >= 0 ? Math.min(idx + 1, length) : idx + length + 1;
              }
            } else if (sortedIndex && idx && length) {
              idx = sortedIndex(array, item);
              return array[idx] === item ? idx : -1;
            }
            if (item !== item) {
              idx = predicateFind(
                _setup_js__WEBPACK_IMPORTED_MODULE_1__.slice.call(
                  array,
                  i,
                  length
                ),
                _isNaN_js__WEBPACK_IMPORTED_MODULE_2__["default"]
              );
              return idx >= 0 ? idx + i : -1;
            }
            for (
              idx = dir > 0 ? i : length - 1;
              idx >= 0 && idx < length;
              idx += dir
            ) {
              if (array[idx] === item) return idx;
            }
            return -1;
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_createPredicateIndexFinder.js":
      /*!************************************************************************!*\
  !*** ./node_modules/underscore/modules/_createPredicateIndexFinder.js ***!
  \************************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () =>
            /* binding */ createPredicateIndexFinder,
          /* harmony export */
        });
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _getLength_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_getLength.js */ "./node_modules/underscore/modules/_getLength.js"
          );

        // Internal function to generate `_.findIndex` and `_.findLastIndex`.
        function createPredicateIndexFinder(dir) {
          return function (array, predicate, context) {
            predicate = (0, _cb_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
              predicate,
              context
            );
            var length = (0,
            _getLength_js__WEBPACK_IMPORTED_MODULE_1__["default"])(array);
            var index = dir > 0 ? 0 : length - 1;
            for (; index >= 0 && index < length; index += dir) {
              if (predicate(array[index], index, array)) return index;
            }
            return -1;
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_createReduce.js":
      /*!**********************************************************!*\
  !*** ./node_modules/underscore/modules/_createReduce.js ***!
  \**********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ createReduce,
          /* harmony export */
        });
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );
        /* harmony import */ var _optimizeCb_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_optimizeCb.js */ "./node_modules/underscore/modules/_optimizeCb.js"
          );

        // Internal helper to create a reducing function, iterating left or right.
        function createReduce(dir) {
          // Wrap code that reassigns argument variables in a separate function than
          // the one that accesses `arguments.length` to avoid a perf hit. (#1991)
          var reducer = function (obj, iteratee, memo, initial) {
            var _keys =
                !(0, _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
                  obj
                ) && (0, _keys_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj),
              length = (_keys || obj).length,
              index = dir > 0 ? 0 : length - 1;
            if (!initial) {
              memo = obj[_keys ? _keys[index] : index];
              index += dir;
            }
            for (; index >= 0 && index < length; index += dir) {
              var currentKey = _keys ? _keys[index] : index;
              memo = iteratee(memo, obj[currentKey], currentKey, obj);
            }
            return memo;
          };

          return function (obj, iteratee, memo, context) {
            var initial = arguments.length >= 3;
            return reducer(
              obj,
              (0, _optimizeCb_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
                iteratee,
                context,
                4
              ),
              memo,
              initial
            );
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_createSizePropertyCheck.js":
      /*!*********************************************************************!*\
  !*** ./node_modules/underscore/modules/_createSizePropertyCheck.js ***!
  \*********************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () =>
            /* binding */ createSizePropertyCheck,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );

        // Common internal logic for `isArrayLike` and `isBufferLike`.
        function createSizePropertyCheck(getSizeProperty) {
          return function (collection) {
            var sizeProperty = getSizeProperty(collection);
            return (
              typeof sizeProperty == "number" &&
              sizeProperty >= 0 &&
              sizeProperty <=
                _setup_js__WEBPACK_IMPORTED_MODULE_0__.MAX_ARRAY_INDEX
            );
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_deepGet.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/_deepGet.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ deepGet,
          /* harmony export */
        });
        // Internal function to obtain a nested property in `obj` along `path`.
        function deepGet(obj, path) {
          var length = path.length;
          for (var i = 0; i < length; i++) {
            if (obj == null) return void 0;
            obj = obj[path[i]];
          }
          return length ? obj : void 0;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_escapeMap.js":
      /*!*******************************************************!*\
  !*** ./node_modules/underscore/modules/_escapeMap.js ***!
  \*******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        // Internal list of HTML entities for escaping.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = {
          "&": "&amp;",
          "<": "&lt;",
          ">": "&gt;",
          '"': "&quot;",
          "'": "&#x27;",
          "`": "&#x60;",
        };

        /***/
      },

    /***/ "./node_modules/underscore/modules/_executeBound.js":
      /*!**********************************************************!*\
  !*** ./node_modules/underscore/modules/_executeBound.js ***!
  \**********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ executeBound,
          /* harmony export */
        });
        /* harmony import */ var _baseCreate_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_baseCreate.js */ "./node_modules/underscore/modules/_baseCreate.js"
          );
        /* harmony import */ var _isObject_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isObject.js */ "./node_modules/underscore/modules/isObject.js"
          );

        // Internal function to execute `sourceFunc` bound to `context` with optional
        // `args`. Determines whether to execute a function as a constructor or as a
        // normal function.
        function executeBound(
          sourceFunc,
          boundFunc,
          context,
          callingContext,
          args
        ) {
          if (!(callingContext instanceof boundFunc))
            return sourceFunc.apply(context, args);
          var self = (0,
          _baseCreate_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            sourceFunc.prototype
          );
          var result = sourceFunc.apply(self, args);
          if ((0, _isObject_js__WEBPACK_IMPORTED_MODULE_1__["default"])(result))
            return result;
          return self;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_flatten.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/_flatten.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ flatten,
          /* harmony export */
        });
        /* harmony import */ var _getLength_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_getLength.js */ "./node_modules/underscore/modules/_getLength.js"
          );
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _isArray_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./isArray.js */ "./node_modules/underscore/modules/isArray.js"
          );
        /* harmony import */ var _isArguments_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./isArguments.js */ "./node_modules/underscore/modules/isArguments.js"
          );

        // Internal implementation of a recursive `flatten` function.
        function flatten(input, depth, strict, output) {
          output = output || [];
          if (!depth && depth !== 0) {
            depth = Infinity;
          } else if (depth <= 0) {
            return output.concat(input);
          }
          var idx = output.length;
          for (
            var i = 0,
              length = (0,
              _getLength_js__WEBPACK_IMPORTED_MODULE_0__["default"])(input);
            i < length;
            i++
          ) {
            var value = input[i];
            if (
              (0, _isArrayLike_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
                value
              ) &&
              ((0, _isArray_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
                value
              ) ||
                (0, _isArguments_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
                  value
                ))
            ) {
              // Flatten current level of array or arguments object.
              if (depth > 1) {
                flatten(value, depth - 1, strict, output);
                idx = output.length;
              } else {
                var j = 0,
                  len = value.length;
                while (j < len) output[idx++] = value[j++];
              }
            } else if (!strict) {
              output[idx++] = value;
            }
          }
          return output;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_getByteLength.js":
      /*!***********************************************************!*\
  !*** ./node_modules/underscore/modules/_getByteLength.js ***!
  \***********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _shallowProperty_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_shallowProperty.js */ "./node_modules/underscore/modules/_shallowProperty.js"
          );

        // Internal helper to obtain the `byteLength` property of an object.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _shallowProperty_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          "byteLength"
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/_getLength.js":
      /*!*******************************************************!*\
  !*** ./node_modules/underscore/modules/_getLength.js ***!
  \*******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _shallowProperty_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_shallowProperty.js */ "./node_modules/underscore/modules/_shallowProperty.js"
          );

        // Internal helper to obtain the `length` property of an object.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _shallowProperty_js__WEBPACK_IMPORTED_MODULE_0__["default"])("length");

        /***/
      },

    /***/ "./node_modules/underscore/modules/_group.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/_group.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ group,
          /* harmony export */
        });
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _each_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./each.js */ "./node_modules/underscore/modules/each.js"
          );

        // An internal function used for aggregate "group by" operations.
        function group(behavior, partition) {
          return function (obj, iteratee, context) {
            var result = partition ? [[], []] : {};
            iteratee = (0, _cb_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
              iteratee,
              context
            );
            (0, _each_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              obj,
              function (value, index) {
                var key = iteratee(value, index, obj);
                behavior(result, value, key);
              }
            );
            return result;
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_has.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/_has.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ has,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );

        // Internal function to check whether `key` is an own property name of `obj`.
        function has(obj, key) {
          return (
            obj != null &&
            _setup_js__WEBPACK_IMPORTED_MODULE_0__.hasOwnProperty.call(obj, key)
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_hasObjectTag.js":
      /*!**********************************************************!*\
  !*** ./node_modules/underscore/modules/_hasObjectTag.js ***!
  \**********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("Object");

        /***/
      },

    /***/ "./node_modules/underscore/modules/_isArrayLike.js":
      /*!*********************************************************!*\
  !*** ./node_modules/underscore/modules/_isArrayLike.js ***!
  \*********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _createSizePropertyCheck_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_createSizePropertyCheck.js */ "./node_modules/underscore/modules/_createSizePropertyCheck.js"
          );
        /* harmony import */ var _getLength_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_getLength.js */ "./node_modules/underscore/modules/_getLength.js"
          );

        // Internal helper for collection methods to determine whether a collection
        // should be iterated as an array or as an object.
        // Related: https://people.mozilla.org/~jorendorff/es6-draft.html#sec-tolength
        // Avoids a very nasty iOS 8 JIT bug on ARM-64. #2094
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createSizePropertyCheck_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          _getLength_js__WEBPACK_IMPORTED_MODULE_1__["default"]
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/_isBufferLike.js":
      /*!**********************************************************!*\
  !*** ./node_modules/underscore/modules/_isBufferLike.js ***!
  \**********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _createSizePropertyCheck_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_createSizePropertyCheck.js */ "./node_modules/underscore/modules/_createSizePropertyCheck.js"
          );
        /* harmony import */ var _getByteLength_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_getByteLength.js */ "./node_modules/underscore/modules/_getByteLength.js"
          );

        // Internal helper to determine whether we should spend extensive checks against
        // `ArrayBuffer` et al.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createSizePropertyCheck_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          _getByteLength_js__WEBPACK_IMPORTED_MODULE_1__["default"]
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/_keyInObj.js":
      /*!******************************************************!*\
  !*** ./node_modules/underscore/modules/_keyInObj.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ keyInObj,
          /* harmony export */
        });
        // Internal `_.pick` helper function to determine whether `key` is an enumerable
        // property name of `obj`.
        function keyInObj(value, key, obj) {
          return key in obj;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_methodFingerprint.js":
      /*!***************************************************************!*\
  !*** ./node_modules/underscore/modules/_methodFingerprint.js ***!
  \***************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ ie11fingerprint: () =>
            /* binding */ ie11fingerprint,
          /* harmony export */ mapMethods: () => /* binding */ mapMethods,
          /* harmony export */ weakMapMethods: () =>
            /* binding */ weakMapMethods,
          /* harmony export */ setMethods: () => /* binding */ setMethods,
          /* harmony export */
        });
        /* harmony import */ var _getLength_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_getLength.js */ "./node_modules/underscore/modules/_getLength.js"
          );
        /* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isFunction.js */ "./node_modules/underscore/modules/isFunction.js"
          );
        /* harmony import */ var _allKeys_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./allKeys.js */ "./node_modules/underscore/modules/allKeys.js"
          );

        // Since the regular `Object.prototype.toString` type tests don't work for
        // some types in IE 11, we use a fingerprinting heuristic instead, based
        // on the methods. It's not great, but it's the best we got.
        // The fingerprint method lists are defined below.
        function ie11fingerprint(methods) {
          var length = (0,
          _getLength_js__WEBPACK_IMPORTED_MODULE_0__["default"])(methods);
          return function (obj) {
            if (obj == null) return false;
            // `Map`, `WeakMap` and `Set` have no enumerable keys.
            var keys = (0, _allKeys_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
              obj
            );
            if (
              (0, _getLength_js__WEBPACK_IMPORTED_MODULE_0__["default"])(keys)
            )
              return false;
            for (var i = 0; i < length; i++) {
              if (
                !(0, _isFunction_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
                  obj[methods[i]]
                )
              )
                return false;
            }
            // If we are testing against `WeakMap`, we need to ensure that
            // `obj` doesn't have a `forEach` method in order to distinguish
            // it from a regular `Map`.
            return (
              methods !== weakMapMethods ||
              !(0, _isFunction_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
                obj[forEachName]
              )
            );
          };
        }

        // In the interest of compact minification, we write
        // each string in the fingerprints only once.
        var forEachName = "forEach",
          hasName = "has",
          commonInit = ["clear", "delete"],
          mapTail = ["get", hasName, "set"];

        // `Map`, `WeakMap` and `Set` each have slightly different
        // combinations of the above sublists.
        var mapMethods = commonInit.concat(forEachName, mapTail),
          weakMapMethods = commonInit.concat(mapTail),
          setMethods = ["add"].concat(commonInit, forEachName, hasName);

        /***/
      },

    /***/ "./node_modules/underscore/modules/_optimizeCb.js":
      /*!********************************************************!*\
  !*** ./node_modules/underscore/modules/_optimizeCb.js ***!
  \********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ optimizeCb,
          /* harmony export */
        });
        // Internal function that returns an efficient (for current engines) version
        // of the passed-in callback, to be repeatedly applied in other Underscore
        // functions.
        function optimizeCb(func, context, argCount) {
          if (context === void 0) return func;
          switch (argCount == null ? 3 : argCount) {
            case 1:
              return function (value) {
                return func.call(context, value);
              };
            // The 2-argument case is omitted because we’re not using it.
            case 3:
              return function (value, index, collection) {
                return func.call(context, value, index, collection);
              };
            case 4:
              return function (accumulator, value, index, collection) {
                return func.call(
                  context,
                  accumulator,
                  value,
                  index,
                  collection
                );
              };
          }
          return function () {
            return func.apply(context, arguments);
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_setup.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/_setup.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ VERSION: () => /* binding */ VERSION,
          /* harmony export */ root: () => /* binding */ root,
          /* harmony export */ ArrayProto: () => /* binding */ ArrayProto,
          /* harmony export */ ObjProto: () => /* binding */ ObjProto,
          /* harmony export */ SymbolProto: () => /* binding */ SymbolProto,
          /* harmony export */ push: () => /* binding */ push,
          /* harmony export */ slice: () => /* binding */ slice,
          /* harmony export */ toString: () => /* binding */ toString,
          /* harmony export */ hasOwnProperty: () =>
            /* binding */ hasOwnProperty,
          /* harmony export */ supportsArrayBuffer: () =>
            /* binding */ supportsArrayBuffer,
          /* harmony export */ supportsDataView: () =>
            /* binding */ supportsDataView,
          /* harmony export */ nativeIsArray: () => /* binding */ nativeIsArray,
          /* harmony export */ nativeKeys: () => /* binding */ nativeKeys,
          /* harmony export */ nativeCreate: () => /* binding */ nativeCreate,
          /* harmony export */ nativeIsView: () => /* binding */ nativeIsView,
          /* harmony export */ _isNaN: () => /* binding */ _isNaN,
          /* harmony export */ _isFinite: () => /* binding */ _isFinite,
          /* harmony export */ hasEnumBug: () => /* binding */ hasEnumBug,
          /* harmony export */ nonEnumerableProps: () =>
            /* binding */ nonEnumerableProps,
          /* harmony export */ MAX_ARRAY_INDEX: () =>
            /* binding */ MAX_ARRAY_INDEX,
          /* harmony export */
        });
        // Current version.
        var VERSION = "1.13.1";

        // Establish the root object, `window` (`self`) in the browser, `global`
        // on the server, or `this` in some virtual machines. We use `self`
        // instead of `window` for `WebWorker` support.
        var root =
          (typeof self == "object" && self.self === self && self) ||
          (typeof __webpack_require__.g == "object" &&
            __webpack_require__.g.global === __webpack_require__.g &&
            __webpack_require__.g) ||
          Function("return this")() ||
          {};

        // Save bytes in the minified (but not gzipped) version:
        var ArrayProto = Array.prototype,
          ObjProto = Object.prototype;
        var SymbolProto =
          typeof Symbol !== "undefined" ? Symbol.prototype : null;

        // Create quick reference variables for speed access to core prototypes.
        var push = ArrayProto.push,
          slice = ArrayProto.slice,
          toString = ObjProto.toString,
          hasOwnProperty = ObjProto.hasOwnProperty;

        // Modern feature detection.
        var supportsArrayBuffer = typeof ArrayBuffer !== "undefined",
          supportsDataView = typeof DataView !== "undefined";

        // All **ECMAScript 5+** native function implementations that we hope to use
        // are declared here.
        var nativeIsArray = Array.isArray,
          nativeKeys = Object.keys,
          nativeCreate = Object.create,
          nativeIsView = supportsArrayBuffer && ArrayBuffer.isView;

        // Create references to these builtin functions because we override them.
        var _isNaN = isNaN,
          _isFinite = isFinite;

        // Keys in IE < 9 that won't be iterated by `for key in ...` and thus missed.
        var hasEnumBug = !{ toString: null }.propertyIsEnumerable("toString");
        var nonEnumerableProps = [
          "valueOf",
          "isPrototypeOf",
          "toString",
          "propertyIsEnumerable",
          "hasOwnProperty",
          "toLocaleString",
        ];

        // The largest integer that can be represented exactly.
        var MAX_ARRAY_INDEX = Math.pow(2, 53) - 1;

        /***/
      },

    /***/ "./node_modules/underscore/modules/_shallowProperty.js":
      /*!*************************************************************!*\
  !*** ./node_modules/underscore/modules/_shallowProperty.js ***!
  \*************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ shallowProperty,
          /* harmony export */
        });
        // Internal helper to generate a function to obtain property `key` from `obj`.
        function shallowProperty(key) {
          return function (obj) {
            return obj == null ? void 0 : obj[key];
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_stringTagBug.js":
      /*!**********************************************************!*\
  !*** ./node_modules/underscore/modules/_stringTagBug.js ***!
  \**********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ hasStringTagBug: () =>
            /* binding */ hasStringTagBug,
          /* harmony export */ isIE11: () => /* binding */ isIE11,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _hasObjectTag_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_hasObjectTag.js */ "./node_modules/underscore/modules/_hasObjectTag.js"
          );

        // In IE 10 - Edge 13, `DataView` has string tag `'[object Object]'`.
        // In IE 11, the most common among them, this problem also applies to
        // `Map`, `WeakMap` and `Set`.
        var hasStringTagBug =
            _setup_js__WEBPACK_IMPORTED_MODULE_0__.supportsDataView &&
            (0, _hasObjectTag_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              new DataView(new ArrayBuffer(8))
            ),
          isIE11 =
            typeof Map !== "undefined" &&
            (0, _hasObjectTag_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              new Map()
            );

        /***/
      },

    /***/ "./node_modules/underscore/modules/_tagTester.js":
      /*!*******************************************************!*\
  !*** ./node_modules/underscore/modules/_tagTester.js ***!
  \*******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ tagTester,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );

        // Internal function for creating a `toString`-based type tester.
        function tagTester(name) {
          var tag = "[object " + name + "]";
          return function (obj) {
            return (
              _setup_js__WEBPACK_IMPORTED_MODULE_0__.toString.call(obj) === tag
            );
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_toBufferView.js":
      /*!**********************************************************!*\
  !*** ./node_modules/underscore/modules/_toBufferView.js ***!
  \**********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ toBufferView,
          /* harmony export */
        });
        /* harmony import */ var _getByteLength_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_getByteLength.js */ "./node_modules/underscore/modules/_getByteLength.js"
          );

        // Internal function to wrap or shallow-copy an ArrayBuffer,
        // typed array or DataView to a new view, reusing the buffer.
        function toBufferView(bufferSource) {
          return new Uint8Array(
            bufferSource.buffer || bufferSource,
            bufferSource.byteOffset || 0,
            (0, _getByteLength_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
              bufferSource
            )
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_toPath.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/_toPath.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ toPath,
          /* harmony export */
        });
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );
        /* harmony import */ var _toPath_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./toPath.js */ "./node_modules/underscore/modules/toPath.js"
          );

        // Internal wrapper for `_.toPath` to enable minification.
        // Similar to `cb` for `_.iteratee`.
        function toPath(path) {
          return _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"].toPath(
            path
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/_unescapeMap.js":
      /*!*********************************************************!*\
  !*** ./node_modules/underscore/modules/_unescapeMap.js ***!
  \*********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _invert_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./invert.js */ "./node_modules/underscore/modules/invert.js"
          );
        /* harmony import */ var _escapeMap_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_escapeMap.js */ "./node_modules/underscore/modules/_escapeMap.js"
          );

        // Internal list of HTML entities for unescaping.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _invert_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          _escapeMap_js__WEBPACK_IMPORTED_MODULE_1__["default"]
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/after.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/after.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ after,
          /* harmony export */
        });
        // Returns a function that will only be executed on and after the Nth call.
        function after(times, func) {
          return function () {
            if (--times < 1) {
              return func.apply(this, arguments);
            }
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/allKeys.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/allKeys.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ allKeys,
          /* harmony export */
        });
        /* harmony import */ var _isObject_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./isObject.js */ "./node_modules/underscore/modules/isObject.js"
          );
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _collectNonEnumProps_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_collectNonEnumProps.js */ "./node_modules/underscore/modules/_collectNonEnumProps.js"
          );

        // Retrieve all the enumerable property names of an object.
        function allKeys(obj) {
          if (!(0, _isObject_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj))
            return [];
          var keys = [];
          for (var key in obj) keys.push(key);
          // Ahem, IE < 9.
          if (_setup_js__WEBPACK_IMPORTED_MODULE_1__.hasEnumBug)
            (0,
            _collectNonEnumProps_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
              obj,
              keys
            );
          return keys;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/before.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/before.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ before,
          /* harmony export */
        });
        // Returns a function that will only be executed up to (but not including) the
        // Nth call.
        function before(times, func) {
          var memo;
          return function () {
            if (--times > 0) {
              memo = func.apply(this, arguments);
            }
            if (times <= 1) func = null;
            return memo;
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/bind.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/bind.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );
        /* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isFunction.js */ "./node_modules/underscore/modules/isFunction.js"
          );
        /* harmony import */ var _executeBound_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_executeBound.js */ "./node_modules/underscore/modules/_executeBound.js"
          );

        // Create a function bound to a given object (assigning `this`, and arguments,
        // optionally).
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          func,
          context,
          args
        ) {
          if (
            !(0, _isFunction_js__WEBPACK_IMPORTED_MODULE_1__["default"])(func)
          )
            throw new TypeError("Bind must be called on a function");
          var bound = (0,
          _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
            callArgs
          ) {
            return (0,
            _executeBound_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
              func,
              bound,
              context,
              this,
              args.concat(callArgs)
            );
          });
          return bound;
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/bindAll.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/bindAll.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );
        /* harmony import */ var _flatten_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_flatten.js */ "./node_modules/underscore/modules/_flatten.js"
          );
        /* harmony import */ var _bind_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./bind.js */ "./node_modules/underscore/modules/bind.js"
          );

        // Bind a number of an object's methods to that object. Remaining arguments
        // are the method names to be bound. Useful for ensuring that all callbacks
        // defined on an object belong to it.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          obj,
          keys
        ) {
          keys = (0, _flatten_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
            keys,
            false,
            false
          );
          var index = keys.length;
          if (index < 1)
            throw new Error("bindAll must be passed function names");
          while (index--) {
            var key = keys[index];
            obj[key] = (0, _bind_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
              obj[key],
              obj
            );
          }
          return obj;
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/chain.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/chain.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ chain,
          /* harmony export */
        });
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );

        // Start chaining a wrapped Underscore object.
        function chain(obj) {
          var instance = (0,
          _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj);
          instance._chain = true;
          return instance;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/chunk.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/chunk.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ chunk,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );

        // Chunk a single array into multiple arrays, each containing `count` or fewer
        // items.
        function chunk(array, count) {
          if (count == null || count < 1) return [];
          var result = [];
          var i = 0,
            length = array.length;
          while (i < length) {
            result.push(
              _setup_js__WEBPACK_IMPORTED_MODULE_0__.slice.call(
                array,
                i,
                (i += count)
              )
            );
          }
          return result;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/clone.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/clone.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ clone,
          /* harmony export */
        });
        /* harmony import */ var _isObject_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./isObject.js */ "./node_modules/underscore/modules/isObject.js"
          );
        /* harmony import */ var _isArray_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isArray.js */ "./node_modules/underscore/modules/isArray.js"
          );
        /* harmony import */ var _extend_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./extend.js */ "./node_modules/underscore/modules/extend.js"
          );

        // Create a (shallow-cloned) duplicate of an object.
        function clone(obj) {
          if (!(0, _isObject_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj))
            return obj;
          return (0, _isArray_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj)
            ? obj.slice()
            : (0, _extend_js__WEBPACK_IMPORTED_MODULE_2__["default"])({}, obj);
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/compact.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/compact.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ compact,
          /* harmony export */
        });
        /* harmony import */ var _filter_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./filter.js */ "./node_modules/underscore/modules/filter.js"
          );

        // Trim out all falsy values from an array.
        function compact(array) {
          return (0, _filter_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            array,
            Boolean
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/compose.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/compose.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ compose,
          /* harmony export */
        });
        // Returns a function that is the composition of a list of functions, each
        // consuming the return value of the function that follows.
        function compose() {
          var args = arguments;
          var start = args.length - 1;
          return function () {
            var i = start;
            var result = args[start].apply(this, arguments);
            while (i--) result = args[i].call(this, result);
            return result;
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/constant.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/constant.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ constant,
          /* harmony export */
        });
        // Predicate-generating function. Often useful outside of Underscore.
        function constant(value) {
          return function () {
            return value;
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/contains.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/contains.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ contains,
          /* harmony export */
        });
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _values_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./values.js */ "./node_modules/underscore/modules/values.js"
          );
        /* harmony import */ var _indexOf_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./indexOf.js */ "./node_modules/underscore/modules/indexOf.js"
          );

        // Determine if the array or object contains a given item (using `===`).
        function contains(obj, item, fromIndex, guard) {
          if (
            !(0, _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj)
          )
            obj = (0, _values_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj);
          if (typeof fromIndex != "number" || guard) fromIndex = 0;
          return (
            (0, _indexOf_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
              obj,
              item,
              fromIndex
            ) >= 0
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/countBy.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/countBy.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _group_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_group.js */ "./node_modules/underscore/modules/_group.js"
          );
        /* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_has.js */ "./node_modules/underscore/modules/_has.js"
          );

        // Counts instances of an object that group by a certain criterion. Pass
        // either a string attribute to count by, or a function that returns the
        // criterion.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _group_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          result,
          value,
          key
        ) {
          if ((0, _has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(result, key))
            result[key]++;
          else result[key] = 1;
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/create.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/create.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ create,
          /* harmony export */
        });
        /* harmony import */ var _baseCreate_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_baseCreate.js */ "./node_modules/underscore/modules/_baseCreate.js"
          );
        /* harmony import */ var _extendOwn_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./extendOwn.js */ "./node_modules/underscore/modules/extendOwn.js"
          );

        // Creates an object that inherits from the given prototype object.
        // If additional properties are provided then they will be added to the
        // created object.
        function create(prototype, props) {
          var result = (0,
          _baseCreate_js__WEBPACK_IMPORTED_MODULE_0__["default"])(prototype);
          if (props)
            (0, _extendOwn_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              result,
              props
            );
          return result;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/debounce.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/debounce.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ debounce,
          /* harmony export */
        });
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );
        /* harmony import */ var _now_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./now.js */ "./node_modules/underscore/modules/now.js"
          );

        // When a sequence of calls of the returned function ends, the argument
        // function is triggered. The end of a sequence is defined by the `wait`
        // parameter. If `immediate` is passed, the argument function will be
        // triggered at the beginning of the sequence instead of at the end.
        function debounce(func, wait, immediate) {
          var timeout, previous, args, result, context;

          var later = function () {
            var passed =
              (0, _now_js__WEBPACK_IMPORTED_MODULE_1__["default"])() - previous;
            if (wait > passed) {
              timeout = setTimeout(later, wait - passed);
            } else {
              timeout = null;
              if (!immediate) result = func.apply(context, args);
              // This check is needed because `func` can recursively invoke `debounced`.
              if (!timeout) args = context = null;
            }
          };

          var debounced = (0,
          _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
            _args
          ) {
            context = this;
            args = _args;
            previous = (0, _now_js__WEBPACK_IMPORTED_MODULE_1__["default"])();
            if (!timeout) {
              timeout = setTimeout(later, wait);
              if (immediate) result = func.apply(context, args);
            }
            return result;
          });

          debounced.cancel = function () {
            clearTimeout(timeout);
            timeout = args = context = null;
          };

          return debounced;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/defaults.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/defaults.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _createAssigner_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_createAssigner.js */ "./node_modules/underscore/modules/_createAssigner.js"
          );
        /* harmony import */ var _allKeys_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./allKeys.js */ "./node_modules/underscore/modules/allKeys.js"
          );

        // Fill in a given object with default properties.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createAssigner_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          _allKeys_js__WEBPACK_IMPORTED_MODULE_1__["default"],
          true
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/defer.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/defer.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _partial_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./partial.js */ "./node_modules/underscore/modules/partial.js"
          );
        /* harmony import */ var _delay_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./delay.js */ "./node_modules/underscore/modules/delay.js"
          );
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );

        // Defers a function, scheduling it to run after the current call stack has
        // cleared.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _partial_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          _delay_js__WEBPACK_IMPORTED_MODULE_1__["default"],
          _underscore_js__WEBPACK_IMPORTED_MODULE_2__["default"],
          1
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/delay.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/delay.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );

        // Delays a function for the given number of milliseconds, and then calls
        // it with the arguments supplied.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          func,
          wait,
          args
        ) {
          return setTimeout(function () {
            return func.apply(null, args);
          }, wait);
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/difference.js":
      /*!*******************************************************!*\
  !*** ./node_modules/underscore/modules/difference.js ***!
  \*******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );
        /* harmony import */ var _flatten_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_flatten.js */ "./node_modules/underscore/modules/_flatten.js"
          );
        /* harmony import */ var _filter_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./filter.js */ "./node_modules/underscore/modules/filter.js"
          );
        /* harmony import */ var _contains_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./contains.js */ "./node_modules/underscore/modules/contains.js"
          );

        // Take the difference between one array and a number of other arrays.
        // Only the elements present in just the first array will remain.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          array,
          rest
        ) {
          rest = (0, _flatten_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
            rest,
            true,
            true
          );
          return (0, _filter_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
            array,
            function (value) {
              return !(0, _contains_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
                rest,
                value
              );
            }
          );
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/each.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/each.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ each,
          /* harmony export */
        });
        /* harmony import */ var _optimizeCb_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_optimizeCb.js */ "./node_modules/underscore/modules/_optimizeCb.js"
          );
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // The cornerstone for collection functions, an `each`
        // implementation, aka `forEach`.
        // Handles raw objects in addition to array-likes. Treats all
        // sparse array-likes as if they were dense.
        function each(obj, iteratee, context) {
          iteratee = (0,
          _optimizeCb_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            iteratee,
            context
          );
          var i, length;
          if (
            (0, _isArrayLike_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj)
          ) {
            for (i = 0, length = obj.length; i < length; i++) {
              iteratee(obj[i], i, obj);
            }
          } else {
            var _keys = (0, _keys_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
              obj
            );
            for (i = 0, length = _keys.length; i < length; i++) {
              iteratee(obj[_keys[i]], _keys[i], obj);
            }
          }
          return obj;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/escape.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/escape.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _createEscaper_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_createEscaper.js */ "./node_modules/underscore/modules/_createEscaper.js"
          );
        /* harmony import */ var _escapeMap_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_escapeMap.js */ "./node_modules/underscore/modules/_escapeMap.js"
          );

        // Function for escaping strings to HTML interpolation.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createEscaper_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          _escapeMap_js__WEBPACK_IMPORTED_MODULE_1__["default"]
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/every.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/every.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ every,
          /* harmony export */
        });
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Determine whether all of the elements pass a truth test.
        function every(obj, predicate, context) {
          predicate = (0, _cb_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            predicate,
            context
          );
          var _keys =
              !(0, _isArrayLike_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
                obj
              ) && (0, _keys_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj),
            length = (_keys || obj).length;
          for (var index = 0; index < length; index++) {
            var currentKey = _keys ? _keys[index] : index;
            if (!predicate(obj[currentKey], currentKey, obj)) return false;
          }
          return true;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/extend.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/extend.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _createAssigner_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_createAssigner.js */ "./node_modules/underscore/modules/_createAssigner.js"
          );
        /* harmony import */ var _allKeys_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./allKeys.js */ "./node_modules/underscore/modules/allKeys.js"
          );

        // Extend a given object with all the properties in passed-in object(s).
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createAssigner_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          _allKeys_js__WEBPACK_IMPORTED_MODULE_1__["default"]
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/extendOwn.js":
      /*!******************************************************!*\
  !*** ./node_modules/underscore/modules/extendOwn.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _createAssigner_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_createAssigner.js */ "./node_modules/underscore/modules/_createAssigner.js"
          );
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Assigns a given object with all the own properties in the passed-in
        // object(s).
        // (https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object/assign)
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createAssigner_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          _keys_js__WEBPACK_IMPORTED_MODULE_1__["default"]
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/filter.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/filter.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ filter,
          /* harmony export */
        });
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _each_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./each.js */ "./node_modules/underscore/modules/each.js"
          );

        // Return all the elements that pass a truth test.
        function filter(obj, predicate, context) {
          var results = [];
          predicate = (0, _cb_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            predicate,
            context
          );
          (0, _each_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
            obj,
            function (value, index, list) {
              if (predicate(value, index, list)) results.push(value);
            }
          );
          return results;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/find.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/find.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ find,
          /* harmony export */
        });
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _findIndex_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./findIndex.js */ "./node_modules/underscore/modules/findIndex.js"
          );
        /* harmony import */ var _findKey_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./findKey.js */ "./node_modules/underscore/modules/findKey.js"
          );

        // Return the first value which passes a truth test.
        function find(obj, predicate, context) {
          var keyFinder = (0,
          _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj)
            ? _findIndex_js__WEBPACK_IMPORTED_MODULE_1__["default"]
            : _findKey_js__WEBPACK_IMPORTED_MODULE_2__["default"];
          var key = keyFinder(obj, predicate, context);
          if (key !== void 0 && key !== -1) return obj[key];
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/findIndex.js":
      /*!******************************************************!*\
  !*** ./node_modules/underscore/modules/findIndex.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _createPredicateIndexFinder_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_createPredicateIndexFinder.js */ "./node_modules/underscore/modules/_createPredicateIndexFinder.js"
          );

        // Returns the first index on an array-like that passes a truth test.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createPredicateIndexFinder_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          1
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/findKey.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/findKey.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ findKey,
          /* harmony export */
        });
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Returns the first key on an object that passes a truth test.
        function findKey(obj, predicate, context) {
          predicate = (0, _cb_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            predicate,
            context
          );
          var _keys = (0, _keys_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              obj
            ),
            key;
          for (var i = 0, length = _keys.length; i < length; i++) {
            key = _keys[i];
            if (predicate(obj[key], key, obj)) return key;
          }
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/findLastIndex.js":
      /*!**********************************************************!*\
  !*** ./node_modules/underscore/modules/findLastIndex.js ***!
  \**********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _createPredicateIndexFinder_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_createPredicateIndexFinder.js */ "./node_modules/underscore/modules/_createPredicateIndexFinder.js"
          );

        // Returns the last index on an array-like that passes a truth test.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createPredicateIndexFinder_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          -1
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/findWhere.js":
      /*!******************************************************!*\
  !*** ./node_modules/underscore/modules/findWhere.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ findWhere,
          /* harmony export */
        });
        /* harmony import */ var _find_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./find.js */ "./node_modules/underscore/modules/find.js"
          );
        /* harmony import */ var _matcher_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./matcher.js */ "./node_modules/underscore/modules/matcher.js"
          );

        // Convenience version of a common use case of `_.find`: getting the first
        // object containing specific `key:value` pairs.
        function findWhere(obj, attrs) {
          return (0, _find_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            obj,
            (0, _matcher_js__WEBPACK_IMPORTED_MODULE_1__["default"])(attrs)
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/first.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/first.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ first,
          /* harmony export */
        });
        /* harmony import */ var _initial_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./initial.js */ "./node_modules/underscore/modules/initial.js"
          );

        // Get the first element of an array. Passing **n** will return the first N
        // values in the array. The **guard** check allows it to work with `_.map`.
        function first(array, n, guard) {
          if (array == null || array.length < 1)
            return n == null || guard ? void 0 : [];
          if (n == null || guard) return array[0];
          return (0, _initial_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            array,
            array.length - n
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/flatten.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/flatten.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ flatten,
          /* harmony export */
        });
        /* harmony import */ var _flatten_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_flatten.js */ "./node_modules/underscore/modules/_flatten.js"
          );

        // Flatten out an array, either recursively (by default), or up to `depth`.
        // Passing `true` or `false` as `depth` means `1` or `Infinity`, respectively.
        function flatten(array, depth) {
          return (0, _flatten_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            array,
            depth,
            false
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/functions.js":
      /*!******************************************************!*\
  !*** ./node_modules/underscore/modules/functions.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ functions,
          /* harmony export */
        });
        /* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./isFunction.js */ "./node_modules/underscore/modules/isFunction.js"
          );

        // Return a sorted list of the function names available on the object.
        function functions(obj) {
          var names = [];
          for (var key in obj) {
            if (
              (0, _isFunction_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
                obj[key]
              )
            )
              names.push(key);
          }
          return names.sort();
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/get.js":
      /*!************************************************!*\
  !*** ./node_modules/underscore/modules/get.js ***!
  \************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ get,
          /* harmony export */
        });
        /* harmony import */ var _toPath_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_toPath.js */ "./node_modules/underscore/modules/_toPath.js"
          );
        /* harmony import */ var _deepGet_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_deepGet.js */ "./node_modules/underscore/modules/_deepGet.js"
          );
        /* harmony import */ var _isUndefined_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./isUndefined.js */ "./node_modules/underscore/modules/isUndefined.js"
          );

        // Get the value of the (deep) property on `path` from `object`.
        // If any property in `path` does not exist or if the value is
        // `undefined`, return `defaultValue` instead.
        // The `path` is normalized through `_.toPath`.
        function get(object, path, defaultValue) {
          var value = (0, _deepGet_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
            object,
            (0, _toPath_js__WEBPACK_IMPORTED_MODULE_0__["default"])(path)
          );
          return (0, _isUndefined_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
            value
          )
            ? defaultValue
            : value;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/groupBy.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/groupBy.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _group_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_group.js */ "./node_modules/underscore/modules/_group.js"
          );
        /* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_has.js */ "./node_modules/underscore/modules/_has.js"
          );

        // Groups the object's values by a criterion. Pass either a string attribute
        // to group by, or a function that returns the criterion.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _group_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          result,
          value,
          key
        ) {
          if ((0, _has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(result, key))
            result[key].push(value);
          else result[key] = [value];
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/has.js":
      /*!************************************************!*\
  !*** ./node_modules/underscore/modules/has.js ***!
  \************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ has,
          /* harmony export */
        });
        /* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_has.js */ "./node_modules/underscore/modules/_has.js"
          );
        /* harmony import */ var _toPath_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_toPath.js */ "./node_modules/underscore/modules/_toPath.js"
          );

        // Shortcut function for checking if an object has a given property directly on
        // itself (in other words, not on a prototype). Unlike the internal `has`
        // function, this public version can also traverse nested properties.
        function has(obj, path) {
          path = (0, _toPath_js__WEBPACK_IMPORTED_MODULE_1__["default"])(path);
          var length = path.length;
          for (var i = 0; i < length; i++) {
            var key = path[i];
            if (!(0, _has_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj, key))
              return false;
            obj = obj[key];
          }
          return !!length;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/identity.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/identity.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ identity,
          /* harmony export */
        });
        // Keep the identity function around for default iteratees.
        function identity(value) {
          return value;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/index-all.js":
      /*!******************************************************!*\
  !*** ./node_modules/underscore/modules/index-all.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () =>
            /* reexport safe */ _index_default_js__WEBPACK_IMPORTED_MODULE_0__[
              "default"
            ],
          /* harmony export */ VERSION: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.VERSION,
          /* harmony export */ after: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.after,
          /* harmony export */ all: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.all,
          /* harmony export */ allKeys: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.allKeys,
          /* harmony export */ any: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.any,
          /* harmony export */ assign: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.assign,
          /* harmony export */ before: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.before,
          /* harmony export */ bind: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.bind,
          /* harmony export */ bindAll: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.bindAll,
          /* harmony export */ chain: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.chain,
          /* harmony export */ chunk: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.chunk,
          /* harmony export */ clone: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.clone,
          /* harmony export */ collect: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.collect,
          /* harmony export */ compact: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.compact,
          /* harmony export */ compose: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.compose,
          /* harmony export */ constant: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.constant,
          /* harmony export */ contains: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.contains,
          /* harmony export */ countBy: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.countBy,
          /* harmony export */ create: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.create,
          /* harmony export */ debounce: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.debounce,
          /* harmony export */ defaults: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.defaults,
          /* harmony export */ defer: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.defer,
          /* harmony export */ delay: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.delay,
          /* harmony export */ detect: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.detect,
          /* harmony export */ difference: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.difference,
          /* harmony export */ drop: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.drop,
          /* harmony export */ each: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.each,
          /* harmony export */ escape: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.escape,
          /* harmony export */ every: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.every,
          /* harmony export */ extend: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.extend,
          /* harmony export */ extendOwn: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.extendOwn,
          /* harmony export */ filter: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.filter,
          /* harmony export */ find: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.find,
          /* harmony export */ findIndex: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.findIndex,
          /* harmony export */ findKey: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.findKey,
          /* harmony export */ findLastIndex: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.findLastIndex,
          /* harmony export */ findWhere: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.findWhere,
          /* harmony export */ first: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.first,
          /* harmony export */ flatten: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.flatten,
          /* harmony export */ foldl: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.foldl,
          /* harmony export */ foldr: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.foldr,
          /* harmony export */ forEach: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.forEach,
          /* harmony export */ functions: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.functions,
          /* harmony export */ get: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.get,
          /* harmony export */ groupBy: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.groupBy,
          /* harmony export */ has: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.has,
          /* harmony export */ head: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.head,
          /* harmony export */ identity: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.identity,
          /* harmony export */ include: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.include,
          /* harmony export */ includes: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.includes,
          /* harmony export */ indexBy: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.indexBy,
          /* harmony export */ indexOf: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.indexOf,
          /* harmony export */ initial: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.initial,
          /* harmony export */ inject: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.inject,
          /* harmony export */ intersection: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.intersection,
          /* harmony export */ invert: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.invert,
          /* harmony export */ invoke: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.invoke,
          /* harmony export */ isArguments: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isArguments,
          /* harmony export */ isArray: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isArray,
          /* harmony export */ isArrayBuffer: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isArrayBuffer,
          /* harmony export */ isBoolean: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isBoolean,
          /* harmony export */ isDataView: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isDataView,
          /* harmony export */ isDate: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isDate,
          /* harmony export */ isElement: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isElement,
          /* harmony export */ isEmpty: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isEmpty,
          /* harmony export */ isEqual: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isEqual,
          /* harmony export */ isError: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isError,
          /* harmony export */ isFinite: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isFinite,
          /* harmony export */ isFunction: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isFunction,
          /* harmony export */ isMap: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isMap,
          /* harmony export */ isMatch: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isMatch,
          /* harmony export */ isNaN: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isNaN,
          /* harmony export */ isNull: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isNull,
          /* harmony export */ isNumber: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isNumber,
          /* harmony export */ isObject: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isObject,
          /* harmony export */ isRegExp: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isRegExp,
          /* harmony export */ isSet: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isSet,
          /* harmony export */ isString: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isString,
          /* harmony export */ isSymbol: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isSymbol,
          /* harmony export */ isTypedArray: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isTypedArray,
          /* harmony export */ isUndefined: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isUndefined,
          /* harmony export */ isWeakMap: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isWeakMap,
          /* harmony export */ isWeakSet: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.isWeakSet,
          /* harmony export */ iteratee: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.iteratee,
          /* harmony export */ keys: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.keys,
          /* harmony export */ last: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.last,
          /* harmony export */ lastIndexOf: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.lastIndexOf,
          /* harmony export */ map: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.map,
          /* harmony export */ mapObject: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.mapObject,
          /* harmony export */ matcher: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.matcher,
          /* harmony export */ matches: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.matches,
          /* harmony export */ max: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.max,
          /* harmony export */ memoize: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.memoize,
          /* harmony export */ methods: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.methods,
          /* harmony export */ min: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.min,
          /* harmony export */ mixin: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.mixin,
          /* harmony export */ negate: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.negate,
          /* harmony export */ noop: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.noop,
          /* harmony export */ now: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.now,
          /* harmony export */ object: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.object,
          /* harmony export */ omit: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.omit,
          /* harmony export */ once: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.once,
          /* harmony export */ pairs: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.pairs,
          /* harmony export */ partial: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.partial,
          /* harmony export */ partition: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.partition,
          /* harmony export */ pick: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.pick,
          /* harmony export */ pluck: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.pluck,
          /* harmony export */ property: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.property,
          /* harmony export */ propertyOf: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.propertyOf,
          /* harmony export */ random: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.random,
          /* harmony export */ range: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.range,
          /* harmony export */ reduce: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.reduce,
          /* harmony export */ reduceRight: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.reduceRight,
          /* harmony export */ reject: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.reject,
          /* harmony export */ rest: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.rest,
          /* harmony export */ restArguments: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.restArguments,
          /* harmony export */ result: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.result,
          /* harmony export */ sample: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.sample,
          /* harmony export */ select: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.select,
          /* harmony export */ shuffle: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.shuffle,
          /* harmony export */ size: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.size,
          /* harmony export */ some: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.some,
          /* harmony export */ sortBy: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.sortBy,
          /* harmony export */ sortedIndex: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.sortedIndex,
          /* harmony export */ tail: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.tail,
          /* harmony export */ take: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.take,
          /* harmony export */ tap: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.tap,
          /* harmony export */ template: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.template,
          /* harmony export */ templateSettings: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.templateSettings,
          /* harmony export */ throttle: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.throttle,
          /* harmony export */ times: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.times,
          /* harmony export */ toArray: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.toArray,
          /* harmony export */ toPath: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.toPath,
          /* harmony export */ transpose: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.transpose,
          /* harmony export */ unescape: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.unescape,
          /* harmony export */ union: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.union,
          /* harmony export */ uniq: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.uniq,
          /* harmony export */ unique: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.unique,
          /* harmony export */ uniqueId: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.uniqueId,
          /* harmony export */ unzip: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.unzip,
          /* harmony export */ values: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.values,
          /* harmony export */ where: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.where,
          /* harmony export */ without: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.without,
          /* harmony export */ wrap: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.wrap,
          /* harmony export */ zip: () =>
            /* reexport safe */ _index_js__WEBPACK_IMPORTED_MODULE_1__.zip,
          /* harmony export */
        });
        /* harmony import */ var _index_default_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./index-default.js */ "./node_modules/underscore/modules/index-default.js"
          );
        /* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./index.js */ "./node_modules/underscore/modules/index.js"
          );
        // ESM Exports
        // ===========
        // This module is the package entry point for ES module users. In other words,
        // it is the module they are interfacing with when they import from the whole
        // package instead of from a submodule, like this:
        //
        // ```js
        // import { map } from 'underscore';
        // ```
        //
        // The difference with `./index-default`, which is the package entry point for
        // CommonJS, AMD and UMD users, is purely technical. In ES modules, named and
        // default exports are considered to be siblings, so when you have a default
        // export, its properties are not automatically available as named exports. For
        // this reason, we re-export the named exports in addition to providing the same
        // default export as in `./index-default`.

        /***/
      },

    /***/ "./node_modules/underscore/modules/index-default.js":
      /*!**********************************************************!*\
  !*** ./node_modules/underscore/modules/index-default.js ***!
  \**********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _index_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./index.js */ "./node_modules/underscore/modules/index.js"
          );
        // Default Export
        // ==============
        // In this module, we mix our bundled exports into the `_` object and export
        // the result. This is analogous to setting `module.exports = _` in CommonJS.
        // Hence, this module is also the entry point of our UMD bundle and the package
        // entry point for CommonJS and AMD users. In other words, this is (the source
        // of) the module you are interfacing with when you do any of the following:
        //
        // ```js
        // // CommonJS
        // var _ = require('underscore');
        //
        // // AMD
        // define(['underscore'], function(_) {...});
        //
        // // UMD in the browser
        // // _ is available as a global variable
        // ```

        // Add all of the Underscore functions to the wrapper object.
        var _ = (0, _index_js__WEBPACK_IMPORTED_MODULE_0__.mixin)(
          _index_js__WEBPACK_IMPORTED_MODULE_0__
        );
        // Legacy Node.js API.
        _._ = _;
        // Export the Underscore API.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = _;

        /***/
      },

    /***/ "./node_modules/underscore/modules/index.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/index.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ VERSION: () =>
            /* reexport safe */ _setup_js__WEBPACK_IMPORTED_MODULE_0__.VERSION,
          /* harmony export */ restArguments: () =>
            /* reexport safe */ _restArguments_js__WEBPACK_IMPORTED_MODULE_1__[
              "default"
            ],
          /* harmony export */ isObject: () =>
            /* reexport safe */ _isObject_js__WEBPACK_IMPORTED_MODULE_2__[
              "default"
            ],
          /* harmony export */ isNull: () =>
            /* reexport safe */ _isNull_js__WEBPACK_IMPORTED_MODULE_3__[
              "default"
            ],
          /* harmony export */ isUndefined: () =>
            /* reexport safe */ _isUndefined_js__WEBPACK_IMPORTED_MODULE_4__[
              "default"
            ],
          /* harmony export */ isBoolean: () =>
            /* reexport safe */ _isBoolean_js__WEBPACK_IMPORTED_MODULE_5__[
              "default"
            ],
          /* harmony export */ isElement: () =>
            /* reexport safe */ _isElement_js__WEBPACK_IMPORTED_MODULE_6__[
              "default"
            ],
          /* harmony export */ isString: () =>
            /* reexport safe */ _isString_js__WEBPACK_IMPORTED_MODULE_7__[
              "default"
            ],
          /* harmony export */ isNumber: () =>
            /* reexport safe */ _isNumber_js__WEBPACK_IMPORTED_MODULE_8__[
              "default"
            ],
          /* harmony export */ isDate: () =>
            /* reexport safe */ _isDate_js__WEBPACK_IMPORTED_MODULE_9__[
              "default"
            ],
          /* harmony export */ isRegExp: () =>
            /* reexport safe */ _isRegExp_js__WEBPACK_IMPORTED_MODULE_10__[
              "default"
            ],
          /* harmony export */ isError: () =>
            /* reexport safe */ _isError_js__WEBPACK_IMPORTED_MODULE_11__[
              "default"
            ],
          /* harmony export */ isSymbol: () =>
            /* reexport safe */ _isSymbol_js__WEBPACK_IMPORTED_MODULE_12__[
              "default"
            ],
          /* harmony export */ isArrayBuffer: () =>
            /* reexport safe */ _isArrayBuffer_js__WEBPACK_IMPORTED_MODULE_13__[
              "default"
            ],
          /* harmony export */ isDataView: () =>
            /* reexport safe */ _isDataView_js__WEBPACK_IMPORTED_MODULE_14__[
              "default"
            ],
          /* harmony export */ isArray: () =>
            /* reexport safe */ _isArray_js__WEBPACK_IMPORTED_MODULE_15__[
              "default"
            ],
          /* harmony export */ isFunction: () =>
            /* reexport safe */ _isFunction_js__WEBPACK_IMPORTED_MODULE_16__[
              "default"
            ],
          /* harmony export */ isArguments: () =>
            /* reexport safe */ _isArguments_js__WEBPACK_IMPORTED_MODULE_17__[
              "default"
            ],
          /* harmony export */ isFinite: () =>
            /* reexport safe */ _isFinite_js__WEBPACK_IMPORTED_MODULE_18__[
              "default"
            ],
          /* harmony export */ isNaN: () =>
            /* reexport safe */ _isNaN_js__WEBPACK_IMPORTED_MODULE_19__[
              "default"
            ],
          /* harmony export */ isTypedArray: () =>
            /* reexport safe */ _isTypedArray_js__WEBPACK_IMPORTED_MODULE_20__[
              "default"
            ],
          /* harmony export */ isEmpty: () =>
            /* reexport safe */ _isEmpty_js__WEBPACK_IMPORTED_MODULE_21__[
              "default"
            ],
          /* harmony export */ isMatch: () =>
            /* reexport safe */ _isMatch_js__WEBPACK_IMPORTED_MODULE_22__[
              "default"
            ],
          /* harmony export */ isEqual: () =>
            /* reexport safe */ _isEqual_js__WEBPACK_IMPORTED_MODULE_23__[
              "default"
            ],
          /* harmony export */ isMap: () =>
            /* reexport safe */ _isMap_js__WEBPACK_IMPORTED_MODULE_24__[
              "default"
            ],
          /* harmony export */ isWeakMap: () =>
            /* reexport safe */ _isWeakMap_js__WEBPACK_IMPORTED_MODULE_25__[
              "default"
            ],
          /* harmony export */ isSet: () =>
            /* reexport safe */ _isSet_js__WEBPACK_IMPORTED_MODULE_26__[
              "default"
            ],
          /* harmony export */ isWeakSet: () =>
            /* reexport safe */ _isWeakSet_js__WEBPACK_IMPORTED_MODULE_27__[
              "default"
            ],
          /* harmony export */ keys: () =>
            /* reexport safe */ _keys_js__WEBPACK_IMPORTED_MODULE_28__[
              "default"
            ],
          /* harmony export */ allKeys: () =>
            /* reexport safe */ _allKeys_js__WEBPACK_IMPORTED_MODULE_29__[
              "default"
            ],
          /* harmony export */ values: () =>
            /* reexport safe */ _values_js__WEBPACK_IMPORTED_MODULE_30__[
              "default"
            ],
          /* harmony export */ pairs: () =>
            /* reexport safe */ _pairs_js__WEBPACK_IMPORTED_MODULE_31__[
              "default"
            ],
          /* harmony export */ invert: () =>
            /* reexport safe */ _invert_js__WEBPACK_IMPORTED_MODULE_32__[
              "default"
            ],
          /* harmony export */ functions: () =>
            /* reexport safe */ _functions_js__WEBPACK_IMPORTED_MODULE_33__[
              "default"
            ],
          /* harmony export */ methods: () =>
            /* reexport safe */ _functions_js__WEBPACK_IMPORTED_MODULE_33__[
              "default"
            ],
          /* harmony export */ extend: () =>
            /* reexport safe */ _extend_js__WEBPACK_IMPORTED_MODULE_34__[
              "default"
            ],
          /* harmony export */ extendOwn: () =>
            /* reexport safe */ _extendOwn_js__WEBPACK_IMPORTED_MODULE_35__[
              "default"
            ],
          /* harmony export */ assign: () =>
            /* reexport safe */ _extendOwn_js__WEBPACK_IMPORTED_MODULE_35__[
              "default"
            ],
          /* harmony export */ defaults: () =>
            /* reexport safe */ _defaults_js__WEBPACK_IMPORTED_MODULE_36__[
              "default"
            ],
          /* harmony export */ create: () =>
            /* reexport safe */ _create_js__WEBPACK_IMPORTED_MODULE_37__[
              "default"
            ],
          /* harmony export */ clone: () =>
            /* reexport safe */ _clone_js__WEBPACK_IMPORTED_MODULE_38__[
              "default"
            ],
          /* harmony export */ tap: () =>
            /* reexport safe */ _tap_js__WEBPACK_IMPORTED_MODULE_39__[
              "default"
            ],
          /* harmony export */ get: () =>
            /* reexport safe */ _get_js__WEBPACK_IMPORTED_MODULE_40__[
              "default"
            ],
          /* harmony export */ has: () =>
            /* reexport safe */ _has_js__WEBPACK_IMPORTED_MODULE_41__[
              "default"
            ],
          /* harmony export */ mapObject: () =>
            /* reexport safe */ _mapObject_js__WEBPACK_IMPORTED_MODULE_42__[
              "default"
            ],
          /* harmony export */ identity: () =>
            /* reexport safe */ _identity_js__WEBPACK_IMPORTED_MODULE_43__[
              "default"
            ],
          /* harmony export */ constant: () =>
            /* reexport safe */ _constant_js__WEBPACK_IMPORTED_MODULE_44__[
              "default"
            ],
          /* harmony export */ noop: () =>
            /* reexport safe */ _noop_js__WEBPACK_IMPORTED_MODULE_45__[
              "default"
            ],
          /* harmony export */ toPath: () =>
            /* reexport safe */ _toPath_js__WEBPACK_IMPORTED_MODULE_46__[
              "default"
            ],
          /* harmony export */ property: () =>
            /* reexport safe */ _property_js__WEBPACK_IMPORTED_MODULE_47__[
              "default"
            ],
          /* harmony export */ propertyOf: () =>
            /* reexport safe */ _propertyOf_js__WEBPACK_IMPORTED_MODULE_48__[
              "default"
            ],
          /* harmony export */ matcher: () =>
            /* reexport safe */ _matcher_js__WEBPACK_IMPORTED_MODULE_49__[
              "default"
            ],
          /* harmony export */ matches: () =>
            /* reexport safe */ _matcher_js__WEBPACK_IMPORTED_MODULE_49__[
              "default"
            ],
          /* harmony export */ times: () =>
            /* reexport safe */ _times_js__WEBPACK_IMPORTED_MODULE_50__[
              "default"
            ],
          /* harmony export */ random: () =>
            /* reexport safe */ _random_js__WEBPACK_IMPORTED_MODULE_51__[
              "default"
            ],
          /* harmony export */ now: () =>
            /* reexport safe */ _now_js__WEBPACK_IMPORTED_MODULE_52__[
              "default"
            ],
          /* harmony export */ escape: () =>
            /* reexport safe */ _escape_js__WEBPACK_IMPORTED_MODULE_53__[
              "default"
            ],
          /* harmony export */ unescape: () =>
            /* reexport safe */ _unescape_js__WEBPACK_IMPORTED_MODULE_54__[
              "default"
            ],
          /* harmony export */ templateSettings: () =>
            /* reexport safe */ _templateSettings_js__WEBPACK_IMPORTED_MODULE_55__[
              "default"
            ],
          /* harmony export */ template: () =>
            /* reexport safe */ _template_js__WEBPACK_IMPORTED_MODULE_56__[
              "default"
            ],
          /* harmony export */ result: () =>
            /* reexport safe */ _result_js__WEBPACK_IMPORTED_MODULE_57__[
              "default"
            ],
          /* harmony export */ uniqueId: () =>
            /* reexport safe */ _uniqueId_js__WEBPACK_IMPORTED_MODULE_58__[
              "default"
            ],
          /* harmony export */ chain: () =>
            /* reexport safe */ _chain_js__WEBPACK_IMPORTED_MODULE_59__[
              "default"
            ],
          /* harmony export */ iteratee: () =>
            /* reexport safe */ _iteratee_js__WEBPACK_IMPORTED_MODULE_60__[
              "default"
            ],
          /* harmony export */ partial: () =>
            /* reexport safe */ _partial_js__WEBPACK_IMPORTED_MODULE_61__[
              "default"
            ],
          /* harmony export */ bind: () =>
            /* reexport safe */ _bind_js__WEBPACK_IMPORTED_MODULE_62__[
              "default"
            ],
          /* harmony export */ bindAll: () =>
            /* reexport safe */ _bindAll_js__WEBPACK_IMPORTED_MODULE_63__[
              "default"
            ],
          /* harmony export */ memoize: () =>
            /* reexport safe */ _memoize_js__WEBPACK_IMPORTED_MODULE_64__[
              "default"
            ],
          /* harmony export */ delay: () =>
            /* reexport safe */ _delay_js__WEBPACK_IMPORTED_MODULE_65__[
              "default"
            ],
          /* harmony export */ defer: () =>
            /* reexport safe */ _defer_js__WEBPACK_IMPORTED_MODULE_66__[
              "default"
            ],
          /* harmony export */ throttle: () =>
            /* reexport safe */ _throttle_js__WEBPACK_IMPORTED_MODULE_67__[
              "default"
            ],
          /* harmony export */ debounce: () =>
            /* reexport safe */ _debounce_js__WEBPACK_IMPORTED_MODULE_68__[
              "default"
            ],
          /* harmony export */ wrap: () =>
            /* reexport safe */ _wrap_js__WEBPACK_IMPORTED_MODULE_69__[
              "default"
            ],
          /* harmony export */ negate: () =>
            /* reexport safe */ _negate_js__WEBPACK_IMPORTED_MODULE_70__[
              "default"
            ],
          /* harmony export */ compose: () =>
            /* reexport safe */ _compose_js__WEBPACK_IMPORTED_MODULE_71__[
              "default"
            ],
          /* harmony export */ after: () =>
            /* reexport safe */ _after_js__WEBPACK_IMPORTED_MODULE_72__[
              "default"
            ],
          /* harmony export */ before: () =>
            /* reexport safe */ _before_js__WEBPACK_IMPORTED_MODULE_73__[
              "default"
            ],
          /* harmony export */ once: () =>
            /* reexport safe */ _once_js__WEBPACK_IMPORTED_MODULE_74__[
              "default"
            ],
          /* harmony export */ findKey: () =>
            /* reexport safe */ _findKey_js__WEBPACK_IMPORTED_MODULE_75__[
              "default"
            ],
          /* harmony export */ findIndex: () =>
            /* reexport safe */ _findIndex_js__WEBPACK_IMPORTED_MODULE_76__[
              "default"
            ],
          /* harmony export */ findLastIndex: () =>
            /* reexport safe */ _findLastIndex_js__WEBPACK_IMPORTED_MODULE_77__[
              "default"
            ],
          /* harmony export */ sortedIndex: () =>
            /* reexport safe */ _sortedIndex_js__WEBPACK_IMPORTED_MODULE_78__[
              "default"
            ],
          /* harmony export */ indexOf: () =>
            /* reexport safe */ _indexOf_js__WEBPACK_IMPORTED_MODULE_79__[
              "default"
            ],
          /* harmony export */ lastIndexOf: () =>
            /* reexport safe */ _lastIndexOf_js__WEBPACK_IMPORTED_MODULE_80__[
              "default"
            ],
          /* harmony export */ find: () =>
            /* reexport safe */ _find_js__WEBPACK_IMPORTED_MODULE_81__[
              "default"
            ],
          /* harmony export */ detect: () =>
            /* reexport safe */ _find_js__WEBPACK_IMPORTED_MODULE_81__[
              "default"
            ],
          /* harmony export */ findWhere: () =>
            /* reexport safe */ _findWhere_js__WEBPACK_IMPORTED_MODULE_82__[
              "default"
            ],
          /* harmony export */ each: () =>
            /* reexport safe */ _each_js__WEBPACK_IMPORTED_MODULE_83__[
              "default"
            ],
          /* harmony export */ forEach: () =>
            /* reexport safe */ _each_js__WEBPACK_IMPORTED_MODULE_83__[
              "default"
            ],
          /* harmony export */ map: () =>
            /* reexport safe */ _map_js__WEBPACK_IMPORTED_MODULE_84__[
              "default"
            ],
          /* harmony export */ collect: () =>
            /* reexport safe */ _map_js__WEBPACK_IMPORTED_MODULE_84__[
              "default"
            ],
          /* harmony export */ reduce: () =>
            /* reexport safe */ _reduce_js__WEBPACK_IMPORTED_MODULE_85__[
              "default"
            ],
          /* harmony export */ foldl: () =>
            /* reexport safe */ _reduce_js__WEBPACK_IMPORTED_MODULE_85__[
              "default"
            ],
          /* harmony export */ inject: () =>
            /* reexport safe */ _reduce_js__WEBPACK_IMPORTED_MODULE_85__[
              "default"
            ],
          /* harmony export */ reduceRight: () =>
            /* reexport safe */ _reduceRight_js__WEBPACK_IMPORTED_MODULE_86__[
              "default"
            ],
          /* harmony export */ foldr: () =>
            /* reexport safe */ _reduceRight_js__WEBPACK_IMPORTED_MODULE_86__[
              "default"
            ],
          /* harmony export */ filter: () =>
            /* reexport safe */ _filter_js__WEBPACK_IMPORTED_MODULE_87__[
              "default"
            ],
          /* harmony export */ select: () =>
            /* reexport safe */ _filter_js__WEBPACK_IMPORTED_MODULE_87__[
              "default"
            ],
          /* harmony export */ reject: () =>
            /* reexport safe */ _reject_js__WEBPACK_IMPORTED_MODULE_88__[
              "default"
            ],
          /* harmony export */ every: () =>
            /* reexport safe */ _every_js__WEBPACK_IMPORTED_MODULE_89__[
              "default"
            ],
          /* harmony export */ all: () =>
            /* reexport safe */ _every_js__WEBPACK_IMPORTED_MODULE_89__[
              "default"
            ],
          /* harmony export */ some: () =>
            /* reexport safe */ _some_js__WEBPACK_IMPORTED_MODULE_90__[
              "default"
            ],
          /* harmony export */ any: () =>
            /* reexport safe */ _some_js__WEBPACK_IMPORTED_MODULE_90__[
              "default"
            ],
          /* harmony export */ contains: () =>
            /* reexport safe */ _contains_js__WEBPACK_IMPORTED_MODULE_91__[
              "default"
            ],
          /* harmony export */ includes: () =>
            /* reexport safe */ _contains_js__WEBPACK_IMPORTED_MODULE_91__[
              "default"
            ],
          /* harmony export */ include: () =>
            /* reexport safe */ _contains_js__WEBPACK_IMPORTED_MODULE_91__[
              "default"
            ],
          /* harmony export */ invoke: () =>
            /* reexport safe */ _invoke_js__WEBPACK_IMPORTED_MODULE_92__[
              "default"
            ],
          /* harmony export */ pluck: () =>
            /* reexport safe */ _pluck_js__WEBPACK_IMPORTED_MODULE_93__[
              "default"
            ],
          /* harmony export */ where: () =>
            /* reexport safe */ _where_js__WEBPACK_IMPORTED_MODULE_94__[
              "default"
            ],
          /* harmony export */ max: () =>
            /* reexport safe */ _max_js__WEBPACK_IMPORTED_MODULE_95__[
              "default"
            ],
          /* harmony export */ min: () =>
            /* reexport safe */ _min_js__WEBPACK_IMPORTED_MODULE_96__[
              "default"
            ],
          /* harmony export */ shuffle: () =>
            /* reexport safe */ _shuffle_js__WEBPACK_IMPORTED_MODULE_97__[
              "default"
            ],
          /* harmony export */ sample: () =>
            /* reexport safe */ _sample_js__WEBPACK_IMPORTED_MODULE_98__[
              "default"
            ],
          /* harmony export */ sortBy: () =>
            /* reexport safe */ _sortBy_js__WEBPACK_IMPORTED_MODULE_99__[
              "default"
            ],
          /* harmony export */ groupBy: () =>
            /* reexport safe */ _groupBy_js__WEBPACK_IMPORTED_MODULE_100__[
              "default"
            ],
          /* harmony export */ indexBy: () =>
            /* reexport safe */ _indexBy_js__WEBPACK_IMPORTED_MODULE_101__[
              "default"
            ],
          /* harmony export */ countBy: () =>
            /* reexport safe */ _countBy_js__WEBPACK_IMPORTED_MODULE_102__[
              "default"
            ],
          /* harmony export */ partition: () =>
            /* reexport safe */ _partition_js__WEBPACK_IMPORTED_MODULE_103__[
              "default"
            ],
          /* harmony export */ toArray: () =>
            /* reexport safe */ _toArray_js__WEBPACK_IMPORTED_MODULE_104__[
              "default"
            ],
          /* harmony export */ size: () =>
            /* reexport safe */ _size_js__WEBPACK_IMPORTED_MODULE_105__[
              "default"
            ],
          /* harmony export */ pick: () =>
            /* reexport safe */ _pick_js__WEBPACK_IMPORTED_MODULE_106__[
              "default"
            ],
          /* harmony export */ omit: () =>
            /* reexport safe */ _omit_js__WEBPACK_IMPORTED_MODULE_107__[
              "default"
            ],
          /* harmony export */ first: () =>
            /* reexport safe */ _first_js__WEBPACK_IMPORTED_MODULE_108__[
              "default"
            ],
          /* harmony export */ head: () =>
            /* reexport safe */ _first_js__WEBPACK_IMPORTED_MODULE_108__[
              "default"
            ],
          /* harmony export */ take: () =>
            /* reexport safe */ _first_js__WEBPACK_IMPORTED_MODULE_108__[
              "default"
            ],
          /* harmony export */ initial: () =>
            /* reexport safe */ _initial_js__WEBPACK_IMPORTED_MODULE_109__[
              "default"
            ],
          /* harmony export */ last: () =>
            /* reexport safe */ _last_js__WEBPACK_IMPORTED_MODULE_110__[
              "default"
            ],
          /* harmony export */ rest: () =>
            /* reexport safe */ _rest_js__WEBPACK_IMPORTED_MODULE_111__[
              "default"
            ],
          /* harmony export */ tail: () =>
            /* reexport safe */ _rest_js__WEBPACK_IMPORTED_MODULE_111__[
              "default"
            ],
          /* harmony export */ drop: () =>
            /* reexport safe */ _rest_js__WEBPACK_IMPORTED_MODULE_111__[
              "default"
            ],
          /* harmony export */ compact: () =>
            /* reexport safe */ _compact_js__WEBPACK_IMPORTED_MODULE_112__[
              "default"
            ],
          /* harmony export */ flatten: () =>
            /* reexport safe */ _flatten_js__WEBPACK_IMPORTED_MODULE_113__[
              "default"
            ],
          /* harmony export */ without: () =>
            /* reexport safe */ _without_js__WEBPACK_IMPORTED_MODULE_114__[
              "default"
            ],
          /* harmony export */ uniq: () =>
            /* reexport safe */ _uniq_js__WEBPACK_IMPORTED_MODULE_115__[
              "default"
            ],
          /* harmony export */ unique: () =>
            /* reexport safe */ _uniq_js__WEBPACK_IMPORTED_MODULE_115__[
              "default"
            ],
          /* harmony export */ union: () =>
            /* reexport safe */ _union_js__WEBPACK_IMPORTED_MODULE_116__[
              "default"
            ],
          /* harmony export */ intersection: () =>
            /* reexport safe */ _intersection_js__WEBPACK_IMPORTED_MODULE_117__[
              "default"
            ],
          /* harmony export */ difference: () =>
            /* reexport safe */ _difference_js__WEBPACK_IMPORTED_MODULE_118__[
              "default"
            ],
          /* harmony export */ unzip: () =>
            /* reexport safe */ _unzip_js__WEBPACK_IMPORTED_MODULE_119__[
              "default"
            ],
          /* harmony export */ transpose: () =>
            /* reexport safe */ _unzip_js__WEBPACK_IMPORTED_MODULE_119__[
              "default"
            ],
          /* harmony export */ zip: () =>
            /* reexport safe */ _zip_js__WEBPACK_IMPORTED_MODULE_120__[
              "default"
            ],
          /* harmony export */ object: () =>
            /* reexport safe */ _object_js__WEBPACK_IMPORTED_MODULE_121__[
              "default"
            ],
          /* harmony export */ range: () =>
            /* reexport safe */ _range_js__WEBPACK_IMPORTED_MODULE_122__[
              "default"
            ],
          /* harmony export */ chunk: () =>
            /* reexport safe */ _chunk_js__WEBPACK_IMPORTED_MODULE_123__[
              "default"
            ],
          /* harmony export */ mixin: () =>
            /* reexport safe */ _mixin_js__WEBPACK_IMPORTED_MODULE_124__[
              "default"
            ],
          /* harmony export */ default: () =>
            /* reexport safe */ _underscore_array_methods_js__WEBPACK_IMPORTED_MODULE_125__[
              "default"
            ],
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );
        /* harmony import */ var _isObject_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./isObject.js */ "./node_modules/underscore/modules/isObject.js"
          );
        /* harmony import */ var _isNull_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./isNull.js */ "./node_modules/underscore/modules/isNull.js"
          );
        /* harmony import */ var _isUndefined_js__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! ./isUndefined.js */ "./node_modules/underscore/modules/isUndefined.js"
          );
        /* harmony import */ var _isBoolean_js__WEBPACK_IMPORTED_MODULE_5__ =
          __webpack_require__(
            /*! ./isBoolean.js */ "./node_modules/underscore/modules/isBoolean.js"
          );
        /* harmony import */ var _isElement_js__WEBPACK_IMPORTED_MODULE_6__ =
          __webpack_require__(
            /*! ./isElement.js */ "./node_modules/underscore/modules/isElement.js"
          );
        /* harmony import */ var _isString_js__WEBPACK_IMPORTED_MODULE_7__ =
          __webpack_require__(
            /*! ./isString.js */ "./node_modules/underscore/modules/isString.js"
          );
        /* harmony import */ var _isNumber_js__WEBPACK_IMPORTED_MODULE_8__ =
          __webpack_require__(
            /*! ./isNumber.js */ "./node_modules/underscore/modules/isNumber.js"
          );
        /* harmony import */ var _isDate_js__WEBPACK_IMPORTED_MODULE_9__ =
          __webpack_require__(
            /*! ./isDate.js */ "./node_modules/underscore/modules/isDate.js"
          );
        /* harmony import */ var _isRegExp_js__WEBPACK_IMPORTED_MODULE_10__ =
          __webpack_require__(
            /*! ./isRegExp.js */ "./node_modules/underscore/modules/isRegExp.js"
          );
        /* harmony import */ var _isError_js__WEBPACK_IMPORTED_MODULE_11__ =
          __webpack_require__(
            /*! ./isError.js */ "./node_modules/underscore/modules/isError.js"
          );
        /* harmony import */ var _isSymbol_js__WEBPACK_IMPORTED_MODULE_12__ =
          __webpack_require__(
            /*! ./isSymbol.js */ "./node_modules/underscore/modules/isSymbol.js"
          );
        /* harmony import */ var _isArrayBuffer_js__WEBPACK_IMPORTED_MODULE_13__ =
          __webpack_require__(
            /*! ./isArrayBuffer.js */ "./node_modules/underscore/modules/isArrayBuffer.js"
          );
        /* harmony import */ var _isDataView_js__WEBPACK_IMPORTED_MODULE_14__ =
          __webpack_require__(
            /*! ./isDataView.js */ "./node_modules/underscore/modules/isDataView.js"
          );
        /* harmony import */ var _isArray_js__WEBPACK_IMPORTED_MODULE_15__ =
          __webpack_require__(
            /*! ./isArray.js */ "./node_modules/underscore/modules/isArray.js"
          );
        /* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_16__ =
          __webpack_require__(
            /*! ./isFunction.js */ "./node_modules/underscore/modules/isFunction.js"
          );
        /* harmony import */ var _isArguments_js__WEBPACK_IMPORTED_MODULE_17__ =
          __webpack_require__(
            /*! ./isArguments.js */ "./node_modules/underscore/modules/isArguments.js"
          );
        /* harmony import */ var _isFinite_js__WEBPACK_IMPORTED_MODULE_18__ =
          __webpack_require__(
            /*! ./isFinite.js */ "./node_modules/underscore/modules/isFinite.js"
          );
        /* harmony import */ var _isNaN_js__WEBPACK_IMPORTED_MODULE_19__ =
          __webpack_require__(
            /*! ./isNaN.js */ "./node_modules/underscore/modules/isNaN.js"
          );
        /* harmony import */ var _isTypedArray_js__WEBPACK_IMPORTED_MODULE_20__ =
          __webpack_require__(
            /*! ./isTypedArray.js */ "./node_modules/underscore/modules/isTypedArray.js"
          );
        /* harmony import */ var _isEmpty_js__WEBPACK_IMPORTED_MODULE_21__ =
          __webpack_require__(
            /*! ./isEmpty.js */ "./node_modules/underscore/modules/isEmpty.js"
          );
        /* harmony import */ var _isMatch_js__WEBPACK_IMPORTED_MODULE_22__ =
          __webpack_require__(
            /*! ./isMatch.js */ "./node_modules/underscore/modules/isMatch.js"
          );
        /* harmony import */ var _isEqual_js__WEBPACK_IMPORTED_MODULE_23__ =
          __webpack_require__(
            /*! ./isEqual.js */ "./node_modules/underscore/modules/isEqual.js"
          );
        /* harmony import */ var _isMap_js__WEBPACK_IMPORTED_MODULE_24__ =
          __webpack_require__(
            /*! ./isMap.js */ "./node_modules/underscore/modules/isMap.js"
          );
        /* harmony import */ var _isWeakMap_js__WEBPACK_IMPORTED_MODULE_25__ =
          __webpack_require__(
            /*! ./isWeakMap.js */ "./node_modules/underscore/modules/isWeakMap.js"
          );
        /* harmony import */ var _isSet_js__WEBPACK_IMPORTED_MODULE_26__ =
          __webpack_require__(
            /*! ./isSet.js */ "./node_modules/underscore/modules/isSet.js"
          );
        /* harmony import */ var _isWeakSet_js__WEBPACK_IMPORTED_MODULE_27__ =
          __webpack_require__(
            /*! ./isWeakSet.js */ "./node_modules/underscore/modules/isWeakSet.js"
          );
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_28__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );
        /* harmony import */ var _allKeys_js__WEBPACK_IMPORTED_MODULE_29__ =
          __webpack_require__(
            /*! ./allKeys.js */ "./node_modules/underscore/modules/allKeys.js"
          );
        /* harmony import */ var _values_js__WEBPACK_IMPORTED_MODULE_30__ =
          __webpack_require__(
            /*! ./values.js */ "./node_modules/underscore/modules/values.js"
          );
        /* harmony import */ var _pairs_js__WEBPACK_IMPORTED_MODULE_31__ =
          __webpack_require__(
            /*! ./pairs.js */ "./node_modules/underscore/modules/pairs.js"
          );
        /* harmony import */ var _invert_js__WEBPACK_IMPORTED_MODULE_32__ =
          __webpack_require__(
            /*! ./invert.js */ "./node_modules/underscore/modules/invert.js"
          );
        /* harmony import */ var _functions_js__WEBPACK_IMPORTED_MODULE_33__ =
          __webpack_require__(
            /*! ./functions.js */ "./node_modules/underscore/modules/functions.js"
          );
        /* harmony import */ var _extend_js__WEBPACK_IMPORTED_MODULE_34__ =
          __webpack_require__(
            /*! ./extend.js */ "./node_modules/underscore/modules/extend.js"
          );
        /* harmony import */ var _extendOwn_js__WEBPACK_IMPORTED_MODULE_35__ =
          __webpack_require__(
            /*! ./extendOwn.js */ "./node_modules/underscore/modules/extendOwn.js"
          );
        /* harmony import */ var _defaults_js__WEBPACK_IMPORTED_MODULE_36__ =
          __webpack_require__(
            /*! ./defaults.js */ "./node_modules/underscore/modules/defaults.js"
          );
        /* harmony import */ var _create_js__WEBPACK_IMPORTED_MODULE_37__ =
          __webpack_require__(
            /*! ./create.js */ "./node_modules/underscore/modules/create.js"
          );
        /* harmony import */ var _clone_js__WEBPACK_IMPORTED_MODULE_38__ =
          __webpack_require__(
            /*! ./clone.js */ "./node_modules/underscore/modules/clone.js"
          );
        /* harmony import */ var _tap_js__WEBPACK_IMPORTED_MODULE_39__ =
          __webpack_require__(
            /*! ./tap.js */ "./node_modules/underscore/modules/tap.js"
          );
        /* harmony import */ var _get_js__WEBPACK_IMPORTED_MODULE_40__ =
          __webpack_require__(
            /*! ./get.js */ "./node_modules/underscore/modules/get.js"
          );
        /* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_41__ =
          __webpack_require__(
            /*! ./has.js */ "./node_modules/underscore/modules/has.js"
          );
        /* harmony import */ var _mapObject_js__WEBPACK_IMPORTED_MODULE_42__ =
          __webpack_require__(
            /*! ./mapObject.js */ "./node_modules/underscore/modules/mapObject.js"
          );
        /* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_43__ =
          __webpack_require__(
            /*! ./identity.js */ "./node_modules/underscore/modules/identity.js"
          );
        /* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_44__ =
          __webpack_require__(
            /*! ./constant.js */ "./node_modules/underscore/modules/constant.js"
          );
        /* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_45__ =
          __webpack_require__(
            /*! ./noop.js */ "./node_modules/underscore/modules/noop.js"
          );
        /* harmony import */ var _toPath_js__WEBPACK_IMPORTED_MODULE_46__ =
          __webpack_require__(
            /*! ./toPath.js */ "./node_modules/underscore/modules/toPath.js"
          );
        /* harmony import */ var _property_js__WEBPACK_IMPORTED_MODULE_47__ =
          __webpack_require__(
            /*! ./property.js */ "./node_modules/underscore/modules/property.js"
          );
        /* harmony import */ var _propertyOf_js__WEBPACK_IMPORTED_MODULE_48__ =
          __webpack_require__(
            /*! ./propertyOf.js */ "./node_modules/underscore/modules/propertyOf.js"
          );
        /* harmony import */ var _matcher_js__WEBPACK_IMPORTED_MODULE_49__ =
          __webpack_require__(
            /*! ./matcher.js */ "./node_modules/underscore/modules/matcher.js"
          );
        /* harmony import */ var _times_js__WEBPACK_IMPORTED_MODULE_50__ =
          __webpack_require__(
            /*! ./times.js */ "./node_modules/underscore/modules/times.js"
          );
        /* harmony import */ var _random_js__WEBPACK_IMPORTED_MODULE_51__ =
          __webpack_require__(
            /*! ./random.js */ "./node_modules/underscore/modules/random.js"
          );
        /* harmony import */ var _now_js__WEBPACK_IMPORTED_MODULE_52__ =
          __webpack_require__(
            /*! ./now.js */ "./node_modules/underscore/modules/now.js"
          );
        /* harmony import */ var _escape_js__WEBPACK_IMPORTED_MODULE_53__ =
          __webpack_require__(
            /*! ./escape.js */ "./node_modules/underscore/modules/escape.js"
          );
        /* harmony import */ var _unescape_js__WEBPACK_IMPORTED_MODULE_54__ =
          __webpack_require__(
            /*! ./unescape.js */ "./node_modules/underscore/modules/unescape.js"
          );
        /* harmony import */ var _templateSettings_js__WEBPACK_IMPORTED_MODULE_55__ =
          __webpack_require__(
            /*! ./templateSettings.js */ "./node_modules/underscore/modules/templateSettings.js"
          );
        /* harmony import */ var _template_js__WEBPACK_IMPORTED_MODULE_56__ =
          __webpack_require__(
            /*! ./template.js */ "./node_modules/underscore/modules/template.js"
          );
        /* harmony import */ var _result_js__WEBPACK_IMPORTED_MODULE_57__ =
          __webpack_require__(
            /*! ./result.js */ "./node_modules/underscore/modules/result.js"
          );
        /* harmony import */ var _uniqueId_js__WEBPACK_IMPORTED_MODULE_58__ =
          __webpack_require__(
            /*! ./uniqueId.js */ "./node_modules/underscore/modules/uniqueId.js"
          );
        /* harmony import */ var _chain_js__WEBPACK_IMPORTED_MODULE_59__ =
          __webpack_require__(
            /*! ./chain.js */ "./node_modules/underscore/modules/chain.js"
          );
        /* harmony import */ var _iteratee_js__WEBPACK_IMPORTED_MODULE_60__ =
          __webpack_require__(
            /*! ./iteratee.js */ "./node_modules/underscore/modules/iteratee.js"
          );
        /* harmony import */ var _partial_js__WEBPACK_IMPORTED_MODULE_61__ =
          __webpack_require__(
            /*! ./partial.js */ "./node_modules/underscore/modules/partial.js"
          );
        /* harmony import */ var _bind_js__WEBPACK_IMPORTED_MODULE_62__ =
          __webpack_require__(
            /*! ./bind.js */ "./node_modules/underscore/modules/bind.js"
          );
        /* harmony import */ var _bindAll_js__WEBPACK_IMPORTED_MODULE_63__ =
          __webpack_require__(
            /*! ./bindAll.js */ "./node_modules/underscore/modules/bindAll.js"
          );
        /* harmony import */ var _memoize_js__WEBPACK_IMPORTED_MODULE_64__ =
          __webpack_require__(
            /*! ./memoize.js */ "./node_modules/underscore/modules/memoize.js"
          );
        /* harmony import */ var _delay_js__WEBPACK_IMPORTED_MODULE_65__ =
          __webpack_require__(
            /*! ./delay.js */ "./node_modules/underscore/modules/delay.js"
          );
        /* harmony import */ var _defer_js__WEBPACK_IMPORTED_MODULE_66__ =
          __webpack_require__(
            /*! ./defer.js */ "./node_modules/underscore/modules/defer.js"
          );
        /* harmony import */ var _throttle_js__WEBPACK_IMPORTED_MODULE_67__ =
          __webpack_require__(
            /*! ./throttle.js */ "./node_modules/underscore/modules/throttle.js"
          );
        /* harmony import */ var _debounce_js__WEBPACK_IMPORTED_MODULE_68__ =
          __webpack_require__(
            /*! ./debounce.js */ "./node_modules/underscore/modules/debounce.js"
          );
        /* harmony import */ var _wrap_js__WEBPACK_IMPORTED_MODULE_69__ =
          __webpack_require__(
            /*! ./wrap.js */ "./node_modules/underscore/modules/wrap.js"
          );
        /* harmony import */ var _negate_js__WEBPACK_IMPORTED_MODULE_70__ =
          __webpack_require__(
            /*! ./negate.js */ "./node_modules/underscore/modules/negate.js"
          );
        /* harmony import */ var _compose_js__WEBPACK_IMPORTED_MODULE_71__ =
          __webpack_require__(
            /*! ./compose.js */ "./node_modules/underscore/modules/compose.js"
          );
        /* harmony import */ var _after_js__WEBPACK_IMPORTED_MODULE_72__ =
          __webpack_require__(
            /*! ./after.js */ "./node_modules/underscore/modules/after.js"
          );
        /* harmony import */ var _before_js__WEBPACK_IMPORTED_MODULE_73__ =
          __webpack_require__(
            /*! ./before.js */ "./node_modules/underscore/modules/before.js"
          );
        /* harmony import */ var _once_js__WEBPACK_IMPORTED_MODULE_74__ =
          __webpack_require__(
            /*! ./once.js */ "./node_modules/underscore/modules/once.js"
          );
        /* harmony import */ var _findKey_js__WEBPACK_IMPORTED_MODULE_75__ =
          __webpack_require__(
            /*! ./findKey.js */ "./node_modules/underscore/modules/findKey.js"
          );
        /* harmony import */ var _findIndex_js__WEBPACK_IMPORTED_MODULE_76__ =
          __webpack_require__(
            /*! ./findIndex.js */ "./node_modules/underscore/modules/findIndex.js"
          );
        /* harmony import */ var _findLastIndex_js__WEBPACK_IMPORTED_MODULE_77__ =
          __webpack_require__(
            /*! ./findLastIndex.js */ "./node_modules/underscore/modules/findLastIndex.js"
          );
        /* harmony import */ var _sortedIndex_js__WEBPACK_IMPORTED_MODULE_78__ =
          __webpack_require__(
            /*! ./sortedIndex.js */ "./node_modules/underscore/modules/sortedIndex.js"
          );
        /* harmony import */ var _indexOf_js__WEBPACK_IMPORTED_MODULE_79__ =
          __webpack_require__(
            /*! ./indexOf.js */ "./node_modules/underscore/modules/indexOf.js"
          );
        /* harmony import */ var _lastIndexOf_js__WEBPACK_IMPORTED_MODULE_80__ =
          __webpack_require__(
            /*! ./lastIndexOf.js */ "./node_modules/underscore/modules/lastIndexOf.js"
          );
        /* harmony import */ var _find_js__WEBPACK_IMPORTED_MODULE_81__ =
          __webpack_require__(
            /*! ./find.js */ "./node_modules/underscore/modules/find.js"
          );
        /* harmony import */ var _findWhere_js__WEBPACK_IMPORTED_MODULE_82__ =
          __webpack_require__(
            /*! ./findWhere.js */ "./node_modules/underscore/modules/findWhere.js"
          );
        /* harmony import */ var _each_js__WEBPACK_IMPORTED_MODULE_83__ =
          __webpack_require__(
            /*! ./each.js */ "./node_modules/underscore/modules/each.js"
          );
        /* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_84__ =
          __webpack_require__(
            /*! ./map.js */ "./node_modules/underscore/modules/map.js"
          );
        /* harmony import */ var _reduce_js__WEBPACK_IMPORTED_MODULE_85__ =
          __webpack_require__(
            /*! ./reduce.js */ "./node_modules/underscore/modules/reduce.js"
          );
        /* harmony import */ var _reduceRight_js__WEBPACK_IMPORTED_MODULE_86__ =
          __webpack_require__(
            /*! ./reduceRight.js */ "./node_modules/underscore/modules/reduceRight.js"
          );
        /* harmony import */ var _filter_js__WEBPACK_IMPORTED_MODULE_87__ =
          __webpack_require__(
            /*! ./filter.js */ "./node_modules/underscore/modules/filter.js"
          );
        /* harmony import */ var _reject_js__WEBPACK_IMPORTED_MODULE_88__ =
          __webpack_require__(
            /*! ./reject.js */ "./node_modules/underscore/modules/reject.js"
          );
        /* harmony import */ var _every_js__WEBPACK_IMPORTED_MODULE_89__ =
          __webpack_require__(
            /*! ./every.js */ "./node_modules/underscore/modules/every.js"
          );
        /* harmony import */ var _some_js__WEBPACK_IMPORTED_MODULE_90__ =
          __webpack_require__(
            /*! ./some.js */ "./node_modules/underscore/modules/some.js"
          );
        /* harmony import */ var _contains_js__WEBPACK_IMPORTED_MODULE_91__ =
          __webpack_require__(
            /*! ./contains.js */ "./node_modules/underscore/modules/contains.js"
          );
        /* harmony import */ var _invoke_js__WEBPACK_IMPORTED_MODULE_92__ =
          __webpack_require__(
            /*! ./invoke.js */ "./node_modules/underscore/modules/invoke.js"
          );
        /* harmony import */ var _pluck_js__WEBPACK_IMPORTED_MODULE_93__ =
          __webpack_require__(
            /*! ./pluck.js */ "./node_modules/underscore/modules/pluck.js"
          );
        /* harmony import */ var _where_js__WEBPACK_IMPORTED_MODULE_94__ =
          __webpack_require__(
            /*! ./where.js */ "./node_modules/underscore/modules/where.js"
          );
        /* harmony import */ var _max_js__WEBPACK_IMPORTED_MODULE_95__ =
          __webpack_require__(
            /*! ./max.js */ "./node_modules/underscore/modules/max.js"
          );
        /* harmony import */ var _min_js__WEBPACK_IMPORTED_MODULE_96__ =
          __webpack_require__(
            /*! ./min.js */ "./node_modules/underscore/modules/min.js"
          );
        /* harmony import */ var _shuffle_js__WEBPACK_IMPORTED_MODULE_97__ =
          __webpack_require__(
            /*! ./shuffle.js */ "./node_modules/underscore/modules/shuffle.js"
          );
        /* harmony import */ var _sample_js__WEBPACK_IMPORTED_MODULE_98__ =
          __webpack_require__(
            /*! ./sample.js */ "./node_modules/underscore/modules/sample.js"
          );
        /* harmony import */ var _sortBy_js__WEBPACK_IMPORTED_MODULE_99__ =
          __webpack_require__(
            /*! ./sortBy.js */ "./node_modules/underscore/modules/sortBy.js"
          );
        /* harmony import */ var _groupBy_js__WEBPACK_IMPORTED_MODULE_100__ =
          __webpack_require__(
            /*! ./groupBy.js */ "./node_modules/underscore/modules/groupBy.js"
          );
        /* harmony import */ var _indexBy_js__WEBPACK_IMPORTED_MODULE_101__ =
          __webpack_require__(
            /*! ./indexBy.js */ "./node_modules/underscore/modules/indexBy.js"
          );
        /* harmony import */ var _countBy_js__WEBPACK_IMPORTED_MODULE_102__ =
          __webpack_require__(
            /*! ./countBy.js */ "./node_modules/underscore/modules/countBy.js"
          );
        /* harmony import */ var _partition_js__WEBPACK_IMPORTED_MODULE_103__ =
          __webpack_require__(
            /*! ./partition.js */ "./node_modules/underscore/modules/partition.js"
          );
        /* harmony import */ var _toArray_js__WEBPACK_IMPORTED_MODULE_104__ =
          __webpack_require__(
            /*! ./toArray.js */ "./node_modules/underscore/modules/toArray.js"
          );
        /* harmony import */ var _size_js__WEBPACK_IMPORTED_MODULE_105__ =
          __webpack_require__(
            /*! ./size.js */ "./node_modules/underscore/modules/size.js"
          );
        /* harmony import */ var _pick_js__WEBPACK_IMPORTED_MODULE_106__ =
          __webpack_require__(
            /*! ./pick.js */ "./node_modules/underscore/modules/pick.js"
          );
        /* harmony import */ var _omit_js__WEBPACK_IMPORTED_MODULE_107__ =
          __webpack_require__(
            /*! ./omit.js */ "./node_modules/underscore/modules/omit.js"
          );
        /* harmony import */ var _first_js__WEBPACK_IMPORTED_MODULE_108__ =
          __webpack_require__(
            /*! ./first.js */ "./node_modules/underscore/modules/first.js"
          );
        /* harmony import */ var _initial_js__WEBPACK_IMPORTED_MODULE_109__ =
          __webpack_require__(
            /*! ./initial.js */ "./node_modules/underscore/modules/initial.js"
          );
        /* harmony import */ var _last_js__WEBPACK_IMPORTED_MODULE_110__ =
          __webpack_require__(
            /*! ./last.js */ "./node_modules/underscore/modules/last.js"
          );
        /* harmony import */ var _rest_js__WEBPACK_IMPORTED_MODULE_111__ =
          __webpack_require__(
            /*! ./rest.js */ "./node_modules/underscore/modules/rest.js"
          );
        /* harmony import */ var _compact_js__WEBPACK_IMPORTED_MODULE_112__ =
          __webpack_require__(
            /*! ./compact.js */ "./node_modules/underscore/modules/compact.js"
          );
        /* harmony import */ var _flatten_js__WEBPACK_IMPORTED_MODULE_113__ =
          __webpack_require__(
            /*! ./flatten.js */ "./node_modules/underscore/modules/flatten.js"
          );
        /* harmony import */ var _without_js__WEBPACK_IMPORTED_MODULE_114__ =
          __webpack_require__(
            /*! ./without.js */ "./node_modules/underscore/modules/without.js"
          );
        /* harmony import */ var _uniq_js__WEBPACK_IMPORTED_MODULE_115__ =
          __webpack_require__(
            /*! ./uniq.js */ "./node_modules/underscore/modules/uniq.js"
          );
        /* harmony import */ var _union_js__WEBPACK_IMPORTED_MODULE_116__ =
          __webpack_require__(
            /*! ./union.js */ "./node_modules/underscore/modules/union.js"
          );
        /* harmony import */ var _intersection_js__WEBPACK_IMPORTED_MODULE_117__ =
          __webpack_require__(
            /*! ./intersection.js */ "./node_modules/underscore/modules/intersection.js"
          );
        /* harmony import */ var _difference_js__WEBPACK_IMPORTED_MODULE_118__ =
          __webpack_require__(
            /*! ./difference.js */ "./node_modules/underscore/modules/difference.js"
          );
        /* harmony import */ var _unzip_js__WEBPACK_IMPORTED_MODULE_119__ =
          __webpack_require__(
            /*! ./unzip.js */ "./node_modules/underscore/modules/unzip.js"
          );
        /* harmony import */ var _zip_js__WEBPACK_IMPORTED_MODULE_120__ =
          __webpack_require__(
            /*! ./zip.js */ "./node_modules/underscore/modules/zip.js"
          );
        /* harmony import */ var _object_js__WEBPACK_IMPORTED_MODULE_121__ =
          __webpack_require__(
            /*! ./object.js */ "./node_modules/underscore/modules/object.js"
          );
        /* harmony import */ var _range_js__WEBPACK_IMPORTED_MODULE_122__ =
          __webpack_require__(
            /*! ./range.js */ "./node_modules/underscore/modules/range.js"
          );
        /* harmony import */ var _chunk_js__WEBPACK_IMPORTED_MODULE_123__ =
          __webpack_require__(
            /*! ./chunk.js */ "./node_modules/underscore/modules/chunk.js"
          );
        /* harmony import */ var _mixin_js__WEBPACK_IMPORTED_MODULE_124__ =
          __webpack_require__(
            /*! ./mixin.js */ "./node_modules/underscore/modules/mixin.js"
          );
        /* harmony import */ var _underscore_array_methods_js__WEBPACK_IMPORTED_MODULE_125__ =
          __webpack_require__(
            /*! ./underscore-array-methods.js */ "./node_modules/underscore/modules/underscore-array-methods.js"
          );
        // Named Exports
        // =============

        //     Underscore.js 1.13.1
        //     https://underscorejs.org
        //     (c) 2009-2021 Jeremy Ashkenas, Julian Gonggrijp, and DocumentCloud and Investigative Reporters & Editors
        //     Underscore may be freely distributed under the MIT license.

        // Baseline setup.

        // Object Functions
        // ----------------
        // Our most fundamental functions operate on any JavaScript object.
        // Most functions in Underscore depend on at least one function in this section.

        // A group of functions that check the types of core JavaScript values.
        // These are often informally referred to as the "isType" functions.

        // Functions that treat an object as a dictionary of key-value pairs.

        // Utility Functions
        // -----------------
        // A bit of a grab bag: Predicate-generating functions for use with filters and
        // loops, string escaping and templating, create random numbers and unique ids,
        // and functions that facilitate Underscore's chaining and iteration conventions.

        // Function (ahem) Functions
        // -------------------------
        // These functions take a function as an argument and return a new function
        // as the result. Also known as higher-order functions.

        // Finders
        // -------
        // Functions that extract (the position of) a single element from an object
        // or array based on some criterion.

        // Collection Functions
        // --------------------
        // Functions that work on any collection of elements: either an array, or
        // an object of key-value pairs.

        // `_.pick` and `_.omit` are actually object functions, but we put
        // them here in order to create a more natural reading order in the
        // monolithic build as they depend on `_.contains`.

        // Array Functions
        // ---------------
        // Functions that operate on arrays (and array-likes) only, because they’re
        // expressed in terms of operations on an ordered list of values.

        // OOP
        // ---
        // These modules support the "object-oriented" calling style. See also
        // `underscore.js` and `index-default.js`.

        /***/
      },

    /***/ "./node_modules/underscore/modules/indexBy.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/indexBy.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _group_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_group.js */ "./node_modules/underscore/modules/_group.js"
          );

        // Indexes the object's values by a criterion, similar to `_.groupBy`, but for
        // when you know that your index values will be unique.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _group_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          result,
          value,
          key
        ) {
          result[key] = value;
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/indexOf.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/indexOf.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _sortedIndex_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./sortedIndex.js */ "./node_modules/underscore/modules/sortedIndex.js"
          );
        /* harmony import */ var _findIndex_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./findIndex.js */ "./node_modules/underscore/modules/findIndex.js"
          );
        /* harmony import */ var _createIndexFinder_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_createIndexFinder.js */ "./node_modules/underscore/modules/_createIndexFinder.js"
          );

        // Return the position of the first occurrence of an item in an array,
        // or -1 if the item is not included in the array.
        // If the array is large and already in sort order, pass `true`
        // for **isSorted** to use binary search.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createIndexFinder_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
          1,
          _findIndex_js__WEBPACK_IMPORTED_MODULE_1__["default"],
          _sortedIndex_js__WEBPACK_IMPORTED_MODULE_0__["default"]
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/initial.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/initial.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ initial,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );

        // Returns everything but the last entry of the array. Especially useful on
        // the arguments object. Passing **n** will return all the values in
        // the array, excluding the last N.
        function initial(array, n, guard) {
          return _setup_js__WEBPACK_IMPORTED_MODULE_0__.slice.call(
            array,
            0,
            Math.max(0, array.length - (n == null || guard ? 1 : n))
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/intersection.js":
      /*!*********************************************************!*\
  !*** ./node_modules/underscore/modules/intersection.js ***!
  \*********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ intersection,
          /* harmony export */
        });
        /* harmony import */ var _getLength_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_getLength.js */ "./node_modules/underscore/modules/_getLength.js"
          );
        /* harmony import */ var _contains_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./contains.js */ "./node_modules/underscore/modules/contains.js"
          );

        // Produce an array that contains every item shared between all the
        // passed-in arrays.
        function intersection(array) {
          var result = [];
          var argsLength = arguments.length;
          for (
            var i = 0,
              length = (0,
              _getLength_js__WEBPACK_IMPORTED_MODULE_0__["default"])(array);
            i < length;
            i++
          ) {
            var item = array[i];
            if (
              (0, _contains_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
                result,
                item
              )
            )
              continue;
            var j;
            for (j = 1; j < argsLength; j++) {
              if (
                !(0, _contains_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
                  arguments[j],
                  item
                )
              )
                break;
            }
            if (j === argsLength) result.push(item);
          }
          return result;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/invert.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/invert.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ invert,
          /* harmony export */
        });
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Invert the keys and values of an object. The values must be serializable.
        function invert(obj) {
          var result = {};
          var _keys = (0, _keys_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            obj
          );
          for (var i = 0, length = _keys.length; i < length; i++) {
            result[obj[_keys[i]]] = _keys[i];
          }
          return result;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/invoke.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/invoke.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );
        /* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isFunction.js */ "./node_modules/underscore/modules/isFunction.js"
          );
        /* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./map.js */ "./node_modules/underscore/modules/map.js"
          );
        /* harmony import */ var _deepGet_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./_deepGet.js */ "./node_modules/underscore/modules/_deepGet.js"
          );
        /* harmony import */ var _toPath_js__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! ./_toPath.js */ "./node_modules/underscore/modules/_toPath.js"
          );

        // Invoke a method (with arguments) on every item in a collection.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          obj,
          path,
          args
        ) {
          var contextPath, func;
          if (
            (0, _isFunction_js__WEBPACK_IMPORTED_MODULE_1__["default"])(path)
          ) {
            func = path;
          } else {
            path = (0, _toPath_js__WEBPACK_IMPORTED_MODULE_4__["default"])(
              path
            );
            contextPath = path.slice(0, -1);
            path = path[path.length - 1];
          }
          return (0, _map_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
            obj,
            function (context) {
              var method = func;
              if (!method) {
                if (contextPath && contextPath.length) {
                  context = (0,
                  _deepGet_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
                    context,
                    contextPath
                  );
                }
                if (context == null) return void 0;
                method = context[path];
              }
              return method == null ? method : method.apply(context, args);
            }
          );
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/isArguments.js":
      /*!********************************************************!*\
  !*** ./node_modules/underscore/modules/isArguments.js ***!
  \********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );
        /* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_has.js */ "./node_modules/underscore/modules/_has.js"
          );

        var isArguments = (0,
        _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("Arguments");

        // Define a fallback version of the method in browsers (ahem, IE < 9), where
        // there isn't any inspectable "Arguments" type.
        (function () {
          if (!isArguments(arguments)) {
            isArguments = function (obj) {
              return (0, _has_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
                obj,
                "callee"
              );
            };
          }
        })();

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ =
          isArguments;

        /***/
      },

    /***/ "./node_modules/underscore/modules/isArray.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/isArray.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );

        // Is a given value an array?
        // Delegates to ECMA5's native `Array.isArray`.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ =
          _setup_js__WEBPACK_IMPORTED_MODULE_0__.nativeIsArray ||
          (0, _tagTester_js__WEBPACK_IMPORTED_MODULE_1__["default"])("Array");

        /***/
      },

    /***/ "./node_modules/underscore/modules/isArrayBuffer.js":
      /*!**********************************************************!*\
  !*** ./node_modules/underscore/modules/isArrayBuffer.js ***!
  \**********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("ArrayBuffer");

        /***/
      },

    /***/ "./node_modules/underscore/modules/isBoolean.js":
      /*!******************************************************!*\
  !*** ./node_modules/underscore/modules/isBoolean.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ isBoolean,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );

        // Is a given value a boolean?
        function isBoolean(obj) {
          return (
            obj === true ||
            obj === false ||
            _setup_js__WEBPACK_IMPORTED_MODULE_0__.toString.call(obj) ===
              "[object Boolean]"
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/isDataView.js":
      /*!*******************************************************!*\
  !*** ./node_modules/underscore/modules/isDataView.js ***!
  \*******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );
        /* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isFunction.js */ "./node_modules/underscore/modules/isFunction.js"
          );
        /* harmony import */ var _isArrayBuffer_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./isArrayBuffer.js */ "./node_modules/underscore/modules/isArrayBuffer.js"
          );
        /* harmony import */ var _stringTagBug_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./_stringTagBug.js */ "./node_modules/underscore/modules/_stringTagBug.js"
          );

        var isDataView = (0,
        _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("DataView");

        // In IE 10 - Edge 13, we need a different heuristic
        // to determine whether an object is a `DataView`.
        function ie10IsDataView(obj) {
          return (
            obj != null &&
            (0, _isFunction_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              obj.getInt8
            ) &&
            (0, _isArrayBuffer_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
              obj.buffer
            )
          );
        }

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ =
          _stringTagBug_js__WEBPACK_IMPORTED_MODULE_3__.hasStringTagBug
            ? ie10IsDataView
            : isDataView;

        /***/
      },

    /***/ "./node_modules/underscore/modules/isDate.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/isDate.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("Date");

        /***/
      },

    /***/ "./node_modules/underscore/modules/isElement.js":
      /*!******************************************************!*\
  !*** ./node_modules/underscore/modules/isElement.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ isElement,
          /* harmony export */
        });
        // Is a given value a DOM element?
        function isElement(obj) {
          return !!(obj && obj.nodeType === 1);
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/isEmpty.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/isEmpty.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ isEmpty,
          /* harmony export */
        });
        /* harmony import */ var _getLength_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_getLength.js */ "./node_modules/underscore/modules/_getLength.js"
          );
        /* harmony import */ var _isArray_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isArray.js */ "./node_modules/underscore/modules/isArray.js"
          );
        /* harmony import */ var _isString_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./isString.js */ "./node_modules/underscore/modules/isString.js"
          );
        /* harmony import */ var _isArguments_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./isArguments.js */ "./node_modules/underscore/modules/isArguments.js"
          );
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Is a given array, string, or object empty?
        // An "empty" object has no enumerable own-properties.
        function isEmpty(obj) {
          if (obj == null) return true;
          // Skip the more expensive `toString`-based type checks if `obj` has no
          // `.length`.
          var length = (0,
          _getLength_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj);
          if (
            typeof length == "number" &&
            ((0, _isArray_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj) ||
              (0, _isString_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj) ||
              (0, _isArguments_js__WEBPACK_IMPORTED_MODULE_3__["default"])(obj))
          )
            return length === 0;
          return (
            (0, _getLength_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
              (0, _keys_js__WEBPACK_IMPORTED_MODULE_4__["default"])(obj)
            ) === 0
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/isEqual.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/isEqual.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ isEqual,
          /* harmony export */
        });
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _getByteLength_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_getByteLength.js */ "./node_modules/underscore/modules/_getByteLength.js"
          );
        /* harmony import */ var _isTypedArray_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./isTypedArray.js */ "./node_modules/underscore/modules/isTypedArray.js"
          );
        /* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! ./isFunction.js */ "./node_modules/underscore/modules/isFunction.js"
          );
        /* harmony import */ var _stringTagBug_js__WEBPACK_IMPORTED_MODULE_5__ =
          __webpack_require__(
            /*! ./_stringTagBug.js */ "./node_modules/underscore/modules/_stringTagBug.js"
          );
        /* harmony import */ var _isDataView_js__WEBPACK_IMPORTED_MODULE_6__ =
          __webpack_require__(
            /*! ./isDataView.js */ "./node_modules/underscore/modules/isDataView.js"
          );
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_7__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );
        /* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_8__ =
          __webpack_require__(
            /*! ./_has.js */ "./node_modules/underscore/modules/_has.js"
          );
        /* harmony import */ var _toBufferView_js__WEBPACK_IMPORTED_MODULE_9__ =
          __webpack_require__(
            /*! ./_toBufferView.js */ "./node_modules/underscore/modules/_toBufferView.js"
          );

        // We use this string twice, so give it a name for minification.
        var tagDataView = "[object DataView]";

        // Internal recursive comparison function for `_.isEqual`.
        function eq(a, b, aStack, bStack) {
          // Identical objects are equal. `0 === -0`, but they aren't identical.
          // See the [Harmony `egal` proposal](https://wiki.ecmascript.org/doku.php?id=harmony:egal).
          if (a === b) return a !== 0 || 1 / a === 1 / b;
          // `null` or `undefined` only equal to itself (strict comparison).
          if (a == null || b == null) return false;
          // `NaN`s are equivalent, but non-reflexive.
          if (a !== a) return b !== b;
          // Exhaust primitive checks
          var type = typeof a;
          if (type !== "function" && type !== "object" && typeof b != "object")
            return false;
          return deepEq(a, b, aStack, bStack);
        }

        // Internal recursive comparison function for `_.isEqual`.
        function deepEq(a, b, aStack, bStack) {
          // Unwrap any wrapped objects.
          if (
            a instanceof _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"]
          )
            a = a._wrapped;
          if (
            b instanceof _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"]
          )
            b = b._wrapped;
          // Compare `[[Class]]` names.
          var className =
            _setup_js__WEBPACK_IMPORTED_MODULE_1__.toString.call(a);
          if (
            className !==
            _setup_js__WEBPACK_IMPORTED_MODULE_1__.toString.call(b)
          )
            return false;
          // Work around a bug in IE 10 - Edge 13.
          if (
            _stringTagBug_js__WEBPACK_IMPORTED_MODULE_5__.hasStringTagBug &&
            className == "[object Object]" &&
            (0, _isDataView_js__WEBPACK_IMPORTED_MODULE_6__["default"])(a)
          ) {
            if (!(0, _isDataView_js__WEBPACK_IMPORTED_MODULE_6__["default"])(b))
              return false;
            className = tagDataView;
          }
          switch (className) {
            // These types are compared by value.
            case "[object RegExp]":
            // RegExps are coerced to strings for comparison (Note: '' + /a/i === '/a/i')
            case "[object String]":
              // Primitives and their corresponding object wrappers are equivalent; thus, `"5"` is
              // equivalent to `new String("5")`.
              return "" + a === "" + b;
            case "[object Number]":
              // `NaN`s are equivalent, but non-reflexive.
              // Object(NaN) is equivalent to NaN.
              if (+a !== +a) return +b !== +b;
              // An `egal` comparison is performed for other numeric values.
              return +a === 0 ? 1 / +a === 1 / b : +a === +b;
            case "[object Date]":
            case "[object Boolean]":
              // Coerce dates and booleans to numeric primitive values. Dates are compared by their
              // millisecond representations. Note that invalid dates with millisecond representations
              // of `NaN` are not equivalent.
              return +a === +b;
            case "[object Symbol]":
              return (
                _setup_js__WEBPACK_IMPORTED_MODULE_1__.SymbolProto.valueOf.call(
                  a
                ) ===
                _setup_js__WEBPACK_IMPORTED_MODULE_1__.SymbolProto.valueOf.call(
                  b
                )
              );
            case "[object ArrayBuffer]":
            case tagDataView:
              // Coerce to typed array so we can fall through.
              return deepEq(
                (0, _toBufferView_js__WEBPACK_IMPORTED_MODULE_9__["default"])(
                  a
                ),
                (0, _toBufferView_js__WEBPACK_IMPORTED_MODULE_9__["default"])(
                  b
                ),
                aStack,
                bStack
              );
          }

          var areArrays = className === "[object Array]";
          if (
            !areArrays &&
            (0, _isTypedArray_js__WEBPACK_IMPORTED_MODULE_3__["default"])(a)
          ) {
            var byteLength = (0,
            _getByteLength_js__WEBPACK_IMPORTED_MODULE_2__["default"])(a);
            if (
              byteLength !==
              (0, _getByteLength_js__WEBPACK_IMPORTED_MODULE_2__["default"])(b)
            )
              return false;
            if (a.buffer === b.buffer && a.byteOffset === b.byteOffset)
              return true;
            areArrays = true;
          }
          if (!areArrays) {
            if (typeof a != "object" || typeof b != "object") return false;

            // Objects with different constructors are not equivalent, but `Object`s or `Array`s
            // from different frames are.
            var aCtor = a.constructor,
              bCtor = b.constructor;
            if (
              aCtor !== bCtor &&
              !(
                (0, _isFunction_js__WEBPACK_IMPORTED_MODULE_4__["default"])(
                  aCtor
                ) &&
                aCtor instanceof aCtor &&
                (0, _isFunction_js__WEBPACK_IMPORTED_MODULE_4__["default"])(
                  bCtor
                ) &&
                bCtor instanceof bCtor
              ) &&
              "constructor" in a &&
              "constructor" in b
            ) {
              return false;
            }
          }
          // Assume equality for cyclic structures. The algorithm for detecting cyclic
          // structures is adapted from ES 5.1 section 15.12.3, abstract operation `JO`.

          // Initializing stack of traversed objects.
          // It's done here since we only need them for objects and arrays comparison.
          aStack = aStack || [];
          bStack = bStack || [];
          var length = aStack.length;
          while (length--) {
            // Linear search. Performance is inversely proportional to the number of
            // unique nested structures.
            if (aStack[length] === a) return bStack[length] === b;
          }

          // Add the first object to the stack of traversed objects.
          aStack.push(a);
          bStack.push(b);

          // Recursively compare objects and arrays.
          if (areArrays) {
            // Compare array lengths to determine if a deep comparison is necessary.
            length = a.length;
            if (length !== b.length) return false;
            // Deep compare the contents, ignoring non-numeric properties.
            while (length--) {
              if (!eq(a[length], b[length], aStack, bStack)) return false;
            }
          } else {
            // Deep compare objects.
            var _keys = (0, _keys_js__WEBPACK_IMPORTED_MODULE_7__["default"])(
                a
              ),
              key;
            length = _keys.length;
            // Ensure that both objects contain the same number of properties before comparing deep equality.
            if (
              (0, _keys_js__WEBPACK_IMPORTED_MODULE_7__["default"])(b)
                .length !== length
            )
              return false;
            while (length--) {
              // Deep compare each member
              key = _keys[length];
              if (
                !(
                  (0, _has_js__WEBPACK_IMPORTED_MODULE_8__["default"])(
                    b,
                    key
                  ) && eq(a[key], b[key], aStack, bStack)
                )
              )
                return false;
            }
          }
          // Remove the first object from the stack of traversed objects.
          aStack.pop();
          bStack.pop();
          return true;
        }

        // Perform a deep comparison to check if two objects are equal.
        function isEqual(a, b) {
          return eq(a, b);
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/isError.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/isError.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("Error");

        /***/
      },

    /***/ "./node_modules/underscore/modules/isFinite.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/isFinite.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ isFinite,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _isSymbol_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isSymbol.js */ "./node_modules/underscore/modules/isSymbol.js"
          );

        // Is a given object a finite number?
        function isFinite(obj) {
          return (
            !(0, _isSymbol_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj) &&
            (0, _setup_js__WEBPACK_IMPORTED_MODULE_0__._isFinite)(obj) &&
            !isNaN(parseFloat(obj))
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/isFunction.js":
      /*!*******************************************************!*\
  !*** ./node_modules/underscore/modules/isFunction.js ***!
  \*******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );

        var isFunction = (0,
        _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("Function");

        // Optimize `isFunction` if appropriate. Work around some `typeof` bugs in old
        // v8, IE 11 (#1621), Safari 8 (#1929), and PhantomJS (#2236).
        var nodelist =
          _setup_js__WEBPACK_IMPORTED_MODULE_1__.root.document &&
          _setup_js__WEBPACK_IMPORTED_MODULE_1__.root.document.childNodes;
        if (
          true &&
          typeof Int8Array != "object" &&
          typeof nodelist != "function"
        ) {
          isFunction = function (obj) {
            return typeof obj == "function" || false;
          };
        }

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ =
          isFunction;

        /***/
      },

    /***/ "./node_modules/underscore/modules/isMap.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/isMap.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );
        /* harmony import */ var _stringTagBug_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_stringTagBug.js */ "./node_modules/underscore/modules/_stringTagBug.js"
          );
        /* harmony import */ var _methodFingerprint_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_methodFingerprint.js */ "./node_modules/underscore/modules/_methodFingerprint.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ =
          _stringTagBug_js__WEBPACK_IMPORTED_MODULE_1__.isIE11
            ? (0,
              _methodFingerprint_js__WEBPACK_IMPORTED_MODULE_2__.ie11fingerprint)(
                _methodFingerprint_js__WEBPACK_IMPORTED_MODULE_2__.mapMethods
              )
            : (0, _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("Map");

        /***/
      },

    /***/ "./node_modules/underscore/modules/isMatch.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/isMatch.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ isMatch,
          /* harmony export */
        });
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Returns whether an object has a given set of `key:value` pairs.
        function isMatch(object, attrs) {
          var _keys = (0, _keys_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
              attrs
            ),
            length = _keys.length;
          if (object == null) return !length;
          var obj = Object(object);
          for (var i = 0; i < length; i++) {
            var key = _keys[i];
            if (attrs[key] !== obj[key] || !(key in obj)) return false;
          }
          return true;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/isNaN.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/isNaN.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ isNaN,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _isNumber_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isNumber.js */ "./node_modules/underscore/modules/isNumber.js"
          );

        // Is the given value `NaN`?
        function isNaN(obj) {
          return (
            (0, _isNumber_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj) &&
            (0, _setup_js__WEBPACK_IMPORTED_MODULE_0__._isNaN)(obj)
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/isNull.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/isNull.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ isNull,
          /* harmony export */
        });
        // Is a given value equal to null?
        function isNull(obj) {
          return obj === null;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/isNumber.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/isNumber.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("Number");

        /***/
      },

    /***/ "./node_modules/underscore/modules/isObject.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/isObject.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ isObject,
          /* harmony export */
        });
        // Is a given variable an object?
        function isObject(obj) {
          var type = typeof obj;
          return type === "function" || (type === "object" && !!obj);
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/isRegExp.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/isRegExp.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("RegExp");

        /***/
      },

    /***/ "./node_modules/underscore/modules/isSet.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/isSet.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );
        /* harmony import */ var _stringTagBug_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_stringTagBug.js */ "./node_modules/underscore/modules/_stringTagBug.js"
          );
        /* harmony import */ var _methodFingerprint_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_methodFingerprint.js */ "./node_modules/underscore/modules/_methodFingerprint.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ =
          _stringTagBug_js__WEBPACK_IMPORTED_MODULE_1__.isIE11
            ? (0,
              _methodFingerprint_js__WEBPACK_IMPORTED_MODULE_2__.ie11fingerprint)(
                _methodFingerprint_js__WEBPACK_IMPORTED_MODULE_2__.setMethods
              )
            : (0, _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("Set");

        /***/
      },

    /***/ "./node_modules/underscore/modules/isString.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/isString.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("String");

        /***/
      },

    /***/ "./node_modules/underscore/modules/isSymbol.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/isSymbol.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("Symbol");

        /***/
      },

    /***/ "./node_modules/underscore/modules/isTypedArray.js":
      /*!*********************************************************!*\
  !*** ./node_modules/underscore/modules/isTypedArray.js ***!
  \*********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _isDataView_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isDataView.js */ "./node_modules/underscore/modules/isDataView.js"
          );
        /* harmony import */ var _constant_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./constant.js */ "./node_modules/underscore/modules/constant.js"
          );
        /* harmony import */ var _isBufferLike_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./_isBufferLike.js */ "./node_modules/underscore/modules/_isBufferLike.js"
          );

        // Is a given value a typed array?
        var typedArrayPattern =
          /\[object ((I|Ui)nt(8|16|32)|Float(32|64)|Uint8Clamped|Big(I|Ui)nt64)Array\]/;
        function isTypedArray(obj) {
          // `ArrayBuffer.isView` is the most future-proof, so use it when available.
          // Otherwise, fall back on the above regular expression.
          return _setup_js__WEBPACK_IMPORTED_MODULE_0__.nativeIsView
            ? (0, _setup_js__WEBPACK_IMPORTED_MODULE_0__.nativeIsView)(obj) &&
                !(0, _isDataView_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
                  obj
                )
            : (0, _isBufferLike_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
                obj
              ) &&
                typedArrayPattern.test(
                  _setup_js__WEBPACK_IMPORTED_MODULE_0__.toString.call(obj)
                );
        }

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ =
          _setup_js__WEBPACK_IMPORTED_MODULE_0__.supportsArrayBuffer
            ? isTypedArray
            : (0, _constant_js__WEBPACK_IMPORTED_MODULE_2__["default"])(false);

        /***/
      },

    /***/ "./node_modules/underscore/modules/isUndefined.js":
      /*!********************************************************!*\
  !*** ./node_modules/underscore/modules/isUndefined.js ***!
  \********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ isUndefined,
          /* harmony export */
        });
        // Is a given variable undefined?
        function isUndefined(obj) {
          return obj === void 0;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/isWeakMap.js":
      /*!******************************************************!*\
  !*** ./node_modules/underscore/modules/isWeakMap.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );
        /* harmony import */ var _stringTagBug_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_stringTagBug.js */ "./node_modules/underscore/modules/_stringTagBug.js"
          );
        /* harmony import */ var _methodFingerprint_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_methodFingerprint.js */ "./node_modules/underscore/modules/_methodFingerprint.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ =
          _stringTagBug_js__WEBPACK_IMPORTED_MODULE_1__.isIE11
            ? (0,
              _methodFingerprint_js__WEBPACK_IMPORTED_MODULE_2__.ie11fingerprint)(
                _methodFingerprint_js__WEBPACK_IMPORTED_MODULE_2__.weakMapMethods
              )
            : (0, _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
                "WeakMap"
              );

        /***/
      },

    /***/ "./node_modules/underscore/modules/isWeakSet.js":
      /*!******************************************************!*\
  !*** ./node_modules/underscore/modules/isWeakSet.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _tagTester_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_tagTester.js */ "./node_modules/underscore/modules/_tagTester.js"
          );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _tagTester_js__WEBPACK_IMPORTED_MODULE_0__["default"])("WeakSet");

        /***/
      },

    /***/ "./node_modules/underscore/modules/iteratee.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/iteratee.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ iteratee,
          /* harmony export */
        });
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );
        /* harmony import */ var _baseIteratee_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_baseIteratee.js */ "./node_modules/underscore/modules/_baseIteratee.js"
          );

        // External wrapper for our callback generator. Users may customize
        // `_.iteratee` if they want additional predicate/iteratee shorthand styles.
        // This abstraction hides the internal-only `argCount` argument.
        function iteratee(value, context) {
          return (0, _baseIteratee_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
            value,
            context,
            Infinity
          );
        }
        _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"].iteratee =
          iteratee;

        /***/
      },

    /***/ "./node_modules/underscore/modules/keys.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/keys.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ keys,
          /* harmony export */
        });
        /* harmony import */ var _isObject_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./isObject.js */ "./node_modules/underscore/modules/isObject.js"
          );
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_has.js */ "./node_modules/underscore/modules/_has.js"
          );
        /* harmony import */ var _collectNonEnumProps_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./_collectNonEnumProps.js */ "./node_modules/underscore/modules/_collectNonEnumProps.js"
          );

        // Retrieve the names of an object's own properties.
        // Delegates to **ECMAScript 5**'s native `Object.keys`.
        function keys(obj) {
          if (!(0, _isObject_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj))
            return [];
          if (_setup_js__WEBPACK_IMPORTED_MODULE_1__.nativeKeys)
            return (0, _setup_js__WEBPACK_IMPORTED_MODULE_1__.nativeKeys)(obj);
          var keys = [];
          for (var key in obj)
            if ((0, _has_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj, key))
              keys.push(key);
          // Ahem, IE < 9.
          if (_setup_js__WEBPACK_IMPORTED_MODULE_1__.hasEnumBug)
            (0,
            _collectNonEnumProps_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
              obj,
              keys
            );
          return keys;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/last.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/last.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ last,
          /* harmony export */
        });
        /* harmony import */ var _rest_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./rest.js */ "./node_modules/underscore/modules/rest.js"
          );

        // Get the last element of an array. Passing **n** will return the last N
        // values in the array.
        function last(array, n, guard) {
          if (array == null || array.length < 1)
            return n == null || guard ? void 0 : [];
          if (n == null || guard) return array[array.length - 1];
          return (0, _rest_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            array,
            Math.max(0, array.length - n)
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/lastIndexOf.js":
      /*!********************************************************!*\
  !*** ./node_modules/underscore/modules/lastIndexOf.js ***!
  \********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _findLastIndex_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./findLastIndex.js */ "./node_modules/underscore/modules/findLastIndex.js"
          );
        /* harmony import */ var _createIndexFinder_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_createIndexFinder.js */ "./node_modules/underscore/modules/_createIndexFinder.js"
          );

        // Return the position of the last occurrence of an item in an array,
        // or -1 if the item is not included in the array.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createIndexFinder_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
          -1,
          _findLastIndex_js__WEBPACK_IMPORTED_MODULE_0__["default"]
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/map.js":
      /*!************************************************!*\
  !*** ./node_modules/underscore/modules/map.js ***!
  \************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ map,
          /* harmony export */
        });
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Return the results of applying the iteratee to each element.
        function map(obj, iteratee, context) {
          iteratee = (0, _cb_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            iteratee,
            context
          );
          var _keys =
              !(0, _isArrayLike_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
                obj
              ) && (0, _keys_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj),
            length = (_keys || obj).length,
            results = Array(length);
          for (var index = 0; index < length; index++) {
            var currentKey = _keys ? _keys[index] : index;
            results[index] = iteratee(obj[currentKey], currentKey, obj);
          }
          return results;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/mapObject.js":
      /*!******************************************************!*\
  !*** ./node_modules/underscore/modules/mapObject.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ mapObject,
          /* harmony export */
        });
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Returns the results of applying the `iteratee` to each element of `obj`.
        // In contrast to `_.map` it returns an object.
        function mapObject(obj, iteratee, context) {
          iteratee = (0, _cb_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            iteratee,
            context
          );
          var _keys = (0, _keys_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              obj
            ),
            length = _keys.length,
            results = {};
          for (var index = 0; index < length; index++) {
            var currentKey = _keys[index];
            results[currentKey] = iteratee(obj[currentKey], currentKey, obj);
          }
          return results;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/matcher.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/matcher.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ matcher,
          /* harmony export */
        });
        /* harmony import */ var _extendOwn_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./extendOwn.js */ "./node_modules/underscore/modules/extendOwn.js"
          );
        /* harmony import */ var _isMatch_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isMatch.js */ "./node_modules/underscore/modules/isMatch.js"
          );

        // Returns a predicate for checking whether an object has a given set of
        // `key:value` pairs.
        function matcher(attrs) {
          attrs = (0, _extendOwn_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            {},
            attrs
          );
          return function (obj) {
            return (0, _isMatch_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              obj,
              attrs
            );
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/max.js":
      /*!************************************************!*\
  !*** ./node_modules/underscore/modules/max.js ***!
  \************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ max,
          /* harmony export */
        });
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _values_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./values.js */ "./node_modules/underscore/modules/values.js"
          );
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _each_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./each.js */ "./node_modules/underscore/modules/each.js"
          );

        // Return the maximum element (or element-based computation).
        function max(obj, iteratee, context) {
          var result = -Infinity,
            lastComputed = -Infinity,
            value,
            computed;
          if (
            iteratee == null ||
            (typeof iteratee == "number" &&
              typeof obj[0] != "object" &&
              obj != null)
          ) {
            obj = (0, _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
              obj
            )
              ? obj
              : (0, _values_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj);
            for (var i = 0, length = obj.length; i < length; i++) {
              value = obj[i];
              if (value != null && value > result) {
                result = value;
              }
            }
          } else {
            iteratee = (0, _cb_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
              iteratee,
              context
            );
            (0, _each_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
              obj,
              function (v, index, list) {
                computed = iteratee(v, index, list);
                if (
                  computed > lastComputed ||
                  (computed === -Infinity && result === -Infinity)
                ) {
                  result = v;
                  lastComputed = computed;
                }
              }
            );
          }
          return result;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/memoize.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/memoize.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ memoize,
          /* harmony export */
        });
        /* harmony import */ var _has_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_has.js */ "./node_modules/underscore/modules/_has.js"
          );

        // Memoize an expensive function by storing its results.
        function memoize(func, hasher) {
          var memoize = function (key) {
            var cache = memoize.cache;
            var address = "" + (hasher ? hasher.apply(this, arguments) : key);
            if (
              !(0, _has_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
                cache,
                address
              )
            )
              cache[address] = func.apply(this, arguments);
            return cache[address];
          };
          memoize.cache = {};
          return memoize;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/min.js":
      /*!************************************************!*\
  !*** ./node_modules/underscore/modules/min.js ***!
  \************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ min,
          /* harmony export */
        });
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _values_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./values.js */ "./node_modules/underscore/modules/values.js"
          );
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _each_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./each.js */ "./node_modules/underscore/modules/each.js"
          );

        // Return the minimum element (or element-based computation).
        function min(obj, iteratee, context) {
          var result = Infinity,
            lastComputed = Infinity,
            value,
            computed;
          if (
            iteratee == null ||
            (typeof iteratee == "number" &&
              typeof obj[0] != "object" &&
              obj != null)
          ) {
            obj = (0, _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
              obj
            )
              ? obj
              : (0, _values_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj);
            for (var i = 0, length = obj.length; i < length; i++) {
              value = obj[i];
              if (value != null && value < result) {
                result = value;
              }
            }
          } else {
            iteratee = (0, _cb_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
              iteratee,
              context
            );
            (0, _each_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
              obj,
              function (v, index, list) {
                computed = iteratee(v, index, list);
                if (
                  computed < lastComputed ||
                  (computed === Infinity && result === Infinity)
                ) {
                  result = v;
                  lastComputed = computed;
                }
              }
            );
          }
          return result;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/mixin.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/mixin.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ mixin,
          /* harmony export */
        });
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );
        /* harmony import */ var _each_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./each.js */ "./node_modules/underscore/modules/each.js"
          );
        /* harmony import */ var _functions_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./functions.js */ "./node_modules/underscore/modules/functions.js"
          );
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _chainResult_js__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! ./_chainResult.js */ "./node_modules/underscore/modules/_chainResult.js"
          );

        // Add your own custom functions to the Underscore object.
        function mixin(obj) {
          (0, _each_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
            (0, _functions_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj),
            function (name) {
              var func = (_underscore_js__WEBPACK_IMPORTED_MODULE_0__[
                "default"
              ][name] = obj[name]);
              _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"].prototype[
                name
              ] = function () {
                var args = [this._wrapped];
                _setup_js__WEBPACK_IMPORTED_MODULE_3__.push.apply(
                  args,
                  arguments
                );
                return (0,
                _chainResult_js__WEBPACK_IMPORTED_MODULE_4__["default"])(
                  this,
                  func.apply(
                    _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"],
                    args
                  )
                );
              };
            }
          );
          return _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"];
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/negate.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/negate.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ negate,
          /* harmony export */
        });
        // Returns a negated version of the passed-in predicate.
        function negate(predicate) {
          return function () {
            return !predicate.apply(this, arguments);
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/noop.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/noop.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ noop,
          /* harmony export */
        });
        // Predicate-generating function. Often useful outside of Underscore.
        function noop() {}

        /***/
      },

    /***/ "./node_modules/underscore/modules/now.js":
      /*!************************************************!*\
  !*** ./node_modules/underscore/modules/now.js ***!
  \************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        // A (possibly faster) way to get the current timestamp as an integer.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ =
          Date.now ||
          function () {
            return new Date().getTime();
          };

        /***/
      },

    /***/ "./node_modules/underscore/modules/object.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/object.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ object,
          /* harmony export */
        });
        /* harmony import */ var _getLength_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_getLength.js */ "./node_modules/underscore/modules/_getLength.js"
          );

        // Converts lists into objects. Pass either a single array of `[key, value]`
        // pairs, or two parallel arrays of the same length -- one of keys, and one of
        // the corresponding values. Passing by pairs is the reverse of `_.pairs`.
        function object(list, values) {
          var result = {};
          for (
            var i = 0,
              length = (0,
              _getLength_js__WEBPACK_IMPORTED_MODULE_0__["default"])(list);
            i < length;
            i++
          ) {
            if (values) {
              result[list[i]] = values[i];
            } else {
              result[list[i][0]] = list[i][1];
            }
          }
          return result;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/omit.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/omit.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );
        /* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isFunction.js */ "./node_modules/underscore/modules/isFunction.js"
          );
        /* harmony import */ var _negate_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./negate.js */ "./node_modules/underscore/modules/negate.js"
          );
        /* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./map.js */ "./node_modules/underscore/modules/map.js"
          );
        /* harmony import */ var _flatten_js__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! ./_flatten.js */ "./node_modules/underscore/modules/_flatten.js"
          );
        /* harmony import */ var _contains_js__WEBPACK_IMPORTED_MODULE_5__ =
          __webpack_require__(
            /*! ./contains.js */ "./node_modules/underscore/modules/contains.js"
          );
        /* harmony import */ var _pick_js__WEBPACK_IMPORTED_MODULE_6__ =
          __webpack_require__(
            /*! ./pick.js */ "./node_modules/underscore/modules/pick.js"
          );

        // Return a copy of the object without the disallowed properties.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          obj,
          keys
        ) {
          var iteratee = keys[0],
            context;
          if (
            (0, _isFunction_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              iteratee
            )
          ) {
            iteratee = (0, _negate_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
              iteratee
            );
            if (keys.length > 1) context = keys[1];
          } else {
            keys = (0, _map_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
              (0, _flatten_js__WEBPACK_IMPORTED_MODULE_4__["default"])(
                keys,
                false,
                false
              ),
              String
            );
            iteratee = function (value, key) {
              return !(0, _contains_js__WEBPACK_IMPORTED_MODULE_5__["default"])(
                keys,
                key
              );
            };
          }
          return (0, _pick_js__WEBPACK_IMPORTED_MODULE_6__["default"])(
            obj,
            iteratee,
            context
          );
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/once.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/once.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _partial_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./partial.js */ "./node_modules/underscore/modules/partial.js"
          );
        /* harmony import */ var _before_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./before.js */ "./node_modules/underscore/modules/before.js"
          );

        // Returns a function that will be executed at most one time, no matter how
        // often you call it. Useful for lazy initialization.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _partial_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          _before_js__WEBPACK_IMPORTED_MODULE_1__["default"],
          2
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/pairs.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/pairs.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ pairs,
          /* harmony export */
        });
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Convert an object into a list of `[key, value]` pairs.
        // The opposite of `_.object` with one argument.
        function pairs(obj) {
          var _keys = (0, _keys_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            obj
          );
          var length = _keys.length;
          var pairs = Array(length);
          for (var i = 0; i < length; i++) {
            pairs[i] = [_keys[i], obj[_keys[i]]];
          }
          return pairs;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/partial.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/partial.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );
        /* harmony import */ var _executeBound_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_executeBound.js */ "./node_modules/underscore/modules/_executeBound.js"
          );
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );

        // Partially apply a function by creating a version that has had some of its
        // arguments pre-filled, without changing its dynamic `this` context. `_` acts
        // as a placeholder by default, allowing any combination of arguments to be
        // pre-filled. Set `_.partial.placeholder` for a custom placeholder argument.
        var partial = (0,
        _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          func,
          boundArgs
        ) {
          var placeholder = partial.placeholder;
          var bound = function () {
            var position = 0,
              length = boundArgs.length;
            var args = Array(length);
            for (var i = 0; i < length; i++) {
              args[i] =
                boundArgs[i] === placeholder
                  ? arguments[position++]
                  : boundArgs[i];
            }
            while (position < arguments.length)
              args.push(arguments[position++]);
            return (0,
            _executeBound_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              func,
              bound,
              this,
              this,
              args
            );
          };
          return bound;
        });

        partial.placeholder =
          _underscore_js__WEBPACK_IMPORTED_MODULE_2__["default"];
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = partial;

        /***/
      },

    /***/ "./node_modules/underscore/modules/partition.js":
      /*!******************************************************!*\
  !*** ./node_modules/underscore/modules/partition.js ***!
  \******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _group_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_group.js */ "./node_modules/underscore/modules/_group.js"
          );

        // Split a collection into two arrays: one whose elements all pass the given
        // truth test, and one whose elements all do not pass the truth test.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _group_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          result,
          value,
          pass
        ) {
          result[pass ? 0 : 1].push(value);
        },
        true);

        /***/
      },

    /***/ "./node_modules/underscore/modules/pick.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/pick.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );
        /* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isFunction.js */ "./node_modules/underscore/modules/isFunction.js"
          );
        /* harmony import */ var _optimizeCb_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_optimizeCb.js */ "./node_modules/underscore/modules/_optimizeCb.js"
          );
        /* harmony import */ var _allKeys_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./allKeys.js */ "./node_modules/underscore/modules/allKeys.js"
          );
        /* harmony import */ var _keyInObj_js__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! ./_keyInObj.js */ "./node_modules/underscore/modules/_keyInObj.js"
          );
        /* harmony import */ var _flatten_js__WEBPACK_IMPORTED_MODULE_5__ =
          __webpack_require__(
            /*! ./_flatten.js */ "./node_modules/underscore/modules/_flatten.js"
          );

        // Return a copy of the object only containing the allowed properties.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          obj,
          keys
        ) {
          var result = {},
            iteratee = keys[0];
          if (obj == null) return result;
          if (
            (0, _isFunction_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              iteratee
            )
          ) {
            if (keys.length > 1)
              iteratee = (0,
              _optimizeCb_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
                iteratee,
                keys[1]
              );
            keys = (0, _allKeys_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
              obj
            );
          } else {
            iteratee = _keyInObj_js__WEBPACK_IMPORTED_MODULE_4__["default"];
            keys = (0, _flatten_js__WEBPACK_IMPORTED_MODULE_5__["default"])(
              keys,
              false,
              false
            );
            obj = Object(obj);
          }
          for (var i = 0, length = keys.length; i < length; i++) {
            var key = keys[i];
            var value = obj[key];
            if (iteratee(value, key, obj)) result[key] = value;
          }
          return result;
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/pluck.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/pluck.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ pluck,
          /* harmony export */
        });
        /* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./map.js */ "./node_modules/underscore/modules/map.js"
          );
        /* harmony import */ var _property_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./property.js */ "./node_modules/underscore/modules/property.js"
          );

        // Convenience version of a common use case of `_.map`: fetching a property.
        function pluck(obj, key) {
          return (0, _map_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            obj,
            (0, _property_js__WEBPACK_IMPORTED_MODULE_1__["default"])(key)
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/property.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/property.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ property,
          /* harmony export */
        });
        /* harmony import */ var _deepGet_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_deepGet.js */ "./node_modules/underscore/modules/_deepGet.js"
          );
        /* harmony import */ var _toPath_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_toPath.js */ "./node_modules/underscore/modules/_toPath.js"
          );

        // Creates a function that, when passed an object, will traverse that object’s
        // properties down the given `path`, specified as an array of keys or indices.
        function property(path) {
          path = (0, _toPath_js__WEBPACK_IMPORTED_MODULE_1__["default"])(path);
          return function (obj) {
            return (0, _deepGet_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
              obj,
              path
            );
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/propertyOf.js":
      /*!*******************************************************!*\
  !*** ./node_modules/underscore/modules/propertyOf.js ***!
  \*******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ propertyOf,
          /* harmony export */
        });
        /* harmony import */ var _noop_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./noop.js */ "./node_modules/underscore/modules/noop.js"
          );
        /* harmony import */ var _get_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./get.js */ "./node_modules/underscore/modules/get.js"
          );

        // Generates a function for a given object that returns a given property.
        function propertyOf(obj) {
          if (obj == null)
            return _noop_js__WEBPACK_IMPORTED_MODULE_0__["default"];
          return function (path) {
            return (0, _get_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              obj,
              path
            );
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/random.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/random.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ random,
          /* harmony export */
        });
        // Return a random integer between `min` and `max` (inclusive).
        function random(min, max) {
          if (max == null) {
            max = min;
            min = 0;
          }
          return min + Math.floor(Math.random() * (max - min + 1));
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/range.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/range.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ range,
          /* harmony export */
        });
        // Generate an integer Array containing an arithmetic progression. A port of
        // the native Python `range()` function. See
        // [the Python documentation](https://docs.python.org/library/functions.html#range).
        function range(start, stop, step) {
          if (stop == null) {
            stop = start || 0;
            start = 0;
          }
          if (!step) {
            step = stop < start ? -1 : 1;
          }

          var length = Math.max(Math.ceil((stop - start) / step), 0);
          var range = Array(length);

          for (var idx = 0; idx < length; idx++, start += step) {
            range[idx] = start;
          }

          return range;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/reduce.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/reduce.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _createReduce_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_createReduce.js */ "./node_modules/underscore/modules/_createReduce.js"
          );

        // **Reduce** builds up a single result from a list of values, aka `inject`,
        // or `foldl`.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createReduce_js__WEBPACK_IMPORTED_MODULE_0__["default"])(1);

        /***/
      },

    /***/ "./node_modules/underscore/modules/reduceRight.js":
      /*!********************************************************!*\
  !*** ./node_modules/underscore/modules/reduceRight.js ***!
  \********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _createReduce_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_createReduce.js */ "./node_modules/underscore/modules/_createReduce.js"
          );

        // The right-associative version of reduce, also known as `foldr`.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createReduce_js__WEBPACK_IMPORTED_MODULE_0__["default"])(-1);

        /***/
      },

    /***/ "./node_modules/underscore/modules/reject.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/reject.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ reject,
          /* harmony export */
        });
        /* harmony import */ var _filter_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./filter.js */ "./node_modules/underscore/modules/filter.js"
          );
        /* harmony import */ var _negate_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./negate.js */ "./node_modules/underscore/modules/negate.js"
          );
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );

        // Return all the elements for which a truth test fails.
        function reject(obj, predicate, context) {
          return (0, _filter_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            obj,
            (0, _negate_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              (0, _cb_js__WEBPACK_IMPORTED_MODULE_2__["default"])(predicate)
            ),
            context
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/rest.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/rest.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ rest,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );

        // Returns everything but the first entry of the `array`. Especially useful on
        // the `arguments` object. Passing an **n** will return the rest N values in the
        // `array`.
        function rest(array, n, guard) {
          return _setup_js__WEBPACK_IMPORTED_MODULE_0__.slice.call(
            array,
            n == null || guard ? 1 : n
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/restArguments.js":
      /*!**********************************************************!*\
  !*** ./node_modules/underscore/modules/restArguments.js ***!
  \**********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ restArguments,
          /* harmony export */
        });
        // Some functions take a variable number of arguments, or a few expected
        // arguments at the beginning and then a variable number of values to operate
        // on. This helper accumulates all remaining arguments past the function’s
        // argument length (or an explicit `startIndex`), into an array that becomes
        // the last argument. Similar to ES6’s "rest parameter".
        function restArguments(func, startIndex) {
          startIndex = startIndex == null ? func.length - 1 : +startIndex;
          return function () {
            var length = Math.max(arguments.length - startIndex, 0),
              rest = Array(length),
              index = 0;
            for (; index < length; index++) {
              rest[index] = arguments[index + startIndex];
            }
            switch (startIndex) {
              case 0:
                return func.call(this, rest);
              case 1:
                return func.call(this, arguments[0], rest);
              case 2:
                return func.call(this, arguments[0], arguments[1], rest);
            }
            var args = Array(startIndex + 1);
            for (index = 0; index < startIndex; index++) {
              args[index] = arguments[index];
            }
            args[startIndex] = rest;
            return func.apply(this, args);
          };
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/result.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/result.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ result,
          /* harmony export */
        });
        /* harmony import */ var _isFunction_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./isFunction.js */ "./node_modules/underscore/modules/isFunction.js"
          );
        /* harmony import */ var _toPath_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_toPath.js */ "./node_modules/underscore/modules/_toPath.js"
          );

        // Traverses the children of `obj` along `path`. If a child is a function, it
        // is invoked with its parent as context. Returns the value of the final
        // child, or `fallback` if any child is undefined.
        function result(obj, path, fallback) {
          path = (0, _toPath_js__WEBPACK_IMPORTED_MODULE_1__["default"])(path);
          var length = path.length;
          if (!length) {
            return (0, _isFunction_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
              fallback
            )
              ? fallback.call(obj)
              : fallback;
          }
          for (var i = 0; i < length; i++) {
            var prop = obj == null ? void 0 : obj[path[i]];
            if (prop === void 0) {
              prop = fallback;
              i = length; // Ensure we don't continue iterating.
            }
            obj = (0, _isFunction_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
              prop
            )
              ? prop.call(obj)
              : prop;
          }
          return obj;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/sample.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/sample.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ sample,
          /* harmony export */
        });
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _clone_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./clone.js */ "./node_modules/underscore/modules/clone.js"
          );
        /* harmony import */ var _values_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./values.js */ "./node_modules/underscore/modules/values.js"
          );
        /* harmony import */ var _getLength_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./_getLength.js */ "./node_modules/underscore/modules/_getLength.js"
          );
        /* harmony import */ var _random_js__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! ./random.js */ "./node_modules/underscore/modules/random.js"
          );

        // Sample **n** random values from a collection using the modern version of the
        // [Fisher-Yates shuffle](https://en.wikipedia.org/wiki/Fisher–Yates_shuffle).
        // If **n** is not specified, returns a single random element.
        // The internal `guard` argument allows it to work with `_.map`.
        function sample(obj, n, guard) {
          if (n == null || guard) {
            if (
              !(0, _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj)
            )
              obj = (0, _values_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
                obj
              );
            return obj[
              (0, _random_js__WEBPACK_IMPORTED_MODULE_4__["default"])(
                obj.length - 1
              )
            ];
          }
          var sample = (0,
          _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj)
            ? (0, _clone_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj)
            : (0, _values_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj);
          var length = (0,
          _getLength_js__WEBPACK_IMPORTED_MODULE_3__["default"])(sample);
          n = Math.max(Math.min(n, length), 0);
          var last = length - 1;
          for (var index = 0; index < n; index++) {
            var rand = (0, _random_js__WEBPACK_IMPORTED_MODULE_4__["default"])(
              index,
              last
            );
            var temp = sample[index];
            sample[index] = sample[rand];
            sample[rand] = temp;
          }
          return sample.slice(0, n);
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/shuffle.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/shuffle.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ shuffle,
          /* harmony export */
        });
        /* harmony import */ var _sample_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./sample.js */ "./node_modules/underscore/modules/sample.js"
          );

        // Shuffle a collection.
        function shuffle(obj) {
          return (0, _sample_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            obj,
            Infinity
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/size.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/size.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ size,
          /* harmony export */
        });
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Return the number of elements in a collection.
        function size(obj) {
          if (obj == null) return 0;
          return (0, _isArrayLike_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            obj
          )
            ? obj.length
            : (0, _keys_js__WEBPACK_IMPORTED_MODULE_1__["default"])(obj).length;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/some.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/some.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ some,
          /* harmony export */
        });
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Determine if at least one element in the object passes a truth test.
        function some(obj, predicate, context) {
          predicate = (0, _cb_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            predicate,
            context
          );
          var _keys =
              !(0, _isArrayLike_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
                obj
              ) && (0, _keys_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj),
            length = (_keys || obj).length;
          for (var index = 0; index < length; index++) {
            var currentKey = _keys ? _keys[index] : index;
            if (predicate(obj[currentKey], currentKey, obj)) return true;
          }
          return false;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/sortBy.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/sortBy.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ sortBy,
          /* harmony export */
        });
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _pluck_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./pluck.js */ "./node_modules/underscore/modules/pluck.js"
          );
        /* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./map.js */ "./node_modules/underscore/modules/map.js"
          );

        // Sort the object's values by a criterion produced by an iteratee.
        function sortBy(obj, iteratee, context) {
          var index = 0;
          iteratee = (0, _cb_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            iteratee,
            context
          );
          return (0, _pluck_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
            (0, _map_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
              obj,
              function (value, key, list) {
                return {
                  value: value,
                  index: index++,
                  criteria: iteratee(value, key, list),
                };
              }
            ).sort(function (left, right) {
              var a = left.criteria;
              var b = right.criteria;
              if (a !== b) {
                if (a > b || a === void 0) return 1;
                if (a < b || b === void 0) return -1;
              }
              return left.index - right.index;
            }),
            "value"
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/sortedIndex.js":
      /*!********************************************************!*\
  !*** ./node_modules/underscore/modules/sortedIndex.js ***!
  \********************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ sortedIndex,
          /* harmony export */
        });
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _getLength_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_getLength.js */ "./node_modules/underscore/modules/_getLength.js"
          );

        // Use a comparator function to figure out the smallest index at which
        // an object should be inserted so as to maintain order. Uses binary search.
        function sortedIndex(array, obj, iteratee, context) {
          iteratee = (0, _cb_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            iteratee,
            context,
            1
          );
          var value = iteratee(obj);
          var low = 0,
            high = (0, _getLength_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              array
            );
          while (low < high) {
            var mid = Math.floor((low + high) / 2);
            if (iteratee(array[mid]) < value) low = mid + 1;
            else high = mid;
          }
          return low;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/tap.js":
      /*!************************************************!*\
  !*** ./node_modules/underscore/modules/tap.js ***!
  \************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ tap,
          /* harmony export */
        });
        // Invokes `interceptor` with the `obj` and then returns `obj`.
        // The primary purpose of this method is to "tap into" a method chain, in
        // order to perform operations on intermediate results within the chain.
        function tap(obj, interceptor) {
          interceptor(obj);
          return obj;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/template.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/template.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ template,
          /* harmony export */
        });
        /* harmony import */ var _defaults_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./defaults.js */ "./node_modules/underscore/modules/defaults.js"
          );
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );
        /* harmony import */ var _templateSettings_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./templateSettings.js */ "./node_modules/underscore/modules/templateSettings.js"
          );

        // When customizing `_.templateSettings`, if you don't want to define an
        // interpolation, evaluation or escaping regex, we need one that is
        // guaranteed not to match.
        var noMatch = /(.)^/;

        // Certain characters need to be escaped so that they can be put into a
        // string literal.
        var escapes = {
          "'": "'",
          "\\": "\\",
          "\r": "r",
          "\n": "n",
          "\u2028": "u2028",
          "\u2029": "u2029",
        };

        var escapeRegExp = /\\|'|\r|\n|\u2028|\u2029/g;

        function escapeChar(match) {
          return "\\" + escapes[match];
        }

        // In order to prevent third-party code injection through
        // `_.templateSettings.variable`, we test it against the following regular
        // expression. It is intentionally a bit more liberal than just matching valid
        // identifiers, but still prevents possible loopholes through defaults or
        // destructuring assignment.
        var bareIdentifier = /^\s*(\w|\$)+\s*$/;

        // JavaScript micro-templating, similar to John Resig's implementation.
        // Underscore templating handles arbitrary delimiters, preserves whitespace,
        // and correctly escapes quotes within interpolated code.
        // NB: `oldSettings` only exists for backwards compatibility.
        function template(text, settings, oldSettings) {
          if (!settings && oldSettings) settings = oldSettings;
          settings = (0, _defaults_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            {},
            settings,
            _underscore_js__WEBPACK_IMPORTED_MODULE_1__["default"]
              .templateSettings
          );

          // Combine delimiters into one regular expression via alternation.
          var matcher = RegExp(
            [
              (settings.escape || noMatch).source,
              (settings.interpolate || noMatch).source,
              (settings.evaluate || noMatch).source,
            ].join("|") + "|$",
            "g"
          );

          // Compile the template source, escaping string literals appropriately.
          var index = 0;
          var source = "__p+='";
          text.replace(
            matcher,
            function (match, escape, interpolate, evaluate, offset) {
              source += text
                .slice(index, offset)
                .replace(escapeRegExp, escapeChar);
              index = offset + match.length;

              if (escape) {
                source +=
                  "'+\n((__t=(" + escape + "))==null?'':_.escape(__t))+\n'";
              } else if (interpolate) {
                source += "'+\n((__t=(" + interpolate + "))==null?'':__t)+\n'";
              } else if (evaluate) {
                source += "';\n" + evaluate + "\n__p+='";
              }

              // Adobe VMs need the match returned to produce the correct offset.
              return match;
            }
          );
          source += "';\n";

          var argument = settings.variable;
          if (argument) {
            // Insure against third-party code injection. (CVE-2021-23358)
            if (!bareIdentifier.test(argument))
              throw new Error("variable is not a bare identifier: " + argument);
          } else {
            // If a variable is not specified, place data values in local scope.
            source = "with(obj||{}){\n" + source + "}\n";
            argument = "obj";
          }

          source =
            "var __t,__p='',__j=Array.prototype.join," +
            "print=function(){__p+=__j.call(arguments,'');};\n" +
            source +
            "return __p;\n";

          var render;
          try {
            render = new Function(argument, "_", source);
          } catch (e) {
            e.source = source;
            throw e;
          }

          var template = function (data) {
            return render.call(
              this,
              data,
              _underscore_js__WEBPACK_IMPORTED_MODULE_1__["default"]
            );
          };

          // Provide the compiled source as a convenience for precompilation.
          template.source = "function(" + argument + "){\n" + source + "}";

          return template;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/templateSettings.js":
      /*!*************************************************************!*\
  !*** ./node_modules/underscore/modules/templateSettings.js ***!
  \*************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );

        // By default, Underscore uses ERB-style template delimiters. Change the
        // following template settings to use alternative delimiters.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ =
          (_underscore_js__WEBPACK_IMPORTED_MODULE_0__[
            "default"
          ].templateSettings = {
            evaluate: /<%([\s\S]+?)%>/g,
            interpolate: /<%=([\s\S]+?)%>/g,
            escape: /<%-([\s\S]+?)%>/g,
          });

        /***/
      },

    /***/ "./node_modules/underscore/modules/throttle.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/throttle.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ throttle,
          /* harmony export */
        });
        /* harmony import */ var _now_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./now.js */ "./node_modules/underscore/modules/now.js"
          );

        // Returns a function, that, when invoked, will only be triggered at most once
        // during a given window of time. Normally, the throttled function will run
        // as much as it can, without ever going more than once per `wait` duration;
        // but if you'd like to disable the execution on the leading edge, pass
        // `{leading: false}`. To disable execution on the trailing edge, ditto.
        function throttle(func, wait, options) {
          var timeout, context, args, result;
          var previous = 0;
          if (!options) options = {};

          var later = function () {
            previous =
              options.leading === false
                ? 0
                : (0, _now_js__WEBPACK_IMPORTED_MODULE_0__["default"])();
            timeout = null;
            result = func.apply(context, args);
            if (!timeout) context = args = null;
          };

          var throttled = function () {
            var _now = (0, _now_js__WEBPACK_IMPORTED_MODULE_0__["default"])();
            if (!previous && options.leading === false) previous = _now;
            var remaining = wait - (_now - previous);
            context = this;
            args = arguments;
            if (remaining <= 0 || remaining > wait) {
              if (timeout) {
                clearTimeout(timeout);
                timeout = null;
              }
              previous = _now;
              result = func.apply(context, args);
              if (!timeout) context = args = null;
            } else if (!timeout && options.trailing !== false) {
              timeout = setTimeout(later, remaining);
            }
            return result;
          };

          throttled.cancel = function () {
            clearTimeout(timeout);
            previous = 0;
            timeout = context = args = null;
          };

          return throttled;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/times.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/times.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ times,
          /* harmony export */
        });
        /* harmony import */ var _optimizeCb_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_optimizeCb.js */ "./node_modules/underscore/modules/_optimizeCb.js"
          );

        // Run a function **n** times.
        function times(n, iteratee, context) {
          var accum = Array(Math.max(0, n));
          iteratee = (0,
          _optimizeCb_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            iteratee,
            context,
            1
          );
          for (var i = 0; i < n; i++) accum[i] = iteratee(i);
          return accum;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/toArray.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/toArray.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ toArray,
          /* harmony export */
        });
        /* harmony import */ var _isArray_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./isArray.js */ "./node_modules/underscore/modules/isArray.js"
          );
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _isString_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./isString.js */ "./node_modules/underscore/modules/isString.js"
          );
        /* harmony import */ var _isArrayLike_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./_isArrayLike.js */ "./node_modules/underscore/modules/_isArrayLike.js"
          );
        /* harmony import */ var _map_js__WEBPACK_IMPORTED_MODULE_4__ =
          __webpack_require__(
            /*! ./map.js */ "./node_modules/underscore/modules/map.js"
          );
        /* harmony import */ var _identity_js__WEBPACK_IMPORTED_MODULE_5__ =
          __webpack_require__(
            /*! ./identity.js */ "./node_modules/underscore/modules/identity.js"
          );
        /* harmony import */ var _values_js__WEBPACK_IMPORTED_MODULE_6__ =
          __webpack_require__(
            /*! ./values.js */ "./node_modules/underscore/modules/values.js"
          );

        // Safely create a real, live array from anything iterable.
        var reStrSymbol =
          /[^\ud800-\udfff]|[\ud800-\udbff][\udc00-\udfff]|[\ud800-\udfff]/g;
        function toArray(obj) {
          if (!obj) return [];
          if ((0, _isArray_js__WEBPACK_IMPORTED_MODULE_0__["default"])(obj))
            return _setup_js__WEBPACK_IMPORTED_MODULE_1__.slice.call(obj);
          if ((0, _isString_js__WEBPACK_IMPORTED_MODULE_2__["default"])(obj)) {
            // Keep surrogate pair characters together.
            return obj.match(reStrSymbol);
          }
          if ((0, _isArrayLike_js__WEBPACK_IMPORTED_MODULE_3__["default"])(obj))
            return (0, _map_js__WEBPACK_IMPORTED_MODULE_4__["default"])(
              obj,
              _identity_js__WEBPACK_IMPORTED_MODULE_5__["default"]
            );
          return (0, _values_js__WEBPACK_IMPORTED_MODULE_6__["default"])(obj);
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/toPath.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/toPath.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ toPath,
          /* harmony export */
        });
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );
        /* harmony import */ var _isArray_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./isArray.js */ "./node_modules/underscore/modules/isArray.js"
          );

        // Normalize a (deep) property `path` to array.
        // Like `_.iteratee`, this function can be customized.
        function toPath(path) {
          return (0, _isArray_js__WEBPACK_IMPORTED_MODULE_1__["default"])(path)
            ? path
            : [path];
        }
        _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"].toPath = toPath;

        /***/
      },

    /***/ "./node_modules/underscore/modules/underscore-array-methods.js":
      /*!*********************************************************************!*\
  !*** ./node_modules/underscore/modules/underscore-array-methods.js ***!
  \*********************************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _underscore_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./underscore.js */ "./node_modules/underscore/modules/underscore.js"
          );
        /* harmony import */ var _each_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./each.js */ "./node_modules/underscore/modules/each.js"
          );
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );
        /* harmony import */ var _chainResult_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./_chainResult.js */ "./node_modules/underscore/modules/_chainResult.js"
          );

        // Add all mutator `Array` functions to the wrapper.
        (0, _each_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
          ["pop", "push", "reverse", "shift", "sort", "splice", "unshift"],
          function (name) {
            var method =
              _setup_js__WEBPACK_IMPORTED_MODULE_2__.ArrayProto[name];
            _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"].prototype[
              name
            ] = function () {
              var obj = this._wrapped;
              if (obj != null) {
                method.apply(obj, arguments);
                if (
                  (name === "shift" || name === "splice") &&
                  obj.length === 0
                ) {
                  delete obj[0];
                }
              }
              return (0,
              _chainResult_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
                this,
                obj
              );
            };
          }
        );

        // Add all accessor `Array` functions to the wrapper.
        (0, _each_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
          ["concat", "join", "slice"],
          function (name) {
            var method =
              _setup_js__WEBPACK_IMPORTED_MODULE_2__.ArrayProto[name];
            _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"].prototype[
              name
            ] = function () {
              var obj = this._wrapped;
              if (obj != null) obj = method.apply(obj, arguments);
              return (0,
              _chainResult_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
                this,
                obj
              );
            };
          }
        );

        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ =
          _underscore_js__WEBPACK_IMPORTED_MODULE_0__["default"];

        /***/
      },

    /***/ "./node_modules/underscore/modules/underscore.js":
      /*!*******************************************************!*\
  !*** ./node_modules/underscore/modules/underscore.js ***!
  \*******************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ _,
          /* harmony export */
        });
        /* harmony import */ var _setup_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_setup.js */ "./node_modules/underscore/modules/_setup.js"
          );

        // If Underscore is called as a function, it returns a wrapped object that can
        // be used OO-style. This wrapper holds altered versions of all functions added
        // through `_.mixin`. Wrapped objects may be chained.
        function _(obj) {
          if (obj instanceof _) return obj;
          if (!(this instanceof _)) return new _(obj);
          this._wrapped = obj;
        }

        _.VERSION = _setup_js__WEBPACK_IMPORTED_MODULE_0__.VERSION;

        // Extracts the result from a wrapped and chained object.
        _.prototype.value = function () {
          return this._wrapped;
        };

        // Provide unwrapping proxies for some methods used in engine operations
        // such as arithmetic and JSON stringification.
        _.prototype.valueOf = _.prototype.toJSON = _.prototype.value;

        _.prototype.toString = function () {
          return String(this._wrapped);
        };

        /***/
      },

    /***/ "./node_modules/underscore/modules/unescape.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/unescape.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _createEscaper_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./_createEscaper.js */ "./node_modules/underscore/modules/_createEscaper.js"
          );
        /* harmony import */ var _unescapeMap_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_unescapeMap.js */ "./node_modules/underscore/modules/_unescapeMap.js"
          );

        // Function for unescaping strings from HTML interpolation.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _createEscaper_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          _unescapeMap_js__WEBPACK_IMPORTED_MODULE_1__["default"]
        );

        /***/
      },

    /***/ "./node_modules/underscore/modules/union.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/union.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );
        /* harmony import */ var _uniq_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./uniq.js */ "./node_modules/underscore/modules/uniq.js"
          );
        /* harmony import */ var _flatten_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_flatten.js */ "./node_modules/underscore/modules/_flatten.js"
          );

        // Produce an array that contains the union: each distinct element from all of
        // the passed-in arrays.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          arrays
        ) {
          return (0, _uniq_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
            (0, _flatten_js__WEBPACK_IMPORTED_MODULE_2__["default"])(
              arrays,
              true,
              true
            )
          );
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/uniq.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/uniq.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ uniq,
          /* harmony export */
        });
        /* harmony import */ var _isBoolean_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./isBoolean.js */ "./node_modules/underscore/modules/isBoolean.js"
          );
        /* harmony import */ var _cb_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_cb.js */ "./node_modules/underscore/modules/_cb.js"
          );
        /* harmony import */ var _getLength_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./_getLength.js */ "./node_modules/underscore/modules/_getLength.js"
          );
        /* harmony import */ var _contains_js__WEBPACK_IMPORTED_MODULE_3__ =
          __webpack_require__(
            /*! ./contains.js */ "./node_modules/underscore/modules/contains.js"
          );

        // Produce a duplicate-free version of the array. If the array has already
        // been sorted, you have the option of using a faster algorithm.
        // The faster algorithm will not work with an iteratee if the iteratee
        // is not a one-to-one function, so providing an iteratee will disable
        // the faster algorithm.
        function uniq(array, isSorted, iteratee, context) {
          if (
            !(0, _isBoolean_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
              isSorted
            )
          ) {
            context = iteratee;
            iteratee = isSorted;
            isSorted = false;
          }
          if (iteratee != null)
            iteratee = (0, _cb_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
              iteratee,
              context
            );
          var result = [];
          var seen = [];
          for (
            var i = 0,
              length = (0,
              _getLength_js__WEBPACK_IMPORTED_MODULE_2__["default"])(array);
            i < length;
            i++
          ) {
            var value = array[i],
              computed = iteratee ? iteratee(value, i, array) : value;
            if (isSorted && !iteratee) {
              if (!i || seen !== computed) result.push(value);
              seen = computed;
            } else if (iteratee) {
              if (
                !(0, _contains_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
                  seen,
                  computed
                )
              ) {
                seen.push(computed);
                result.push(value);
              }
            } else if (
              !(0, _contains_js__WEBPACK_IMPORTED_MODULE_3__["default"])(
                result,
                value
              )
            ) {
              result.push(value);
            }
          }
          return result;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/uniqueId.js":
      /*!*****************************************************!*\
  !*** ./node_modules/underscore/modules/uniqueId.js ***!
  \*****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ uniqueId,
          /* harmony export */
        });
        // Generate a unique integer id (unique within the entire client session).
        // Useful for temporary DOM ids.
        var idCounter = 0;
        function uniqueId(prefix) {
          var id = ++idCounter + "";
          return prefix ? prefix + id : id;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/unzip.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/unzip.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ unzip,
          /* harmony export */
        });
        /* harmony import */ var _max_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./max.js */ "./node_modules/underscore/modules/max.js"
          );
        /* harmony import */ var _getLength_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./_getLength.js */ "./node_modules/underscore/modules/_getLength.js"
          );
        /* harmony import */ var _pluck_js__WEBPACK_IMPORTED_MODULE_2__ =
          __webpack_require__(
            /*! ./pluck.js */ "./node_modules/underscore/modules/pluck.js"
          );

        // Complement of zip. Unzip accepts an array of arrays and groups
        // each array's elements on shared indices.
        function unzip(array) {
          var length =
            (array &&
              (0, _max_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
                array,
                _getLength_js__WEBPACK_IMPORTED_MODULE_1__["default"]
              ).length) ||
            0;
          var result = Array(length);

          for (var index = 0; index < length; index++) {
            result[index] = (0,
            _pluck_js__WEBPACK_IMPORTED_MODULE_2__["default"])(array, index);
          }
          return result;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/values.js":
      /*!***************************************************!*\
  !*** ./node_modules/underscore/modules/values.js ***!
  \***************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ values,
          /* harmony export */
        });
        /* harmony import */ var _keys_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./keys.js */ "./node_modules/underscore/modules/keys.js"
          );

        // Retrieve the values of an object's properties.
        function values(obj) {
          var _keys = (0, _keys_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            obj
          );
          var length = _keys.length;
          var values = Array(length);
          for (var i = 0; i < length; i++) {
            values[i] = obj[_keys[i]];
          }
          return values;
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/where.js":
      /*!**************************************************!*\
  !*** ./node_modules/underscore/modules/where.js ***!
  \**************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ where,
          /* harmony export */
        });
        /* harmony import */ var _filter_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./filter.js */ "./node_modules/underscore/modules/filter.js"
          );
        /* harmony import */ var _matcher_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./matcher.js */ "./node_modules/underscore/modules/matcher.js"
          );

        // Convenience version of a common use case of `_.filter`: selecting only
        // objects containing specific `key:value` pairs.
        function where(obj, attrs) {
          return (0, _filter_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            obj,
            (0, _matcher_js__WEBPACK_IMPORTED_MODULE_1__["default"])(attrs)
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/without.js":
      /*!****************************************************!*\
  !*** ./node_modules/underscore/modules/without.js ***!
  \****************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );
        /* harmony import */ var _difference_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./difference.js */ "./node_modules/underscore/modules/difference.js"
          );

        // Return a version of the array that does not contain the specified value(s).
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(function (
          array,
          otherArrays
        ) {
          return (0, _difference_js__WEBPACK_IMPORTED_MODULE_1__["default"])(
            array,
            otherArrays
          );
        });

        /***/
      },

    /***/ "./node_modules/underscore/modules/wrap.js":
      /*!*************************************************!*\
  !*** ./node_modules/underscore/modules/wrap.js ***!
  \*************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => /* binding */ wrap,
          /* harmony export */
        });
        /* harmony import */ var _partial_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./partial.js */ "./node_modules/underscore/modules/partial.js"
          );

        // Returns the first function passed as an argument to the second,
        // allowing you to adjust arguments, run code before and after, and
        // conditionally execute the original function.
        function wrap(func, wrapper) {
          return (0, _partial_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
            wrapper,
            func
          );
        }

        /***/
      },

    /***/ "./node_modules/underscore/modules/zip.js":
      /*!************************************************!*\
  !*** ./node_modules/underscore/modules/zip.js ***!
  \************************************************/
      /***/ (
        __unused_webpack_module,
        __webpack_exports__,
        __webpack_require__
      ) => {
        "use strict";
        __webpack_require__.r(__webpack_exports__);
        /* harmony export */ __webpack_require__.d(__webpack_exports__, {
          /* harmony export */ default: () => __WEBPACK_DEFAULT_EXPORT__,
          /* harmony export */
        });
        /* harmony import */ var _restArguments_js__WEBPACK_IMPORTED_MODULE_0__ =
          __webpack_require__(
            /*! ./restArguments.js */ "./node_modules/underscore/modules/restArguments.js"
          );
        /* harmony import */ var _unzip_js__WEBPACK_IMPORTED_MODULE_1__ =
          __webpack_require__(
            /*! ./unzip.js */ "./node_modules/underscore/modules/unzip.js"
          );

        // Zip together multiple lists into a single array -- elements that share
        // an index go together.
        /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (0,
        _restArguments_js__WEBPACK_IMPORTED_MODULE_0__["default"])(
          _unzip_js__WEBPACK_IMPORTED_MODULE_1__["default"]
        );

        /***/
      },

    /***/ "./node_modules/@jupyter-widgets/controls/package.json":
      /*!*************************************************************!*\
  !*** ./node_modules/@jupyter-widgets/controls/package.json ***!
  \*************************************************************/
      /***/ (module) => {
        "use strict";
        module.exports = JSON.parse(
          '{"name":"@jupyter-widgets/controls","version":"3.0.0","description":"Jupyter interactive widgets","repository":{"type":"git","url":"https://github.com/jupyter-widgets/ipywidgets.git"},"license":"BSD-3-Clause","author":"Project Jupyter","main":"lib/index.js","typings":"lib/index.d.ts","files":["lib/**/*.d.ts","lib/**/*.js","css/*.css","dist/"],"scripts":{"build":"npm run build:src && npm run build:css","build:css":"postcss --use postcss-import --use postcss-cssnext -o css/widgets.built.css css/widgets.css","build:src":"tsc","build:test":"tsc --project test && webpack --config test/webpack.conf.js","clean":"npm run clean:src","clean:src":"rimraf lib && rimraf tsconfig.tsbuildinfo","lint":"tslint --project tslint.json --format stylish","prepublish":"npm run clean && npm run build","test":"npm run test:unit","test:coverage":"npm run build:test && webpack --config test/webpack-cov.conf.js && karma start test/karma-cov.conf.js","test:unit":"npm run test:unit:firefox && npm run test:unit:chrome","test:unit:chrome":"npm run test:unit:default -- --browsers=Chrome","test:unit:default":"npm run build:test && karma start test/karma.conf.js --log-level debug","test:unit:firefox":"npm run test:unit:default -- --browsers=Firefox","test:unit:ie":"npm run test:unit:default -- --browsers=IE"},"dependencies":{"@jupyter-widgets/base":"^4.0.0","@lumino/algorithm":"^1.1.0","@lumino/domutils":"^1.1.0","@lumino/messaging":"^1.2.1","@lumino/signaling":"^1.2.0","@lumino/widgets":"^1.3.0","d3-format":"^1.3.0","jquery":"^3.1.1","jquery-ui":"^1.12.1","underscore":"^1.8.3"},"devDependencies":{"@jupyterlab/services":"^6.0.0","@types/d3-format":"^1.3.1","@types/expect.js":"^0.3.29","@types/mathjax":"^0.0.35","@types/mocha":"^5.2.7","@types/node":"^12.0.10","chai":"^4.0.0","css-loader":"^3.4.0","expect.js":"^0.3.1","file-loader":"^5.0.2","istanbul-instrumenter-loader":"^3.0.1","karma":"^4.1.0","karma-chrome-launcher":"^2.2.0","karma-coverage":"^1.1.2","karma-firefox-launcher":"^1.1.0","karma-ie-launcher":"^1.0.0","karma-mocha":"^1.3.0","karma-mocha-reporter":"^2.2.5","karma-webpack":"^4.0.2","mocha":"^6.1.4","npm-run-all":"^4.1.5","postcss-cli":"^6.1.2","postcss-cssnext":"^3.1.0","postcss-import":"^12.0.1","postcss-loader":"^3.0.0","rimraf":"^2.6.1","sinon":"^7.3.2","sinon-chai":"^3.3.0","style-loader":"^1.1.2","tslint":"^5.20.1","typescript":"~3.7.4","url-loader":"^3.0.0","webpack":"^4.41.5"},"gitHead":"8ec6746db708fc084102cabe34f706c204098009"}'
        );

        /***/
      },
  },
]);
//# sourceMappingURL=vendors-node_modules_jupyter-widgets_controls_lib_index_js.361d02ed940b95b2613e.js.map
